(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    960618,      15480]*)
(*NotebookOutlinePosition[    961394,      15507]*)
(*  CellTagsIndexPosition[    961350,      15503]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Diffraction des ondes lumineuses", "Title"],

Cell[BoxData[
    \(TraditionalForm\`Clear[e, a, f, \[CurlyPhi], intensite]\)], "Input",
  CellLabel->"In[41]:="],

Cell["Diffraction par une fente fine", "Section"],

Cell["\<\
Calcul de la fonction de diffraction d'une fente fine \
\[EAcute]clair\[EAcute]e en incidence normale
\
\>", "Subsection"],

Cell[BoxData[
    StyleBox[
      RowBox[{
        RowBox[{\(On\ pose\ u\), "=", 
          FormBox[\(Sin\[Theta]\/\[Lambda]\_0\),
            "TraditionalForm"]}], " ", ",", 
        RowBox[{\(dans\ l' approximation\ de\ Gauss\ u\), "=", 
          RowBox[{
            FormBox[\(X\/\(\(\[Lambda]\_0\) f'\)\),
              "TraditionalForm"], "  ", \(f'\), " ", "est", " ", "la", " ", 
            "focale", " ", "de", " ", "la", " ", "lentille", " ", "de", " ", 
            "projection"}]}], 
        ",", \(X\ \ la\ position\ d' 
          un\ point\ M\ du\ plan\ focal\ image\ sur\ un\ axe\ passant\ \
par\ \ l' 
          image\ g\[EAcute]om\[EAcute]trique\ \((\ 
            ici\ F' est\ le\ foyer\ image\ de\ la\ lentille)\)\ \
perpendiculaire\ \[AGrave]\ la\ direction\ de\ la\ fente . \ 
            e\ est\ la\ largeur\ de\ la\ fente\ qu' 
          on\ pourra\ \(\(modifier\)\(.\)\)\)}],
      FontFamily->"Century Schoolbook"]], "Text",
  TextAlignment->Center,
  TextJustification->1,
  FontSize->12,
  Background->GrayLevel[0.900008]],

Cell[BoxData[{
    \(TraditionalForm\`FD(e_, u_) = 
      ExpToTrig[\(\[Integral]\_\(-\(e\/2\)\)\%\(e\/2\)\(\[ExponentialE]\^\(\
\[ImaginaryI]\ 2\ \[Pi]\ x\ u\)\) \[DifferentialD]x\)\/e]\), "\n", 
    \(TraditionalForm\`\(FD(e_, 0. ) = 0;\)\)}], "Input",
  CellLabel->"In[31]:="],

Cell[TextData[{
  "Prenons une longueur d'onde au milieu du spectre visible ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_0\)]],
  "=500 nm."
}], "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(lambda0 = 500\ 10\^\(-9\);\)\)], "Input",
  CellLabel->"In[50]:="],

Cell["\<\
Tra\[CCedilla]ons l'intensit\[EAcute] diffract\[EAcute]e par trois fentes de \
largeurs e=0,1 mm (rouge), e=0,2 mm (vert) et e=0,3 mm (bleu)\
\>", "Subsection"],

Cell[BoxData[
    \(TraditionalForm\`Plot[
      Evaluate[Table[\[LeftBracketingBar]FD(0.0001\ i, \
u)\[RightBracketingBar]\^2, {i, 1, 3, 1}]], {u, \(-2\)\ 10\^4, 2\ 10\^4}, 
      PlotRange \[Rule] All, 
      PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], 
          RGBColor[0, 0, 1]}]\)], "Input",
  CellLabel->"In[5]:="],

Cell["\<\
D\[EAcute]termination des z\[EAcute]ros et des maxima secondaires de la \
fonction intensit\[EAcute] pour e=0,1 mm\
\>", "Subsection"],

Cell[BoxData[
    \(TraditionalForm\`i1(u_) := \(FD(0.0001, u)\)\^2\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(TraditionalForm\`Plot[i1(u), {u, \(-45000\), 45000}, 
      PlotRange \[Rule] {0, 0.5}]\)], "Input",
  CellLabel->"In[7]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`zero = 
      Table[FindRoot[i1(u) == 0, {u, 10000\ i}], {i, 0, 4}]\)], "Input",
  CellLabel->"In[8]:="],

Cell[OutputFormData["\<\
{{u -> 0.}, {u -> 10000.}, {u -> 20000.}, {u -> 30000.}, {u -> 40000.}}\
\>", "\<\
{{u -> 0.}, {u -> 10000.}, {u -> 20000.}, {u -> 30000.}, {u -> 40000.}}\
\>"], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["\<\
En utilisant une lentille de focale f'=1m on obtient les valeurs de X (en mm) \
correspondantes \[AGrave] une intensit\[EAcute] nulle:\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`X = 
      10\^3\ lambda0\ u /. \[InvisibleSpace]zero\)], "Input",
  CellLabel->"In[11]:="],

Cell[OutputFormData["\<\
{0., 5., 10., 15., 20.}\
\>", "\<\
{0., 5., 10., 15., 20.}\
\>"], "Output",
  CellLabel->"Out[11]="]
}, Open  ]],

Cell["Cherchons les z\[EAcute]ros de la d\[EAcute]riv\[EAcute]e:", "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    FormBox[
      RowBox[{"zeroder", "=", 
        RowBox[{"Table", "[", 
          RowBox[{
            RowBox[{"FindRoot", "[", 
              RowBox[{
                RowBox[{
                  RowBox[{
                    SuperscriptBox["i1", "\[Prime]",
                      MultilineFunction->None], "(", "u", ")"}], "==", "0"}], 
                ",", \({u, 10000\ i + 15000}\)}], "]"}], ",", \({i, 0, 4}\)}],
           "]"}]}], TraditionalForm]], "Input",
  CellLabel->"In[12]:="],

Cell[OutputFormData["\<\
{{u -> 14219.018865058233}, {u -> 24573.99696205136}, {u -> 35000.}, 
 {u -> 45000.}, {u -> 55000.}}\
\>", "\<\
{{u -> 14219.}, {u -> 24574.}, {u -> 35000.}, {u -> 45000.}, 
 
  {u -> 55000.}}\
\>"], "Output",
  CellLabel->"Out[12]="]
}, Open  ]],

Cell["et les valeurs de X correspondantes:", "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`X = 
      10\^3\ lambda0\ u /. \[InvisibleSpace]zeroder\)], "Input",
  CellLabel->"In[13]:="],

Cell[OutputFormData["\<\
{7.109509432529117, 12.286998481025678, 17.5, 22.5, 27.5}\
\>", "\<\
{7.10951, 12.287, 17.5, 22.5, 27.5}\
\>"], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["Les valeurs des intensit\[EAcute]s maximales des taches secondaires:", \
"Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`i1(u) /. \[InvisibleSpace]zeroder\)], "Input",
  CellLabel->"In[14]:=",
  TextAlignment->Left],

Cell[OutputFormData["\<\
{0.04715750524306088, 0.0164795966569359, 0.008271117032027575, 
 0.005003515241596927, 0.003349460616275629}\
\>", "\<\
{0.0471575, 0.0164796, 0.00827112, 0.00500352, 0.00334946}\
\>"], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[BoxData[
    StyleBox[\(On\ constate\ que\ ces\ intensit\[EAcute]s\ sont\ faibles\ \
devant\ \ l' 
        intensit\[EAcute]\ maximale\ \((I\_0 = 
            1)\)\ de\ la\ tache\ \(\(principale\)\(.\)\)\),
      "Subsubtitle"]], "Text",
  TextAlignment->Left,
  TextJustification->0,
  Background->GrayLevel[0.900008]],

Cell["Diffraction par une ouverture rectangulaire", "Section"],

Cell[TextData[{
  "On appelle k le rapport des deux dimensions (largeur et longueur) de \
l'ouverture rectangulaire.Dans l'approximation de Gauss: u = ",
  Cell[BoxData[
      \(TraditionalForm\`X\/\(\(\[Lambda]\_0\) f'\)\)]],
  "et v = ",
  Cell[BoxData[
      \(TraditionalForm\`Y\/\(\(\[Lambda]\_0\) f'\)\)]],
  "."
}], "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\(FDrec[k_, u_, v_] := FD[0.0001, u]\ FD[0.0001\ k, v];\)\)], "Input",
  CellLabel->"In[5]:="],

Cell["Pour k=3:", "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Plot3D[\(FDrec(3, u, v)\)\^2, {u, \(-50000\), 
        50000}, {v, \(-50000\), 50000}, PlotRange \[Rule] {0, 0.1}, 
      PlotPoints \[Rule] 90, Mesh \[Rule] False]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(TraditionalForm\`DensityPlot[\(FDrec(3, u, v)\)\^2, {u, \(-30000\), 
        30000}, {v, \(-30000\), 30000}, PlotRange \[Rule] {0, 0.03}, 
      PlotPoints \[Rule] 150, Mesh \[Rule] False]\)], "Input",
  CellLabel->"In[11]:="]
}, Open  ]],

Cell["Pour k=6:", "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Plot3D[\(FDrec(6, u, v)\)\^2, {u, \(-50000\), 
        50000}, {v, \(-50000\), 50000}, PlotRange \[Rule] {0, 0.1}, 
      PlotPoints \[Rule] 150, Mesh \[Rule] False]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(TraditionalForm\`DensityPlot[\(FDrec(6, u, v)\)\^2, {u, \(-30000\), 
        30000}, {v, \(-30000\), 30000}, PlotRange \[Rule] {0, 0.03}, 
      PlotPoints \[Rule] 150, Mesh \[Rule] False]\)], "Input",
  CellLabel->"In[12]:="]
}, Open  ]],

Cell["Interf\[EAcute]rences \[AGrave] deux ondes", "Section"],

Cell["La fonction d'interf\[EAcute]rences \[AGrave] deux ondes:", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(TraditionalForm\`FI(\[CurlyPhi]_) := \[ExponentialE]\^\(\[ImaginaryI]\ \
\[CurlyPhi]\) + 1; \)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(TraditionalForm\`i(\[CurlyPhi]_) = \[LeftBracketingBar]FI(\[CurlyPhi])\
\[RightBracketingBar]\^2; \)], "Input",
  CellLabel->"In[14]:="],

Cell["\<\
Trac\[EAcute]s pour trois radiations: 450 nm (bleu), 500 nm (vert) et 650 nm \
(rouge).\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Plot[{i(\[CurlyPhi]), i(\(0.65\ \[CurlyPhi]\)\/0.5), 
        i(\(0.65\ \[CurlyPhi]\)\/0.45)}, {\[CurlyPhi], 0, 10\ \[Pi]}, 
      PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], 
          RGBColor[0, 0, 1]}]\)], "Input",
  CellLabel->"In[15]:="],

Cell[OutputFormData["\<\
Graphics[{{RGBColor[1, 0, 0], 
   {Line[{{1.3089969389957471*^-6, 3.999999999998286}, 
      {0.03878067298341026, 3.998496247879948}, {0.07406330390058102, 
       3.994517133999966}, {0.114790022741458, 3.9868377132189674}, 
      {0.1532892799003927, 3.9765483720909764}, {0.22176468530106952, 
       3.951021646789422}, {0.29609259997149656, 3.912967817858444}, 
      {0.3779474894874068, 3.8588479941330895}, {0.46472294619216314, 
       3.787891537090902}, {0.6204070819094094, 3.6272837206605413}, 
      {0.9316404517871855, 3.193036319204924}, {1.274449627037113, 
       2.5840562226091683}, {1.9440504143058828, 1.2707052264091077}, 
      {2.3133208771225817, 0.6476998760939908}, {2.495351153808959, 
       0.4032944728595869}, {2.6643470259797546, 0.2234730632775597}, 
      {2.7470442014396914, 0.15365954085982247}, {2.8249494209863317, 
       0.09942801011942297}, {2.868083560180346, 0.07434204208828976}, 
      {2.914743080419725, 0.051240423167099376}, {2.9568489353551453, 
       0.03403327901547324}, {2.996158505479512, 0.021113836988490536}, 
      {3.0398870664963504, 0.010335112946303482}, 
      {3.063052532142737, 0.006165380410724377}, {3.0878860794426295, 
       0.002883702861539227}, {3.113916481162276, 0.0007659216289161719}, 
      {3.138575679369691, 9.102126540693788*^-6}, 
      {3.160712725697122, 0.0003655660203036725}, 
      {3.184793090167517, 0.0018659874891840242}, {3.2055701013639073, 
       0.004091717882428632}, {3.2285039009647964, 0.00754881142203044}, 
      {3.252455289132839, 0.012277941033955724}, {3.2749411421034087, 
       0.017755485576866643}, {3.315078066126265, 0.030021777324592096}, 
      {3.3583459066120196, 0.046798318373131975}, 
      {3.435408864124413, 0.08570870679695772}, {3.519706204357722, 
       0.14127458923687108}, {3.6895912403456275, 0.29286214591065374}, 
      {3.8469242577821996, 0.47720676168521664}, {3.993303006085639, 
       0.6826055462610595}, {4.611320894781117, 1.7982077817522524}, 
      {5.281276608464903, 3.077390416121051}, {5.4592274918527, 
       3.3586442628373425}, {5.647627367807735, 3.609481228185888}, 
      {5.808474628657021, 3.778850004473143}, {5.900929308888306, 
       3.8556509542193296}, {5.9854069982143665, 3.9119813709044546}, 
      {6.026043423986337, 3.934241592488709}, {6.070341515163573, 
       3.954868288368334}, {6.1126569225430964, 3.970990471953692}, 
      {6.1509735096010605, 3.982545488164727}, {6.172461888948004, 
       3.9877528445077948}, {6.195675921401195, 3.992346993096657}, 
      {6.2201975772539475, 3.996033857429703}, {6.2432679074722275, 
       3.9984068127660093}, {6.264968422092629, 3.999668154274933}, 
      {6.287864102850356, 3.999978108911006}, {6.328840692035206, 
       3.9979159478737314}, {6.367150103807448, 3.9929540539312987}, 
      {6.40816401532433, 3.984400643121606}, {6.446873850826936, 
       3.9732658335368205}, {6.482121933288509, 3.9605545669375735}, 
      {6.568464236356095, 3.9191663846210156}, {6.650150670791063, 
       3.866840844727756}, {6.802025392933568, 3.736789868233017}, 
      {6.969444768878095, 3.5472432113366024}, {7.308208249083005, 
       3.0381585558527537}, {7.9162399034021735, 1.8755638851521745}, 
      {8.25413491780115, 1.2208809570260437}, {8.609413079925483, 
       0.6287943706509914}, {8.756172947927036, 0.4306256591544419}, 
      {8.91275269026145, 0.2564919450711575}, {9.002807986363711, 
       0.1754322171622517}, {9.08452720979601, 0.11465797264416613}, 
      {9.166678045689663, 0.066246583537557}, {9.206719178436371, 
       0.04736151696995155}, {9.244131588001713, 0.032544465137051976}, 
      {9.282819594776958, 0.020118357878322016}, {9.318123029345243, 
       0.011364495412636417}, {9.357335866725782, 0.00454671228781018}, 
      {9.399406546969066, 0.0006436741089000526}, 
      {9.439755277950926, 0.00022431583669834786}, 
      {9.462562988787253, 0.0014275384878025198}, 
      {9.483681818533585, 0.003468661361237274}, {9.522407763340127, 
       0.009524009839532575}, {9.563582706271319, 0.019235843238641775}, 
      {9.598243600849926, 0.030014951606030613}, {9.635638684840538, 
       0.04429774798490665}, {9.703340786996254, 0.07709676650091196}, 
      {9.78385266941144, 0.1275552414110073}, {9.857732449792719, 
       0.18453971184757792}, {10.012147106571277, 0.3351969869754059}, 
      {10.181195304701749, 0.5454009554552262}, {10.52202403864857, 
       1.087902572137517}, {11.222206387688209, 2.449394051717139}, 
      {11.553358111235118, 3.0586144565854525}, {11.85893257947417, 
       3.520058721460795}, {12.013030661852113, 3.701548039425851}, 
      {12.176309950050468, 3.84977198857608}, {12.260952214918799, 
       3.9074424531712504}, {12.34020637783007, 3.9490673958206055}, 
      {12.385623134027538, 3.9674191937314744}, {12.4271551544445, 
       3.980650337255924}, {12.450081071151615, 3.986491975147739}, 
      {12.47509316173928, 3.9916742096298545}, {12.498717837585621, 
       3.9954248471949567}, {12.52063981821203, 3.9979090587216417}, 
      {12.559935988500241, 3.9999585957329153}, {12.602422472574423, 
       3.998700404289372}, {12.642537895512394, 3.994201349479134}, 
      {12.6794274242106, 3.9872317665711594}, {12.712803044287451, 
       3.97859583100211}, {12.74941962264434, 3.966586515714329}, 
      {12.823326785097887, 3.934336018968837}, {12.90386705641708, 
       3.8871732288317427}, {12.990163384930804, 3.823071669479227}, 
      {13.145841886347087, 3.6735045771808257}, {13.48176221587399, 
       3.218960319949101}, {13.8469876824214, 2.572247988184557}, 
      {14.510865291357213, 1.269877951830536}, {14.847637351398214, 
       0.6956191198343243}, {15.012531875352092, 0.46444525440870826}, 
      {15.16364404266874, 0.2890399629452185}, {15.322279653655837, 
       0.14691704292053484}, {15.405563770013876, 0.09075072107271111}, 
      {15.493203745224358, 0.0459446576686052}, {15.536727939154948, 
       0.02924996176790652}, {15.560639511096808, 0.02166506137511247}, 
      {15.583202198982475, 0.015545144858727062}, {15.604252802785208, 
       0.010746223328881517}, {15.627061003203638, 
       0.0065416072751425325}, {15.666892414459447, 
       0.0016865779076171482}, {15.689763143152597, 
       0.00033123539912546953}, {15.714908331909504, 
       0.00004823371954040249}, {15.74116511790417, 
       0.001102261577182926}, {15.765718108651877, 
       0.0033346945300698687}, {15.788672003854236, 
       0.006510364911265642}, {15.809634878631542, 0.01032821482185343}, 
      {15.856790688408871, 0.022108747518424707}, {15.899510334360615, 
       0.03657823438096646}, {15.9396813881729, 0.0534534693926605}, 
      {16.014701088421255, 0.09335268623048516}, {16.095495505601992, 
       0.14831108543421467}, {16.18273431321316, 0.22120518376576292}, 
      {16.484788087905983, 0.57371402118635}, {16.8414654449974, 
       1.153020427495268}, {17.16902849765663, 1.7809779616369483}, 
      {17.495335497484994, 2.429773565040624}, {17.8445028353395, 
       3.072086801208467}, {18.0138824838571, 3.3413566269952337}, 
      {18.17404804375464, 3.560778957987714}, {18.31674665533896, 
       3.72276698006017}, {18.397911514744933, 3.799461249916531}, 
      {18.473971516981667, 3.8605868233836884}, {18.55323585106573, 
       3.91283502337217}, {18.6257793619023, 3.9501326695814862}, 
      {18.66284801545265, 3.9652413075891513}, {18.70332273783992, 
       3.9786539356342296}, {18.746093067608008, 3.989304983420794}, 
      {18.786762907142734, 3.996058332752335}, {18.82477161890563, 
       3.9993857697854613}, {18.85924464212261, 3.999906129427765}, 
      {18.89903808836202, 3.9975520147155335}, {18.936537324948524, 
       3.9924390043241464}, {18.97132566192637, 3.9851904434156418}, 
      {19.003342550358116, 3.9763962475640557}, {19.075630291096882, 
       3.9491076916872827}, {19.153915022963897, 3.9080784282516077}, 
      {19.22702352862677, 3.8592019463443825}, {19.393253284158543, 
       3.7116037517110003}, {19.555225699285305, 3.5223546846523366}, 
      {19.728915302354025, 3.2752895270717817}, {20.38211354781351, 
       2.0764587648829176}, {20.726690699161676, 1.396860833817223}, 
      {21.092874411857803, 0.7540781275701405}, {21.248918846282045, 
       0.5260735098997968}, {21.41718798954051, 0.32048576257238653}, 
      {21.513511637490474, 0.22383268352795194}, {21.601856214958744, 
       0.14964427055125573}, {21.691681586593738, 0.08901226185927347}, 
      {21.775278882599693, 0.04641904381918052}, {21.811796688535182, 
       0.032080964771063335}, {21.846282526751462, 0.02094949601915175}, 
      {21.886031827823242, 0.011039359966892835}, {21.922160526998443, 
       0.004757463465913742}, {21.962272486221472, 
       0.0008337705730145357}, {21.999267682189892, 
       0.00006591953735485402}, {22.0398753880588, 
       0.0023738325595670535}, {22.082880878494375, 0.00840891637571285}, 
      {22.121284750991954, 0.01691153704030053}, {22.162554649046104, 
       0.02930818034476915}, {22.237119079900648, 0.06019706787463988}, 
      {22.325789309559756, 0.11094327175084971}, {22.406834287408902, 
       0.1703207338294566}, {22.56442168607817, 0.31973961399491846}, 
      {22.73224773444002, 0.5245460740972809}, {23.034055830908322, 
       0.9925782164584642}, {23.718007801150314, 2.3108603371595637}, 
      {24.057958554769204, 2.9518467797189776}, {24.236689986422608, 
       3.249396564245771}, {24.425323752184735, 3.5200854424216237}, 
      {24.590765083903616, 3.7133820002237234}, {24.678365968761195, 
       3.7970708051395423}, {24.77218030984594, 3.8713981583839887}, 
      {24.85850638077832, 3.9252653811531206}, {24.93713693111809, 
       3.9618607955545824}, {24.975016482132496, 3.975174434058441}, 
      {25.016179857085927, 3.9864288225475293}, {25.055053836303777, 
       3.9939677038841923}, {25.090983766880154, 3.9982565677360684}, 
      {25.129956906875226, 3.9999922475568823}, {25.170947772343055, 
       3.998540437585679}, {25.20594603548502, 3.9946434490286244}, 
      {25.244191272497027, 3.987591739422114}, {25.28555707272286, 
       3.9766927281070896}, {25.329704429810068, 3.9613307531298836}, 
      {25.40918373404135, 3.9240649770893583}, {25.489690015326904, 
       3.873934658634266}, {25.565616633426668, 3.8155266428369314}, 
      {25.707613336169647, 3.6785236959495795}, {26.03405170067785, 
       3.241165813715083}, {26.387567700776128, 2.6214769194913314}, 
      {27.031283384121043, 1.3561806693268972}, {27.372481123409603, 
       0.7596848274121552}, {27.560420088232696, 0.4883901377040668}, 
      {27.73865929673781, 0.2801509956937611}, {27.906964533842874, 
       0.13344919460701013}, {28.00211690651868, 0.0736456174886005}, 
      {28.047549814444622, 0.0512109618909897}, {28.0902507778544, 
       0.03379100562405122}, {28.12877234062215, 0.02115077731183099}, 
      {28.164131720207827, 0.01213223073253917}, {28.203397497370464, 
       0.0050298610011525234}, {28.245773892926962, 
       0.0008156175514243462}, {28.284211010095763, 
       0.00009755686021099328}, {28.32630382659652, 
       0.002700267270199783}, {28.347539070277026, 0.005356606733354086}, 
      {28.37025057920399, 0.009192961553213185}, {28.41118357732915, 
       0.018698629604056077}, {28.453382269483587, 0.03197277173537361}, 
      {28.492333764275372, 0.04733603596128259}, {28.58040282480144, 
       0.0929491769148652}, {28.65804381891839, 0.14543568717303443}, 
      {28.740336259113175, 0.21325674394147148}, {29.039751658746816, 
       0.5578140622997994}, {29.350315066850474, 1.0502620517562433}, 
      {29.68432719143147, 1.6797781677674353}, {30.28805842499345, 
       2.8571738867608127}, {30.564566539752672, 3.3179215947921774}, 
      {30.71063954336438, 3.52285107905818}, {30.8663297533626, 
       3.705470418738994}, {31.015831439343522, 3.842047914991246}, 
      {31.15135773124239, 3.930410690430762}, {31.216811470016914, 
       3.9604840066767073}, {31.251237864977057, 3.9729388881355634}, 
      {31.28760117566271, 3.9835551874531334}, {31.319468459199857, 
       3.990703051153065}, {31.354441116053405, 3.9962207339843046}, 
      {31.38624198485404, 3.9991188921328478}, {31.415925226900992, 
       3.999999999998286}}]}}, {RGBColor[0, 1, 0], 
   {Line[{{1.3089969389957471*^-6, 3.9999999999971045}, 
      {1.274449627037113, 1.8282354762761417}, {1.5949436066554339, 
       1.036535525769846}, {1.7711833665362098, 0.663666493387971}, 
      {1.9377840657918728, 0.375122290299689}, {2.0322243487402587, 
       0.24454825842617692}, {2.1347363273311766, 0.1327791521032406}, 
      {2.179963510115963, 0.09389834368748917}, {2.2279094479191843, 
       0.059876008547169284}, {2.2688429992352264, 0.03678782795467963}, 
      {2.3139294145261498, 0.01779164765359468}, {2.337264674467989, 
       0.01063019876177023}, {2.3594470238697896, 0.00551966162617434}, 
      {2.401092233985229, 0.00040692601890396325}, 
      {2.424339050245001, 0.00010096369982876888}, 
      {2.4459212620645374, 0.0014518143603550126}, 
      {2.469605633630095, 0.004744598450045066}, {2.4948541959094404, 
       0.010337593277587853}, {2.516842124644095, 0.01695463020775148}, 
      {2.5406271409904746, 0.02593648322354866}, {2.583747735085757, 
       0.04702489591107004}, {2.6643470259797546, 0.10282824321602191}, 
      {2.7458539425856694, 0.1804191580804964}, {2.821947917137553, 
       0.2712997153247591}, {2.994939825380666, 0.5391183062228342}, 
      {3.344199688832371, 1.2862333393067347}, {3.969696570014143, 
       2.8667179008304804}, {4.134825750116397, 3.230786053223045}, 
      {4.314450926065562, 3.562164617802476}, {4.396706443694356, 
       3.6865303964958627}, {4.484092589991771, 3.7975185308793287}, 
      {4.5596227254733375, 3.8748227713357606}, {4.599285977067504, 
       3.9082255530998014}, {4.641044656362282, 3.9379102906412506}, 
      {4.678433959026668, 3.9596464800390305}, {4.71933322982456, 
       3.9781205823927914}, {4.756518289474428, 3.990065845475658}, 
      {4.791114349321376, 3.9970046467887483}, {4.826803195933355, 
       3.9999304255789223}, {4.859231195370646, 3.9988566380400283}, 
      {4.896663308053307, 3.9932014008191405}, {4.9320015925801695, 
       3.983531784867887}, {4.970947587073175, 3.968027880495781}, 
      {5.012180428359148, 3.946118018960992}, {5.086106240781208, 
       3.8928915044327135}, {5.165656390431417, 3.816119676306091}, 
      {5.253161744280376, 3.709294817699177}, {5.425125103065903, 
       3.4365488455218407}, {5.588377324743202, 3.11121112209366}, 
      {5.894670500953999, 2.3795048471161406}, {6.228466810376494, 
       1.5187199103574425}, {6.411571879990494, 1.074558529718224}, 
      {6.583839790689603, 0.7039169656996164}, {6.7489821249539235, 
       0.409166228511484}, {6.8357936863759985, 0.2827818606289213}, 
      {6.92738643572633, 0.1731504199646159}, {7.004725861707293, 
       0.10067175285800883}, {7.04567078697341, 0.07002779495857966}, 
      {7.089506269280312, 0.04328180076245464}, {7.129854331970767, 
       0.02427653567091022}, {7.166594137821457, 0.011697028368020357}, 
      {7.203526737429041, 0.003622127734681722}, {7.238467806513059, 
       0.00021814338978798993}, {7.273364820025002, 
       0.0009360608691437067}, {7.311833606285662, 0.006493766160959202}, 
      {7.352007180529707, 0.017618246077892783}, {7.3896729832359025, 
       0.03295919354619207}, {7.424793264796119, 0.0515123379552374}, 
      {7.4569518847053935, 0.07206370085349817}, {7.529383453530987, 
       0.13062722627878381}, {7.6030085916812515, 0.20712605730881561}, 
      {7.683439291447717, 0.30942479159404235}, {7.845420595187683, 
       0.5701350673019038}, {8.547775178803565, 2.232539738064273}, 
      {8.879585465110502, 3.041769045943143}, {9.025176277978689, 
       3.3443682982649094}, {9.18511549782297, 3.6210827313589373}, 
      {9.340048199593495, 3.822647718705467}, {9.424735216074003, 
       3.9020786866766834}, {9.462619220401887, 3.9302030053987114}, 
      {9.503862481665557, 3.955497462117648}, {9.527062284183607, 
       3.9672600300418535}, {9.548544171736605, 3.976556338398129}, 
      {9.5909066184665, 3.990366073431717}, {9.629403942616964, 
       3.997682459614223}, {9.670335807102578, 3.999974336358735}, 
      {9.69138169313421, 3.9989486734463764}, {9.71408776247771, 
       3.996164232394479}, {9.755196070367441, 3.9867012328835383}, 
      {9.779000242906749, 3.9786257987292717}, {9.80408239953183, 
       3.968067066857001}, {9.848941756361755, 3.943974242137291}, 
      {9.92371321980825, 3.8891776654944747}, {10.003657904511963, 
       3.810877037884546}, {10.147719216242695, 3.62114844276743}, 
      {10.319027875805592, 3.322420276784685}, {10.474811166505576, 
       2.9936082728213473}, {11.16018462042801, 1.27476865640666}, 
      {11.46121624044933, 0.6186613715875775}, {11.632366454111855, 
       0.33355595038506286}, {11.714543752577038, 0.2251394650853202}, 
      {11.79262169937271, 0.14086252446323402}, {11.866722296880184, 
       0.07856723819785222}, {11.908655143875032, 0.05117837033812915}, 
      {11.947565775513336, 0.03094087883391611}, {11.983552151930146, 
       0.01670693861979261}, {12.016164373359286, 0.007555468021646075}, 
      {12.053810142354635, 0.0014445924636954414}, 
      {12.089256663911005, 0.00006513092413435511}, 
      {12.128087053917211, 0.0034271118355534745}, 
      {12.169089394271468, 0.012498042725712446}, {12.204096195007802, 
       0.024711674308879522}, {12.242502350735673, 0.042815414770156573}, 
      {12.283878670497153, 0.06777595047376656}, {12.328212075691116, 
       0.10072068508463425}, {12.408189500016642, 0.17601679953202032}, 
      {12.583474983920274, 0.40850344948929374}, {12.749443472338292, 
       0.704719897466157}, {13.060432998287162, 1.4085837745267962}, 
      {13.66189481673472, 2.926579297294062}, {13.82668026863829, 
       3.282190853433216}, {14.004230589748834, 3.5993336982869057}, 
      {14.085904127070698, 3.717592872763285}, {14.171849288035952, 
       3.8211263964091695}, {14.245229485104035, 3.891593160027144}, 
      {14.325457935391926, 3.9489343940026536}, {14.369564476859848, 
       3.971465824005367}, {14.411182908775437, 3.986785405261694}, 
      {14.448549547819702, 3.9955871495584527}, {14.489036072589792, 
       3.9998093137987416}, {14.510072209464138, 3.999816726688255}, 
      {14.53320035896556, 3.9980989448890925}, {14.557350938139265, 
       3.994377591559884}, {14.579934393217286, 3.9891191234855965}, 
      {14.620328348161458, 3.9754419344186016}, {14.663701521015094, 
       3.9546939487469976}, {14.704071504578405, 3.929798405252848}, 
      {14.748056995787616, 3.8966268360619623}, {14.828099021878897, 
       3.8204470626621263}, {14.978236686703452, 3.625252637480809}, 
      {15.152528911772722, 3.3218709818793735}, {15.337994116295345, 
       2.9252607731333566}, {15.671383332443584, 2.0950719906220105}, 
      {16.011875783189378, 1.2302243717664785}, {16.19082103795105, 
       0.8254060791736132}, {16.379526871472123, 0.46743805055305654}, 
      {16.54516215053666, 0.22826685496589966}, {16.639101168110958, 
       0.12842982845158207}, {16.684095469493602, 0.09040853357298531}, 
      {16.726642124515156, 0.060461942931148656}, {16.765294613074612, 
       0.03839668548054867}, {16.807263736621124, 0.020046930620355598}, 
      {16.845409953107193, 0.008479292096141268}, {16.880638537111395, 
       0.0021450177660296936}, {16.918689577966564, 
       9.909116564122883*^-6}, {16.960614089826862, 
       0.003322572346875266}, {16.98170302050483, 0.007231751637357536}, 
      {17.00439566091296, 0.013110968990093739}, {17.045423593679768, 
       0.028124948022138035}, {17.08925421504967, 0.05035910371393573}, 
      {17.129007575740374, 0.07599986836477912}, {17.21813941311335, 
       0.15203709168468432}, {17.30071902092531, 0.2446298680396228}, 
      {17.378537670557492, 0.35040278407601144}, {17.742260074626003, 
       1.0464067618523996}, {18.064418859786777, 1.8437585891371195}, 
      {18.40487427507052, 2.7127619191325643}, {18.720411497679535, 
       3.3988462722488166}, {18.80686096799635, 3.5503276343028594}, 
      {18.89956424820044, 3.6909869430838547}, {18.979687391313718, 
       3.792861168896523}, {19.066871327928666, 3.881603424456112}, 
      {19.108063982451622, 3.9151914765146483}, {19.15183960457284, 
       3.944865693407489}, {19.189211891139742, 3.965219822230043}, 
      {19.23047650783581, 3.9823047499721733}, {19.26894561937011, 
       3.9930963834859314}, {19.310428447409922, 3.999148340172625}, 
      {19.34959212226835, 3.9995278895492143}, {19.385511633012687, 
       3.99531999704485}, {19.420519999740705, 3.987032904377371}, 
      {19.45310104831058, 3.9756230751110033}, {19.4888526209113, 
       3.9590261454613405}, {19.52705851677812, 3.9366143208122977}, 
      {19.60515065924022, 3.8760186751107026}, {19.676129706591656, 
       3.804163292020593}, {19.83594057974766, 3.587335860344276}, 
      {20.005187889585805, 3.283523518107214}, {20.308677726549234, 
       2.595350359513648}, {20.63930090324282, 1.745583962697415}, 
      {20.994598010255785, 0.8882090185372532}, {21.16754695771771, 
       0.5455457679712964}, {21.331785873866416, 0.28768782356995665}, 
      {21.40318074264759, 0.19927887488428647}, {21.479214225032834, 
       0.12218582008217367}, {21.522979236135438, 0.08608250342256353}, 
      {21.562620778368668, 0.05872381891489891}, {21.59951766089126, 
       0.037889518827073226}, {21.639977056435637, 0.020233218029129686}, 
      {21.677889749397956, 0.008657113978364286}, 
      {21.71790293553711, 0.0016856921792020253}, 
      {21.75496260600411, 0.000050658670642886895}, 
      {21.789526317310525, 0.0027086252649974997}, 
      {21.83036514384719, 0.011044408902184348}, {21.867563401234857, 
       0.023515574678146297}, {21.910500847608308, 0.04365396184632311}, 
      {21.95113558912358, 0.0683260087224965}, {22.024064083499297, 
       0.12606578836294857}, {22.091469473754685, 0.19441417614197298}, 
      {22.243969072008767, 0.3991901277868379}, {22.397176577625636, 
       0.6680491264364969}, {22.562169039169962, 1.0161307424688883}, 
      {22.86059864129826, 1.747967908225553}, {23.185504219636243, 
       2.5834413676383137}, {23.357254130698948, 2.9925453646760296}, 
      {23.54055300590474, 3.3743432917492644}, {23.72041906213429, 
       3.6736026060512357}, {23.80540617139657, 3.784133191109926}, 
      {23.883686424820375, 3.8667196781138506}, {23.962482979999713, 
       3.930342760608745}, {24.003953811871785, 3.9557332833960355}, 
      {24.047815606422127, 3.9764024912068323}, {24.08593616297652, 
       3.9891501991660534}, {24.121565159263312, 3.9966494720730164}, 
      {24.16065567912171, 3.999949956567469}, {24.202608170325327, 
       3.997747583493969}, {24.225109101882335, 3.9941176490434924}, 
      {24.249040412580836, 3.9883848137820497}, {24.292047782231183, 
       3.9732505010758943}, {24.315899920314322, 3.962194730771665}, 
      {24.338317795859364, 3.9500838194384364}, {24.389448497824123, 
       3.9162837388528176}, {24.474671470347186, 3.841227938429025}, 
      {24.566645771000385, 3.73492940059578}, {24.73990384219962, 
       3.4688890868106426}, {24.898939391789146, 3.1589781821873406}, 
      {25.574918225755646, 1.484542443698756}, {25.904622774086015, 
       0.7280261515743411}, {26.060582024961892, 0.4432995625599276}, 
      {26.20454018191118, 0.23685854889447963}, {26.27715516766556, 
       0.15571801081411157}, {26.35412049301206, 0.08765766706806735}, 
      {26.39134326267309, 0.06156946054051544}, {26.431376492773136, 
       0.0385779307857596}, {26.45431977340342, 0.027792166359278288}, 
      {26.475307123534225, 0.01946207800593506}, {26.516454037364607, 
       0.007413609795959585}, {26.55393567715638, 0.0013988070493719364}, 
      {26.588726730465087, 0.00006123907862173225}, 
      {26.626906764962403, 0.0033006979188885737}, 
      {26.667600510155918, 0.012167297898860544}, {26.706401895445147, 
       0.02580202276416064}, {26.74294788101646, 0.04323763372213212}, 
      {26.811251791504542, 0.08762580702429562}, {26.890217642890846, 
       0.15769406033421135}, {26.973626312048378, 0.2527515249685595}, 
      {27.1229898955822, 0.4733705061230531}, {27.460141738080537, 
       1.166019786493168}, {27.79672545554329, 2.0148550152573264}, 
      {28.11551771283731, 2.8189116416709172}, {28.401705632183777, 
       3.426188251559504}, {28.563392955999145, 3.6873532730869414}, 
      {28.640542201652497, 3.7863795175652846}, {28.712956932440203, 
       3.8630097323024866}, {28.784377817151125, 3.922430750340052}, 
      {28.821144589236273, 3.9465898078550343}, {28.861355154423, 
       3.9679196575516817}, {28.90298196165757, 3.984336609363594}, 
      {28.925683046426688, 3.9908439329480885}, {28.946799515524788, 
       3.9953406796749875}, {28.984673212445056, 3.9996376162574068}, 
      {29.02512655998526, 3.998874322947366}, {29.06801795110599, 
       3.9920287578471925}, {29.092206830418387, 3.9854354497294833}, 
      {29.114504969111717, 3.9776184193696116}, {29.155487263582902, 
       3.958923611112533}, {29.19886763924632, 3.933079851626029}, 
      {29.27403522185495, 3.8738052313081006}, {29.356703836774336, 
       3.787998908337149}, {29.52858618024133, 3.5449713478872806}, 
      {29.713202942203928, 3.1987888344431687}, {30.046672586746766, 
       2.4154209567796148}, {30.36231585795069, 1.600500640402199}, 
      {30.698297826497985, 0.8090142841452653}, {30.891732534467746, 
       0.4466824704685897}, {31.066853898355948, 0.20241964321968595}, 
      {31.15148946029624, 0.11701734042868388}, {31.195976281401514, 
       0.08120348463567735}, {31.24290422071821, 0.05038011401458155}, 
      {31.284082482907635, 0.029305176708631073}, {31.305880990819034, 
       0.0204310564204279}, {31.329213906939444, 0.012693794760255879}, 
      {31.37025001703358, 0.0035248861059683514}, {31.408503105237855, 
       0.00009313065268725976}, {31.415925226900992, 
       2.8957693426693157*^-12}}]}}, {RGBColor[0, 0, 1], 
   {Line[{{1.3089969389957471*^-6, 3.999999999996424}, 
      {0.03878067298341026, 3.996862969054305}, {0.07406330390058102, 
       3.9885661205577145}, {0.114790022741458, 3.9725706974695743}, 
      {0.1532892799003927, 3.9511741038326345}, {0.22176468530106952, 
       3.8982651544559053}, {0.29609259997149656, 3.819853161908761}, 
      {0.3779474894874068, 3.7092956576778717}, {0.46472294619216314, 
       3.566069144984447}, {0.6204070819094094, 3.249252379060456}, 
      {1.274449627037113, 1.4663918749424498}, {1.5930865582994056, 
       0.6657709216294436}, {1.684850677449774, 0.48056719086135036}, 
      {1.7720810643670566, 0.32918219989072706}, {1.8513468786067406, 
       0.21453691944028835}, {1.9358476576083674, 0.1180983105258408}, 
      {1.9847575800346846, 0.07499793594315526}, {2.029103942006195, 
       0.04421574486583168}, {2.0505192684444986, 0.03221654220215887}, 
      {2.073684883339153, 0.02135680782168977}, {2.1156825453248707, 
       0.0073240419622373504}, {2.139382511559683, 0.002638653031341386}, 
      {2.1653969734966556, 0.00019035488486919037}, 
      {2.19255971080191, 0.0006470589749419057}, {2.2179185481538246, 
       0.00385113444963933}, {2.2416643369679607, 0.009279403442624476}, 
      {2.263315107104646, 0.016269933588951697}, {2.2883060514457103, 
       0.02675038848435447}, {2.3119805477725053, 0.03905044282204813}, 
      {2.354488075283054, 0.06687833153122831}, {2.3996469792065747, 
       0.10442035011251578}, {2.480755754294344, 0.19196561893755779}, 
      {2.568021989758564, 0.3137981065956047}, {2.6643470259797546, 
       0.47925335207083886}, {2.9972806712073843, 1.2526209059626001}, 
      {3.3025404136666117, 2.11582949648322}, {3.658935484574285, 
       3.083873746598261}, {3.8326626876725505, 3.467302006272406}, 
      {3.908406917835378, 3.6069240719749307}, {3.990516644275951, 
       3.7365263751785065}, {4.071289386765699, 3.8402208676163645}, 
      {4.145762788032993, 3.913684929081715}, {4.18254295411297, 
       3.9418484980300037}, {4.21695377225465, 3.9632377109694374}, 
      {4.252844781825437, 3.980379687914361}, {4.292324977730762, 
       3.993088342549918}, {4.3339921826908805, 3.9994722012345725}, 
      {4.373548654655972, 3.998833020047988}, {4.409056723405732, 
       3.992702366837377}, {4.447764351774206, 3.980049701798623}, 
      {4.489732469905391, 3.9593410523222157}, {4.534413416930287, 
       3.929385008045105}, {4.614752006879541, 3.855418406405172}, 
      {4.703507729197688, 3.7447364100213854}, {4.799391098763801, 
       3.593052556157646}, {4.973102239909891, 3.2429307190367864}, 
      {5.297588254613681, 2.401081221919345}, {5.638619380043209, 
       1.426771769207888}, {5.956583264458606, 0.6367634986105167}, 
      {6.116773128095948, 0.3374946640157128}, {6.206536134007845, 
       0.20770088510428855}, {6.288271790935867, 0.11563978656220338}, 
      {6.3348171964190945, 0.07487095533943583}, {6.377824192813515, 
       0.04492975555357591}, {6.425027809960803, 0.020752528377443253}, 
      {6.448849665107763, 0.012037991623736697}, {6.4751097304187155, 
       0.0051590080139183765}, {6.498042765539761, 
       0.0014987560117186707}, {6.519041878504141, 
       0.0000702933291166708}, {6.542097215481295, 
       0.0006208754520702197}, {6.566338643733707, 
       0.0035909389702608947}, {6.607216415880472, 0.014139330986038838}, 
      {6.63036459511884, 0.023185500579632357}, {6.651872737094404, 
       0.03357154293094003}, {6.694160242104089, 0.05951432132959601}, 
      {6.7388718955808375, 0.09481379899246015}, {6.818980490266564, 
       0.177807535074072}, {6.905188864869818, 0.2943070498452053}, 
      {6.999893330807319, 0.45265491692643406}, {7.328014493390521, 
       1.2015627329781182}, {7.94156840577701, 2.9157084557378194}, 
      {8.114090760065793, 3.3259400649047275}, {8.277658186267733, 
       3.6395787139772464}, {8.348824758376953, 3.7484519036304125}, 
      {8.424491848227026, 3.8439392915416306}, {8.463927216593088, 
       3.88504334507228}, {8.507491725088384, 3.9233378441109914}, 
      {8.544180203792223, 3.9496876770460276}, {8.584345569868365, 
       3.972255372137326}, {8.62777422120356, 3.9891875005724304}, 
      {8.651470270383024, 3.995129596548977}, {8.673534443828677, 
       3.9985613379157368}, {8.713087179968683, 3.9996313806663104}, 
      {8.755376455504193, 3.993557898026252}, {8.77920989748465, 
       3.986855958344622}, {8.805067336280823, 3.976922280558653}, 
      {8.852016862612526, 3.951849019882871}, {8.897723009621366, 
       3.9188187261263923}, {8.939898938581926, 3.8809189680343192}, 
      {9.017105284656274, 3.793579070837006}, {9.10210168653178, 
       3.6717080960234463}, {9.27396851848958, 3.3506933028688866}, 
      {9.968477928660356, 1.4824657771899121}, {10.127965833693672, 
       1.0550144663215169}, {10.29790132305103, 0.6550031768334814}, 
      {10.4582595511185, 0.3511245635733578}, {10.533964842560003, 
       0.23744358956287911}, {10.603582269392462, 0.15146021891426345}, 
      {10.681242580212738, 0.07761398085262877}, {10.722083024688013, 
       0.04842795377914298}, {10.765207850483655, 0.02498094592807579}, 
      {10.802747354791919, 0.010805188891965379}, 
      {10.83777620206208, 0.002850630818888923}, {10.876210365455044, 
       4.487494191987184*^-6}, {10.917391344063432, 
       0.003793607347889973}, {10.940293830283041, 0.00895824613780331}, 
      {10.961472495229787, 0.01567325688089446}, {10.984717129284158, 
       0.025180421978770507}, {11.009399213518474, 0.037712014287726345}, 
      {11.050819551393356, 0.06433665923381719}, {11.096516564459014, 
       0.10174219402227001}, {11.180732606938797, 0.19219021697573643}, 
      {11.259755887351943, 0.301389585801451}, {11.416348700964006, 
       0.5814374107284733}, {11.559853038668695, 0.901955277490328}, 
      {11.883196786342662, 1.772211344171857}, {12.185314910054615, 
       2.6334046607581}, {12.507910572650578, 3.418201911033373}, 
      {12.603337716726465, 3.5985183831941487}, {12.693381686769087, 
       3.740909179522549}, {12.77422664828805, 3.843757196089877}, 
      {12.815949519989601, 3.8870855334554846}, {12.86182166942969, 
       3.926809640805064}, {12.904824031352703, 3.956372081738863}, 
      {12.945035982451355, 3.977190932396896}, {12.987498216469811, 
       3.9919348699628823}, {13.011328744171951, 3.996930029745871}, 
      {13.033092212362995, 3.9994250695658082}, {13.071850430342106, 
       3.998975715492702}, {13.114079807362568, 3.991356526135386}, 
      {13.153964655912734, 3.977357898545924}, {13.19092616747739, 
       3.9585264637412854}, {13.233603742222053, 3.9298443829800394}, 
      {13.278609167627582, 3.89165827802141}, {13.359134916247378, 
       3.8035198445507694}, {13.445802381409742, 3.681468297949021}, 
      {13.540760468909438, 3.517609489624506}, {13.869724163133037, 
       2.753538864960663}, {14.48406596876668, 1.0392602658760577}, 
      {14.657710240058197, 0.6339505486434638}, {14.821908431386456, 
       0.3289681843907061}, {14.89345274088682, 0.22451954536383004}, 
      {14.969321393071226, 0.13447549531323807}, {15.008912891401422, 
       0.09631622645853918}, {15.052534674249074, 0.061483581776918664}, 
      {15.092206591060224, 0.03648217281087141}, {15.129383345920337, 
       0.01890249301309168}, {15.171938966490329, 0.005792312489732988}, 
      {15.196030981607855, 0.0017075990429708868}, 
      {15.218404828171781, 0.00008114833944325844}, 
      {15.259370079307983, 0.002515875336772487}, {15.282277700504043, 
       0.0069269844288287995}, {15.30305438355144, 0.012814869391460903}, 
      {15.342357463883454, 0.028842116656444466}, {15.384886036519141, 
       0.053337084908617355}, {15.461999853111925, 0.11640001566901681}, 
      {15.552616240723276, 0.22026489061833296}, {15.648379079723117, 
       0.3630741486347974}, {15.819910214085933, 0.6948717278855611}, 
      {16.47478479181896, 2.4656207423535696}, {16.76082277068543, 
       3.2073972235801413}, {16.911714406755067, 3.523599795855652}, 
      {17.072067637648605, 3.780331076763259}, {17.153588212289993, 
       3.8750592679683047}, {17.1968972495496, 3.9148912986980955}, 
      {17.243599168922195, 3.9494452337804202}, {17.28630165923775, 
       3.97328203296054}, {17.325466843946398, 3.9885476256899293}, 
      {17.362912706290796, 3.9971939422849703}, {17.40234910435749, 
       3.9999841177607864}, {17.43976894287652, 3.996632752528921}, 
      {17.479757630081362, 3.9866058996325715}, {17.517497085050476, 
       3.9710645066082955}, {17.55179900681642, 3.951857145522458}, 
      {17.59214931238791, 3.923134983866285}, {17.635904240349106, 
       3.8846121028515608}, {17.715329589228908, 3.795582183713132}, 
      {17.88960393157602, 3.5195910298867363}, {18.074168742677877, 
       3.1233433785930904}, {18.40512552115817, 2.2361602285920896}, 
      {18.71620725396015, 1.3500523824955428}, {18.887673592840056, 
       0.9061987910523565}, {19.05050456733802, 0.5461163702010625}, 
      {19.20146011236235, 0.2834438496671333}, {19.28686215082915, 
       0.1701974176360132}, {19.327667222524468, 0.12581636248943473}, 
      {19.366069162399615, 0.08999188765393556}, {19.401294240233224, 
       0.06229505686893575}, {19.43935995279472, 0.03800486298583552}, 
      {19.473951528386756, 0.021072883726561784}, {19.505745402942168, 
       0.009865937020725876}, {19.54026434289457, 0.0024505027952533114}, 
      {19.578116197843343, 0.000026700850865069715}, 
      {19.61763725689792, 0.0038742177519999425}, 
      {19.65449658291115, 0.013324162267025657}, {19.696232473290067, 
       0.03081902161933339}, {19.717298085383945, 0.042371194507556866}, 
      {19.740527031253087, 0.057210350177710464}, {19.820042123316544, 
       0.12444010801222062}, {19.91287448989276, 0.23411876433491738}, 
      {19.999939006175172, 0.36583819023555764}, {20.326855596781357, 
       1.069146742756958}, {20.939277298771376, 2.7797439379525146}, 
      {21.10770375839024, 3.2004385323357774}, {21.264245958973955, 
       3.528518236462575}, {21.427566410652414, 3.7876455741544457}, 
      {21.513900025464395, 3.885313716024566}, {21.562198053502566, 
       3.9272591354466972}, {21.606038963933536, 3.957220059343578}, 
      {21.644211374456784, 3.976920560019461}, {21.684584580208398, 
       3.9912175959131777}, {21.719053717574106, 3.998067824756734}, 
      {21.756931678500084, 3.9998843836691353}, {21.797672696060296, 
       3.995157698961158}, {21.820531239635745, 3.989478663232981}, 
      {21.841396524421054, 3.9824013606868633}, {21.881914218957245, 
       3.963522283238366}, {21.920340746481116, 3.939404228253613}, 
      {21.9940055730381, 3.8765463661993937}, {22.062236833732587, 
       3.7993700370856502}, {22.216763224708885, 3.561471794113502}, 
      {22.369144338185777, 3.250944426195729}, {22.533597019544665, 
       2.848609279845406}, {22.83137915363825, 2.0161279956302085}, 
      {23.155554068571682, 1.1117658651764442}, {23.327094715713006, 
       0.6994148441249054}, {23.42141566126673, 0.5051057815268073}, 
      {23.510560796795172, 0.34687114682991776}, {23.596370323972867, 
       0.22038499710570705}, {23.641578935839878, 0.16462166774255002}, 
      {23.689495980574666, 0.11406307892432005}, {23.7297775044491, 
       0.07853927832713532}, {23.774137206663017, 0.046947052960839786}, 
      {23.814479406362487, 0.025172940591961103}, 
      {23.8522652743549, 0.010857625141011311}, {23.89332687062219, 
       0.0020188982237635154}, {23.93235226637959, 
       0.0001307368564765372}, {23.96738227905113, 0.003846858191478817}, 
      {24.005611787092025, 0.013732613675771768}, {24.047014982466905, 
       0.031267724062394996}, {24.091144096150686, 0.05770502497364272}, 
      {24.17053654377592, 0.1250395611040831}, {24.260804020252106, 
       0.23145673934223912}, {24.358430347010156, 0.3802768271040673}, 
      {24.535402487843587, 0.7295656195543556}, {24.866160820869887, 
       1.5820481151541017}, {25.206440104070797, 2.5546078748405323}, 
      {25.52406011596859, 3.3482380389069033}, {25.68397621466073, 
       3.650631603812047}, {25.773638531866958, 3.7826627471335335}, 
      {25.855374492418996, 3.877052824616362}, {25.89875149221909, 
       3.916599731989259}, {25.944825248920235, 3.950364705784739}, 
      {25.968849327776432, 3.9645534577852577}, {25.99536215999941, 
       3.977465761448285}, {26.019475890596254, 3.986691982224854}, 
      {26.04210980353565, 3.9931594819842515}, {26.063745588944116, 
       3.9973504642341195}, {26.08652002819555, 3.999654685264588}, 
      {26.127230984384823, 3.998382424814418}, {26.149933103512133, 
       3.9946713600646704}, {26.171050534766586, 3.989293856793123}, 
      {26.1942233368074, 3.981263470116554}, {26.218974483134915, 
       3.9702349516666473}, {26.259662338716474, 3.9466413736574335}, 
      {26.304410467474057, 3.91293564793494}, {26.39484574308831, 
       3.8206096550758377}, {26.478613476207077, 3.707371520171939}, 
      {26.55696990336729, 3.5788117132905053}, {26.923299807239303, 
       2.743135943131305}, {27.24140139424311, 1.8425974776734395}, 
      {27.58809979154872, 0.9046727455861255}, {27.766320810317527, 
       0.5147256784666016}, {27.853030293957406, 0.35904394680088003}, 
      {27.93153059618565, 0.24021490015492297}, {28.007439672996632, 
       0.14678934741216423}, {28.08942896817523, 0.07091128909859823}, 
      {28.134568351896334, 0.040618725716601474}, {28.176036067788115, 
       0.020126102241362454}, {28.215681131964644, 0.007173294618878561}, 
      {28.257501633399883, 0.0005911049294985643}, 
      {28.295678592282158, 0.0009504905416558446}, 
      {28.330434766002806, 0.006563015407138477}, {28.370553547821952, 
       0.019285467447478277}, {28.40850169940667, 0.03744024751909521}, 
      {28.443574687719977, 0.0594631595779789}, {28.47597517761468, 
       0.08423416798462674}, {28.549261114238103, 0.1556403717540738}, 
      {28.623076069083115, 0.24843200485583528}, {28.704430465174593, 
       0.3736976672738855}, {28.869029850092915, 0.6936180374762517}, 
      {29.562397909901495, 2.571407297790867}, {29.8657949160333, 
       3.3307271242292082}, {29.948917464158633, 3.499979555816677}, 
      {30.037584801092986, 3.6566616220887402}, {30.120676694450395, 
       3.7789026960907175}, {30.1971727807801, 3.8688474717247767}, 
      {30.278128982889708, 3.939191963808736}, {30.320726012092727, 
       3.965617112354649}, {30.342451699768766, 3.9762352170917676}, 
      {30.36575628282566, 3.9854614222866793}, {30.40491154289471, 
       3.995893674238548}, {30.441489208394607, 3.9998732771786956}, 
      {30.48498596923472, 3.997340972689933}, {30.524669836417253, 
       3.9881541109967213}, {30.562595881394465, 3.9732703522604735}, 
      {30.597706802690418, 3.954212515706538}, {30.636241304782697, 
       3.927514369609242}, {30.677204827736126, 3.892589014461015}, 
      {30.821794578330096, 3.7173958655271546}, {30.891824049451248, 
       3.605114924895508}, {30.967363203094976, 3.4656406832807014}, 
      {31.104109783088468, 3.1700889584033676}, {31.415925226900992, 
       2.3473000794297505}}]}}}, {PlotRange -> Automatic, 
  AspectRatio -> GoldenRatio^(-1), DisplayFunction :> $DisplayFunction, 
  ColorOutput -> Automatic, Axes -> Automatic, AxesOrigin -> Automatic, 
  PlotLabel -> None, AxesLabel -> None, Ticks -> Automatic, 
  GridLines -> None, Prolog -> {}, Epilog -> {}, AxesStyle -> Automatic, 
  Background -> Automatic, DefaultColor -> Automatic, 
  DefaultFont :> $DefaultFont, RotateLabel -> True, Frame -> False, 
  FrameStyle -> Automatic, FrameTicks -> Automatic, FrameLabel -> None, 
  PlotRegion -> Automatic, ImageSize -> Automatic, 
  TextStyle :> $TextStyle, FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell["\<\
Interf\[EAcute]rences avec les fentes d'Young de largeurs e=0,1mm, espac\
\[EAcute]es de a=0.5 mm :\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(TraditionalForm\`e = 0.0001; f = 1; 
    a = 0.0005; \[CurlyPhi] = \(2\ \[Pi]\ a\ x\)\/\(lambda0\ f\); 
    lambda0 = 500\ 10\^\(-9\);\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(TraditionalForm\`intensite(
        x_) = \(FD(e, x\/\(lambda0\ f\))\)\^2\ \(i(\[CurlyPhi])\); \)], \
"Input",
  CellLabel->"In[51]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Plot[{intensite(x), 
        4\ \(FD(e, x\/\(lambda0\ f\))\)\^2}, {x, \(-0.02\), 0.02}, 
      PlotRange \[Rule] All, 
      PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 0, 1]}]\)], "Input",
  CellLabel->"In[53]:="],

Cell[OutputFormData["\<\
Graphics[{{RGBColor[1, 0, 0], 
   {Line[{{-0.019999998333333335, 2.7777782369574106*^-14}, 
      {-0.01995062291358608, 0.000023909253415222425}, 
      {-0.01990569967266004, 0.0000820230635820043}, 
      {-0.019857329902446236, 0.00016725756978786733}, 
      {-0.01980482602704684, 0.00025853260978574535}, 
      {-0.019756226769206908, 0.00031394843773018384}, 
      {-0.019711358608624416, 0.00032219966748093723}, 
      {-0.01966846998886244, 0.0002855496113725279}, 
      {-0.019623003192812842, 0.0002058132638191276}, 
      {-0.01957412648326741, 0.0000984572837850113}, 
      {-0.019521549292581975, 0.000010668066043514946}, 
      {-0.019471916330286734, 0.000022015658754349032}, 
      {-0.019426505879842557, 0.0001747928560854152}, 
      {-0.019373455471146883, 0.0005953641632230738}, 
      {-0.019343426889053068, 0.0009709606814193258}, 
      {-0.01931554852445694, 0.0014154299625216678}, 
      {-0.01926449666015998, 0.002466763637143354}, 
      {-0.019210073169479192, 0.0038858553848915554}, 
      {-0.0191020419924394, 0.007151767115352663}, 
      {-0.01904521602625817, 0.008725018437772153}, 
      {-0.019014167719996564, 0.009427133516700999}, 
      {-0.01898518135755112, 0.00994007540652087}, 
      {-0.01893257929384164, 0.010436584660795748}, 
      {-0.01890471303729316, 0.010442024858058736}, 
      {-0.018874840208029504, 0.010237043947112298}, 
      {-0.018821738130057136, 0.009341004337249744}, 
      {-0.01877332108680964, 0.00799520199382463}, 
      {-0.018675918144205186, 0.00437477654938199}, 
      {-0.01862454360074938, 0.0024575322579029543}, 
      {-0.01856996460714737, 0.0008550515605365018}, 
      {-0.01852240097760436, 0.00009361016191866589}, 
      {-0.0184698999350858, 0.00017804345107055023}, 
      {-0.018422149254084346, 0.0012257462625781513}, 
      {-0.01837732033708337, 0.0030769762736390593}, 
      {-0.018160899840173793, 0.019689654875844686}, 
      {-0.01810828737210484, 0.023639362647892882}, 
      {-0.018079375348905097, 0.02541983191526358}, 
      {-0.01805208056833149, 0.02676867621645059}, 
      {-0.018019772555105635, 0.027884122780616073}, 
      {-0.017990416486356794, 0.028400026854695497}, 
      {-0.017962887861880196, 0.028429204309677495}, 
      {-0.017933045749547686, 0.027956110797167755}, 
      {-0.017884023798374664, 0.026077147045172343}, 
      {-0.017830099535471024, 0.022619414125692693}, 
      {-0.017721108483598483, 0.012966102626132202}, 
      {-0.017673147653443654, 0.00858597741254898}, 
      {-0.0176208651707505, 0.0044572555645667885}, 
      {-0.017571484372377797, 0.0016241103624415286}, 
      {-0.017525699877130384, 0.00021451329877888236}, 
      {-0.01749532924360304, 7.126811697778458*^-6}, 
      {-0.017467828645224795, 0.0003379123871297012}, 
      {-0.01743608318954539, 0.0013236915047556133}, 
      {-0.01740621660346118, 0.0028101611043987802}, 
      {-0.017353736709859707, 0.006561874612671362}, 
      {-0.017297042348059094, 0.01180627825360157}, 
      {-0.017177511209212102, 0.023720321900514475}, 
      {-0.01714845533390764, 0.026168781196479692}, 
      {-0.01711734822357487, 0.028383399436123377}, 
      {-0.017083218259723684, 0.030227569961968227}, 
      {-0.017051396836188188, 0.03132111153040187}, 
      {-0.01702158503270123, 0.03175805027817121}, 
      {-0.0169891988848325, 0.031573991967795347}, 
      {-0.01695861434356703, 0.030782554922184197}, 
      {-0.016930354857109167, 0.029549072727586754}, 
      {-0.016876876607732464, 0.026067804164488093}, 
      {-0.016820137451003112, 0.021160185518215607}, 
      {-0.016716557095274743, 0.011142937910083684}, 
      {-0.016660102665994263, 0.006331221790101948}, 
      {-0.01660764800562505, 0.0029002304002495533}, 
      {-0.016560019185621375, 0.0008955547249216631}, 
      {-0.01650920346559232, 0.000020505575279746604}, 
      {-0.016480182954220414, 0.00009279972864533777}, 
      {-0.016452821803466314, 0.0005110182112196495}, 
      {-0.016401659175123758, 0.0020708034316262256}, 
      {-0.01635450792693607, 0.004172150974094015}, 
      {-0.0163110911825019, 0.006412102612237035}, 
      {-0.016213041196811447, 0.011303654070051966}, 
      {-0.01616217190172014, 0.013152798774138075}, 
      {-0.01611464220483831, 0.014193492999697655}, 
      {-0.016062494232037823, 0.014478861717459279}, 
      {-0.016033240346077775, 0.014248893175390734}, 
      {-0.016006545699986077, 0.013811931475179572}, 
      {-0.015952887136456047, 0.012370527158931591}, 
      {-0.01589447055156844, 0.010182353637410312}, 
      {-0.015788212764608334, 0.005681972202496053}, 
      {-0.015744024727842386, 0.003994728852660097}, 
      {-0.015696350962743934, 0.002470543742566873}, 
      {-0.015644030091269252, 0.0012265956419549055}, 
      {-0.015594870631418846, 0.0004789474899817994}, 
      {-0.015542671979413754, 0.00008378558509949277}, 
      {-0.0154876709176021, 5.763031132565045*^-6}, 
      {-0.015440711430374215, 0.00010892280765343934}, 
      {-0.015389301694623617, 0.0002914191554448951}, 
      {-0.015341771429881452, 0.00044452236568999975}, 
      {-0.015296863322373837, 0.00052847326330451}, 
      {-0.015245100796194504, 0.0005286738756531369}, 
      {-0.015198029406553515, 0.0004461687824998652}, 
      {-0.015112205116591022, 0.0001939051106446725}, 
      {-0.015064005925433142, 0.00006929559515837177}, 
      {-0.015019929466459575, 7.014379876673934*^-6}, 
      {-0.014968547289063848, 0.000017486909351518448}, 
      {-0.0149197282722809, 0.00010848712800468364}, 
      {-0.014874858440845896, 0.00024106426174510902}, 
      {-0.014825905620208746, 0.0004007700584511868}, 
      {-0.014772266045718458, 0.0005379215726177011}, 
      {-0.014742283773932498, 0.0005765145825375972}, 
      {-0.014715112700215402, 0.00058038547204665}, 
      {-0.014662162142243482, 0.0004975586580859743}, 
      {-0.014612304930007886, 0.00032960790880532206}, 
      {-0.014559719346208864, 0.0001240322253035567}, 
      {-0.014504192425044528, 7.848914482356504*^-7}, 
      {-0.014456784890549976, 0.000099501831611525}, 
      {-0.01440477382086709, 0.0005660895472924184}, 
      {-0.014375457142425737, 0.0010427863124515718}, 
      {-0.014348740442635125, 0.001630685574569955}, 
      {-0.01431790186961658, 0.002501759266174864}, 
      {-0.014288702467390718, 0.0035188563431718146}, 
      {-0.014180394012383494, 0.008699537562338214}, 
      {-0.014086868140924134, 0.013949433184619664}, 
      {-0.014035633827038202, 0.016474389913096302}, 
      {-0.013987558621486299, 0.018249852511722144}, 
      {-0.01394674752611184, 0.01912558782568529}, 
      {-0.013902775057639026, 0.019291090423889705}, 
      {-0.013853966519625737, 0.01845419632596033}, 
      {-0.013809237539027158, 0.016766626361745803}, 
      {-0.013700429858894199, 0.009942113832438527}, 
      {-0.013646999127940323, 0.00609748845159473}, 
      {-0.013597760166898508, 0.0029803076481922093}, 
      {-0.013552972757694251, 0.0009422947058295737}, 
      {-0.013505579343522702, 0.000011111946444507372}, 
      {-0.013458006203591773, 0.0006576545979880259}, 
      {-0.013405701985419642, 0.003409756985776462}, 
      {-0.013356032748517658, 0.008001010278460185}, 
      {-0.013302700204065512, 0.014809005142382937}, 
      {-0.013206382178504462, 0.03010294700687067}, 
      {-0.013154119030643344, 0.038547519091655116}, 
      {-0.013097175231614896, 0.04651470876384411}, 
      {-0.013043392889549553, 0.0519017512025728}, 
      {-0.01299355249324663, 0.054401932997792196}, 
      {-0.01294260958602568, 0.05412918937061194}, 
      {-0.012896504032080846, 0.05137746914238388}, 
      {-0.012843281574963585, 0.045515619379103936}, 
      {-0.012793234292472184, 0.037941262300380016}, 
      {-0.012705938361257389, 0.022423608390003846}, 
      {-0.012659733528485513, 0.014480891121945585}, 
      {-0.012610291688551172, 0.007313041040422347}, 
      {-0.012555376132476398, 0.0019234200480702176}, 
      {-0.012504200801667217, 0.000011285589202599477}, 
      {-0.012474096377842366, 0.0004301588272467059}, 
      {-0.01244562960547922, 0.001887802360717278}, 
      {-0.012392323181525288, 0.007233030970791839}, 
      {-0.01234242971979985, 0.014863290587335078}, 
      {-0.01229635238449461, 0.02349586146874744}, 
      {-0.012192146668703722, 0.04449120061382359}, 
      {-0.012141927764731605, 0.053160659187380124}, 
      {-0.012087889959452064, 0.059980433509002215}, 
      {-0.012056927467532015, 0.062396333643947276}, 
      {-0.012028590285442689, 0.06354633280274566}, 
      {-0.012000105823438405, 0.06364458645606784}, 
      {-0.011973020259562024, 0.0627565433372548}, 
      {-0.011945147871940582, 0.06087901892854302}, 
      {-0.011915425465093903, 0.057875831276018745}, 
      {-0.011861938154546227, 0.050261191494626704}, 
      {-0.011740649223546867, 0.027299081103657686}, 
      {-0.011684128267929826, 0.01684806783729086}, 
      {-0.011631344506585161, 0.008798694005635368}, 
      {-0.011576286090429962, 0.002979164155535434}, 
      {-0.011547114180753148, 0.0011277316355725667}, 
      {-0.01151583195650183, 0.00012538566096617762}, 
      {-0.011489223828772559, 0.00005698933134225002}, 
      {-0.011460270879209514, 0.0007539029879584908}, 
      {-0.01140762023221982, 0.003815223117715158}, 
      {-0.01135636290130068, 0.008465925849071253}, 
      {-0.01130892498762042, 0.013574566284426205}, 
      {-0.011257136880551185, 0.01926388185061246}, 
      {-0.011201291630833237, 0.024664049148346454}, 
      {-0.011169323689062434, 0.02710883462887459}, 
      {-0.011140003845302582, 0.028816492159625562}, 
      {-0.011111971120790794, 0.02991754655598408}, 
      {-0.011082448241264796, 0.030486439402395458}, 
      {-0.011053672878031138, 0.03045421474136186}, 
      {-0.011022922103973916, 0.029802377264718256}, 
      {-0.01096752323360333, 0.027193363375679614}, 
      {-0.010933642286145757, 0.024858611230695837}, 
      {-0.010901646583153627, 0.022286353718995768}, 
      {-0.010841770368412907, 0.016955756960841912}, 
      {-0.010739099160993625, 0.008208504687901472}, 
      {-0.010687329715019166, 0.004789219359305319}, 
      {-0.010657567901006639, 0.0032451810320083163}, 
      {-0.01063036547278841, 0.002116042916986121}, 
      {-0.010581817671653596, 0.0007472889132808752}, 
      {-0.010529646818213924, 0.00008435541999817865}, 
      {-0.010481299516487266, 0.000028202443542101524}, 
      {-0.010435387074978774, 0.0002759933427884145}, 
      {-0.010382795848563756, 0.0006909468191660441}, 
      {-0.010333301875612808, 0.0010256229713748238}, 
      {-0.010305884234485125, 0.0011416948478748601}, 
      {-0.010276255569043683, 0.0011959349917276688}, 
      {-0.010224584073615338, 0.001110967121193898}, 
      {-0.010194350024151429, 0.0009710905428451129}, 
      {-0.010162440904687344, 0.0007754670374711598}, 
      {-0.010105323757417907, 0.00038809300056681244}, 
      {-0.010052566105886309, 0.00010638040711931437}, 
      {-0.010022632302470894, 0.000020292109894017397}, 
      {-0.009994714532924756, 1.1183161607314542*^-6}, 
      {-0.009941574746859586, 0.00013348776409155224}, 
      {-0.009914753176507609, 0.00027473175923378165}, 
      {-0.009885177164044502, 0.0004716416272151633}, 
      {-0.009832335780154028, 0.0008659726421812531}, 
      {-0.009783935404426056, 0.0011745280822505156}, 
      {-0.009756198351869748, 0.001287451770966156}, 
      {-0.009727025290885857, 0.00133536505936032}, 
      {-0.009697739907487056, 0.0013005827833474234}, 
      {-0.009665737564269868, 0.001166551954880011}, 
      {-0.009637944998731492, 0.0009783342319097182}, 
      {-0.00960828358015639, 0.0007253236647617235}, 
      {-0.009554883579195863, 0.00024893163967681833}, 
      {-0.00950097518770891, 1.0022215992904858*^-7}, 
      {-0.009470586080944043, 0.00010256243797091229}, 
      {-0.0094425951656214, 0.00043039981250740964}, 
      {-0.009391128400736522, 0.0018009906297192192}, 
      {-0.009336694366847, 0.004588465789977616}, {-0.009287919894637262, 
       0.008397767110543812}, {-0.009242333322815533, 
       0.013055339666114744}, {-0.00913864044820607, 
       0.026467235754625087}, {-0.009090331163580679, 
       0.03306695371198902}, {-0.009037721824250703, 
       0.039522925116029305}, {-0.00898803428542845, 0.0441684282705962}, 
      {-0.008942011732018567, 0.04663549814800016}, 
      {-0.008900693566972186, 0.04701938264996308}, 
      {-0.008855034907787553, 0.04525135618100287}, 
      {-0.008807348213191669, 0.04098831197568554}, 
      {-0.008762528986467472, 0.03502404496781779}, 
      {-0.00866801438022345, 0.01886356913775269}, 
      {-0.008616435919530282, 0.01018878435114448}, 
      {-0.008568394576095656, 0.003846756970973911}, 
      {-0.008516253825983816, 0.00023465912119496128}, 
      {-0.00848866298658017, 0.0001178995315241296}, 
      {-0.008459154043577385, 0.0015737604826685533}, 
      {-0.008406645542457885, 0.008496634786658627}, 
      {-0.008358880919178364, 0.019637869580385478}, 
      {-0.008155818219705978, 0.09961523097309417}, 
      {-0.008106466825962892, 0.11854096047756135}, 
      {-0.008053389214611913, 0.13423582875118745}, 
      {-0.008022970122038887, 0.1402831493795927}, 
      {-0.007995144278090095, 0.1436202913182315}, 
      {-0.007940590101594137, 0.14356911625305155}, 
      {-0.007891499553565164, 0.13594537245569704}, 
      {-0.007845932927267128, 0.12295526460513773}, 
      {-0.00779592767595874, 0.10341774800611594}, 
      {-0.007742630161122177, 0.07873668669098281}, 
      {-0.007694971895406008, 0.05571686841767061}, 
      {-0.007644632255574919, 0.03312298580150102}, 
      {-0.007601653619663638, 0.017212421281105547}, 
      {-0.0075544868417358356, 0.005145390155708033}, 
      {-0.007526206329756913, 0.0012093748884482722}, 
      {-0.0074958952410863425, 0.000029984811983454032}, 
      {-0.007441205267837472, 0.006163860641642814}, 
      {-0.0074082897256852525, 0.014856165082045887}, 
      {-0.00737711406436134, 0.026239506473209214}, 
      {-0.007318688671818683, 0.05430589226071292}, 
      {-0.007203317401137742, 0.12154063407087844}, 
      {-0.00715258484348754, 0.14860916807686944}, 
      {-0.007125638945301297, 0.1608072970958332}, 
      {-0.007096596691047916, 0.17169995395668072}, 
      {-0.007046860043460853, 0.18389548254420474}, 
      {-0.007000175647329709, 0.18703635896359805}, 
      {-0.006946742436394452, 0.1804472295833737}, 
      {-0.006897760087710192, 0.1655613985522635}, 
      {-0.006847440331713067, 0.14310620815555972}, 
      {-0.006792407330066459, 0.11305828849958674}, 
      {-0.0067347034529355995, 0.07937375808644233}, 
      {-0.00668151003959927, 0.05013568534469898}, 
      {-0.006629737884443842, 0.02642823461774306}, 
      {-0.006574936278810794, 0.008907434245237262}, 
      {-0.0065199270164157585, 0.000621648433928434}, 
      {-0.006488668027778539, 0.00019747162158443337}, 
      {-0.006459428336371571, 0.002472269899964675}, 
      {-0.00640661242427869, 0.0123412091766709}, {-0.006358362750441736, 
       0.02636717665413121}, {-0.006249809417715025, 
       0.06491161774393915}, {-0.006203174352703745, 
       0.07992373054375383}, {-0.006153534324306946, 
       0.09230530379423993}, {-0.006099081598906397, 
       0.10014860071190079}, {-0.006048604258099418, 
       0.10139832396564813}, {-0.0059969547583160875, 
       0.09681535740191353}, {-0.0059483714928306826, 
       0.0878457449687735}, {-0.0059047469892214675, 
       0.07690071224824538}, {-0.005857628219586817, 0.0632150016452672}, 
      {-0.005801832773422535, 0.046298165616824684}, 
      {-0.005742109857040206, 0.029515122805273648}, 
      {-0.005686770774167491, 0.016800410022531204}, 
      {-0.005634425817262265, 0.008077701665443606}, 
      {-0.005606239420555084, 0.0047817033056770505}, 
      {-0.005575624925236535, 0.0022603469911425624}, 
      {-0.005522092792819239, 0.0001658887718073222}, 
      {-0.005491038039045944, 0.00002455547449969655}, 
      {-0.00545809600932793, 0.00047224174086939647}, 
      {-0.00542997212080263, 0.0011656751343867933}, 
      {-0.005398975665253429, 0.0020832150939731225}, 
      {-0.005345295400602825, 0.003585177904046212}, 
      {-0.005294235558347212, 0.00443171954729079}, 
      {-0.005266104302261309, 0.004548384962296278}, 
      {-0.005235378634617964, 0.004381454325084743}, 
      {-0.005181495425502651, 0.00346271618778315}, 
      {-0.005129896403140371, 0.0021559960878927017}, 
      {-0.005075349924430451, 0.000832534775750075}, 
      {-0.0050287799555673775, 0.00012993091145375158}, 
      {-0.004977630218145718, 0.00008038276842155656}, 
      {-0.0049223134127180405, 0.0009374300041840457}, 
      {-0.004870638117958447, 0.002375466555134802}, 
      {-0.004839549143048525, 0.0033596745203805997}, 
      {-0.0048100795302758684, 0.00424697512352487}, 
      {-0.004754829463283735, 0.005435495484450747}, 
      {-0.0047063112562007745, 0.005612987669540829}, 
      {-0.004653500989856634, 0.004694870103170432}, 
      {-0.00462614278813527, 0.0038212068004318026}, 
      {-0.0045970600632179, 0.0027111919368239317}, 
      {-0.004544808558103826, 0.0007685887015778858}, 
      {-0.0044985236618878205, 1.0343537184164635*^-6}, 
      {-0.004448597226193391, 0.0015261584314339364}, 
      {-0.004401461411494706, 0.006547470741940979}, 
      {-0.004358216688377493, 0.01524706828004317}, 
      {-0.004310301601147408, 0.03029663384114558}, 
      {-0.004257855793167572, 0.053695937012051255}, 
      {-0.004152127091749773, 0.1195306133704705}, 
      {-0.004097758643322706, 0.1581091404360003}, 
      {-0.004038784426521552, 0.1973674858305949}, 
      {-0.0040117421603480365, 0.21280965639776175}, 
      {-0.003983094212317655, 0.22647973132939891}, 
      {-0.0039317152367600305, 0.2420458009711446}, 
      {-0.0039013727500656122, 0.24481420732369244}, 
      {-0.0038729672440838444, 0.24261127689786469}, 
      {-0.0038418037092561256, 0.23468753515179408}, 
      {-0.003808304069184679, 0.219849195051193}, 
      {-0.0037782443273282926, 0.20136017511548848}, 
      {-0.003749689577565902, 0.17987512945578477}, 
      {-0.0036960990016315985, 0.13219654333209785}, 
      {-0.0036454569169713947, 0.08393687025296206}, 
      {-0.003597782477892525, 0.042590029165978094}, 
      {-0.003542833197561932, 0.009134422306862698}, 
      {-0.00349304565246473, 0.0002610329181130619}, 
      {-0.003437833859616582, 0.02231414863926597}, 
      {-0.0034067394972469986, 0.05163358852578226}, 
      {-0.0033781510951140345, 0.08983441078959312}, 
      {-0.0033262993323773028, 0.18595234648522277}, 
      {-0.0032715577937760952, 0.3204973698676472}, 
      {-0.00316440878338843, 0.6393112979660313}, 
      {-0.0031117034891174258, 0.7930242391649105}, 
      {-0.003062974578077889, 0.9136713220668106}, 
      {-0.0030188049947908187, 0.9943158003162698}, 
      {-0.00297191296995239, 1.041085751167337}, {-0.0029248445757715474, 
       1.0416819563787572}, {-0.0028729263312001043, 0.9859399053161342}, 
      {-0.002817573792096485, 0.8656203146148077}, 
      {-0.002766857530665409, 0.7113362761794761}, 
      {-0.0026525942263153084, 0.30353486026397497}, 
      {-0.0026003954873528305, 0.14360557743958646}, 
      {-0.002551864829168015, 0.04089992790362591}, 
      {-0.00250123345467672, 0.00002431842810862986}, 
      {-0.002445887520310164, 0.04842081129557974}, 
      {-0.002266219849561659, 0.8670933556271041}, 
      {-0.0021679810218829007, 1.5400361969281005}, 
      {-0.002119971384220976, 1.8400425476738569}, 
      {-0.002076134533728423, 2.06504030447412}, {-0.0020282419743723645, 
       2.235154082145664}, {-0.0019768270265266867, 2.3102584773712067}, 
      {-0.0019500155365467283, 2.301139332518667}, 
      {-0.001920808444955734, 2.252875453689087}, 
      {-0.0018676645364118455, 2.066958185498697}, 
      {-0.0018193571124232842, 1.8021667092305151}, 
      {-0.0017679628225242836, 1.4479710370659462}, 
      {-0.0016755864462821908, 0.74816335153904}, 
      {-0.0016180016189465353, 0.3672914467795835}, 
      {-0.0015855930574842202, 0.20043948494114272}, 
      {-0.0015558356141733545, 0.08763704804486308}, 
      {-0.0015010321732702669, 0.000030977614450881734}, 
      {-0.001473457373581543, 0.020673337732999997}, 
      {-0.0014432505750070332, 0.09488292331057617}, 
      {-0.0013906705901934437, 0.34930333103678163}, 
      {-0.0013612179044952737, 0.5555544669420138}, 
      {-0.0013344177797641296, 0.7773030357389771}, 
      {-0.0012330169298421794, 1.8042120670114956}, 
      {-0.0011301118074740686, 2.8387238300754474}, 
      {-0.0011019193512857254, 3.063483245739468}, 
      {-0.0010720286050574337, 3.257814570437044}, 
      {-0.0010183982365121957, 3.4713984119360046}, 
      {-0.0009685520076876238, 3.4956129664280993}, 
      {-0.0009218498275999428, 3.361182013955008}, 
      {-0.0008706144996752394, 3.0512497929967823}, 
      {-0.0008154935713763938, 2.563364046929929}, 
      {-0.0007155469794017915, 1.467423777821015}, 
      {-0.0006627394877553571, 0.903486869533284}, 
      {-0.000633750333666783, 0.6311916419206532}, 
      {-0.0006064377373557901, 0.4103768448058145}, 
      {-0.00055238939586763, 0.10313646847000141}, 
      {-0.0005033782296415529, 0.000435704187212222}, 
      {-0.00045741391677796116, 0.06923278047982377}, 
      {-0.00040768700336650765, 0.3200042424498317}, 
      {-0.00036264216199562426, 0.6877197460473305}, 
      {-0.00031319244480596155, 1.2108497291370388}, 
      {-0.0002133503585807185, 2.4418143129416254}, 
      {-0.00016872213658387014, 2.9664103903906085}, 
      {-0.0001208746763062095, 3.4437621411177983}, 
      {-0.00007571259269423088, 3.775080816210512}, 
      {-0.00003453012691354914, 3.9524928428008588}, 
      {0.000014943606903126368, 3.991073208543955}, 
      {0.00006139566222270357, 3.851114374317975}, 
      {0.00011235296417340263, 3.516164586074731}, 
      {0.0001672917616832259, 2.982182191025877}, 
      {0.00027174402529617865, 1.7108827233093236}, 
      {0.0003287159957529212, 1.0358082534521313}, 
      {0.00038172760430959184, 0.5172538626276965}, 
      {0.0004281157867139867, 0.19576320865181965}, 
      {0.00047767896462104574, 0.01905445498231608}, 
      {0.000532674110237714, 0.040454265531772005}, 
      {0.0005826503568961822, 0.25210301669442764}, 
      {0.0006281202966109032, 0.5825703296027867}, 
      {0.0006774173577608638, 1.0532150867802657}, 
      {0.0007668940293428851, 2.0459224009453245}, 
      {0.0008174659274701283, 2.5829891101706117}, 
      {0.0008718014898061444, 3.0601604960087174}, 
      {0.0009029553847432803, 3.265461067509734}, {0.0009314247050730165, 
       3.400833642648524}, {0.0009600424162029464, 3.4823259999599805}, 
      {0.000987213666878097, 3.506937397496255}, {0.0010152598205081021, 
       3.478025440895258}, {0.0010451224297139965, 3.388098711234615}, 
      {0.001098820193682134, 3.0858655544175506}, {0.0011317181004964424, 
       2.8248566249020604}, {0.0011626726045019943, 2.5388856087461864}, 
      {0.001220497816833561, 1.9392233832085084}, {0.0013183242688537295, 
       0.9237819291138307}, {0.0013675655316375136, 0.5075861758292308}, 
      {0.0014215508123793716, 0.18113322852821978}, 
      {0.0014498394098816508, 0.07410443349879016}, 
      {0.001480128672510703, 0.011567049254536615}, 
      {0.0015347508311558144, 0.03447544272310447}, 
      {0.0015891945956325385, 0.2168592442086136}, 
      {0.0016387754432876551, 0.4942966775995711}, 
      {0.0017432764976269331, 1.2620605457815648}, 
      {0.0017944250588553439, 1.6375701188856016}, 
      {0.0018412658749664594, 1.9321660662180513}, 
      {0.0018904757749644433, 2.1615965559008097}, 
      {0.0019434607910789896, 2.293771201302657}, {0.0019983787979596227, 
       2.2932850248283496}, {0.002025976572293982, 2.240925187681621}, 
      {0.0020561289387231573, 2.146832127279521}, {0.0021068285359659767, 
       1.9133759607874845}, {0.0021528405370121245, 1.6391391587613522}, 
      {0.002256035474948034, 0.9352935606740211}, {0.0023019417056936806, 
       0.6395378568248158}, {0.0023516462420491804, 0.3667732827472258}, 
      {0.002398579572716676, 0.1721199807746174}, {0.0024418007947698463, 
       0.056103236727064285}, {0.002492187352646179, 
       0.0009825109344723051}, {0.002546252518350719, 
       0.03273725544317662}, {0.002597285007032329, 0.1354765496211771}, 
      {0.0026438585178263844, 0.274200885487535}, {0.002759118349069725, 
       0.6850919182747641}, {0.0028098289865110195, 0.8444138766571465}, 
      {0.002838713545654789, 0.918353146885187}, {0.0028658560205234193, 
       0.9738892078327751}, {0.0029192600817255043, 1.0385195461335226}, 
      {0.0029465749937564283, 1.0474233886107778}, 
      {0.0029760481159030387, 1.0387487902360952}, 
      {0.00300650951330423, 1.010750027064497}, {0.003038610114161781, 
       0.9621145735620418}, {0.0030660173328097493, 0.9069990200422544}, 
      {0.0030960254407741434, 0.8347683040687124}, 
      {0.003209526564683861, 0.5010822805176282}, {0.003314273616404931, 
       0.21286214698530662}, {0.003365842851287861, 0.10958347288154634}, 
      {0.003420491082919112, 0.037104576541306576}, 
      {0.003475345804227919, 0.0033608560471687574}, 
      {0.003506535133843143, 0.00022594586091739756}, 
      {0.0035357425017400693, 0.00644150278979016}, 
      {0.0035884128871035087, 0.03554528358476198}, 
      {0.0036365838206622878, 0.07572574200354179}, 
      {0.0036928246249679523, 0.12909132187211803}, 
      {0.00374501819986943, 0.17604901981962448}, {0.0037915225969944576, 
       0.2100930664105073}, {0.003841079244810156, 0.23443491601113287}, 
      {0.0038960612446786082, 0.24476206356431648}, 
      {0.0039458939470498455, 0.23904022750617795}, 
      {0.0039931260621833605, 0.22204914933150507}, 
      {0.004044198849083191, 0.19403345288181192}, 
      {0.004136771817417022, 0.13037602143091054}, 
      {0.0041924114161653895, 0.09215114995406175}, 
      {0.004252034550034493, 0.056728349825991994}, 
      {0.00428093897301147, 0.04251187085654505}, {0.004308310280703754, 
       0.031052678151578635}, {0.004359601239580306, 
       0.014899754993424571}, {0.004413355730309168, 0.004881351532162}, 
      {0.004443722321127404, 0.0018613755940266393}, 
      {0.004471806619817088, 0.00042085700649545257}, 
      {0.004500193265567471, 1.759894489325005*^-8}, 
      {0.004531514574062012, 0.0004057782208083036}, 
      {0.004564225131950791, 0.00142816470014336}, 
      {0.004594922401397644, 0.0026260753328519897}, 
      {0.004646481955175017, 0.004492333370481959}, 
      {0.004700744575921557, 0.005570749284021108}, 
      {0.004747074090064541, 0.005526466977965878}, 
      {0.004797733356402498, 0.0045802025943425485}, 
      {0.0048529866982554275, 0.002933498531609738}, 
      {0.004883203014597092, 0.0019902187783513215}, 
      {0.004911461958673394, 0.0012006250983091985}, 
      {0.004961385662776083, 0.0002387036441576104}, 
      {0.005016280731396663, 0.00004202351375715143}, 
      {0.005067698669793983, 0.0006816197860520344}, 
      {0.005122915447527124, 0.001972150168680282}, 
      {0.005151287321902046, 0.002719493433203921}, 
      {0.005182203835595128, 0.003478760220863774}, 
      {0.0052114040355521135, 0.004057519137906283}, 
      {0.0052384672384869916, 0.0044114666138680494}, 
      {0.005291555067995322, 0.004454120883098573}, 
      {0.005321210311976814, 0.004078835970813254}, 
      {0.005348052793693533, 0.003519395087941612}, 
      {0.005400225275246231, 0.002045229167669918}, 
      {0.005448144797006934, 0.0006933144004673421}, 
      {0.005495447039750757, 6.439200772958191*^-6}, 
      {0.005545335307709952, 0.0007493812298197419}, 
      {0.005595414346036847, 0.0037684105445700707}, 
      {0.005650290475317267, 0.010362794340563605}, 
      {0.005697822345765013, 0.019068684948152226}, 
      {0.005748690233396051, 0.031234379581212498}, 
      {0.005840399006961752, 0.05798424942959517}, 
      {0.005895488947875565, 0.07432488016386801}, 
      {0.0059539156187589015, 0.08906301405692431}, 
      {0.005984403373774079, 0.09488890336728323}, 
      {0.006017998676490517, 0.09935847935267461}, 
      {0.0060485521375206325, 0.1013966012342422}, 
      {0.006077187341329893, 0.10141180192044469}, 
      {0.006106051405107533, 0.09951439583180431}, 
      {0.006133501186237981, 0.09594699216452471}, 
      {0.006185046306102911, 0.08495275270872274}, 
      {0.006240531035261851, 0.06808998539599481}, 
      {0.006301121203058819, 0.04645871258528267}, 
      {0.006355285485296521, 0.02737846765147498}, 
      {0.006406333097208595, 0.01241050759937589}, 
      {0.00643459065787953, 0.0062654478734221475}, 
      {0.006465170869378972, 0.0018313667046714998}, 
      {0.0065185417148173105, 0.0005378799575563166}, 
      {0.006569662896014572, 0.007695983719116435}, 
      {0.006623693858599294, 0.024077897959097063}, 
      {0.0066698237797987595, 0.044281051384219}, {0.006720480449304467, 
       0.07123648864802604}, {0.006825769519837678, 0.1317718212366487}, 
      {0.006881315137596482, 0.1589194467487839}, {0.006909370125169269, 
       0.16978319391944877}, {0.00694035072842952, 0.17895822678196105}, 
      {0.006967199004526927, 0.18422786121309256}, 
      {0.0069961540463501625, 0.18691578859377003}, 
      {0.007048565387969057, 0.18362420579914152}, 
      {0.007100807814218539, 0.17028052115791892}, 
      {0.00714872837906919, 0.15046443999634024}, {0.007246524937571239, 
       0.09610098453292287}, {0.007300278763325536, 0.06449911669125682}, 
      {0.007351047580971608, 0.037813993323969154}, 
      {0.007398370103753491, 0.018163144947169294}, 
      {0.007449691638662752, 0.004518045545352856}, 
      {0.007496336072688907, 0.00002388768806514806}, 
      {0.007539361271605151, 0.0027101213191445335}, 
      {0.007586578137084386, 0.012667838425314435}, 
      {0.007638539148485074, 0.03063597628323913}, 
      {0.0077435857042184525, 0.07919769459943823}, 
      {0.007799226595805377, 0.10484136204027274}, 
      {0.007829897382788815, 0.11721244405492182}, 
      {0.007859026989350605, 0.12721817511352687}, 
      {0.007886028953736215, 0.13466998767728242}, 
      {0.007915476669514237, 0.14054596479040365}, 
      {0.007967078057326998, 0.14470850414927494}, 
      {0.00799766796654524, 0.14340865169496916}, {0.008026459763529394, 
       0.13971250212621206}, {0.008080253017411798, 0.12702626199954742}, 
      {0.008110437815864287, 0.11714665371252049}, 
      {0.008138184622151219, 0.10673463387967469}, 
      {0.008200795408285864, 0.08039874165370411}, 
      {0.008259077471648883, 0.055275989024140645}, 
      {0.008314240457438825, 0.03383585891397261}, 
      {0.008363762831504817, 0.018296379005037937}, 
      {0.0084175847551282, 0.0065882632118465295}, 
      {0.00846744259818498, 0.0009927265600615492}, 
      {0.008520363317506378, 0.000366370081557203}, 
      {0.008565543517031263, 0.003549612248275231}, 
      {0.008615369423088168, 0.010025017514813248}, 
      {0.0087173595427888, 0.027632913559366642}, {0.008770894588897944, 
       0.036259799663443504}, {0.008800079300848222, 
       0.040138407486164714}, {0.008827207946490319, 
       0.04304955886731487}, {0.008876371812444158, 
       0.046367381080520645}, {0.008930103256153215, 
       0.046933738422106394}, {0.008975696827118865, 
       0.04502291871151708}, {0.00902436202121022, 0.040941109195164464}, 
      {0.009074243275550523, 0.03515966806948373}, 
      {0.00912129258110007, 0.02886710124255839}, {0.009209288498818146, 
       0.017003575296074595}, {0.009263781864770183, 
       0.010739422329266411}, {0.009314719592312263, 
       0.006148867893694985}, {0.009367850371217498, 
       0.0028105779397539195}, {0.009396013646960657, 
       0.0016219031383564338}, {0.009426242457488805, 
       0.0007482890216677154}, {0.009479862032756725, 
       0.00004644375859445769}, {0.009530720274051538, 
       0.00008746828406169147}, {0.009576374801671185, 
       0.0004317083667858038}, {0.009626098990466889, 
       0.000882169732000209}, {0.009680041071221984, 
       0.0012383997052032509}, {0.009710771185226988, 
       0.0013266151170240508}, {0.00973965688397536, 
       0.0013243304805745626}, {0.009769943762368227, 
       0.0012388903037153594}, {0.009797747735794208, 
       0.0010981759130052721}, {0.00986044796867134, 
       0.0006551353869711019}, {0.00991516287407405, 
       0.0002722691542341227}, {0.009966131626346155, 
       0.00004566714777079829}, {0.010019302356578939, 
       0.0000147906214521049}, {0.01004743983873891, 
       0.00008718153410355067}, {0.010077537000951374, 
       0.00022284215811309928}, {0.010133465756892222, 
       0.0005775169937214983}, {0.010185856741472444, 
       0.000922823530706023}, {0.010240498530215997, 
       0.0011600394181707802}, {0.010269492588767902, 
       0.0011975169647091169}, {0.010300679513038997, 
       0.0011567576045531647}, {0.01035583277427275, 
       0.0008893335860713493}, {0.01040825726690149, 
       0.00048641761459554487}, {0.010455314400380703, 
       0.00014451340616475114}, {0.010506675640299317, 
       3.954482434790779*^-6}, {0.010538252416452615, 
       0.0001443442633557748}, {0.010567997267583808, 
       0.0004976415108911707}, {0.010594704864496873, 
       0.0010336397165434119}, {0.010623593169294863, 
       0.0018764365407027772}, {0.010655159257360039, 
       0.0031343278610908563}, {0.010688505291456974, 
       0.004856766447513954}, {0.010748223154469553, 
       0.008898338010960079}, {0.010856448349398098, 
       0.01829188897735183}, {0.010916024402972322, 
       0.023478203412321638}, {0.010945338596707483, 
       0.025716851222401194}, {0.010972458028132856, 
       0.027491805893950623}, {0.011024717919330417, 
       0.029857219736013598}, {0.011052281073820145, 
       0.030438223651627218}, {0.011081561311533547, 
       0.030494052005958082}, {0.011128844158521613, 
       0.02931909682008315}, {0.011181031435919966, 
       0.026279451397070965}, {0.01122936316608563, 0.02209684312262079}, 
      {0.011281461230827993, 0.01662604089668822}, 
      {0.011375739018253814, 0.006561016482147912}, 
      {0.01142946600895676, 0.002292137092328627}, 
      {0.011459910059366652, 0.0007673681728796934}, 
      {0.011488232371735088, 0.00006790261303227512}, 
      {0.011518234076957339, 0.00016656331588751552}, 
      {0.01154549255921414, 0.001050789232535938}, 
      {0.011576957446041782, 0.003032125796755233}, 
      {0.01160666011202403, 0.00582897730331365}, {0.01165951845354211, 
       0.012834881059538752}, {0.011708250875997743, 
       0.021139257759141918}, {0.011818371175523883, 
       0.04251569669703871}, {0.011870999819802375, 
       0.051722269046211106}, {0.011920958792847637, 
       0.058508409817351906}, {0.011965804830953433, 
       0.062362140623931715}, {0.012014688263414968, 
       0.06372745803755664}, {0.012067693216400298, 0.06169014652490622}, 
      {0.0120973069897351, 0.05901793832538149}, {0.01212412028075966, 
       0.0557402038774997}, {0.012176396510302048, 0.047398877096464696}, 
      {0.012225575137864231, 0.03792568332651512}, 
      {0.012314687771775735, 0.01992639543146163}, 
      {0.012363341734608155, 0.01140106116925863}, 
      {0.012408701428581165, 0.005249320919153343}, 
      {0.01245788551804743, 0.0011353624685448275}, 
      {0.012511797746609583, 0.00008886606667967383}, 
      {0.012557545557669773, 0.002074481968085779}, 
      {0.012606519396601857, 0.006846172632762109}, 
      {0.012718284390841017, 0.0246498770583208}, {0.01277719429978162, 
       0.03521743483108506}, {0.012839691732639628, 
       0.045030241458656535}, {0.012894229543845176, 
       0.051182769770610016}, {0.012925256741729256, 
       0.05336673744798651}, {0.012954344981222107, 0.054452765259348}, 
      {0.013005358259748632, 0.0540492404292923}, {0.013060274443917089, 
       0.05048465938624826}, {0.013110522475894493, 0.04482045650061629}, 
      {0.013165411167597339, 0.036781268869818855}, 
      {0.01327594858388565, 0.018793948222812707}, 
      {0.013325476433936329, 0.011692373442891979}, 
      {0.01337831437238419, 0.005712627453884497}, 
      {0.013428176948263456, 0.001959664181200103}, 
      {0.013473420612179059, 0.0002602527474346086}, 
      {0.01352376424434206, 0.00019732826001979173}, 
      {0.013570799335940086, 0.0016374721972180206}, 
      {0.013622404771619414, 0.004455271157959763}, 
      {0.013677767162297056, 0.008292713475387518}, 
      {0.01373086734733899, 0.012108247646408263}, 
      {0.013758884764697723, 0.013969395803811416}, 
      {0.013788671795443748, 0.015725339819228093}, 
      {0.01384326508924504, 0.018127515369607775}, 
      {0.013893812109784905, 0.01921871468670287}, 
      {0.013943394781015736, 0.019167827164404776}, 
      {0.013989978073697826, 0.018178225956342803}, 
      {0.014041078283283062, 0.016231902257131305}, 
      {0.01409620543337429, 0.01344337269210371}, {0.014191838496046574, 
       0.00807218585661449}, {0.01428087906047705, 
       0.0038224741624621637}, {0.014332093447615296, 
       0.002074912136305716}, {0.014386847191209364, 
       0.0008373981807591411}, {0.014418088086935212, 
       0.00040355790268216065}, {0.014447603314241263, 
       0.0001508141408108865}, {0.01450284916905472, 
       3.6448753287706444*^-7}, {0.014531177981336279, 
       0.000038679675152648165}, {0.014561192429594961, 
       0.00012927670464994934}, {0.014615025462697532, 
       0.00034020373739521924}, {0.01464294076983763, 
       0.0004407637338297666}, {0.014672952250574255, 
       0.0005237345856694198}, {0.01470588502173238, 
       0.0005744872158121641}, {0.014736719116981364, 
       0.0005798367103436118}, {0.014790302802780575, 
       0.0004998520293119105}, {0.01482062416223627, 
       0.0004169808213180419}, {0.01484875811253657, 
       0.00032714703073523474}, {0.014904598950022826, 
       0.00014941554281345745}, {0.014955200319426622, 
       0.00003517867009487207}, {0.015005019769860128, 
       4.475535529312482*^-7}, {0.015051925350260651, 
       0.000046331043955752863}, {0.015101444015404284, 
       0.00016255867337327067}, {0.015154978990708692, 
       0.0003257065004885957}, {0.01520720550004012, 
       0.00046729892442318486}, {0.015254796752932271, 
       0.0005365411350248795}, {0.015309730461021083, 
       0.0005120188069005803}, {0.015361740447222593, 
       0.00038608776998072785}, {0.0154065717146562, 
       0.00022814111264654848}, {0.015454171858533459, 
       0.00006920693116446674}, {0.015506382313436037, 
       1.6576365198395139*^-6}, {0.01555465945386063, 
       0.00014259202050042385}, {0.015606434886699957, 
       0.0006196145435699262}, {0.015635543375412224, 
       0.001068963281913425}, {0.015662216933918907, 
       0.0016058663520848444}, {0.015711391915909603, 
       0.002913361768614872}, {0.01576313501216652, 
       0.004696861083300678}, {0.015874361840505353, 
       0.009341500891128474}, {0.015935465967094546, 
       0.011770919838126248}, {0.015965470407672287, 
       0.012767695585628264}, {0.015993118896930825, 
       0.013516863048961304}, {0.01604822529017801, 
       0.014400528226382993}, {0.0160772339923851, 0.014490096360326865}, 
      {0.01610792834583359, 0.014281217759488448}, 
      {0.016157590563334857, 0.013284047437008175}, 
      {0.016212187602889432, 0.011340022421780095}, 
      {0.016318658112285316, 0.006011622209217016}, 
      {0.01636519033553173, 0.0036556690356496662}, 
      {0.01641588622864671, 0.0015478657099425913}, 
      {0.016446563840224068, 0.0006507336635851735}, 
      {0.01647499086675132, 0.0001470574000623353}, 
      {0.016502160212001526, 1.1237639571794869*^-6}, 
      {0.01653106912290259, 0.00023695207076286672}, 
      {0.016564527775130417, 0.0010365950146325935}, 
      {0.0165959880239387, 0.002305963221037952}, {0.016624237571950255, 
       0.003855962112204184}, {0.016654738144047478, 
       0.005927960326141118}, {0.01676263125154957, 
       0.015572570787342241}, {0.016821968958513032, 
       0.02133181057464037}, {0.016878074635071027, 0.02615994637234992}, 
      {0.016930144868076234, 0.029538208180830774}, 
      {0.01695953692049121, 0.0308149102799065}, {0.016986678913941265, 
       0.0315311096595181}, {0.017034648537083728, 0.031637931939452434}, 
      {0.017085513848971626, 0.03012458528562931}, 
      {0.017132994045817015, 0.027327790837135577}, 
      {0.017177484714236246, 0.023722695587609963}, 
      {0.017278810465269044, 0.013646546071120993}, 
      {0.017335416622226422, 0.008150754885140951}, 
      {0.017389238850191887, 0.0038771193530975716}, 
      {0.017437550106414006, 0.0012642829255131917}, 
      {0.017490296588099037, 0.00003076832902151407}, 
      {0.017520240744725808, 0.00013326532514550623}, 
      {0.017547397407017638, 0.0007235797159447762}, 
      {0.017578745339053445, 0.0019612487138503973}, 
      {0.01760828380269597, 0.003621287815314736}, 
      {0.017660908841803942, 0.007540035008618534}, 
      {0.017717848487477456, 0.012659802031647634}, 
      {0.017773798616722694, 0.017885586059189204}, 
      {0.017833791810198243, 0.02289553540314751}, 
      {0.017862867562834134, 0.02487678354394139}, 
      {0.017890418232340242, 0.02639600446141966}, 
      {0.017942060954366363, 0.028154108516546126}, 
      {0.01799614755448026, 0.028338086542745777}, 
      {0.018026711637431213, 0.02769144116341793}, 
      {0.018054996174486564, 0.02664150912275918}, 
      {0.01808356676309834, 0.025182756087563117}, 
      {0.018115110665108042, 0.023173218497492022}, 
      {0.018178989921156272, 0.01818698939895009}, 
      {0.018284298010951355, 0.009246873694302073}, 
      {0.0183396050089076, 0.005243293690761548}, {0.0183697732616562, 
       0.0034681566006175947}, {0.018397847726373345, 
       0.002127001409865172}, {0.018449038878913648, 
       0.0005179270453601453}, {0.018476115591163855, 
       0.00011153978142376772}, {0.018505048979273082, 
       4.849499292975577*^-6}, {0.01855655331053922, 
       0.0005701453637539741}, {0.018603362882349435, 
       0.001763056040245399}, {0.018690822344383705, 
       0.00495943001920912}, {0.018772667176758868, 
       0.007974133306942644}, {0.018813815660482888, 
       0.009152391678414758}, {0.018858031750174618, 
       0.010025507154102806}, {0.018907105232591426, 
       0.010448946617785388}, {0.018951955315316536, 
       0.010324573524583594}, {0.018992883863274978, 
       0.009818814684519615}, {0.01903084068527427, 
       0.009067580705398606}, {0.019116854697297108, 
       0.006704348237761097}, {0.019192114734997257, 
       0.0044058801893407835}, {0.019273437951281926, 
       0.002261309130339517}, {0.019323005205526274, 
       0.0012874157059200061}, {0.019368560208365432, 
       0.0006494549634133251}, {0.019412112256113462, 
       0.0002604669178962762}, {0.019458073864440453, 
       0.000051481040229213295}, {0.019499348255026593, 
       1.0694814351859527*^-8}, {0.019537840000636596, 
       0.000030605916464191357}, {0.01958007452505866, 
       0.00011137361918178522}, {0.01962530138859999, 
       0.00021057889212153322}, {0.019673586800526693, 
       0.00029213017841279976}, {0.019726054279645053, 
       0.00032468432901387}, {0.019775603515295156, 
       0.0002967889976334772}, {0.019821396868959004, 
       0.0002318330606411854}, {0.019999998333333335, 
       2.7777782369574106*^-14}}]}}, {RGBColor[0, 0, 1], 
   {Line[{{-0.019999998333333335, 2.7777782464574337*^-14}, 
      {-0.01995062291358608, 0.00002449393986772671}, 
      {-0.01990569967266004, 0.00008966505530267814}, 
      {-0.01985384480370453, 0.0002161613801514024}, 
      {-0.01980482602704684, 0.0003865303499222596}, 
      {-0.019717640433048928, 0.0008116968633561203}, 
      {-0.019623003192812842, 0.0014489936522574165}, 
      {-0.01951878231055126, 0.002358102614670713}, 
      {-0.01940829636756231, 0.0035496975782201693}, 
      {-0.019210073169479192, 0.006226112234136956}, 
      {-0.01837732033708337, 0.021771591696428713}, 
      {-0.01797161919578716, 0.028695845075276467}, 
      {-0.01785478149049712, 0.030229385565612627}, 
      {-0.017743716312371486, 0.03143309558831541}, 
      {-0.01764402253069804, 0.032280765830763586}, 
      {-0.01758798891317527, 0.03265425780579856}, 
      {-0.017535202209750092, 0.032935648360594795}, 
      {-0.017504918398514546, 0.033065563315841345}, 
      {-0.017472159471834333, 0.0331798322442209}, 
      {-0.01744238911290686, 0.033259761855799035}, 
      {-0.01741499896254301, 0.03331301836338355}, 
      {-0.01738529360025369, 0.03334865652415788}, 
      {-0.017352687266179494, 0.03336112982025049}, 
      {-0.017318641692256397, 0.03334426393682766}, 
      {-0.017286857113185224, 0.033300879441629974}, 
      {-0.01725696735110019, 0.03323570324737525}, 
      {-0.01722865209205941, 0.03315217412833019}, 
      {-0.01717558232280223, 0.0329386738826732}, {-0.017118446488587135, 
       0.03262632306907179}, {-0.017056294939917584, 
       0.03219064954315331}, {-0.01694329924407469, 0.031149292815916}, 
      {-0.016823255523087288, 0.02970782439445076}, 
      {-0.01660764800562505, 0.026347602273044536}, 
      {-0.016204721670335896, 0.018195320550886518}, 
      {-0.01578050855268939, 0.009025555600737433}, 
      {-0.015605393923289372, 0.005735070754113726}, 
      {-0.015418315955389618, 0.0028772070053596347}, 
      {-0.01531078239974494, 0.0016272379544350032}, 
      {-0.01521307405629948, 0.0007799934344464839}, 
      {-0.015165942925495356, 0.0004771603013091515}, 
      {-0.015114850924839433, 0.00023055113024776666}, 
      {-0.015066605192079287, 0.00007812531742240692}, 
      {-0.015022122069375646, 8.674030577513332*^-6}, 
      {-0.014975309339231975, 0.000010872739203602382}, 
      {-0.014925018683573611, 0.0001008823078882128}, 
      {-0.014877546709405054, 0.00027044635418142456}, 
      {-0.01483417061772993, 0.0004980629481553756}, 
      {-0.014783426896472482, 0.0008531718938063263}, 
      {-0.014728110762038109, 0.0013499603690639266}, 
      {-0.01462742357382112, 0.0025480457699544705}, 
      {-0.014522401385168351, 0.004197915997537606}, 
      {-0.01441059053787315, 0.006391233214701222}, 
      {-0.014209549010984241, 0.011393113392751543}, 
      {-0.01374984882821708, 0.026801364576453723}, 
      {-0.013333590468334593, 0.04273525094516589}, 
      {-0.01293945938668809, 0.056017893771423216}, 
      {-0.01274108344186723, 0.06099358447316295}, 
      {-0.01262854641010312, 0.06311859547877288}, 
      {-0.012523621348746251, 0.06458694304340656}, 
      {-0.012464389017192242, 0.06518397191904264}, 
      {-0.012435262757417161, 0.06541413173212102}, 
      {-0.012408350693033464, 0.06558902982755757}, 
      {-0.01235804176042579, 0.06581747387281403}, 
      {-0.012303388490915855, 0.06591832563395857}, 
      {-0.01224897213909575, 0.06586455815617463}, 
      {-0.01221801286519793, 0.06576484703275749}, 
      {-0.01218898617478003, 0.06562569333414286}, 
      {-0.012158474254126478, 0.06543174527295764}, 
      {-0.012130535376207258, 0.06521133000967427}, 
      {-0.012067608025325131, 0.06456547227897387}, 
      {-0.011969995954711599, 0.06315868422260697}, 
      {-0.011863361083221417, 0.06107410626325127}, 
      {-0.011648606573335574, 0.055264739933872466}, 
      {-0.011188314256390136, 0.037336709881991066}, 
      {-0.010754340943049834, 0.018249884859936956}, 
      {-0.010564945215050331, 0.01096529920479747}, 
      {-0.010364692299718696, 0.004866154698015635}, 
      {-0.010260041035963612, 0.0025466983566502966}, 
      {-0.010200607639498257, 0.0015388690850991359}, 
      {-0.010145076079377646, 0.0008157137899537373}, 
      {-0.010094066807947326, 0.0003469722111131401}, 
      {-0.010047520019254443, 0.0000894471253281639}, 
      {-0.009993792648569604, 1.543155843856651*^-6}, 
      {-0.009942854045420203, 0.00013207548153188012}, 
      {-0.009894388429102792, 0.0004550588257681732}, 
      {-0.009848851276293064, 0.0009392727947245052}, 
      {-0.009798898766833623, 0.0016758008530908387}, 
      {-0.009745005804476833, 0.0027154207087148633}, 
      {-0.009635307651992454, 0.0056307685890708194}, 
      {-0.009534645797236846, 0.00925990228489281}, 
      {-0.009350595896133221, 0.01824627828816914}, 
      {-0.009156664834732592, 0.03087108710824515}, 
      {-0.00874807429564786, 0.06635826417244808}, 
      {-0.00830076251937985, 0.11286196656212723}, 
      {-0.008097882130450115, 0.13371225263494574}, 
      {-0.007877772620292246, 0.15423812305470339}, 
      {-0.007683726129349469, 0.1693386795575538}, 
      {-0.007577542529330227, 0.17604032584365975}, 
      {-0.007478118295497148, 0.18114798066525523}, 
      {-0.0074185524981611505, 0.18362171732501115}, 
      {-0.0073640816790574055, 0.18547775227963714}, 
      {-0.007303584056119472, 0.18706684615406804}, 
      {-0.007270229527135402, 0.18772436437867995}, 
      {-0.007238538863313978, 0.18820211567965328}, 
      {-0.007183699088081748, 0.18868469719209752}, 
      {-0.007132811765943785, 0.18873577317415816}, 
      {-0.007103515937280748, 0.18858961653931108}, 
      {-0.007076966944399576, 0.18834541155985443}, 
      {-0.007046320235611725, 0.18793067908932856}, 
      {-0.007017463892583785, 0.18740951781600193}, 
      {-0.006966461646689362, 0.1861774188897389}, 
      {-0.006912606626313296, 0.1844447272351492}, 
      {-0.006816181489794561, 0.1802395257311132}, 
      {-0.006712408081134373, 0.17415835008548364}, 
      {-0.006598557697506513, 0.16570075661854108}, 
      {-0.006142056505353044, 0.11612966064770454}, 
      {-0.005709819841281151, 0.05782597313061597}, 
      {-0.005521621972626586, 0.0344375459467983}, 
      {-0.0053217859315004565, 0.014426250073371786}, 
      {-0.005217570237765347, 0.006912184614900525}, 
      {-0.00515825348817167, 0.0037525755559080537}, 
      {-0.00513113306437104, 0.002606602906155784}, 
      {-0.005102594209982923, 0.0016148121254127763}, 
      {-0.005051682622999575, 0.00041852779841805414}, 
      {-0.005005026372287843, 4.034178510788827*^-6}, 
      {-0.004954806860789795, 0.0003326862259444307}, 
      {-0.004899900581675211, 0.0016671544699381987}, 
      {-0.004846877924164093, 0.003979889832545942}, 
      {-0.004816980290895975, 0.005748979923411046}, 
      {-0.004789428199179278, 0.00768701100550325}, 
      {-0.004739776833413644, 0.011949854857283835}, 
      {-0.00468518771292842, 0.017825343423411508}, 
      {-0.00459044575849865, 0.031143376544546714}, 
      {-0.004490191138606829, 0.04982417982923025}, 
      {-0.004381174007564097, 0.07586108462857616}, 
      {-0.004264116421218343, 0.11087864742401937}, 
      {-0.00405271162683652, 0.19392275500125117}, 
      {-0.003841428901767868, 0.30395156886142677}, 
      {-0.0036409499472223957, 0.43436166498061357}, 
      {-0.003264904467718927, 0.7473574973909493}, 
      {-0.002430769720482443, 1.711554041531675}, 
      {-0.0016577723987630632, 2.7472051852393364}, 
      {-0.0012123495320749801, 3.28377095806294}, 
      {-0.0009940137532953128, 3.5062134968563288}, 
      {-0.000793499947807327, 3.679361360261651}, 
      {-0.0006140325670606325, 3.805433394321044}, 
      {-0.0004173973105389425, 3.909130876823482}, 
      {-0.0003150829996867713, 3.9480148468254463}, 
      {-0.0002197371800570113, 3.9746486046183156}, 
      {-0.00016702115843465976, 3.985337643450124}, 
      {-0.00011904360665739576, 3.9925460466280414}, 
      {-0.00006366331982521646, 3.9978670317820644}, 
      {-0.000011295666890567935, 3.999932838666644}, 
      {0.000036850674650272586, 3.9992852431666503}, 
      {0.00008865830929221276, 3.9958642176349}, {0.00013756541570809363, 
       3.9900485949459656}, {0.0001823256883485358, 3.982532357053415}, 
      {0.00023459951077176844, 3.9711135185895934}, 
      {0.00029167653537498826, 3.955418269505541}, 
      {0.00039565706172741576, 3.9182742878506525}, 
      {0.0005039403184548804, 3.868097215520701}, {0.0006194108355433191, 
       3.802079099651979}, {0.0008272071771541958, 3.6525398665256352}, 
      {0.0012332789746763299, 3.260810364626318}, {0.0016015767110234014, 
       2.819502980809354}, {0.0024776085425797165, 1.650246839988693}, 
      {0.002861899250930687, 1.1741944500459536}, {0.0032838503997704937, 
       0.729513110869524}, {0.00348021429044117, 0.5573742288117597}, 
      {0.003690783270356228, 0.39955544366392004}, 
      {0.003872777353799739, 0.285865847542497}, {0.004070809533001731, 
       0.1857766231599684}, {0.00418679344342892, 0.13821973501126222}, 
      {0.004294134864304377, 0.10117841243007997}, 
      {0.004394710852689436, 0.07229106449052507}, 
      {0.004505761847712384, 0.04660050132756052}, 
      {0.004604942149654922, 0.028839986974076748}, 
      {0.004698082767112827, 0.016322199250440712}, 
      {0.004749376342457093, 0.011046843594072615}, 
      {0.00479642096064867, 0.007166740022441592}, 
      {0.004848069271083908, 0.003916462655916429}, 
      {0.004902463086642568, 0.0015813411502450037}, 
      {0.004954247334192622, 0.00034104979450419714}, 
      {0.0049834590461726785, 0.000044066003653013514}, 
      {0.005010400961506868, 0.000017236767468612332}, 
      {0.005059905338849567, 0.000560403915678057}, 
      {0.005112332827198783, 0.0019280302477469727}, 
      {0.005159247151988901, 0.0037982265312595156}, 
      {0.005203152943100283, 0.00606475249708908}, 
      {0.005303086388093891, 0.012908599747249151}, 
      {0.005410903617068988, 0.02255949320939532}, 
      {0.0055094490360629, 0.033049227286745905}, {0.005731212230501248, 
       0.06065673776805539}, {0.006104722280287862, 0.11125797126477108}, 
      {0.006309645273643067, 0.1367795854830374}, {0.006502499743514363, 
       0.15719705170440404}, {0.006606989817830583, 0.16638893351736506}, 
      {0.006719906222252427, 0.17465074591080174}, 
      {0.006822517104232605, 0.18055896712339148}, 
      {0.006871316367280527, 0.18281659580658946}, 
      {0.006916829012662958, 0.1845965821218348}, {0.006963496052953807, 
       0.18609354140255938}, {0.007006002969128318, 0.18716727766752855}, 
      {0.00705322041721977, 0.18803650714353198}, {0.007103786958729075, 
       0.18859156047981526}, {0.007152369327164682, 0.18876173840192023}, 
      {0.00720516335968318, 0.18854821035106326}, {0.007255021130705905, 
       0.18797164161019428}, {0.007301103016007646, 0.18712116263174072}, 
      {0.007351022791826975, 0.18586340606938584}, 
      {0.007404782473240815, 0.1841281809106107}, {0.00750202012994773, 
       0.1800292634357081}, {0.0076176544759945205, 0.17365296562694604}, 
      {0.0077235704339740354, 0.16651979083414176}, 
      {0.00817193771121928, 0.12624785046416737}, {0.008589598512913492, 
       0.08240996182256356}, {0.008818996006515551, 
       0.059497081232158626}, {0.009035344043111456, 
       0.04027784778604566}, {0.009237294093782638, 
       0.025245302234622197}, {0.009343580930547013, 
       0.018647859994054918}, {0.009455995637152017, 
       0.012731236943217327}, {0.00955069251963398, 
       0.008620040363687461}, {0.009654754445420166, 
       0.005035132823833321}, {0.009700398190221437, 
       0.003770801981058355}, {0.009749383693847686, 
       0.0026213908654367547}, {0.009791398970340754, 
       0.0018051574251959082}, {0.009837827972882164, 
       0.0010832030119446695}, {0.009889601683153743, 
       0.0004976576000481722}, {0.009944666636503964, 
       0.00012378803876470586}, {0.00999567945973432, 
       7.473265246436766*^-7}, {0.010043624810310159, 
       0.00007544619901602336}, {0.010070986219519157, 
       0.00019859855244709545}, {0.010099825552764894, 
       0.0003902528671309389}, {0.010151412851998708, 
       0.0008872006719158288}, {0.01020693597222122, 
       0.0016349048067606248}, {0.010267739817130077, 
       0.002694235144101457}, {0.010369744234205351, 
       0.004994585795320941}, {0.010478839955631966, 
       0.008103461678750075}, {0.01067546339333394, 
       0.015074976979574465}, {0.01144005723267003, 0.04786655545670446}, 
      {0.011648434661535185, 0.05525929580133537}, 
      {0.011869295912706178, 0.061204737443146806}, 
      {0.011984579133733912, 0.06339976562238163}, 
      {0.012050133454842706, 0.06434959889653605}, 
      {0.01211153384803401, 0.06503807624305424}, {0.012140381182229092, 
       0.0652936724210948}, {0.012167798008067544, 0.06549619477954222}, 
      {0.012219265609648509, 0.0657698573814199}, {0.012274668437285703, 
       0.06590920725097375}, {0.012306025450579995, 0.0659170109123516}, 
      {0.012335131528307225, 0.06587854040363193}, 
      {0.012388269971136805, 0.06569568215670465}, 
      {0.012418204502479858, 0.06552922476501458}, 
      {0.012445740404404795, 0.06533620516075873}, 
      {0.012496404916798685, 0.06488254259660856}, 
      {0.012549919942320499, 0.06426744192468858}, 
      {0.012642751856853002, 0.06288085744642385}, 
      {0.012744629969187838, 0.06091787676232593}, 
      {0.012970375772674566, 0.05511822394156315}, 
      {0.013181089114124142, 0.048273714494011834}, 
      {0.013964044080625822, 0.0190763492069536}, {0.01417854884932243, 
       0.012275725874544516}, {0.014406389423122086, 
       0.006482168036805567}, {0.014500004773834205, 
       0.0046017251310223285}, {0.014600903277888854, 
       0.0029264076425372975}, {0.014658674283936884, 
       0.002135699385471796}, {0.014711633099485399, 
       0.0015200974187569733}, {0.01476609309374641, 
       0.0009965194028732792}, {0.01481556762474457, 
       0.0006170961618190066}, {0.014867582815900943, 
       0.00031656698706230917}, {0.014896163792888483, 
       0.00019408521797262517}, {0.01492314086215264, 
       0.00010602124420289107}, {0.014971160230346168, 
       0.000014841750081109606}, {0.01502320510871238, 
       9.542699281990084*^-6}, {0.01505054170366337, 
       0.000045093037199231356}, {0.015080606238969459, 
       0.00011417955446880364}, {0.015112000228294209, 
       0.00021934961802922687}, {0.015141366199488696, 
       0.00034775918044886766}, {0.015193883231982933, 
       0.0006481171576345596}, {0.015250291146207304, 
       0.001068590936175492}, {0.015372979120765759, 
       0.002311787443579106}, {0.015489429729681906, 
       0.0038693356995966027}, {0.01570789341225904, 
       0.007602029166645642}, {0.016117282953927628, 
       0.016264847540744604}, {0.01655305180015665, 
       0.025361171018731893}, {0.01677853728322814, 
       0.029088041217458855}, {0.016889082842192222, 
       0.030539547816007064}, {0.016990636551045303, 
       0.031623984689089245}, {0.017083319109432567, 
       0.03239225808101023}, {0.01713054127010306, 0.032699535590784284}, 
      {0.01718108742300617, 0.03296426354560106}, {0.017231880795005903, 
       0.03316276847253496}, {0.01727922941881165, 0.03328649264710458}, 
      {0.017308164385595015, 0.033332914196038996}, 
      {0.017335533823444445, 0.03335645548637087}, 
      {0.01738679316221708, 0.03334741113003739}, {0.017431247267124122, 
       0.03328377899108984}, {0.017480241903320714, 0.03315419168150635}, 
      {0.017531407402703075, 0.03295319696098739}, 
      {0.017579369760814593, 0.03270492283249709}, 
      {0.01766504898545642, 0.032121187917298094}, 
      {0.017757272370112574, 0.03130038537934821}, 
      {0.01796734544904773, 0.028756385493132537}, 
      {0.018159666265776656, 0.025741614568788523}, 
      {0.018577746871942268, 0.01783115189441019}, 
      {0.019023716044070004, 0.009277892515360351}, 
      {0.019240356362974484, 0.0057759053033181445}, 
      {0.019444570194758707, 0.0031334181177511836}, 
      {0.019533703080787782, 0.0022148978189541566}, 
      {0.01962792744488528, 0.0014113673377503643}, 
      {0.019677173297836626, 0.0010619625059693646}, 
      {0.019731262070259322, 0.0007349822087938913}, 
      {0.019777160243899125, 0.0005045191395058221}, 
      {0.019826394027229646, 0.0003054771253361796}, 
      {0.019873329434841668, 0.00016216343688593671}, 
      {0.019916150519581288, 0.00007083503183493116}, 
      {0.019959195489382315, 0.000016714566445571027}, 
      {0.019999998333333335, 2.7777782464574337*^-14}}]}}}, 
 {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
  DisplayFunction :> $DisplayFunction, ColorOutput -> Automatic, 
  Axes -> Automatic, AxesOrigin -> Automatic, PlotLabel -> None, 
  AxesLabel -> None, Ticks -> Automatic, GridLines -> None, Prolog -> {}, 
  Epilog -> {}, AxesStyle -> Automatic, Background -> Automatic, 
  DefaultColor -> Automatic, DefaultFont :> $DefaultFont, 
  RotateLabel -> True, Frame -> False, FrameStyle -> Automatic, 
  FrameTicks -> Automatic, FrameLabel -> None, PlotRegion -> Automatic, 
  ImageSize -> Automatic, TextStyle :> $TextStyle, 
  FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell["On suppose les fentes 10 fois plus hautes que larges:", "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Plot3D[\(intensite(
          x)\)\ \(FD(10\ e, y\/\(lambda0\ f\))\)\^2, {x, \(-0.008\), 
        0.008}, {y, \(-0.008\), 0.008}, PlotRange \[Rule] {0, 4}, 
      PlotPoints \[Rule] 150, Mesh \[Rule] False]\)], "Input",
  CellLabel->"In[64]:="],

Cell[OutputFormData["\<\
SurfaceGraphics[{{2.1758362261602974*^-34, 2.0694610858496655*^-34, 
   1.4997092255892222*^-34, 7.24810323789944*^-35, 
   1.2926920045116922*^-35, 3.69851848979144*^-36, 
   5.412765652581351*^-35, 1.443900542699342*^-34, 
   2.341576381446861*^-34, 2.8207102554703292*^-34, 
   2.6614017242610143*^-34, 1.9443909888949745*^-34, 
   1.005072112224057*^-34, 2.601732013394972*^-35, 
   2.645137417527001*^-38, 2.573200912557385*^-35, 
   8.125673961777189*^-35, 1.3313936299351575*^-34, 
   1.544100089126483*^-34, 1.3719438413769495*^-34, 9.3627060020815*^-35, 
   4.59742465647817*^-35, 1.2927142841023767*^-35, 
   4.831432564849239*^-37, 2.080488644714396*^-36, 
   6.341186323213396*^-36, 6.078497604000305*^-36, 
   2.1357222805033974*^-36, 1.0975182095446143*^-38, 
   2.901416568890392*^-36, 7.642356953752511*^-36, 
   7.789086367368493*^-36, 2.1439619528891603*^-36, 
   1.62354563394589*^-36, 2.6869095793164583*^-35, 9.47593793294447*^-35, 
   2.008498803379768*^-34, 3.1065580137737195*^-34, 
   3.7041817487142476*^-34, 3.370764886250317*^-34, 
   2.131585100818672*^-34, 6.41647599491192*^-35, 8.348430555816106*^-37, 
   1.265033384247667*^-34, 4.721767774379992*^-34, 
   9.557893756520413*^-34, 1.3967134266433613*^-33, 
   1.5910850540013017*^-33, 1.4189981103176235*^-33, 
   9.297896946907687*^-34, 3.5289023812835124*^-34, 
   1.3139249421887256*^-35, 1.7849334113108643*^-34, 
   9.100407383553077*^-34, 1.994697896695052*^-33, 
   3.0093558718312085*^-33, 3.502743782717428*^-33, 
   3.217430495666332*^-33, 2.2432033453653408*^-33, 
   1.0150745877533554*^-33, 1.3886644457215018*^-34, 
   1.1338817104908128*^-34, 1.0775867807186148*^-33, 
   2.710570680405268*^-33, 4.3470645944463014*^-33, 
   5.268690107524076*^-33, 5.041517531846431*^-33, 
   3.7388243634654424*^-33, 1.934435462821154*^-33, 
   4.576779292639444*^-34, 1.6359577371080328*^-35, 
   8.625759140411538*^-34, 2.6619364480594677*^-33, 
   4.634094615896171*^-33, 5.904363356817954*^-33, 
   5.904363356818086*^-33, 4.634094615896507*^-33, 
   2.6619364480598577*^-33, 8.625759140414277*^-34, 
   1.635957737112059*^-35, 4.576779292637429*^-34, 
   1.9344354628208115*^-33, 3.7388243634651195*^-33, 
   5.041517531846272*^-33, 5.268690107524148*^-33, 
   4.3470645944465696*^-33, 2.7105706804056065*^-33, 
   1.0775867807188781*^-33, 1.1338817104917449*^-34, 
   1.3886644457205201*^-34, 1.015074587753134*^-33, 
   2.243203345365111*^-33, 3.217430495666202*^-33, 3.50274378271745*^-33, 
   3.0093558718313682*^-33, 1.994697896695271*^-33, 
   9.100407383554958*^-34, 1.7849334113117628*^-34, 
   1.3139249421864428*^-35, 3.5289023812825113*^-34, 
   9.297896946906582*^-34, 1.4189981103175573*^-33, 
   1.591085054001305*^-33, 1.3967134266434284*^-33, 
   9.557893756521384*^-34, 4.721767774380844*^-34, 
   1.2650333842481337*^-34, 8.348430555851051*^-37, 
   6.416475994909463*^-35, 2.1315851008183726*^-34, 
   3.3707648862501593*^-34, 3.704181748714283*^-34, 
   3.106558013773897*^-34, 2.008498803379991*^-34, 
   9.475937932946213*^-35, 2.686909579317333*^-35, 
   1.6235456339475698*^-36, 2.143961952887994*^-36, 
   7.789086367367833*^-36, 7.64235695375322*^-36, 
   2.9014165688913488*^-36, 1.0975182095515552*^-38, 
   2.135722280502636*^-36, 6.078497603999761*^-36, 
   6.341186323213871*^-36, 2.0804886447152914*^-36, 
   4.8314325648424204*^-37, 1.2927142841019464*^-35, 
   4.597424656477355*^-35, 9.36270600208055*^-35, 1.371943841376884*^-34, 
   1.5441000891264858*^-34, 1.3313936299352383*^-34, 
   8.125673961778384*^-35, 2.573200912558302*^-35, 
   2.6451374175608384*^-38, 2.6017320133939076*^-35, 
   1.0050721122238843*^-34, 1.9443909888948048*^-34, 
   2.6614017242609236*^-34, 2.8207102554703613*^-34, 
   2.3415763814470033*^-34, 1.4439005426995277*^-34, 
   5.412765652582788*^-35, 3.6985184897955204*^-36, 
   1.292692004510966*^-35, 7.248103237897933*^-35, 
   1.4997092255890747*^-34, 2.069461085849591*^-34, 
   2.1758362261603265*^-34}, {0.00002272100856793362, 
   0.00002161019404735814, 0.000015660602463703744, 
   7.568778099636622*^-6, 1.3498840472033585*^-6, 3.8621505279148376*^-7, 
   5.652240425537306*^-6, 0.00001507782442790288, 0.00002445173785860369, 
   0.00002945505783553307, 0.00002779149030272323, 
   0.000020304158827274223, 0.00001049539105869798, 
   2.716839376837332*^-6, 2.762165148479567*^-9, 2.6870459861956396*^-6, 
   8.485174825477563*^-6, 0.000013902979327829403, 
   0.00001612415076694528, 0.000014326421906146233, 
   9.776936367483069*^-6, 4.800826631819033*^-6, 1.349907312500845*^-6, 
   5.045187656198429*^-8, 2.1725348513689961*^-7, 6.621736831491681*^-7, 
   6.347426082907773*^-7, 2.2302121662749377*^-7, 1.1460752579955075*^-9, 
   3.029782753329638*^-7, 7.980474621099786*^-7, 8.133695724041886*^-7, 
   2.2388163831099636*^-7, 1.6953754982015884*^-7, 2.805785418907469*^-6, 
   9.89517797226788*^-6, 0.000020973599929811132, 0.00003244000187104867, 
   0.0000386806434408172, 0.00003519896255985074, 0.00002225891947044577, 
   6.700357513286187*^-6, 8.717786748234892*^-8, 0.000013210017379357563, 
   0.00004930671011338189, 0.00009980759733765948, 
   0.00014585076464929573, 0.00016614787781188176, 
   0.00014817782622961572, 0.00009709259991835879, 
   0.00003685030163416216, 1.3720563850421132*^-6, 
   0.000018639034888739527, 0.00009503032978648582, 
   0.00020829484984366892, 0.0003142497570623722, 0.0003657714240691922, 
   0.00033597779547852794, 0.00023424484718505823, 
   0.00010599841168255531, 0.000014501025578061386, 
   0.000011840475744145913, 0.00011252620111306064, 
   0.0002830493348396919, 0.0004539389992144508, 0.0005501790605173167, 
   0.000526456732631086, 0.00039042396378429856, 0.00020200198983926667, 
   0.00004779267863607163, 1.708336744958234*^-6, 0.00009007385067766753, 
   0.0002779707411636695, 0.0004839118965226521, 0.0006165587685576606, 
   0.0006165587685576743, 0.00048391189652268715, 0.0002779707411637102, 
   0.00009007385067769613, 1.7083367449624385*^-6, 
   0.000047792678636050586, 0.00020200198983923092, 
   0.0003904239637842648, 0.0005264567326310694, 0.0005501790605173243, 
   0.0004539389992144789, 0.00028304933483972724, 0.00011252620111308814, 
   0.000011840475744155645, 0.000014501025578051135, 
   0.00010599841168253219, 0.0002342448471850342, 0.00033597779547851433, 
   0.00036577142406919456, 0.0003142497570623889, 0.00020829484984369182, 
   0.00009503032978650548, 0.00001863903488874891, 
   1.3720563850397295*^-6, 0.000036850301634151705, 
   0.00009709259991834724, 0.0001481778262296088, 0.0001661478778118821, 
   0.00014585076464930275, 0.0000998075973376696, 0.0000493067101133908, 
   0.000013210017379362435, 8.717786748271382*^-8, 6.700357513283621*^-6, 
   0.000022258919470442644, 0.00003519896255984909, 
   0.00003868064344081756, 0.00003244000187105052, 
   0.00002097359992981346, 9.8951779722697*^-6, 2.805785418908382*^-6, 
   1.6953754982033425*^-7, 2.238816383108746*^-7, 8.133695724041197*^-7, 
   7.980474621100526*^-7, 3.0297827533306375*^-7, 1.1460752580027557*^-9, 
   2.2302121662741426*^-7, 6.347426082907207*^-7, 6.621736831492177*^-7, 
   2.172534851369931*^-7, 5.045187656191309*^-8, 1.3499073125003953*^-6, 
   4.800826631818182*^-6, 9.776936367482076*^-6, 0.000014326421906145545, 
   0.000016124150766945308, 0.000013902979327830246, 
   8.48517482547881*^-6, 2.687045986196597*^-6, 2.7621651485149017*^-9, 
   2.7168393768362207*^-6, 0.000010495391058696175, 
   0.000020304158827272447, 0.00002779149030272228, 
   0.00002945505783553341, 0.000024451737858605175, 
   0.00001507782442790482, 5.652240425538807*^-6, 3.8621505279190987*^-7, 
   1.3498840472026001*^-6, 7.56877809963505*^-6, 0.000015660602463702203, 
   0.000021610194047357364, 0.000022721008567933924}, 
  {0.00005695970895269404, 0.00005417498786061621, 
   0.000039259848685384927, 0.000018974307253739786, 
   3.384048829465352*^-6, 9.682095288322392*^-7, 0.00001416970415757105, 
   0.0000377988718452068, 0.00006129850563848903, 0.00007384141934018549, 
   0.00006967099168471026, 0.000050900864452074536, 
   0.000026311086422978846, 6.810893966840617*^-6, 6.924521966807205*^-9, 
   6.73620437484514*^-6, 0.00002127163884591078, 0.000034853631330702214, 
   0.00004042192634400686, 0.00003591516721926063, 
   0.000024509979311692685, 0.000012035279457914664, 
   3.3841071536620777*^-6, 1.2647872547099806*^-7, 5.446367068326698*^-7, 
   1.660015230201565*^-6, 1.5912477705387652*^-6, 5.590959376383475*^-7, 
   2.8731168749893566*^-9, 7.595417399873073*^-7, 2.000639673908392*^-6, 
   2.039050950427648*^-6, 5.612529443804716*^-7, 4.2501676214927636*^-7, 
   7.0338744148106625*^-6, 0.000024806401337788286, 
   0.000052579098507902836, 0.00008132442974417793, 
   0.00009696920741455696, 0.00008824091839283224, 
   0.00005580128940347266, 0.000016797247916820247, 
   2.1854777898896443*^-7, 0.00003311643243910224, 0.0001236078869067787, 
   0.00025020947809702767, 0.0003656359302938859, 0.00041651913184121667, 
   0.0003714696832249547, 0.00024340320176698235, 0.00009238069030365036, 
   3.4396330658041676*^-6, 0.00004672653501482607, 
   0.00023823325932617451, 0.0005221781413429354, 0.0007877984222051382, 
   0.0009169590247678164, 0.0008422688362537404, 0.0005872326608845892, 
   0.00026572934299259817, 0.00003635288433488176, 
   0.000029683103645311514, 0.0002820939768491608, 0.0007095815171900512, 
   0.001137987919868288, 0.0013792538770994822, 0.0013197839425655433, 
   0.0009787609242265822, 0.0005064024563305778, 0.00011981233390414835, 
   4.282660406340551*^-6, 0.00022580777184729394, 0.0006968498984852599, 
   0.0012131275203855635, 0.001545662372525117, 0.0015456623725251515, 
   0.0012131275203856515, 0.000696849898485362, 0.00022580777184736566, 
   4.28266040635109*^-6, 0.00011981233390409559, 0.0005064024563304881, 
   0.0009787609242264976, 0.001319783942565502, 0.001379253877099501, 
   0.0011379879198683582, 0.0007095815171901398, 0.0002820939768492297, 
   0.000029683103645335915, 0.00003635288433485606, 
   0.0002657293429925402, 0.0005872326608845289, 0.0008422688362537063, 
   0.0009169590247678224, 0.00078779842220518, 0.0005221781413429929, 
   0.00023823325932622382, 0.00004672653501484959, 3.439633065798192*^-6, 
   0.00009238069030362415, 0.00024340320176695343, 0.0003714696832249374, 
   0.00041651913184121754, 0.0003656359302939035, 0.00025020947809705304, 
   0.000123607886906801, 0.00003311643243911446, 2.1854777898987923*^-7, 
   0.000016797247916813816, 0.00005580128940346482, 
   0.0000882409183928281, 0.0000969692074145579, 0.00008132442974418258, 
   0.00005257909850790868, 0.000024806401337792846, 
   7.033874414812952*^-6, 4.250167621497161*^-7, 5.612529443801664*^-7, 
   2.0390509504274753*^-6, 2.0006396739085777*^-6, 7.595417399875579*^-7, 
   2.8731168750075273*^-9, 5.590959376381481*^-7, 1.5912477705386231*^-6, 
   1.6600152302016893*^-6, 5.446367068329042*^-7, 1.2647872547081957*^-7, 
   3.384107153660951*^-6, 0.000012035279457912529, 
   0.000024509979311690198, 0.00003591516721925891, 
   0.00004042192634400693, 0.00003485363133070433, 
   0.000021271638845913907, 6.736204374847541*^-6, 6.924521966895786*^-9, 
   6.8108939668378314*^-6, 0.00002631108642297432, 
   0.000050900864452070084, 0.00006967099168470789, 
   0.00007384141934018633, 0.00006129850563849274, 
   0.000037798871845211666, 0.000014169704157574813, 
   9.682095288333074*^-7, 3.3840488294634512*^-6, 
   0.000018974307253735843, 0.000039259848685381064, 
   0.00005417498786061427, 0.0000569597089526948}, 
  {0.000049729309921819644, 0.000047298078077766895, 
   0.000034276249276145734, 0.000016565730817843787, 
   2.9544816173625127*^-6, 8.453061403200886*^-7, 
   0.000012371018435813462, 0.000033000727132341266, 
   0.00005351734481600879, 0.00006446807567933423, 
   0.00006082703724709965, 0.00004443956807658556, 
   0.00002297118779512673, 5.9463270292157815*^-6, 6.045531223373934*^-9, 
   5.88111844692892*^-6, 0.000018571441816738477, 
   0.000030429352014154834, 0.000035290814151939384, 
   0.000031356137774930024, 0.00002139871112018567, 
   0.000010507535118471494, 2.954532537953721*^-6, 
   1.1042366355291078*^-7, 4.755011583955793*^-7, 1.449294832707005*^-6, 
   1.3892566341806088*^-6, 4.881249513044203*^-7, 2.5084067693642583*^-9, 
   6.631263972531319*^-7, 1.7466808067489783*^-6, 1.780216200620201*^-6, 
   4.900081501260932*^-7, 3.7106562999546374*^-7, 6.141002599149221*^-6, 
   0.000021657505679961324, 0.000045904769058440133, 
   0.00007100120146895856, 0.00008466004930602155, 
   0.00007703971911421787, 0.00004871793879928514, 
   0.000014665024854374458, 1.908055787836591*^-7, 
   0.000028912671124019585, 0.00010791724588820422, 
   0.00021844817872924407, 0.00031922253168882277, 0.0003636466789691951, 
   0.00032431575482585437, 0.00021250588317939367, 
   0.00008065399320627291, 3.003010055560052*^-6, 0.00004079512315020597, 
   0.00020799220720309216, 0.0004558934570190493, 0.0006877962091817691, 
   0.000800561315475814, 0.0007353522123917305, 0.0005126900317134318, 
   0.00023199797007346568, 0.000031738291590338145, 
   0.00002591516508353532, 0.0002462852963918986, 0.0006195080668766316, 
   0.0009935330603851396, 0.0012041729983577698, 0.0011522521079626884, 
   0.0008545181538875865, 0.0004421203190653409, 0.00010460349595754257, 
   3.7390244885853163*^-6, 0.00019714399661479497, 0.0006083925850032457, 
   0.0010591345276368186, 0.0013494577934313882, 0.0013494577934314185, 
   0.0010591345276368953, 0.0006083925850033349, 0.00019714399661485758, 
   3.7390244885945185*^-6, 0.00010460349595749651, 0.0004421203190652626, 
   0.0008545181538875125, 0.0011522521079626522, 0.0012041729983577865, 
   0.000993533060385201, 0.0006195080668767089, 0.0002462852963919588, 
   0.000025915165083556622, 0.00003173829159031571, 
   0.00023199797007341508, 0.0005126900317133792, 0.0007353522123917007, 
   0.0008005613154758192, 0.0006877962091818056, 0.00045589345701909945, 
   0.0002079922072031352, 0.000040795123150226506, 
   3.0030100555548346*^-6, 0.00008065399320625003, 
   0.00021250588317936844, 0.0003243157548258392, 0.00036364667896919594, 
   0.0003192225316888381, 0.00021844817872926624, 0.00010791724588822371, 
   0.00002891267112403025, 1.9080557878445778*^-7, 
   0.000014665024854368844, 0.000048717938799278294, 
   0.00007703971911421427, 0.00008466004930602237, 
   0.00007100120146896261, 0.000045904769058445236, 
   0.000021657505679965305, 6.141002599151219*^-6, 3.710656299958476*^-7, 
   4.900081501258267*^-7, 1.78021620062005*^-6, 1.7466808067491403*^-6, 
   6.631263972533506*^-7, 2.508406769380122*^-9, 4.881249513042462*^-7, 
   1.3892566341804847*^-6, 1.4492948327071136*^-6, 
   4.7550115839578393*^-7, 1.1042366355275494*^-7, 2.954532537952737*^-6, 
   0.000010507535118469631, 0.000021398711120183498, 
   0.00003135613777492852, 0.000035290814151939445, 
   0.000030429352014156678, 0.000018571441816741208, 
   5.881118446931017*^-6, 6.0455312234512704*^-9, 5.946327029213349*^-6, 
   0.00002297118779512278, 0.00004443956807658168, 
   0.000060827037247097576, 0.00006446807567933497, 
   0.000053517344816012036, 0.00003300072713234551, 
   0.000012371018435816747, 8.453061403210212*^-7, 2.954481617360853*^-6, 
   0.000016565730817840345, 0.00003427624927614236, 
   0.000047298078077765194, 0.00004972930992182031}, 
  {0.00001161781460142612, 0.00001104982761625191, 8.0076540363936*^-6, 
   3.870103761371438*^-6, 6.902291571671037*^-7, 1.97481325100329*^-7, 
   2.890130565737928*^-6, 7.709665188166451*^-6, 0.000012502779367146962, 
   0.00001506110083028893, 0.000014210477535317199, 
   0.000010382019450760442, 5.366553475161507*^-6, 1.389187283987754*^-6, 
   1.412363473989691*^-9, 1.3739531852113665*^-6, 4.338680111331516*^-6, 
   7.1089377813157395*^-6, 8.244677768406373*^-6, 7.325454462541664*^-6, 
   4.99918979158631*^-6, 2.4547815989462063*^-6, 6.90241053290114*^-7, 
   2.579729444838092*^-8, 1.1108708947878069*^-7, 3.385858097702467*^-7, 
   3.2455962158103076*^-7, 1.1403627348741223*^-7, 
   5.860166738137165*^-10, 1.549202985665849*^-7, 4.080614392715568*^-7, 
   4.158960138754308*^-7, 1.1447622841142418*^-7, 8.668874957295883*^-8, 
   1.4346675989663718*^-6, 5.0596496535883764*^-6, 
   0.000010724321272116404, 0.00001658737666864212, 
   0.000019778371317262046, 0.00001799810162300714, 
   0.000011381536997467521, 3.4260588001578752*^-6, 
   4.457620350476087*^-8, 6.754609168696365*^-6, 0.00002521174247132596, 
   0.000051034097285593115, 0.00007457710946701416, 
   0.00008495552629486082, 0.00007576699370676639, 
   0.00004964585184012896, 0.00001884247220418445, 7.015664228311985*^-7, 
   9.530600326981118*^-6, 0.00004859136202826504, 0.0001065063173001444, 
   0.00016068368642958847, 0.00018702799123683253, 0.0001717937707912405, 
   0.00011977519386072309, 0.00005419961403964934, 7.414733645856675*^-6, 
   6.054328599757257*^-6, 0.00005753743450364898, 0.00014473013754616045, 
   0.00023211025678997993, 0.00028132018451407594, 0.0002691903705371811, 
   0.00019963344556814296, 0.00010328862207216696, 
   0.000024437580666337313, 8.735149023155161*^-7, 
   0.00004605699146148657, 0.00014213332677574098, 
   0.00024743614177229146, 0.00031526177381473283, 0.0003152617738147399, 
   0.0002474361417723094, 0.00014213332677576182, 0.00004605699146150119, 
   8.73514902317666*^-7, 0.000024437580666326555, 0.00010328862207214868, 
   0.0001996334455681257, 0.00026919037053717266, 0.0002813201845140798, 
   0.00023211025678999427, 0.00014473013754617853, 
   0.00005753743450366304, 6.054328599762234*^-6, 7.414733645851434*^-6, 
   0.000054199614039637524, 0.0001197751938607108, 
   0.00017179377079123357, 0.00018702799123683375, 0.000160683686429597, 
   0.0001065063173001561, 0.0000485913620282751, 9.530600326985915*^-6, 
   7.015664228299796*^-7, 0.000018842472204179103, 
   0.00004964585184012306, 0.00007576699370676285, 0.000084955526294861, 
   0.00007457710946701775, 0.00005103409728559829, 
   0.000025211742471330514, 6.754609168698856*^-6, 4.457620350494746*^-8, 
   3.4260588001565636*^-6, 0.000011381536997465922, 
   0.000017998101623006298, 0.000019778371317262232, 
   0.00001658737666864307, 0.000010724321272117595, 
   5.0596496535893065*^-6, 1.434667598966839*^-6, 8.668874957304853*^-8, 
   1.1447622841136193*^-7, 4.1589601387539553*^-7, 
   4.0806143927159465*^-7, 1.5492029856663601*^-7, 
   5.860166738174227*^-10, 1.1403627348737157*^-7, 
   3.2455962158100175*^-7, 3.385858097702721*^-7, 1.1108708947882849*^-7, 
   2.5797294448344512*^-8, 6.902410532898842*^-7, 2.454781598945771*^-6, 
   4.999189791585802*^-6, 7.325454462541312*^-6, 8.244677768406388*^-6, 
   7.108937781316171*^-6, 4.338680111332154*^-6, 1.3739531852118563*^-6, 
   1.4123634740077583*^-9, 1.3891872839871857*^-6, 5.366553475160583*^-6, 
   0.000010382019450759535, 0.000014210477535316716, 
   0.000015061100830289102, 0.000012502779367147721, 
   7.709665188167444*^-6, 2.890130565738695*^-6, 1.9748132510054687*^-7, 
   6.90229157166716*^-7, 3.8701037613706345*^-6, 8.007654036392812*^-6, 
   0.000011049827616251514, 0.000011617814601426275}, 
  {3.440706499161983*^-6, 3.2724927189998835*^-6, 2.3715292618525745*^-6, 
   1.1461614443862259*^-6, 2.0441675379158045*^-7, 5.84856362445666*^-8, 
   8.559347314546165*^-7, 2.283277537931357*^-6, 3.7027957238059444*^-6, 
   4.460462598959697*^-6, 4.208543868995754*^-6, 3.074716116942739*^-6, 
   1.5893467105097307*^-6, 4.114186600966344*^-7, 
   4.1828246971154156*^-10, 4.0690696280527314*^-7, 
   1.284933988790862*^-6, 2.105367426272126*^-6, 2.4417256906277307*^-6, 
   2.169490531849966*^-6, 1.4805490874629568*^-6, 7.270027359948284*^-7, 
   2.044202769212878*^-7, 7.640070160737796*^-9, 3.2899308850712*^-8, 
   1.0027483103900685*^-7, 9.612086589867999*^-8, 3.3772732720333535*^-8, 
   1.7355341321771777*^-10, 4.58808559455521*^-8, 1.2085058113999262*^-7, 
   1.2317085157660378*^-7, 3.390302880598465*^-8, 2.567354999995365*^-8, 
   4.248880104606569*^-7, 1.49845474762932*^-6, 3.176091473825252*^-6, 
   4.912481104737117*^-6, 5.857519083304097*^-6, 5.330278314069231*^-6, 
   3.3707310420353928*^-6, 1.0146540622852847*^-6, 1.320159069227795*^-8, 
   2.0004302412589586*^-6, 7.46665437109326*^-6, 0.000015114146354844616, 
   0.00002208659322213424, 0.000025160242394173933, 
   0.00002243898672964152, 0.00001470300662758006, 5.580345254025504*^-6, 
   2.077743735325934*^-7, 2.8225616960640724*^-6, 
   0.000014390711236970631, 0.00003154267740607873, 
   0.00004758772825826687, 0.000055389799807511786, 
   0.00005087806648286564, 0.00003547235879494828, 
   0.00001605163885602039, 2.1959312590271864*^-6, 1.793036683395686*^-6, 
   0.000017040160446140246, 0.000042862960200669264, 
   0.00006874126472644928, 0.00008331516902363135, 
   0.00007972282991203933, 0.00005912300352357947, 
   0.00003058973184247286, 7.237380308353402*^-6, 2.586982582027868*^-7, 
   0.000013640137606769204, 0.000042093894416663785, 
   0.00007328014521930681, 0.00009336723569065506, 
   0.00009336723569065717, 0.00007328014521931212, 
   0.00004209389441666995, 0.000013640137606773537, 
   2.586982582034235*^-7, 7.237380308350216*^-6, 0.00003058973184246745, 
   0.00005912300352357436, 0.00007972282991203682, 
   0.00008331516902363249, 0.00006874126472645352, 
   0.00004286296020067462, 0.00001704016044614441, 
   1.7930366833971598*^-6, 2.195931259025634*^-6, 0.00001605163885601689, 
   0.000035472358794944644, 0.00005087806648286358, 
   0.00005538979980751215, 0.0000475877282582694, 
   0.000031542677406082194, 0.000014390711236973609, 
   2.8225616960654933*^-6, 2.0777437353223243*^-7, 5.580345254023921*^-6, 
   0.000014703006627578311, 0.00002243898672964047, 
   0.000025160242394173987, 0.0000220865932221353, 
   0.00001511414635484615, 7.466654371094608*^-6, 2.0004302412596963*^-6, 
   1.3201590692333209*^-8, 1.0146540622848962*^-6, 
   3.3707310420349193*^-6, 5.330278314068981*^-6, 5.857519083304153*^-6, 
   4.912481104737398*^-6, 3.176091473825605*^-6, 1.4984547476295953*^-6, 
   4.248880104607952*^-7, 2.567354999998021*^-8, 3.3903028805966214*^-8, 
   1.2317085157659335*^-7, 1.2085058114000384*^-7, 
   4.5880855945567234*^-8, 1.7355341321881536*^-10, 
   3.377273272032149*^-8, 9.61208658986714*^-8, 1.0027483103901435*^-7, 
   3.289930885072616*^-8, 7.640070160727015*^-9, 2.0442027692121971*^-7, 
   7.270027359946995*^-7, 1.4805490874628067*^-6, 2.1694905318498622*^-6, 
   2.441725690627735*^-6, 2.1053674262722533*^-6, 1.2849339887910509*^-6, 
   4.069069628054182*^-7, 4.182824697168924*^-10, 4.114186600964661*^-7, 
   1.5893467105094573*^-6, 3.0747161169424707*^-6, 4.208543868995611*^-6, 
   4.460462598959748*^-6, 3.7027957238061693*^-6, 2.283277537931651*^-6, 
   8.559347314548437*^-7, 5.848563624463112*^-8, 2.0441675379146563*^-7, 
   1.1461614443859877*^-6, 2.3715292618523407*^-6, 3.272492718999766*^-6, 
   3.4407064991620293*^-6}, {0.000041567353356194196, 
   0.000039535153968922376, 0.00002865056779646564, 
   0.000013846835751219132, 2.4695693860694933*^-6, 
   7.065679995174985*^-7, 0.000010340591806037167, 
   0.000027584394150611223, 0.000044733666848577206, 
   0.000053887079594904216, 0.00005084363637531972, 
   0.00003714580459974513, 0.00001920097989681875, 4.970370133498457*^-6, 
   5.053292172824386*^-9, 4.9158640849320145*^-6, 0.00001552335404500868, 
   0.000025435052880502765, 0.000029498614486862077, 
   0.000026209727438910994, 0.000017886590179881038, 
   8.782957693536853*^-6, 2.469611949181895*^-6, 9.230008317037574*^-8, 
   3.974582535607701*^-7, 1.2114254254311613*^-6, 1.1612411575026604*^-6, 
   4.080101325504878*^-7, 2.0967077706719636*^-9, 5.542889961227181*^-7, 
   1.4600021276941227*^-6, 1.4880334349689622*^-6, 4.095842463072143*^-7, 
   3.1016348677689164*^-7, 5.13309405261102*^-6, 0.00001810290938740206, 
   0.00003837052553487053, 0.00005934793856609668, 
   0.00007076499131374743, 0.00006439536828315324, 
   0.00004072197623572471, 0.00001225808825936847, 
   1.5948910065517543*^-7, 0.000024167301315320135, 
   0.00009020503803721672, 0.0001825947846356782, 0.00026682927623224617, 
   0.0003039621910153774, 0.00027108656044133275, 0.00017762778430416558, 
   0.00006741643993178014, 2.510132963998739*^-6, 0.00003409951398601713, 
   0.00017385492752136983, 0.0003810687188396509, 0.0005749098089045697, 
   0.0006691670392369918, 0.000614660555350569, 0.00042854340315468485, 
   0.00019392068008030477, 0.000026529159232886428, 
   0.000021661769005138886, 0.0002058630605904549, 0.0005178296413796579, 
   0.0008304667781840592, 0.001006534870550517, 0.0009631356357528986, 
   0.0007142680666144325, 0.00036955613414773654, 0.00008743516621477586, 
   3.1253470512426144*^-6, 0.0001647872086345589, 0.0005085385178253237, 
   0.0008853012284151666, 0.0011279744083925168, 0.0011279744083925421, 
   0.0008853012284152308, 0.0005085385178253982, 0.00016478720863461125, 
   3.1253470512503063*^-6, 0.00008743516621473736, 0.0003695561341476711, 
   0.0007142680666143707, 0.0009631356357528683, 0.0010065348705505307, 
   0.0008304667781841104, 0.0005178296413797225, 0.00020586306059050522, 
   0.000021661769005156694, 0.000026529159232867675, 
   0.0001939206800802625, 0.0004285434031546409, 0.0006146605553505441, 
   0.0006691670392369963, 0.0005749098089046003, 0.0003810687188396928, 
   0.0001738549275214058, 0.000034099513986034296, 2.510132963994378*^-6, 
   0.00006741643993176102, 0.00017762778430414447, 0.0002710865604413201, 
   0.00030396219101537806, 0.000266829276232259, 0.00018259478463569673, 
   0.00009020503803723301, 0.00002416730131532905, 
   1.5948910065584302*^-7, 0.000012258088259363778, 
   0.00004072197623571899, 0.00006439536828315021, 0.0000707649913137481, 
   0.000059347938566100076, 0.000038370525534874794, 
   0.000018102909387405386, 5.133094052612691*^-6, 3.101634867772125*^-7, 
   4.095842463069915*^-7, 1.4880334349688362*^-6, 1.460002127694258*^-6, 
   5.542889961229009*^-7, 2.096707770685224*^-9, 4.0801013255034236*^-7, 
   1.1612411575025566*^-6, 1.211425425431252*^-6, 3.974582535609411*^-7, 
   9.230008317024548*^-8, 2.4696119491810724*^-6, 8.782957693535296*^-6, 
   0.000017886590179879222, 0.000026209727438909737, 
   0.00002949861448686213, 0.000025435052880504306, 
   0.000015523354045010964, 4.915864084933766*^-6, 5.053292172889029*^-9, 
   4.970370133496424*^-6, 0.00001920097989681545, 
   0.000037145804599741885, 0.00005084363637531798, 
   0.00005388707959490483, 0.000044733666848579916, 
   0.00002758439415061477, 0.000010340591806039913, 7.06567999518278*^-7, 
   2.469569386068106*^-6, 0.000013846835751216255, 
   0.00002865056779646282, 0.00003953515396892095, 
   0.00004156735335619475}, {0.00006903192002193174, 
   0.00006565699681311835, 0.000047580698433229087, 
   0.000022995778681024536, 4.1012742593186105*^-6, 
   1.1734147520720103*^-6, 0.000017172873635155996, 
   0.00004581007779208726, 0.00007429029425368868, 
   0.00008949159059838408, 0.00008443727003278714, 
   0.00006168894589719642, 0.000031887536770064616, 
   8.254415204039787*^-6, 8.392125862155334*^-9, 8.163895676536853*^-6, 
   0.000025780013601647393, 0.00004224061419438014, 
   0.00004898907030633482, 0.00004352713517397706, 
   0.000029704697630902224, 0.000014586072581065524, 
   4.101344944920026*^-6, 1.532850048170206*^-7, 6.600686393658776*^-7, 
   2.011843822826329*^-6, 1.928501582094439*^-6, 6.775924027928495*^-7, 
   3.4820538583272892*^-9, 9.205212879804006*^-7, 2.42466122986423*^-6, 
   2.4712135072085502*^-6, 6.802065719950263*^-7, 5.150960858496722*^-7, 
   8.524654795037463*^-6, 0.00003006394422774079, 0.00006372286989804127, 
   0.00009856057260741623, 0.0001175211512473011, 0.00010694296254594348, 
   0.0000676279815688735, 0.00002035730687713866, 2.6486744889561873*^-7, 
   0.00004013522817411948, 0.00014980571214146183, 
   0.00030323962320573535, 0.00044312990289600715, 0.0005047974423596026, 
   0.00045020007887074245, 0.00029499080431424365, 0.0001119601300966762, 
   4.168639184947146*^-6, 0.00005662989659452785, 0.0002887251288103846, 
   0.0006328501383376813, 0.0009547667759369217, 0.0011113020628973303, 
   0.001020781812447862, 0.0007116925073145724, 0.0003220488146837325, 
   0.00004405762336419733, 0.00003597422940745098, 0.0003418818179828302, 
   0.0008599723461435944, 0.0013791764830735948, 0.001671577068853113, 
   0.0015995028985327218, 0.001186202441763104, 0.0006137309074622442, 
   0.0001452057182838003, 5.190340261343831*^-6, 0.0002736661463533643, 
   0.0008445423500930737, 0.0014702413952503122, 0.001873254678490005, 
   0.001873254678490047, 0.0014702413952504187, 0.0008445423500931974, 
   0.0002736661463534512, 5.1903402613566055*^-6, 0.00014520571828373637, 
   0.0006137309074621355, 0.0011862024417630015, 0.0015995028985326715, 
   0.001671577068853136, 0.00137917648307368, 0.0008599723461437018, 
   0.00034188181798291376, 0.00003597422940748055, 
   0.00004405762336416619, 0.0003220488146836623, 0.0007116925073144994, 
   0.0010207818124478205, 0.0011113020628973377, 0.0009547667759369725, 
   0.0006328501383377508, 0.00028872512881044434, 0.00005662989659455636, 
   4.168639184939904*^-6, 0.00011196013009664443, 0.00029499080431420857, 
   0.0004502000788707214, 0.0005047974423596037, 0.00044312990289602846, 
   0.00030323962320576614, 0.00014980571214148888, 
   0.000040135228174134285, 2.6486744889672744*^-7, 
   0.000020357306877130863, 0.000067627981568864, 0.00010694296254593847, 
   0.00011752115124730223, 0.00009856057260742185, 
   0.00006372286989804835, 0.000030063944227746315, 
   8.524654795040238*^-6, 5.150960858502051*^-7, 6.802065719946564*^-7, 
   2.471213507208341*^-6, 2.424661229864455*^-6, 9.205212879807042*^-7, 
   3.482053858349311*^-9, 6.77592402792608*^-7, 1.9285015820942666*^-6, 
   2.011843822826479*^-6, 6.600686393661615*^-7, 1.532850048168043*^-7, 
   4.101344944918659*^-6, 0.000014586072581062937, 
   0.00002970469763089921, 0.00004352713517397497, 
   0.000048989070306334906, 0.0000422406141943827, 
   0.000025780013601651185, 8.163895676539763*^-6, 8.392125862262689*^-9, 
   8.254415204036411*^-6, 0.00003188753677005913, 0.00006168894589719103, 
   0.00008443727003278426, 0.00008949159059838511, 0.0000742902942536932, 
   0.00004581007779209315, 0.000017172873635160553, 
   1.173414752073305*^-6, 4.101274259316307*^-6, 0.00002299577868101976, 
   0.000047580698433224404, 0.00006565699681311599, 
   0.00006903192002193266}, {0.00004264218107229909, 
   0.00004055743409539908, 0.00002939139976827543, 
   0.00001420488026558186, 2.533426269144203*^-6, 7.248380794691014*^-7, 
   0.000010607973627988064, 0.000028297657540535967, 
   0.00004589036750641903, 0.00005528046459568206, 
   0.00005215832555207504, 0.00003810630213199596, 
   0.00001969746917754411, 5.0988914644815865*^-6, 5.18395766019341*^-9, 
   5.04297602592602*^-6, 0.00001592474912617995, 0.000026092739684911355, 
   0.0000302613748234532, 0.000026887445388415678, 
   0.000018349092632399608, 9.010062996044245*^-6, 
   2.5334699328321575*^-6, 9.468673229716032*^-8, 4.077355291732214*^-7, 
   1.2427498547757481*^-6, 1.1912679472881496*^-6, 4.185602533426153*^-7, 
   2.1509233856325665*^-9, 5.686215221957517*^-7, 1.497754128380111*^-6, 
   1.5265102550996595*^-6, 4.20175069741137*^-7, 3.181835382161748*^-7, 
   5.265823016849909*^-6, 0.000018571005313187426, 
   0.00003936269128506843, 0.000060882527711523375, 
   0.00007259479686672964, 0.00006606047132751632, 
   0.00004177494461544474, 0.000012575051740173436, 
   1.6361308960226777*^-7, 0.000024792207237392597, 
   0.00009253751454068526, 0.00018731622873775707, 0.0002737288134509152, 
   0.0003118218924679024, 0.00027809618037380967, 0.00018222079420990617, 
   0.00006915966032733607, 2.5750387196694286*^-6, 
   0.00003498124206775983, 0.00017835038079404086, 0.0003909222021066679, 
   0.0005897755375829418, 0.0006864700239690855, 0.0006305541388372543, 
   0.00043962446293055175, 0.00019893498349024663, 
   0.000027215136889056286, 0.0000222218881329331, 0.0002111861640690128, 
   0.0005312194197955737, 0.0008519405704375067, 0.0010325613429800525, 
   0.0009880399125973916, 0.0007327372510281534, 0.00037911193079023255, 
   0.000089696020765812, 3.2061607033492793*^-6, 0.00016904819339301217, 
   0.000521688051041494, 0.0009081929023028075, 0.0011571410033115708, 
   0.0011571410033115969, 0.0009081929023028733, 0.0005216880510415705, 
   0.00016904819339306587, 3.20616070335717*^-6, 0.00008969602076577251, 
   0.00037911193079016544, 0.00073273725102809, 0.0009880399125973605, 
   0.0010325613429800666, 0.0008519405704375594, 0.0005312194197956401, 
   0.0002111861640690644, 0.000022221888132951364, 
   0.00002721513688903705, 0.00019893498349020326, 
   0.00043962446293050665, 0.0006305541388372287, 0.0006864700239690901, 
   0.0005897755375829731, 0.00039092220210671085, 0.00017835038079407775, 
   0.00003498124206777743, 2.5750387196649555*^-6, 
   0.00006915966032731646, 0.00018222079420988452, 
   0.00027809618037379666, 0.00031182189246790307, 
   0.00027372881345092835, 0.00018731622873777607, 
   0.00009253751454070197, 0.00002479220723740174, 
   1.6361308960295262*^-7, 0.000012575051740168621, 
   0.00004177494461543887, 0.00006606047132751323, 
   0.00007259479686673033, 0.00006088252771152686, 0.0000393626912850728, 
   0.00001857100531319084, 5.265823016851622*^-6, 3.18183538216504*^-7, 
   4.201750697409085*^-7, 1.52651025509953*^-6, 1.49775412838025*^-6, 
   5.686215221959393*^-7, 2.1509233856461694*^-9, 4.185602533424661*^-7, 
   1.191267947288043*^-6, 1.242749854775841*^-6, 4.0773552917339686*^-7, 
   9.468673229702669*^-8, 2.533469932831314*^-6, 9.01006299604265*^-6, 
   0.000018349092632397744, 0.000026887445388414387, 
   0.000030261374823453254, 0.000026092739684912937, 
   0.000015924749126182292, 5.042976025927818*^-6, 
   5.1839576602597255*^-9, 5.098891464479501*^-6, 
   0.000019697469177540722, 0.000038106302131992626, 
   0.000052158325552073266, 0.0000552804645956827, 
   0.000045890367506421816, 0.000028297657540539606, 
   0.00001060797362799088, 7.24838079469901*^-7, 2.53342626914278*^-6, 
   0.00001420488026557891, 0.00002939139976827254, 
   0.000040557434095397626, 0.00004264218107229966}, 
  {3.211479789969015*^-6, 3.0544727463526975*^-6, 2.2135332663842898*^-6, 
   1.0698018896946228*^-6, 1.9079810314905518*^-7, 5.458920685290989*^-8, 
   7.989106575258766*^-7, 2.131161047808848*^-6, 3.4561081092742895*^-6, 
   4.163297710502377*^-6, 3.9281623072964045*^-6, 2.869872414824867*^-6, 
   1.4834612720669143*^-6, 3.840091308102796*^-7, 3.904156597792103*^-10, 
   3.7979801176446914*^-7, 1.1993291312267361*^-6, 1.965103661581946*^-6, 
   2.2790530694812174*^-6, 2.0249547583504265*^-6, 
   1.3819119630234136*^-6, 6.785683679989044*^-7, 1.908013915608553*^-7, 
   7.131073493519636*^-9, 3.0707491471226543*^-8, 9.35943223877892*^-8, 
   8.971710266572203*^-8, 3.1522726105755606*^-8, 
   1.6199093969933008*^-10, 4.2824182083391206*^-8, 
   1.1279927509993213*^-7, 1.1496496450594634*^-7, 3.164434160707272*^-8, 
   2.3963127044312458*^-8, 3.965811262677839*^-7, 1.3986247125021424*^-6, 
   2.9644939438359524*^-6, 4.585201844536983*^-6, 5.4672795136611065*^-6, 
   4.9751645729482365*^-6, 3.146166236949999*^-6, 9.470557909059673*^-7, 
   1.23220744675606*^-8, 1.8671576005133526*^-6, 6.969211008637361*^-6, 
   0.000014107211868562291, 0.000020615140460084744, 
   0.00002348401701199774, 0.000020944056811349104, 
   0.000013723463087524128, 5.208571556079336*^-6, 
   1.9393203158593012*^-7, 2.6345170229016056*^-6, 
   0.000013431973436870425, 0.0000294412415112438, 
   0.00004441733916833183, 0.00005169962119569888, 
   0.000047488468517212694, 0.000033109119711388356, 
   0.000014982246755004015, 2.049633951702841*^-6, 
   1.6735810138995598*^-6, 0.000015904911071007474, 
   0.00004000734455444614, 0.00006416158497089778, 
   0.00007776454678200904, 0.00007441153644578801, 
   0.00005518411145632083, 0.00002855178307612117, 6.755211639893624*^-6, 
   2.414632657917164*^-7, 0.000012731404514510249, 
   0.00003928951546234199, 0.000068398076219264, 0.00008714692477804865, 
   0.0000871469247780506, 0.00006839807621926897, 0.00003928951546234774, 
   0.000012731404514514293, 2.4146326579231063*^-7, 
   6.755211639890649*^-6, 0.000028551783076116115, 
   0.00005518411145631606, 0.00007441153644578566, 0.0000777645467820101, 
   0.00006416158497090174, 0.00004000734455445113, 
   0.00001590491107101136, 1.6735810139009356*^-6, 
   2.0496339517013923*^-6, 0.000014982246755000749, 
   0.00003310911971138496, 0.00004748846851721077, 
   0.00005169962119569922, 0.0000444173391683342, 
   0.000029441241511247038, 0.000013431973436873203, 
   2.6345170229029317*^-6, 1.939320315855932*^-7, 5.208571556077858*^-6, 
   0.000013723463087522497, 0.000020944056811348125, 
   0.000023484017011997792, 0.000020615140460085733, 
   0.000014107211868563723, 6.96921100863862*^-6, 1.8671576005140412*^-6, 
   1.2322074467612178*^-8, 9.470557909056047*^-7, 3.1461662369495574*^-6, 
   4.9751645729480036*^-6, 5.467279513661159*^-6, 4.585201844537245*^-6, 
   2.9644939438362815*^-6, 1.3986247125023995*^-6, 
   3.9658112626791295*^-7, 2.396312704433725*^-8, 3.164434160705551*^-8, 
   1.1496496450593659*^-7, 1.1279927509994259*^-7, 
   4.2824182083405334*^-8, 1.6199093970035457*^-10, 
   3.152272610574436*^-8, 8.971710266571401*^-8, 9.35943223877962*^-8, 
   3.070749147123976*^-8, 7.131073493509572*^-9, 1.9080139156079177*^-7, 
   6.785683679987842*^-7, 1.3819119630232734*^-6, 2.0249547583503295*^-6, 
   2.2790530694812217*^-6, 1.9651036615820655*^-6, 
   1.1993291312269125*^-6, 3.7979801176460456*^-7, 
   3.904156597842046*^-10, 3.8400913081012246*^-7, 
   1.4834612720666591*^-6, 2.8698724148246157*^-6, 3.928162307296271*^-6, 
   4.163297710502425*^-6, 3.456108109274499*^-6, 2.131161047809122*^-6, 
   7.989106575260887*^-7, 5.458920685297012*^-8, 1.90798103148948*^-7, 
   1.0698018896944004*^-6, 2.2135332663840717*^-6, 3.054472746352588*^-6, 
   3.2114797899690577*^-6}, {0.000015135055288367644, 
   0.00001439511281909897, 0.000010431934983371166, 
   5.041760125255068*^-6, 8.991929044973017*^-7, 2.572679007501712*^-7, 
   3.765104488556334*^-6, 0.000010043731362641906, 
   0.000016287939123835126, 0.00001962078080864892, 
   0.00001851263516847058, 0.000013525128759833982, 
   6.991253203901236*^-6, 1.8097574346272501*^-6, 1.8399501110545336*^-9, 
   1.7899112815288202*^-6, 5.652195840298818*^-6, 9.261136457503105*^-6, 
   0.000010740716575412426, 9.543202582125715*^-6, 6.512671831018381*^-6, 
   3.1979555962579825*^-6, 8.992084021176079*^-7, 3.3607308358890226*^-8, 
   1.447182020686407*^-7, 4.4109112828331463*^-7, 4.2281857522477516*^-7, 
   1.485602381621353*^-7, 7.634305643840421*^-10, 2.0182171643605533*^-7, 
   5.316001895629978*^-7, 5.418066461005223*^-7, 1.4913338744431557*^-7, 
   1.1293337539618962*^-7, 1.8690067087247434*^-6, 6.591435642072487*^-6, 
   0.000013971060905359482, 0.000021609129735816307, 
   0.000025766183544010093, 0.000023446945272860043, 
   0.000014827245711265472, 4.46328256565764*^-6, 5.807144697482662*^-8, 
   8.799536464197433*^-6, 0.00003284448317610138, 0.00006648443881300793, 
   0.00009715499117117524, 0.00011067542663034521, 
   0.00009870510746870994, 0.00006467590835424631, 
   0.00002454694521849706, 9.139624759297744*^-7, 
   0.000012415946357285417, 0.00006330217653366607, 
   0.0001387506218854825, 0.0002093299438391814, 0.00024364986746253689, 
   0.0002238035558601024, 0.00015603659065401766, 0.00007060830140959421, 
   9.659510633332449*^-6, 7.88724912859458*^-6, 0.00007495663188295864, 
   0.0001885465303763156, 0.0003023805844760448, 0.00036648859466492694, 
   0.00035068653451194584, 0.0002600715659303328, 0.0001345587840186106, 
   0.00003183594739526637, 1.1379675778382212*^-6, 0.000060000536770479, 
   0.0001851635469209846, 0.00032234631163801687, 0.00041070584621045005, 
   0.0004107058462104592, 0.00032234631163804024, 0.00018516354692101172, 
   0.00006000053677049805, 1.1379675778410217*^-6, 
   0.00003183594739525235, 0.00013455878401858677, 
   0.00026007156593031033, 0.0003506865345119348, 0.000366488594664932, 
   0.0003023805844760635, 0.00018854653037633911, 0.00007495663188297695, 
   7.887249128601064*^-6, 9.65951063332562*^-6, 0.00007060830140957881, 
   0.00015603659065400167, 0.00022380355586009334, 
   0.00024364986746253846, 0.00020932994383919255, 
   0.00013875062188549775, 0.00006330217653367918, 
   0.000012415946357291669, 9.139624759281865*^-7, 
   0.000024546945218490092, 0.00006467590835423863, 
   0.00009870510746870533, 0.00011067542663034545, 
   0.00009715499117117992, 0.00006648443881301467, 
   0.00003284448317610731, 8.799536464200679*^-6, 5.80714469750697*^-8, 
   4.463282565655931*^-6, 0.00001482724571126339, 
   0.000023446945272858945, 0.00002576618354401034, 
   0.000021609129735817544, 0.000013971060905361033, 
   6.591435642073698*^-6, 1.8690067087253518*^-6, 1.1293337539630646*^-7, 
   1.4913338744423444*^-7, 5.418066461004763*^-7, 5.316001895630471*^-7, 
   2.018217164361219*^-7, 7.634305643888702*^-10, 1.4856023816208234*^-7, 
   4.228185752247374*^-7, 4.410911282833476*^-7, 1.4471820206870298*^-7, 
   3.360730835884279*^-8, 8.992084021173084*^-7, 3.1979555962574154*^-6, 
   6.51267183101772*^-6, 9.543202582125257*^-6, 0.000010740716575412445, 
   9.261136457503666*^-6, 5.652195840299649*^-6, 1.7899112815294582*^-6, 
   1.8399501110780708*^-9, 1.8097574346265098*^-6, 
   6.9912532039000335*^-6, 0.0000135251287598328, 0.00001851263516846995, 
   0.000019620780808649143, 0.000016287939123836116, 
   0.000010043731362643199, 3.7651044885573336*^-6, 2.57267900750455*^-7, 
   8.991929044967967*^-7, 5.041760125254021*^-6, 0.000010431934983370138, 
   0.000014395112819098455, 0.000015135055288367848}, 
  {0.00006432227411319452, 0.00006117760226169004, 
   0.00004433454445634821, 0.00002142691061319583, 3.821468199601997*^-6, 
   1.0933594966975098*^-6, 0.00001600126847001821, 
   0.00004268472295067632, 0.00006922190009226872, 
   0.00008338610050924617, 0.00007867660680295789, 
   0.00005748026835256578, 0.000029712035827295967, 
   7.691264522697398*^-6, 7.819579984541751*^-9, 7.606920615432602*^-6, 
   0.00002402119339865124, 0.00003935878306814308, 
   0.00004564683131793976, 0.00004055753221311425, 
   0.000027678119091246825, 0.000013590949788100552, 
   3.821534062736451*^-6, 1.4282726156465435*^-7, 6.150359998871031*^-7, 
   1.8745874343877342*^-6, 1.7969311494131697*^-6, 6.313642189817821*^-7, 
   3.2444936006571616*^-9, 8.577194809835062*^-7, 2.2592407137077063*^-6, 
   2.3026170002572257*^-6, 6.338000386424154*^-7, 4.799540794770008*^-7, 
   7.943067240090562*^-6, 0.000028012856384787858, 
   0.00005937542956300558, 0.00009183635868730736, 
   0.00010950336745994454, 0.00009964686697359486, 
   0.00006301411820521781, 0.000018968446375846444, 
   2.4679708526307597*^-7, 0.000037397035275726636, 
   0.0001395853407673446, 0.00028255134957312926, 0.00041289773010477873, 
   0.0004703580524600518, 0.00041948554914459344, 0.00027486529955916383, 
   0.00010432174239886952, 3.884237208641829*^-6, 0.00005276636852339937, 
   0.00026902709460795415, 0.0005896744586822562, 0.0008896285987188906, 
   0.0010354843946036943, 0.0009511398137147966, 0.0006631378719475115, 
   0.0003000772994483597, 0.000041051828283313665, 
   0.00003351991722411684, 0.000318557212426112, 0.0008013014408528887, 
   0.0012850833030074672, 0.0015575350995588812, 0.0014903781301691204, 
   0.0011052747567876782, 0.0005718596215922172, 0.00013529917770339515, 
   4.836233570279381*^-6, 0.00025499549883083384, 0.0007869241435792248, 
   0.0013699353865256985, 0.0017454534203217489, 0.0017454534203217881, 
   0.0013699353865257978, 0.0007869241435793401, 0.00025499549883091483, 
   4.836233570291284*^-6, 0.0001352991777033356, 0.000571859621592116, 
   0.0011052747567875825, 0.0014903781301690735, 0.0015575350995589024, 
   0.0012850833030075466, 0.0008013014408529888, 0.00031855721242618983, 
   0.00003351991722414439, 0.00004105182828328465, 0.0003000772994482943, 
   0.0006631378719474435, 0.000951139813714758, 0.001035484394603701, 
   0.0008896285987189379, 0.0005896744586823211, 0.0002690270946080098, 
   0.00005276636852342593, 3.884237208635081*^-6, 0.00010432174239883992, 
   0.00027486529955913114, 0.0004194855491445738, 0.0004703580524600528, 
   0.0004128977301047986, 0.0002825513495731579, 0.00013958534076736982, 
   0.000037397035275740426, 2.4679708526410903*^-7, 
   0.000018968446375839183, 0.00006301411820520896, 
   0.0000996468669735902, 0.00010950336745994558, 0.0000918363586873126, 
   0.000059375429563012175, 0.000028012856384793008, 
   7.943067240093147*^-6, 4.799540794774974*^-7, 6.338000386420707*^-7, 
   2.3026170002570305*^-6, 2.259240713707916*^-6, 8.577194809837891*^-7, 
   3.2444936006776807*^-9, 6.31364218981557*^-7, 1.7969311494130092*^-6, 
   1.8745874343878743*^-6, 6.150359998873677*^-7, 1.4282726156445276*^-7, 
   3.821534062735179*^-6, 0.000013590949788098143, 
   0.00002767811909124402, 0.000040557532213112304, 
   0.000045646831317939844, 0.000039358783068145475, 
   0.00002402119339865477, 7.606920615435313*^-6, 7.81957998464178*^-9, 
   7.69126452269425*^-6, 0.000029712035827290854, 0.00005748026835256075, 
   0.00007867660680295522, 0.00008338610050924713, 
   0.00006922190009227293, 0.00004268472295068181, 
   0.00001600126847002246, 1.093359496698716*^-6, 3.82146819959985*^-6, 
   0.000021426910613191383, 0.000044334544456343846, 
   0.00006117760226168785, 0.00006432227411319538}, 
  {0.00007588540004021831, 0.00007217541489531063, 
   0.000052304503969344175, 0.000025278796589917575, 
   4.508448232993733*^-6, 1.289911215649052*^-6, 0.000018877794290379114, 
   0.00005035809634183175, 0.00008166582498003277, 
   0.00009837630404364029, 0.0000928201911913544, 0.00006781341640187421, 
   0.000035053327262587274, 9.073912469153586*^-6, 9.225295023449917*^-9, 
   8.97440617476355*^-6, 0.000028339449990406588, 0.00004643425686358827, 
   0.00005385269881836569, 0.0000478485034782823, 0.00003265377613832248, 
   0.000016034175964947223, 4.508525936252439*^-6, 1.685031201074928*^-7, 
   7.256001678117679*^-7, 2.2115794152200063*^-6, 2.1199629676957546*^-6, 
   7.448636881867398*^-7, 3.827751711335897*^-9, 1.01191052141874*^-6, 
   2.6653812805988644*^-6, 2.7165552619676955*^-6, 7.477373917664314*^-7, 
   5.662347580863244*^-7, 9.370981411507332*^-6, 0.00003304868869045083, 
   0.00007004926811230725, 0.00010834565340396956, 
   0.00012918863581883733, 0.00011756024592256312, 0.0000743420787606085, 
   0.000022378377649388247, 2.9116345468430236*^-7, 
   0.000044119848393770196, 0.0001646784037087906, 0.0003333452134563468, 
   0.0004871237818731266, 0.0005549136666134632, 0.0004948958839967105, 
   0.00032427745290092134, 0.00012307551721351366, 4.582501139654548*^-6, 
   0.00006225210534411684, 0.00031738972195005855, 0.0006956794175506778, 
   0.0010495558969541078, 0.00122163198679236, 0.0011221248976817529, 
   0.0007823492466388599, 0.0003540217790116349, 0.00004843165846685407, 
   0.00003954574621212472, 0.00037582380029212143, 0.0009453502885317195, 
   0.0015161009444739533, 0.001837531022281776, 0.0017583013377301647, 
   0.001303968465505213, 0.0006746620319269997, 0.00015962172306076156, 
   5.705636565690095*^-6, 0.0003008356856783374, 0.0009283884044853138, 
   0.0016162067692570689, 0.0020592311587054515, 0.002059231158705498, 
   0.0016162067692571862, 0.0009283884044854498, 0.0003008356856784329, 
   5.705636565704137*^-6, 0.00015962172306069127, 0.0006746620319268803, 
   0.0013039684655051004, 0.0017583013377301092, 0.001837531022281801, 
   0.001516100944474047, 0.0009453502885318376, 0.00037582380029221326, 
   0.000039545746212157226, 0.00004843165846681984, 
   0.0003540217790115577, 0.0007823492466387796, 0.0011221248976817073, 
   0.001221631986792368, 0.0010495558969541635, 0.0006956794175507542, 
   0.0003173897219501242, 0.00006225210534414817, 4.582501139646587*^-6, 
   0.00012307551721347875, 0.0003242774529008828, 0.0004948958839966873, 
   0.0005549136666134644, 0.00048712378187315, 0.00033334521345638064, 
   0.00016467840370882036, 0.000044119848393786466, 
   2.9116345468552113*^-7, 0.000022378377649379682, 
   0.00007434207876059806, 0.00011756024592255762, 
   0.00012918863581883858, 0.00010834565340397575, 
   0.00007004926811231503, 0.00003304868869045691, 9.370981411510382*^-6, 
   5.662347580869102*^-7, 7.477373917660247*^-7, 2.716555261967465*^-6, 
   2.6653812805991117*^-6, 1.0119105214190737*^-6, 3.827751711360105*^-9, 
   7.448636881864742*^-7, 2.1199629676955653*^-6, 2.211579415220172*^-6, 
   7.256001678120801*^-7, 1.6850312010725499*^-7, 4.508525936250937*^-6, 
   0.00001603417596494438, 0.00003265377613831917, 0.00004784850347828, 
   0.00005385269881836578, 0.00004643425686359109, 
   0.000028339449990410755, 8.974406174766751*^-6, 9.22529502356793*^-9, 
   9.073912469149875*^-6, 0.00003505332726258124, 0.00006781341640186829, 
   0.00009282019119135124, 0.00009837630404364141, 
   0.00008166582498003773, 0.00005035809634183823, 
   0.00001887779429038413, 1.289911215650475*^-6, 4.5084482329912*^-6, 
   0.000025278796589912323, 0.000052304503969339025, 
   0.00007217541489530804, 0.00007588540004021932}, 
  {0.00003075065904977202, 0.000029247280426080086, 
   0.000021195091117346933, 0.000010243599621443843, 
   1.8269358056076811*^-6, 5.22704235279496*^-7, 7.64975364862702*^-6, 
   0.00002040635814244282, 0.00003309303157983481, 
   0.00003986453497799849, 0.000037613059307156016, 
   0.000027479689711974435, 0.000014204483532281826, 
   3.6769759194592787*^-6, 3.738319910672119*^-9, 3.6366534841756463*^-6, 
   0.000011483852807670471, 0.000018816320402672696, 
   0.00002182245833053474, 0.000019389408446455843, 
   0.000013232125496933034, 6.497448494451171*^-6, 
   1.8269672929084564*^-6, 6.828167200149332*^-8, 2.9403130714223803*^-7, 
   8.96187204954859*^-7, 8.590619326405999*^-7, 3.018373666324055*^-7, 
   1.5511005771872967*^-9, 4.1005141195187904*^-7, 
   1.0800790528072784*^-6, 1.1008160279363322*^-6, 
   3.0300186308287384*^-7, 2.2945246356762314*^-7, 
   3.7973556730845465*^-6, 0.000013392153924516445, 
   0.000028385712657059223, 0.000043904364285942745, 
   0.00005235046123582118, 0.00004763834727439212, 
   0.00003012526672860896, 9.06827743964802*^-6, 1.1798670255418699*^-7, 
   0.000017878464297024422, 0.00006673180140878076, 
   0.00013507980453996308, 0.0001973947205058832, 0.00022486487460098755, 
   0.00020054417036548296, 0.00013140532152956742, 
   0.000049873272924716574, 1.8569438925804642*^-6, 
   0.000025226107598469216, 0.00012861424095301, 0.0002819066719778385, 
   0.0004253062581709831, 0.000495035786728909, 0.00045471302940465626, 
   0.00031702745097854487, 0.00014345846522270244, 
   0.000019625717409935514, 0.000016024923871961736, 
   0.00015229318866933112, 0.0003830795434936852, 0.0006143619616401478, 
   0.0007446134556794696, 0.0007125076090347087, 0.0005284005839483462, 
   0.0002733899024926836, 0.00006468270813855077, 2.3120664133082364*^-6, 
   0.00012190613208069112, 0.0003762061645185944, 0.0006549273416100806, 
   0.0008344518870884, 0.0008344518870884187, 0.0006549273416101281, 
   0.0003762061645186495, 0.00012190613208072984, 2.312066413313927*^-6, 
   0.00006468270813852228, 0.0002733899024926352, 0.0005284005839483005, 
   0.0007125076090346862, 0.0007446134556794798, 0.0006143619616401858, 
   0.000383079543493733, 0.00015229318866936834, 0.00001602492387197491, 
   0.000019625717409921643, 0.00014345846522267116, 
   0.00031702745097851235, 0.00045471302940463783, 0.0004950357867289123, 
   0.00042530625817100565, 0.00028190667197786946, 
   0.00012861424095303662, 0.000025226107598481915, 
   1.8569438925772383*^-6, 0.000049873272924702425, 
   0.0001314053215295518, 0.00020054417036547358, 0.000224864874600988, 
   0.00019739472050589267, 0.0001350798045399768, 0.00006673180140879281, 
   0.00001787846429703102, 1.1798670255468086*^-7, 9.068277439644548*^-6, 
   0.00003012526672860473, 0.00004763834727438989, 
   0.000052350461235821684, 0.00004390436428594525, 
   0.000028385712657062374, 0.000013392153924518906, 
   3.7973556730857827*^-6, 2.2945246356786052*^-7, 
   3.0300186308270904*^-7, 1.100816027936239*^-6, 1.0800790528073788*^-6, 
   4.100514119520143*^-7, 1.5511005771971064*^-9, 3.018373666322979*^-7, 
   8.590619326405233*^-7, 8.96187204954926*^-7, 2.9403130714236456*^-7, 
   6.828167200139696*^-8, 1.826967292907848*^-6, 6.497448494450019*^-6, 
   0.00001323212549693169, 0.00001938940844645491, 
   0.000021822458330534782, 0.000018816320402673835, 
   0.000011483852807672159, 3.6366534841769427*^-6, 
   3.738319910719941*^-9, 3.6769759194577744*^-6, 
   0.000014204483532279381, 0.000027479689711972033, 
   0.000037613059307154735, 0.00003986453497799894, 
   0.00003309303157983682, 0.000020406358142445446, 
   7.649753648629051*^-6, 5.227042352800726*^-7, 1.8269358056066547*^-6, 
   0.000010243599621441716, 0.00002119509111734485, 
   0.00002924728042607904, 0.000030750659049772426}, 
  {3.81995167335125*^-8, 3.633196856813584*^-8, 2.6329264569418033*^-8, 
   1.2724948578090636*^-8, 2.2694819244168738*^-9, 
   6.493210161746109*^-10, 9.50278470568723*^-9, 2.5349473585935153*^-8, 
   4.11092917244624*^-8, 4.952108403598711*^-8, 4.672422422156044*^-8, 
   3.4136207139016786*^-8, 1.764529356928775*^-8, 4.5676648079888415*^-9, 
   4.643868404635097*^-12, 4.517574904586771*^-9, 1.4265633357053366*^-8, 
   2.3374274512999657*^-8, 2.710860150393497*^-8, 2.408618401330783*^-8, 
   1.6437397277304152*^-8, 8.07135196963407*^-9, 2.269521039015065*^-9, 
   8.482182017600023*^-11, 3.652557110784833*^-10, 
   1.1132742903696154*^-9, 1.067156011775672*^-9, 
   3.7495266422783886*^-10, 1.9268300024960383*^-12, 
   5.093798395378574*^-10, 1.3417110112810363*^-9, 
   1.3674711885560203*^-9, 3.763992414076574*^-10, 
   2.8503367057630817*^-10, 4.71720464079508*^-9, 1.663619004423041*^-8, 
   3.526169972100323*^-8, 5.453949769013268*^-8, 6.503152718607098*^-8, 
   5.9177978622169174*^-8, 3.742263307717813*^-8, 1.1264923305848192*^-8, 
   1.4656710320437971*^-10, 2.220923769400492*^-8, 8.289651810213975*^-8, 
   1.678007370681759*^-7, 2.4521044953433*^-7, 2.7933481120507227*^-7, 
   2.4912280349131066*^-7, 1.6323616903679064*^-7, 6.195427943704092*^-8, 
   2.3067589928075766*^-9, 3.133673062972144*^-8, 1.5976899361735595*^-7, 
   3.5019407603838325*^-7, 5.28329929435789*^-7, 6.149503263728809*^-7, 
   5.648600229209757*^-7, 3.938223047199219*^-7, 1.7820899493467186*^-7, 
   2.4379735061762114*^-8, 1.990670660454689*^-8, 1.8918378951026812*^-7, 
   4.7587446526814674*^-7, 7.631813677918679*^-7, 9.249842129948544*^-7, 
   8.851012360425531*^-7, 6.563972146373323*^-7, 3.39614254710422*^-7, 
   8.035106460346884*^-8, 2.8721276998066484*^-9, 1.514359521464848*^-7, 
   4.673361196427804*^-7, 8.135730653634434*^-7, 1.0365845744168121*^-6, 
   1.0365845744168354*^-6, 8.135730653635024*^-7, 4.673361196428489*^-7, 
   1.514359521465329*^-7, 2.872127699813717*^-9, 8.035106460343347*^-8, 
   3.396142547103619*^-7, 6.563972146372755*^-7, 8.851012360425252*^-7, 
   9.249842129948671*^-7, 7.631813677919152*^-7, 4.758744652682062*^-7, 
   1.8918378951031436*^-7, 1.9906706604563254*^-8, 2.437973506174488*^-8, 
   1.78208994934633*^-7, 3.938223047198815*^-7, 5.648600229209528*^-7, 
   6.149503263728849*^-7, 5.28329929435817*^-7, 3.501940760384218*^-7, 
   1.59768993617389*^-7, 3.133673062973722*^-8, 2.306758992803569*^-9, 
   6.195427943702333*^-8, 1.6323616903677123*^-7, 2.49122803491299*^-7, 
   2.7933481120507285*^-7, 2.4521044953434173*^-7, 1.678007370681929*^-7, 
   8.289651810215472*^-8, 2.2209237694013113*^-8, 1.465671032049932*^-10, 
   1.126492330584388*^-8, 3.7422633077172876*^-8, 5.91779786221664*^-8, 
   6.50315271860716*^-8, 5.4539497690135796*^-8, 3.5261699721007145*^-8, 
   1.663619004423347*^-8, 4.717204640796615*^-9, 2.8503367057660306*^-10, 
   3.763992414074527*^-10, 1.3674711885559045*^-9, 
   1.3417110112811608*^-9, 5.093798395380254*^-10, 
   1.9268300025082242*^-12, 3.7495266422770516*^-10, 
   1.067156011775577*^-9, 1.1132742903696988*^-9, 3.652557110786405*^-10, 
   8.482182017588052*^-11, 2.2695210390143096*^-9, 8.07135196963264*^-9, 
   1.6437397277302484*^-8, 2.4086184013306676*^-8, 
   2.7108601503935016*^-8, 2.3374274513001074*^-8, 
   1.4265633357055463*^-8, 4.517574904588381*^-9, 4.643868404694503*^-12, 
   4.567664807986973*^-9, 1.7645293569284714*^-8, 3.41362071390138*^-8, 
   4.6724224221558845*^-8, 4.952108403598768*^-8, 4.1109291724464895*^-8, 
   2.5349473585938416*^-8, 9.502784705689754*^-9, 6.493210161753272*^-10, 
   2.269481924415599*^-9, 1.2724948578087994*^-8, 2.6329264569415442*^-8, 
   3.633196856813454*^-8, 3.819951673351301*^-8}, 
  {0.000036506987099765965, 0.000034722185546981294, 
   0.000025162677546095893, 0.000012161136404586764, 
   2.1689265839625844*^-6, 6.20551147975577*^-7, 9.081738941425542*^-6, 
   0.000024226298768217372, 0.000039287836889015693, 
   0.0000473269227116207, 0.000044653985096272506, 
   0.000032623713078697736, 0.000016863472624522344, 
   4.3652824559168335*^-6, 4.438109652635791*^-9, 4.317411916870887*^-6, 
   0.000013633557109350646, 0.00002233861606327192, 
   0.00002590748391663881, 0.00002301898254867174, 
   0.00001570909534124603, 7.713729581678065*^-6, 2.1689639654860618*^-6, 
   8.106356728401399*^-8, 3.4907210019125076*^-7, 1.063947757259691*^-6, 
   1.0198728697830272*^-6, 3.5833940443491905*^-7, 
   1.8414567528508306*^-9, 4.868104316768799*^-7, 1.2822629909733624*^-6, 
   1.306881796128049*^-6, 3.5972188722418745*^-7, 2.724045072957499*^-7, 
   4.508196534784462*^-6, 0.000015899080073993627, 
   0.00003369933776416436, 0.00005212298240555012, 
   0.00006215013505595391, 0.00005655594329167063, 
   0.00003576452530849058, 0.000010765801375849973, 
   1.4007306383638508*^-7, 0.000021225199251784364, 
   0.00007922357076091887, 0.00016036588594077307, 
   0.00023434575835940054, 0.00026695815081431907, 0.000238084765227828, 
   0.00015600356305066194, 0.000059209232827783374, 
   2.204551994209269*^-6, 0.00002994827470800017, 0.000152690009918748, 
   0.0003346778103381562, 0.0005049208882114325, 0.0005877033416026498, 
   0.0005398324202321238, 0.0003763729760852469, 0.0001703129786831756, 
   0.000023299527049111492, 0.00001902468783259382, 
   0.00018080150624201713, 0.00045478960076505694, 0.0007293666185131753, 
   0.0008840003648963775, 0.0008458845076918132, 0.000627313816932782, 
   0.0003245667557027748, 0.00007679090024607154, 2.744870559939161*^-6, 
   0.00014472618567455228, 0.00044662956890462424, 0.0007775255799475457, 
   0.0009906559800232132, 0.0009906559800232353, 0.000777525579947602, 
   0.00044662956890468967, 0.00014472618567459825, 
   2.7448705599459166*^-6, 0.00007679090024603772, 
   0.00032456675570271735, 0.0006273138169327277, 0.0008458845076917865, 
   0.0008840003648963896, 0.0007293666185132204, 0.0004547896007651137, 
   0.0001808015062420613, 0.00001902468783260946, 
   0.000023299527049095022, 0.00017031297868313846, 
   0.0003763729760852083, 0.000539832420232102, 0.0005877033416026537, 
   0.0005049208882114594, 0.000334677810338193, 0.00015269000991877961, 
   0.00002994827470801525, 2.204551994205439*^-6, 
   0.000059209232827766576, 0.0001560035630506434, 
   0.00023808476522781686, 0.00026695815081431967, 0.0002343457583594118, 
   0.00016036588594078936, 0.00007922357076093317, 
   0.00002122519925179219, 1.4007306383697142*^-7, 
   0.000010765801375845851, 0.00003576452530848556, 
   0.00005655594329166798, 0.0000621501350559545, 0.0000521229824055531, 
   0.0000336993377641681, 0.000015899080073996548, 4.508196534785929*^-6, 
   2.724045072960317*^-7, 3.597218872239918*^-7, 1.306881796127938*^-6, 
   1.2822629909734814*^-6, 4.868104316770405*^-7, 1.8414567528624765*^-9, 
   3.5833940443479125*^-7, 1.0198728697829362*^-6, 
   1.0639477572597706*^-6, 3.4907210019140095*^-7, 8.106356728389959*^-8, 
   2.1689639654853397*^-6, 7.713729581676698*^-6, 
   0.000015709095341244433, 0.000023018982548670635, 
   0.000025907483916638858, 0.000022338616063273277, 
   0.00001363355710935265, 4.317411916872426*^-6, 4.438109652692565*^-9, 
   4.365282455915048*^-6, 0.000016863472624519444, 
   0.00003262371307869488, 0.00004465398509627099, 
   0.00004732692271162125, 0.00003928783688901808, 
   0.00002422629876822049, 9.081738941427953*^-6, 6.205511479762617*^-7, 
   2.168926583961366*^-6, 0.000012161136404584238, 
   0.000025162677546093416, 0.00003472218554698005, 
   0.00003650698709976645}, {0.00008827786502393479, 
   0.0000839620207681308, 0.000060846090804061115, 
   0.000029406950377141702, 5.244700355650561*^-6, 1.500560162133647*^-6, 
   0.000021960632419839323, 0.000058581825085859275, 
   0.00009500226223799024, 0.00011444164602565708, 0.0001079781921837864, 
   0.00007888768612623519, 0.000040777710746553123, 
   0.000010555727712661535, 1.0731831794448906*^-8, 
   0.000010439971543219984, 0.00003296742377031377, 
   0.000054017203015574574, 0.00006264711360739664, 
   0.00005566240316865209, 0.00003798630093447316, 
   0.00001865263701388479, 5.244790748239654*^-6, 1.960205215374434*^-7, 
   8.440943006360068*^-7, 2.572741383758049*^-6, 2.466163512596641*^-6, 
   8.665036501373118*^-7, 4.452842690943975*^-9, 1.1771605655206349*^-6, 
   3.1006513611488646*^-6, 3.160182309363156*^-6, 8.698466438698658*^-7, 
   6.587037232420591*^-7, 0.00001090130949758997, 0.00003844570467952251, 
   0.00008148866359228972, 0.00012603903994782355, 
   0.00015028578553183286, 0.00013675842146489858, 0.0000864825116682464, 
   0.000026032878531843235, 3.3871190161613405*^-7, 
   0.00005132484007882298, 0.00019157120984085197, 
   0.00038778215235444724, 0.0005666735293396868, 0.0006455338409664807, 
   0.0005757148545729248, 0.0003772335811937633, 0.0001431743641144053, 
   5.330846471970285*^-6, 0.00007241818518596698, 0.00036922104936446296, 
   0.0008092873423599287, 0.0012209536189739375, 0.0014211305940513164, 
   0.0013053735001073525, 0.0009101107875791552, 0.00041183530437421506, 
   0.000056340790280558854, 0.00004600376415666957, 
   0.0004371977046623826, 0.0010997307140386903, 0.0017636878038199595, 
   0.002137609019341171, 0.0020454407314356026, 0.0015169130311275803, 
   0.0007848377126517146, 0.00018568874797757827, 6.637395524760655*^-6, 
   0.00034996365625825516, 0.0010799988695784034, 0.001880141409963302, 
   0.0023955138957551412, 0.0023955138957551946, 0.001880141409963438, 
   0.0010799988695785617, 0.0003499636562583663, 6.6373955247769906*^-6, 
   0.00018568874797749652, 0.0007848377126515756, 0.001516913031127449, 
   0.0020454407314355384, 0.0021376090193412005, 0.0017636878038200686, 
   0.0010997307140388278, 0.00043719770466248945, 0.00004600376415670738, 
   0.00005634079028051903, 0.00041183530437412523, 0.0009101107875790619, 
   0.0013053735001072998, 0.0014211305940513258, 0.0012209536189740024, 
   0.0008092873423600176, 0.00036922104936453935, 0.00007241818518600344, 
   5.3308464719610245*^-6, 0.00014317436411436467, 
   0.00037723358119371846, 0.0005757148545728978, 0.0006455338409664821, 
   0.0005666735293397141, 0.0003877821523544866, 0.00019157120984088658, 
   0.00005132484007884191, 3.387119016175518*^-7, 
   0.000026032878531833267, 0.00008648251166823426, 
   0.00013675842146489218, 0.0001502857855318343, 0.00012603903994783073, 
   0.00008148866359229878, 0.00003844570467952958, 
   0.000010901309497593518, 6.587037232427407*^-7, 8.698466438693927*^-7, 
   3.160182309362888*^-6, 3.1006513611491526*^-6, 1.1771605655210232*^-6, 
   4.4528426909721365*^-9, 8.665036501370028*^-7, 2.466163512596421*^-6, 
   2.5727413837582413*^-6, 8.4409430063637*^-7, 1.9602052153716676*^-7, 
   5.244790748237907*^-6, 0.000018652637013881484, 
   0.000037986300934469305, 0.00005566240316864942, 
   0.00006264711360739676, 0.00005401720301557785, 
   0.00003296742377031862, 0.000010439971543223704, 
   1.0731831794586191*^-8, 0.000010555727712657216, 
   0.00004077771074654611, 0.0000788876861262283, 0.00010797819218378271, 
   0.0001144416460256584, 0.000095002262237996, 0.00005858182508586681, 
   0.000021960632419845154, 1.5005601621353025*^-6, 
   5.244700355647615*^-6, 0.000029406950377135594, 
   0.000060846090804055125, 0.0000839620207681278, 
   0.00008827786502393597}, {0.00007528815721037128, 
   0.00007160737085766158, 0.000051892850476737684, 
   0.000025079844222235672, 4.4729652760683564*^-6, 
   1.2797591939916927*^-6, 0.000018729219896921604, 
   0.00004996176171160031, 0.00008102308832203245, 
   0.00009760205046935885, 0.00009208966603599267, 
   0.00006727970271397133, 0.00003477744615293026, 9.002497820776041*^-6, 
   9.15268894503353*^-9, 8.903774673352585*^-6, 0.00002811640928297659, 
   0.00004606880412885464, 0.00005342886052773093, 
   0.000047471920161779136, 0.00003239678027804228, 
   0.000015907981774464008, 4.473042367777092*^-6, 
   1.6717694563601716*^-7, 7.198894580134179*^-7, 2.194173564454544*^-6, 
   2.1032781682306867*^-6, 7.39001368204936*^-7, 3.797626057879258*^-9, 
   1.003946455827153*^-6, 2.6444038612559805*^-6, 2.6951750867135152*^-6, 
   7.418524548008972*^-7, 5.617783060007058*^-7, 9.29722873373682*^-6, 
   0.00003278858473968089, 0.00006949795754276508, 0.0001074929378011485, 
   0.00012817187915155183, 0.0001166350084735269, 0.00007375698237221014, 
   0.000022202252524033136, 2.888719034039305*^-7, 
   0.00004377261080797435, 0.00016338233100187196, 
   0.00033072167798713775, 0.0004832899589530721, 0.0005505463152073513, 
   0.0004910008920999663, 0.00032172528366252384, 0.00012210687278195597, 
   4.546435362219441*^-6, 0.00006176216098670485, 0.00031489176139899933, 
   0.0006902041938082438, 0.001041295549988192, 0.0012120173449187343, 
   0.0011132934090294156, 0.000776191903095258, 0.0003512355122328826, 
   0.000048050485530536954, 0.000039234508301227176, 
   0.00037286594450047545, 0.0009379100736653531, 0.0015041687359340827, 
   0.0018230690542734682, 0.0017444629331607319, 0.0012937058087101395, 
   0.0006693522218591227, 0.000158365448078547, 5.660731346415169*^-6, 
   0.00029846801078780145, 0.0009210816851743777, 0.0016034866952510357, 
   0.0020430243383700165, 0.0020430243383700625, 0.001603486695251152, 
   0.0009210816851745126, 0.0002984680107878962, 5.660731346429101*^-6, 
   0.00015836544807847728, 0.0006693522218590042, 0.0012937058087100276, 
   0.001744462933160677, 0.0018230690542734931, 0.0015041687359341758, 
   0.0009379100736654702, 0.00037286594450056657, 
   0.000039234508301259425, 0.00004805048553050299, 0.000351235512232806, 
   0.0007761919030951784, 0.0011132934090293705, 0.0012120173449187421, 
   0.0010412955499882475, 0.0006902041938083197, 0.00031489176139906443, 
   0.00006176216098673594, 4.5464353622115435*^-6, 
   0.00012210687278192133, 0.00032172528366248556, 0.0004910008920999433, 
   0.0005505463152073525, 0.0004832899589530953, 0.0003307216779871713, 
   0.00016338233100190145, 0.0000437726108079905, 2.888719034051397*^-7, 
   0.00002220225252402464, 0.00007375698237219977, 
   0.00011663500847352146, 0.00012817187915155305, 
   0.00010749293780115464, 0.0000694979575427728, 0.00003278858473968692, 
   9.297228733739846*^-6, 5.61778306001287*^-7, 7.418524548004938*^-7, 
   2.695175086713287*^-6, 2.6444038612562257*^-6, 1.0039464558274842*^-6, 
   3.797626057903275*^-9, 7.390013682046725*^-7, 2.1032781682304987*^-6, 
   2.1941735644547084*^-6, 7.198894580137276*^-7, 1.6717694563578124*^-7, 
   4.473042367775603*^-6, 0.00001590798177446119, 0.00003239678027803899, 
   0.00004747192016177686, 0.000053428860527731027, 
   0.000046068804128857434, 0.000028116409282980723, 
   8.903774673355758*^-6, 9.152688945150614*^-9, 9.002497820772358*^-6, 
   0.00003477744615292428, 0.00006727970271396544, 
   0.00009208966603598954, 0.00009760205046935997, 
   0.00008102308832203737, 0.00004996176171160673, 
   0.000018729219896926575, 1.2797591939931045*^-6, 
   4.472965276065843*^-6, 0.00002507984422223046, 
   0.000051892850476732575, 0.00007160737085765902, 
   0.00007528815721037229}, {0.000016508182664212134, 
   0.000015701108939606475, 0.000011378371929637628, 
   5.499173640998857*^-6, 9.807721501495671*^-7, 2.806085222884096*^-7, 
   4.106693465117599*^-6, 0.000010954948548632041, 
   0.00001776566184640859, 0.000021400875479628197, 
   0.00002019219336396562, 0.000014752195606178663, 
   7.625534412845049*^-6, 1.973947616280216*^-6, 2.0068795222486156*^-9, 
   1.952300921617488*^-6, 6.164991115510905*^-6, 0.000010101352747363814, 
   0.000011715167721106003, 0.000010409009311541365, 
   7.103533761198161*^-6, 3.4880900088710547*^-6, 9.807890537909481*^-7, 
   3.6656330265768016*^-8, 1.5784775602515467*^-7, 4.811091058822109*^-7, 
   4.6117877606942754*^-7, 1.6203836071244983*^-7, 
   8.326927763508407*^-10, 2.2013198478976677*^-7, 5.798295986655924*^-7, 
   5.909620356250591*^-7, 1.6266350894374605*^-7, 1.2317925203479128*^-7, 
   2.0385722787533777*^-6, 7.189443416329054*^-6, 
   0.000015238584930427569, 0.000023569617295530055, 
   0.00002810381966896738, 0.000025574168584613405, 
   0.00001617244707370511, 4.8682137244981516*^-6, 6.333997702488343*^-8, 
   9.597874110378207*^-6, 0.00003582429779423699, 0.00007251623726120804, 
   0.00010596937443805386, 0.00012071645094402552, 
   0.00010766012498391689, 0.00007054362793813712, 
   0.000026773965987874674, 9.968816904474992*^-7, 
   0.00001354238266791511, 0.00006904526434489615, 
   0.00015133876733301404, 0.0002283213958684637, 0.00026575499339430837, 
   0.0002441081258473054, 0.00017019300502966545, 0.0000770142371514946, 
   0.000010535869406734739, 8.602819537306768*^-6, 
   0.00008175706975903917, 0.00020565240792664043, 0.0003298140527096911, 
   0.00039973825994074245, 0.0003825025584182794, 0.0002836665498966055, 
   0.00014676662511835906, 0.00003472426263901597, 
   1.2412096476015245*^-6, 0.00006544408342658074, 
   0.00020196250341248024, 0.0003515911697888058, 0.0004479671201275914, 
   0.0004479671201276014, 0.00035159116978883127, 0.00020196250341250984, 
   0.00006544408342660152, 1.2412096476045793*^-6, 
   0.000034724262639000685, 0.00014676662511833307, 0.000283666549896581, 
   0.00038250255841826736, 0.0003997382599407479, 0.0003298140527097115, 
   0.0002056524079266661, 0.00008175706975905915, 8.60281953731384*^-6, 
   0.000010535869406727292, 0.00007701423715147781, 0.000170193005029648, 
   0.00024410812584729554, 0.0002657549933943101, 0.00022832139586847586, 
   0.00015133876733303066, 0.00006904526434491044, 
   0.000013542382667921927, 9.968816904457674*^-7, 
   0.000026773965987867078, 0.00007054362793812873, 
   0.00010766012498391186, 0.00012071645094402577, 
   0.00010596937443805896, 0.0000725162372612154, 
   0.000035824297794243456, 9.597874110381748*^-6, 6.333997702514856*^-8, 
   4.868213724496288*^-6, 0.00001617244707370284, 
   0.000025574168584612205, 0.000028103819668967647, 
   0.000023569617295531403, 0.000015238584930429261, 
   7.189443416330376*^-6, 2.038572278754041*^-6, 1.231792520349187*^-7, 
   1.626635089436576*^-7, 5.909620356250091*^-7, 5.798295986656462*^-7, 
   2.201319847898394*^-7, 8.326927763561069*^-10, 1.6203836071239208*^-7, 
   4.6117877606938636*^-7, 4.811091058822469*^-7, 1.578477560252226*^-7, 
   3.665633026571628*^-8, 9.807890537906214*^-7, 3.4880900088704363*^-6, 
   7.10353376119744*^-6, 0.000010409009311540865, 
   0.000011715167721106023, 0.000010101352747364425, 
   6.1649911155118115*^-6, 1.9523009216181843*^-6, 
   2.0068795222742884*^-9, 1.973947616279409*^-6, 7.625534412843737*^-6, 
   0.000014752195606177372, 0.00002019219336396493, 
   0.000021400875479628444, 0.000017765661846409668, 
   0.00001095494854863345, 4.106693465118689*^-6, 2.806085222887192*^-7, 
   9.807721501490164*^-7, 5.499173640997714*^-6, 0.000011378371929636508, 
   0.00001570110893960591, 0.000016508182664212354}, 
  {6.399150949681458*^-6, 6.086300850047566*^-6, 4.410656280004549*^-6, 
   2.1316726948720464*^-6, 3.801817052616349*^-7, 1.087737110992457*^-7, 
   1.591898510084249*^-6, 4.246522517627831*^-6, 6.886594011503258*^-6, 
   8.29573039232016*^-6, 7.827202786003277*^-6, 5.718468740221576*^-6, 
   2.9559247539447376*^-6, 7.651713710876757*^-7, 7.779369335750204*^-10, 
   7.567803525530457*^-7, 2.3897669146297987*^-6, 3.915638828403135*^-6, 
   4.5412101485109716*^-6, 4.034897309780406*^-6, 2.753578981931804*^-6, 
   1.3521061007660526*^-6, 3.801882577062617*^-7, 1.4209280052403731*^-8, 
   6.118732984844052*^-8, 1.8649477379971065*^-7, 1.7876907851615755*^-7, 
   6.281175529307649*^-8, 3.227809431821962*^-10, 8.533088276134177*^-8, 
   2.247623013645292*^-7, 2.2907762461909174*^-7, 6.305408468689059*^-8, 
   4.7748601022467895*^-8, 7.902221582427322*^-7, 2.786880579230546*^-6, 
   5.907010311967678*^-6, 9.136410831417095*^-6, 0.000010894026797645208, 
   9.91344526010871*^-6, 6.269008052275046*^-6, 1.8870904879135845*^-6, 
   2.4552797989707054*^-8, 3.720472839296694*^-6, 
   0.000013886755066542867, 0.000028109838495025655, 
   0.00004107744849119562, 0.00004679393288852388, 
   0.000041732842739085127, 0.00002734518589335284, 
   0.0000103785288400929, 3.864263284399285*^-7, 5.249502787378722*^-6, 
   0.000026764367580054048, 0.000058664217400631574, 
   0.00008850538590002973, 0.0001030159620203682, 0.00009462487646972599, 
   0.00006597278161488665, 0.000029853421108270745, 
   4.084072734789073*^-6, 3.334754765673787*^-6, 0.00003169190947504564, 
   0.00007971809061338896, 0.0001278475015418202, 0.00015495257823074841, 
   0.00014827141543958305, 0.00010995910992061698, 
   0.00005689189462046173, 0.000013460342835021106, 
   4.811364192390437*^-7, 0.000025368423473900516, 0.0000782877541277617, 
   0.00013628907638217177, 0.00017364777701454851, 
   0.00017364777701455242, 0.00013628907638218166, 
   0.00007828775412777317, 0.000025368423473908573, 
   4.811364192402279*^-7, 0.00001346034283501518, 0.00005689189462045166, 
   0.00010995910992060747, 0.00014827141543957839, 
   0.00015495257823075053, 0.0001278475015418281, 0.00007971809061339892, 
   0.000031691909475053385, 3.334754765676528*^-6, 4.084072734786186*^-6, 
   0.000029853421108264233, 0.00006597278161487989, 
   0.00009462487646972217, 0.00010301596202036887, 
   0.00008850538590003443, 0.000058664217400638025, 
   0.000026764367580059584, 5.249502787381364*^-6, 
   3.8642632843925717*^-7, 0.000010378528840089956, 
   0.000027345185893349592, 0.000041732842739083175, 
   0.00004679393288852398, 0.00004107744849119759, 
   0.000028109838495028508, 0.000013886755066545376, 
   3.7204728392980667*^-6, 2.4552797989809826*^-8, 1.887090487912862*^-6, 
   6.269008052274165*^-6, 9.913445260108247*^-6, 0.000010894026797645311, 
   9.136410831417619*^-6, 5.907010311968334*^-6, 2.7868805792310582*^-6, 
   7.902221582429894*^-7, 4.7748601022517294*^-8, 6.30540846868563*^-8, 
   2.2907762461907231*^-7, 2.2476230136455005*^-7, 8.533088276136992*^-8, 
   3.227809431842375*^-10, 6.28117552930541*^-8, 1.7876907851614156*^-7, 
   1.864947737997246*^-7, 6.118732984846685*^-8, 1.4209280052383677*^-8, 
   3.8018825770613505*^-7, 1.352106100765813*^-6, 2.753578981931525*^-6, 
   4.034897309780212*^-6, 4.54121014851098*^-6, 3.915638828403372*^-6, 
   2.3897669146301498*^-6, 7.567803525533155*^-7, 7.779369335849721*^-10, 
   7.651713710873626*^-7, 2.955924753944229*^-6, 5.718468740221076*^-6, 
   7.827202786003011*^-6, 8.295730392320257*^-6, 6.886594011503675*^-6, 
   4.2465225176283775*^-6, 1.5918985100846714*^-6, 1.087737110993657*^-7, 
   3.8018170526142136*^-7, 2.1316726948716034*^-6, 4.410656280004115*^-6, 
   6.0863008500473474*^-6, 6.399150949681543*^-6}, 
  {0.00006782166485532157, 0.0000645059101912782, 
   0.000046746522213134954, 0.000022592620838245545, 
   4.029371458984379*^-6, 1.152842656354253*^-6, 0.000016871801913032548, 
   0.000045006943773606055, 0.00007298785021879944, 
   0.0000879226401787022, 0.00008295693104932597, 0.00006060742642807116, 
   0.00003132849022878079, 8.10970028600099*^-6, 8.24499662570516*^-9, 
   8.02076773052208*^-6, 0.000025328043054590877, 
   0.000041500059367666727, 0.00004813020276466954, 
   0.00004276402529357233, 0.00002918392023156333, 
   0.000014330352188293933, 4.029440905338582*^-6, 
   1.5059763976930465*^-7, 6.484964350746438*^-7, 1.976572539915253*^-6, 
   1.8946914403106935*^-6, 6.657129750429722*^-7, 3.4210071183392285*^-9, 
   9.043828748463173*^-7, 2.3821525066563244*^-6, 2.4278886378735267*^-6, 
   6.682813131023629*^-7, 5.060655142097383*^-7, 8.375202085247782*^-6, 
   0.000029536868581883863, 0.00006260569204030776, 
   0.00009683262643144016, 0.00011546079162760873, 
   0.00010506805782197367, 0.0000664423399979141, 
   0.000020000406245974142, 2.6022384057078966*^-7, 
   0.00003943158459524504, 0.00014717934542517582, 
   0.00029792328084427325, 0.00043536102939098264, 0.0004959474246791845, 
   0.0004423072523161787, 0.00028981907875727845, 0.00010999726529643885, 
   4.095555354891239*^-6, 0.000055637071464988464, 0.0002836632519458567, 
   0.0006217551238955246, 0.0009380279770867915, 0.0010918189156393845, 
   0.0010028856498885093, 0.000699215242684796, 0.00031640271297096197, 
   0.000043285213060556, 0.00003534353570819773, 0.0003358880076346269, 
   0.0008448954661331371, 0.001354997009812866, 0.0016422712812794247, 
   0.0015714607023089725, 0.0011654061545769256, 0.0006029710879261723, 
   0.00014265999782986423, 5.09934415235888*^-6, 0.0002688682808522276, 
   0.0008297359859893879, 0.0014444653883798598, 0.0018404131154522258, 
   0.001840413115452267, 0.0014444653883799645, 0.0008297359859895094, 
   0.000268868280852313, 5.09934415237143*^-6, 0.00014265999782980143, 
   0.0006029710879260656, 0.001165406154576825, 0.001571460702308923, 
   0.0016422712812794473, 0.0013549970098129496, 0.0008448954661332426, 
   0.000335888007634709, 0.00003534353570822678, 0.000043285213060525396, 
   0.00031640271297089296, 0.0006992152426847242, 0.0010028856498884686, 
   0.0010918189156393916, 0.0009380279770868414, 0.0006217551238955929, 
   0.0002836632519459154, 0.00005563707146501647, 4.0955553548841235*^-6, 
   0.00010999726529640764, 0.00028981907875724397, 
   0.00044230725231615806, 0.0004959474246791854, 0.00043536102939100357, 
   0.00029792328084430345, 0.00014717934542520238, 
   0.000039431584595259586, 2.602238405718789*^-7, 
   0.000020000406245966485, 0.00006644233999790477, 
   0.00010506805782196875, 0.00011546079162760983, 0.0000968326264314457, 
   0.00006260569204031472, 0.000029536868581889294, 
   8.375202085250508*^-6, 5.060655142102619*^-7, 6.682813131019994*^-7, 
   2.4278886378733213*^-6, 2.3821525066565455*^-6, 9.043828748466157*^-7, 
   3.421007118360864*^-9, 6.657129750427348*^-7, 1.8946914403105243*^-6, 
   1.9765725399154007*^-6, 6.484964350749229*^-7, 1.505976397690921*^-7, 
   4.029440905337241*^-6, 0.000014330352188291392, 
   0.000029183920231560368, 0.00004276402529357028, 
   0.000048130202764669626, 0.00004150005936766925, 
   0.0000253280430545946, 8.02076773052494*^-6, 8.244996625810633*^-9, 
   8.109700285997672*^-6, 0.0000313284902287754, 0.000060607426428065863, 
   0.00008295693104932315, 0.00008792264017870321, 
   0.00007298785021880387, 0.00004500694377361184, 
   0.000016871801913037027, 1.152842656355525*^-6, 4.029371458982115*^-6, 
   0.00002259262083824085, 0.00004674652221313035, 0.0000645059101912759, 
   0.00006782166485532248}, {0.00010979023781752218, 
   0.00010442266841493599, 0.00007567363322428772, 
   0.00003657311008279472, 6.522777812675883*^-6, 1.8662306458757797*^-6, 
   0.000027312203974842786, 0.00007285759013561492, 
   0.00011815329880807132, 0.00014232985278901962, 
   0.00013429132428327065, 0.00009811177262074838, 
   0.00005071480330096733, 0.000013128045808492337, 
   1.334706457400994*^-8, 0.000012984081096971643, 
   0.000041001232811786135, 0.00006718061842240243, 
   0.0000779135460477274, 0.00006922673628008771, 0.00004724315673326511, 
   0.000023198085421788197, 6.5228902329734365*^-6, 
   2.4378862890346984*^-7, 1.0497910657684768*^-6, 3.199690979037535*^-6, 
   3.0671412190527002*^-6, 1.0776613343847054*^-6, 
   5.5379528930633366*^-9, 1.4640220218610673*^-6, 3.856246979211145*^-6, 
   3.930284983643824*^-6, 1.0818189799827281*^-6, 8.19222784855808*^-7, 
   0.000013557842183182748, 0.0000478145122640038, 
   0.00010134658051374305, 0.00015675340773603738, 
   0.00018690882623474683, 0.00017008498803306124, 0.0001075573760255648, 
   0.00003237681296790315, 4.212523741934396*^-7, 0.00006383215539560748, 
   0.00023825506747036755, 0.00048228052090795465, 0.0007047658156915148, 
   0.0008028435429397003, 0.0007160104153119701, 0.0004691613756267163, 
   0.00017806442737634327, 6.629916817399594*^-6, 0.00009006572340331261, 
   0.0004591962753739991, 0.001006502023540291, 0.0015184869746789672, 
   0.0017674449404541804, 0.0016234790791397132, 0.0011318950654449582, 
   0.0005121951691586268, 0.00007007043908518378, 0.00005721439010665402, 
   0.0005437381154963767, 0.0013677233426160128, 0.0021934796833244243, 
   0.0026585215051441987, 0.002543892789943139, 0.001886568534375416, 
   0.0009760942802233523, 0.0002309391124827133, 8.254857918854872*^-6, 
   0.00043524606125970415, 0.001343183058420355, 0.0023383117894216782, 
   0.0029792750452089845, 0.0029792750452090513, 0.002338311789421848, 
   0.001343183058420552, 0.0004352460612598424, 8.254857918875189*^-6, 
   0.00023093911248261162, 0.0009760942802231795, 0.001886568534375253, 
   0.0025438927899430587, 0.002658521505144235, 0.0021934796833245596, 
   0.0013677233426161834, 0.0005437381154965096, 0.00005721439010670106, 
   0.00007007043908513424, 0.0005121951691585151, 0.0011318950654448422, 
   0.0016234790791396475, 0.001767444940454192, 0.0015184869746790479, 
   0.0010065020235404017, 0.00045919627537409406, 0.00009006572340335795, 
   6.629916817388076*^-6, 0.00017806442737629274, 0.0004691613756266606, 
   0.0007160104153119367, 0.000802843542939702, 0.0007047658156915487, 
   0.0004822805209080036, 0.0002382550674704106, 0.00006383215539563102, 
   4.2125237419520284*^-7, 0.00003237681296789076, 0.0001075573760255497, 
   0.0001700849880330533, 0.00018690882623474862, 0.00015675340773604635, 
   0.00010134658051375431, 0.00004781451226401259, 
   0.00001355784218318716, 8.192227848566555*^-7, 1.0818189799821397*^-6, 
   3.9302849836434915*^-6, 3.856246979211502*^-6, 1.4640220218615503*^-6, 
   5.53795289309836*^-9, 1.0776613343843213*^-6, 3.067141219052426*^-6, 
   3.1996909790377743*^-6, 1.0497910657689284*^-6, 2.437886289031258*^-7, 
   6.522890232971265*^-6, 0.000023198085421784084, 
   0.00004724315673326032, 0.00006922673628008439, 
   0.00007791354604772754, 0.0000671806184224065, 
   0.000041001232811792166, 0.000012984081096976271, 
   1.3347064574180678*^-8, 0.000013128045808486965, 
   0.00005071480330095861, 0.0000981117726207398, 0.00013429132428326607, 
   0.00014232985278902124, 0.00011815329880807849, 
   0.00007285759013562428, 0.000027312203974850037, 
   1.8662306458778386*^-6, 6.522777812672219*^-6, 0.00003657311008278712, 
   0.00007567363322428028, 0.00010442266841493225, 
   0.00010979023781752364}, {0.00006604942145860274, 
   0.00006282031055833347, 0.00004552499196187191, 
   0.00002200225457135183, 3.924080222381064*^-6, 1.1227178018621372*^-6, 
   0.000016430925983565094, 0.00004383087033041616, 0.00007108060957723, 
   0.00008562513953770216, 0.00008078918902208656, 
   0.00005902369781408914, 0.00003050984754202919, 7.897786249212105*^-6, 
   8.029547169295533*^-9, 7.811177584403485*^-6, 0.000024666197652372226, 
   0.00004041562408677704, 0.00004687251564928563, 
   0.00004164656140345221, 0.000028421317160242545, 
   0.00001395588671192239, 3.9241478540372224*^-6, 
   1.4666238289803884*^-7, 6.315506180218122*^-7, 1.924922854826083*^-6, 
   1.8451813847691*^-6, 6.483172737335641*^-7, 3.3316130097083326*^-9, 
   8.807505063181918*^-7, 2.319904638531813*^-6, 2.3644456419574158*^-6, 
   6.508184987225811*^-7, 4.928415500416727*^-7, 8.156350238667058*^-6, 
   0.00002876504264078286, 0.00006096974688101193, 
   0.00009430229953447966, 0.00011244369338947985, 
   0.00010232253141712526, 0.00006470613964696368, 
   0.000019477776965540893, 2.5342394876476877*^-7, 
   0.00003840120049054697, 0.00014333341177521908, 0.0002901382674811923, 
   0.00042398463939565006, 0.0004829878556331817, 0.0004307493510333014, 
   0.0002822458357579152, 0.00010712293410013754, 3.988534671322263*^-6, 
   0.000054183222864737494, 0.0002762508664459542, 0.0006055080822599271, 
   0.0009135164306380884, 0.0010632886684420867, 0.0009766793119215709, 
   0.0006809440958561723, 0.00030813481480062216, 0.0000421541300476901, 
   0.000034419976136058516, 0.00032711094053022356, 
   0.0008228175591108555, 0.0013195896734058744, 0.0015993572000624983, 
   0.0015303969676039746, 0.0011349530041514628, 0.0005872148906805118, 
   0.00013893215895021955, 4.966093530733868*^-6, 0.0002618425017542951, 
   0.0008080542103307312, 0.0014067201597452335, 0.001792321403194015, 
   0.0017923214031940551, 0.0014067201597453356, 0.0008080542103308496, 
   0.00026184250175437826, 4.96609353074609*^-6, 0.00013893215895015838, 
   0.0005872148906804079, 0.0011349530041513645, 0.0015303969676039265, 
   0.0015993572000625204, 0.001319589673405956, 0.0008228175591109583, 
   0.0003271109405303035, 0.00003441997613608681, 0.00004215413004766031, 
   0.000308134814800555, 0.0006809440958561024, 0.0009766793119215314, 
   0.0010632886684420937, 0.000913516430638137, 0.0006055080822599937, 
   0.0002762508664460113, 0.000054183222864764776, 3.988534671315334*^-6, 
   0.00010712293410010714, 0.00028224583575788166, 0.0004307493510332813, 
   0.00048298785563318273, 0.00042398463939567044, 0.0002901382674812218, 
   0.000143333411775245, 0.00003840120049056114, 2.5342394876582957*^-7, 
   0.000019477776965533435, 0.0000647061396469546, 
   0.00010232253141712046, 0.00011244369338948092, 
   0.00009430229953448504, 0.0000609697468810187, 
   0.000028765042640788144, 8.156350238669712*^-6, 4.928415500421826*^-7, 
   6.508184987222271*^-7, 2.364445641957215*^-6, 2.3199046385320283*^-6, 
   8.807505063184823*^-7, 3.331613009729403*^-9, 6.483172737333329*^-7, 
   1.845181384768935*^-6, 1.924922854826227*^-6, 6.31550618022084*^-7, 
   1.4666238289783185*^-7, 3.9241478540359155*^-6, 
   0.000013955886711919914, 0.000028421317160239662, 
   0.00004164656140345021, 0.00004687251564928571, 
   0.00004041562408677949, 0.00002466619765237585, 7.81117758440627*^-6, 
   8.029547169398249*^-9, 7.897786249208875*^-6, 0.000030509847542023938, 
   0.00005902369781408398, 0.00008078918902208381, 
   0.00008562513953770315, 0.00007108060957723433, 0.0000438308703304218, 
   0.000016430925983569455, 1.1227178018633758*^-6, 
   3.924080222378859*^-6, 0.00002200225457134726, 0.00004552499196186743, 
   0.00006282031055833122, 0.00006604942145860362}, 
  {4.219727574822718*^-6, 4.013427988738273*^-6, 2.908474588918184*^-6, 
   1.4056674270976513*^-6, 2.50699387739166*^-7, 7.172755131899728*^-8, 
   1.0497295800868844*^-6, 2.800241517295626*^-6, 4.541157237179386*^-6, 
   5.470369829533527*^-6, 5.161413395236654*^-6, 3.7708721701706215*^-6, 
   1.9491956497670316*^-6, 5.045692404246688*^-7, 5.129871065540266*^-10, 
   4.990360356964401*^-7, 1.5758598955326013*^-6, 2.582050223097444*^-6, 
   2.9945644097816463*^-6, 2.6606916407411707*^-6, 
   1.8157648180010972*^-6, 8.91605689934936*^-7, 2.507037085516443*^-7, 
   9.369882243282777*^-9, 4.034814384306565*^-8, 1.229783678727157*^-7, 
   1.1788389054610885*^-7, 4.141932233156736*^-8, 2.128481820921882*^-10, 
   5.62688834508463*^-8, 1.4821273764384785*^-7, 1.5105834773723963*^-7, 
   4.157911915981975*^-8, 3.14863784239604*^-8, 5.210882283592274*^-7, 
   1.8377245544586562*^-6, 3.895200237371013*^-6, 6.0247312531608286*^-6, 
   7.183738224079467*^-6, 6.537123230021421*^-6, 4.13390875648706*^-6, 
   1.2443850489932572*^-6, 1.6190603961510868*^-8, 
   2.4533538831648794*^-6, 9.157202844545647*^-6, 
   0.000018536187308908137, 0.000027087287589345963, 
   0.0000308568512442947, 0.00002751946760853073, 0.00001803196015536688, 
   6.843808604766995*^-6, 2.5481721662412676*^-7, 3.4616266814448856*^-6, 
   0.000017648956992625276, 0.0000386843532473886, 
   0.000058362214040484854, 0.000067930776911252, 0.00006239752799133021, 
   0.00004350376603976692, 0.000019685940407396617, 
   2.6931188953167223*^-6, 2.199003703871937*^-6, 
   0.000020898276249803488, 0.00005256769653015897, 
   0.00008430518858991182, 0.00010217881595412463, 
   0.00009777312415478311, 0.00007250922690893657, 
   0.00003751564831047171, 8.876018127113152*^-6, 3.172709366412931*^-7, 
   0.000016728443648907304, 0.00005162450416649441, 
   0.00008987173115295831, 0.00011450680234561932, 
   0.00011450680234562189, 0.00008987173115296483, 
   0.00005162450416650198, 0.000016728443648912617, 
   3.1727093664207394*^-7, 8.876018127109244*^-6, 0.00003751564831046507, 
   0.00007250922690893029, 0.00009777312415478003, 
   0.00010217881595412603, 0.00008430518858991703, 
   0.000052567696530165535, 0.000020898276249808597, 
   2.1990037038737446*^-6, 2.6931188953148186*^-6, 
   0.000019685940407392324, 0.00004350376603976246, 
   0.0000623975279913277, 0.00006793077691125245, 0.00005836221404048796, 
   0.000038684353247392855, 0.00001764895699262893, 
   3.461626681446628*^-6, 2.548172166236841*^-7, 6.843808604765053*^-6, 
   0.000018031960155364738, 0.000027519467608529445, 
   0.00003085685124429476, 0.000027087287589347264, 
   0.000018536187308910017, 9.1572028445473*^-6, 2.4533538831657845*^-6, 
   1.619060396157864*^-8, 1.244385048992781*^-6, 4.133908756486479*^-6, 
   6.537123230021115*^-6, 7.183738224079536*^-6, 6.0247312531611724*^-6, 
   3.8952002373714454*^-6, 1.837724554458994*^-6, 5.21088228359397*^-7, 
   3.148637842399298*^-8, 4.157911915979714*^-8, 1.5105834773722684*^-7, 
   1.482127376438616*^-7, 5.626888345086486*^-8, 2.1284818209353432*^-10, 
   4.141932233155259*^-8, 1.1788389054609832*^-7, 1.229783678727249*^-7, 
   4.0348143843083015*^-8, 9.369882243269554*^-9, 2.507037085515608*^-7, 
   8.916056899347779*^-7, 1.815764818000913*^-6, 2.660691640741043*^-6, 
   2.994564409781652*^-6, 2.582050223097601*^-6, 1.575859895532833*^-6, 
   4.990360356966181*^-7, 5.12987106560589*^-10, 5.045692404244624*^-7, 
   1.9491956497666962*^-6, 3.770872170170292*^-6, 5.161413395236478*^-6, 
   5.47036982953359*^-6, 4.541157237179661*^-6, 2.800241517295986*^-6, 
   1.0497295800871633*^-6, 7.172755131907642*^-8, 2.5069938773902517*^-7, 
   1.4056674270973593*^-6, 2.9084745889178978*^-6, 4.013427988738129*^-6, 
   4.219727574822774*^-6}, {0.000026803440252094174, 
   0.000025493038447333473, 0.00001847444496984569, 
   8.928709787173818*^-6, 1.5924265112744003*^-6, 4.556088283231255*^-7, 
   6.6678152989288175*^-6, 0.000017786955406338084, 
   0.000028845140953730037, 0.000034747440037979366, 
   0.00003278496848493741, 0.00002395233936771363, 
   0.000012381166369577181, 3.2049916135487344*^-6, 
   3.2584613619738682*^-9, 3.1698450502443693*^-6, 
   0.000010009761484982594, 0.00001640101823056821, 
   0.00001902128201771465, 0.000016900543496542795, 
   0.000011533622241760895, 5.6634224401565265*^-6, 
   1.5924539567995079*^-6, 5.951689402307905*^-8, 2.5628883467102663*^-7, 
   7.811507442432174*^-7, 7.48790949394354*^-7, 2.6309289206733617*^-7, 
   1.35199806867023*^-9, 3.574163565974216*^-7, 9.414378505709778*^-7, 
   9.595129842772544*^-7, 2.6410791132215553*^-7, 1.9999946628708754*^-7, 
   3.309919170666591*^-6, 0.000011673109086268066, 
   0.00002474206331594838, 0.00003826870842149213, 
   0.00004563064673289687, 0.00004152338955763451, 
   0.000026258324594986437, 7.90425441450242*^-6, 1.0284168307853565*^-7, 
   0.000015583547292722033, 0.00005816596805550838, 
   0.00011774067880598165, 0.00017205672205576663, 
   0.00019600074981830033, 0.00017480190195588244, 
   0.00011453786010648436, 0.00004347143548534572, 
   1.6185826975516697*^-6, 0.000021988031759387004, 
   0.00011210504846002658, 0.0002457205429904672, 0.00037071305890636514, 
   0.00043149195959541945, 0.00039634511558823987, 0.0002763331454725404, 
   0.00012504383711029252, 0.000017106519348098037, 
   0.000013967931186491707, 0.00013274451700993984, 
   0.0003339066534871104, 0.0005355011775626695, 0.0006490333178845481, 
   0.0006210486447465547, 0.00046057398178385293, 0.00023829700381796612, 
   0.00005637990067559689, 2.015284741301843*^-6, 0.00010625800644792783, 
   0.00032791555578768694, 0.0005708595006661756, 0.0007273399006707462, 
   0.0007273399006707625, 0.000570859500666217, 0.000327915555787735, 
   0.00010625800644796157, 2.015284741306803*^-6, 0.00005637990067557207, 
   0.00023829700381792392, 0.0004605739817838131, 0.0006210486447465352, 
   0.000649033317884557, 0.0005355011775627026, 0.0003339066534871521, 
   0.00013274451700997228, 0.000013967931186503188, 
   0.000017106519348085945, 0.00012504383711026525, 
   0.00027633314547251205, 0.0003963451155882238, 0.00043149195959542227, 
   0.00037071305890638487, 0.0002457205429904942, 0.00011210504846004979, 
   0.00002198803175939807, 1.6185826975488577*^-6, 
   0.000043471435485333386, 0.00011453786010647074, 
   0.00017480190195587428, 0.00019600074981830076, 0.0001720567220557749, 
   0.00011774067880599359, 0.00005816596805551889, 
   0.000015583547292727783, 1.0284168307896613*^-7, 
   7.904254414499392*^-6, 0.000026258324594982747, 
   0.000041523389557632566, 0.000045630646732897306, 
   0.00003826870842149432, 0.000024742063315951126, 
   0.00001167310908627021, 3.3099191706676684*^-6, 
   1.9999946628729445*^-7, 2.641079113220119*^-7, 9.59512984277173*^-7, 
   9.414378505710651*^-7, 3.574163565975395*^-7, 1.3519980686787804*^-9, 
   2.6309289206724236*^-7, 7.487909493942871*^-7, 7.811507442432759*^-7, 
   2.562888346711369*^-7, 5.951689402299505*^-8, 1.5924539567989776*^-6, 
   5.663422440155523*^-6, 0.000011533622241759725, 
   0.000016900543496541986, 0.000019021282017714686, 
   0.000016401018230569206, 0.000010009761484984066, 
   3.1698450502454992*^-6, 3.2584613620155515*^-9, 3.204991613547423*^-6, 
   0.00001238116636957505, 0.000023952339367711535, 
   0.000032784968484936294, 0.000034747440037979766, 
   0.00002884514095373179, 0.000017786955406340375, 
   6.667815298930588*^-6, 4.5560882832362813*^-7, 1.5924265112735056*^-6, 
   8.928709787171963*^-6, 0.000018474444969843872, 
   0.00002549303844733256, 0.000026803440252094533}, 
  {0.00010787340707290383, 0.00010259955021033282, 
   0.00007435244520607453, 0.00003593457916031389, 6.408896457646555*^-6, 
   1.833648074331402*^-6, 0.000026835359463682517, 0.0000715855674901875, 
   0.00011609045715442801, 0.00013984491202264252, 
   0.00013194672840445015, 0.00009639883651725776, 
   0.00004982937217241711, 0.000012898842900085302, 
   1.3114037811025867*^-8, 0.000012757391672373994, 
   0.00004028539117428544, 0.00006600771018033664, 
   0.00007655325133068029, 0.00006801810481075975, 
   0.00004641833717645117, 0.000022793069418209875, 6.40900691519508*^-6, 
   2.3953231660868085*^-7, 1.031462735032595*^-6, 3.143827487311695*^-6, 
   3.013591917187283*^-6, 1.058846415871929*^-6, 5.441265623059284*^-9, 
   1.4384616216097643*^-6, 3.78892065844227*^-6, 3.861666031344243*^-6, 
   1.062931473022509*^-6, 8.049199519999995*^-7, 0.000013321135448194141, 
   0.00004697971739545724, 0.00009957716781137183, 
   0.00015401664573200995, 0.00018364557995994814, 
   0.00016711546960646227, 0.00010567952887563018, 
   0.00003181154531074785, 4.138977175486519*^-7, 0.00006271770806049087, 
   0.0002340953657749639, 0.00047386037219178726, 0.0006924612901696844, 
   0.0007888266757134638, 0.0007035095700198955, 0.00046097027442440887, 
   0.00017495559570148043, 6.5141649195762566*^-6, 
   0.00008849326349168822, 0.0004511791551277158, 0.0009889294773686615, 
   0.0014919756693368212, 0.0017365870712243716, 0.0015951347137935711, 
   0.0011121332787482868, 0.0005032527397859893, 0.00006884707738566161, 
   0.000056215482515495505, 0.0005342449769667327, 0.0013438442236216996, 
   0.0021551836619451816, 0.002612106305964476, 0.0024994788966161154, 
   0.0018536308830832242, 0.00095905262366835, 0.00022690714024418436, 
   8.110736130198068*^-6, 0.00042764708845227395, 0.0013197323889144756, 
   0.002297487140367574, 0.002927259801259678, 0.0029272598012597436, 
   0.0022974871403677404, 0.0013197323889146688, 0.0004276470884524098, 
   8.11073613021803*^-6, 0.00022690714024408445, 0.0009590526236681802, 
   0.001853630883083064, 0.002499478896616037, 0.0026121063059645114, 
   0.0021551836619453147, 0.0013438442236218674, 0.0005342449769668632, 
   0.00005621548251554171, 0.00006884707738561295, 0.0005032527397858796, 
   0.0011121332787481727, 0.0015951347137935065, 0.0017365870712243829, 
   0.0014919756693369006, 0.00098892947736877, 0.0004511791551278091, 
   0.00008849326349173277, 6.514164919564939*^-6, 0.0001749555957014308, 
   0.0004609702744243541, 0.0007035095700198626, 0.0007888266757134655, 
   0.0006924612901697177, 0.0004738603721918354, 0.00023409536577500615, 
   0.000062717708060514, 4.138977175503844*^-7, 0.000031811545310735665, 
   0.00010567952887561533, 0.00016711546960645446, 0.0001836455799599499, 
   0.00015401664573201876, 0.00009957716781138288, 
   0.00004697971739546587, 0.000013321135448198478, 
   8.049199520008323*^-7, 1.062931473021931*^-6, 3.861666031343916*^-6, 
   3.7889206584426213*^-6, 1.4384616216102388*^-6, 5.441265623093696*^-9, 
   1.0588464158715514*^-6, 3.013591917187014*^-6, 3.1438274873119306*^-6, 
   1.0314627350330388*^-6, 2.3953231660834283*^-7, 6.409006915192946*^-6, 
   0.000022793069418205833, 0.00004641833717644646, 
   0.0000680181048107565, 0.00007655325133068043, 0.00006600771018034064, 
   0.00004028539117429136, 0.000012757391672378541, 
   1.3114037811193626*^-8, 0.000012898842900080025, 
   0.00004982937217240854, 0.00009639883651724933, 
   0.00013194672840444565, 0.00013984491202264414, 
   0.00011609045715443506, 0.00007158556749019671, 
   0.00002683535946368964, 1.833648074333425*^-6, 6.4088964576429555*^-6, 
   0.00003593457916030642, 0.00007435244520606721, 
   0.00010259955021032913, 0.00010787340707290527}, 
  {0.00012465206512654437, 0.0001185579111831449, 0.00008591724405146237, 
   0.00004152385303598656, 7.405737895048883*^-6, 2.118854177158306*^-6, 
   0.000031009338319132564, 0.0000827200054493216, 
   0.00013414719733478175, 0.0001615964263489083, 0.00015246975717741402, 
   0.0001113927368545184, 0.00005757984580067231, 
   0.000014905132310800718, 1.5153798694679146*^-8, 
   0.000014741679721999262, 0.000046551391492729716, 
   0.00007627456674927011, 0.00008846036413841626, 
   0.00007859765868825184, 0.00005363825752601337, 
   0.000026338309418857802, 7.405865533193501*^-6, 
   2.7678923601289747*^-7, 1.1918967196057207*^-6, 
   3.6328192399647805*^-6, 3.4823267950754723*^-6, 
   1.2235396653512118*^-6, 6.28760150644007*^-9, 1.662200319841147*^-6, 
   4.378250372274457*^-6, 4.462310579573771*^-6, 1.2282601133633492*^-6, 
   9.301174126311762*^-7, 0.000015393108352697145, 
   0.00005428695497164987, 0.00011506542663245309, 
   0.00017797243523960958, 0.000212209861675163, 0.00019310865361802678, 
   0.00012211695053855848, 0.000036759521419133895, 
   4.782754771872045*^-7, 0.00007247283683605505, 0.00027050662041926664, 
   0.0005475647388741478, 0.0008001669010185915, 0.0009115209839264355, 
   0.0008129336332169547, 0.0005326697119162908, 0.0002021682349839518, 
   7.527379841180835*^-6, 0.00010225752892528376, 0.0005213556793539531, 
   0.0011427478278794624, 0.001724037956599481, 0.0020066962801488183, 
   0.0018432423859110016, 0.0012851147808675314, 0.0005815288030396534, 
   0.000079555569875065, 0.00006495925342291159, 0.0006173415809271678, 
   0.0015528661069322924, 0.0024904014944748653, 0.003018394006490299, 
   0.002888248500326415, 0.002141945117229013, 0.0011082239205117222, 
   0.00026220033640247036, 9.37228215701383*^-6, 0.0004941634288504815, 
   0.001525003911125182, 0.0026548388932867316, 0.0033825665591737056, 
   0.003382566559173781, 0.002654838893286924, 0.0015250039111254056, 
   0.0004941634288506385, 9.372282157036897*^-6, 0.00026220033640235495, 
   0.0011082239205115261, 0.002141945117228828, 0.002888248500326324, 
   0.00301839400649034, 0.0024904014944750192, 0.0015528661069324863, 
   0.0006173415809273187, 0.00006495925342296499, 0.00007955556987500877, 
   0.0005815288030395266, 0.0012851147808673996, 0.001843242385910927, 
   0.0020066962801488313, 0.0017240379565995724, 0.0011427478278795882, 
   0.0005213556793540609, 0.00010225752892533525, 7.527379841167758*^-6, 
   0.00020216823498389445, 0.0005326697119162276, 0.0008129336332169168, 
   0.0009115209839264374, 0.0008001669010186299, 0.0005475647388742034, 
   0.0002705066204193155, 0.00007247283683608179, 4.782754771892064*^-7, 
   0.00003675952141911983, 0.00012211695053854132, 
   0.00019310865361801775, 0.00021220986167516505, 
   0.00017797243523961975, 0.00011506542663246587, 
   0.000054286954971659844, 0.000015393108352702156, 
   9.301174126321385*^-7, 1.228260113362681*^-6, 4.462310579573392*^-6, 
   4.378250372274864*^-6, 1.6622003198416953*^-6, 6.2876015064798345*^-9, 
   1.2235396653507756*^-6, 3.4823267950751615*^-6, 
   3.6328192399650524*^-6, 1.1918967196062336*^-6, 2.767892360125068*^-7, 
   7.4058655331910355*^-6, 0.000026338309418853133, 
   0.00005363825752600793, 0.00007859765868824806, 
   0.00008846036413841642, 0.00007627456674927474, 
   0.00004655139149273656, 0.000014741679722004517, 
   1.5153798694872997*^-8, 0.000014905132310794621, 
   0.00005757984580066241, 0.00011139273685450866, 
   0.00015246975717740882, 0.00016159642634891016, 0.0001341471973347899, 
   0.00008272000544933224, 0.0000310093383191408, 2.118854177160644*^-6, 
   7.4057378950447225*^-6, 0.00004152385303597794, 
   0.00008591724405145392, 0.00011855791118314065, 
   0.00012465206512654605}, {0.00004872759772858907, 
   0.000046345338906413896, 0.00003358581265251061, 
   0.000016232042403986897, 2.894968620591788*^-6, 8.282788888037795*^-7, 
   0.00001212182535371929, 0.00003233598372838269, 0.0000524393291158955, 
   0.00006316947616963611, 0.00005960178025108863, 0.0000435444087173626, 
   0.00002250847236747364, 5.826548405714544*^-6, 5.923754300458044*^-9, 
   5.762653339180922*^-6, 0.000018197351773201865, 0.0000298164045794809, 
   0.00003457994084803454, 0.00003072452182065386, 
   0.000020967670555130422, 0.000010295878731815039, 
   2.895018515474472*^-6, 1.0819936704897703*^-7, 4.659229979704912*^-7, 
   1.4201012583784847*^-6, 1.361272427036512*^-6, 4.782925060862899*^-7, 
   2.457879190147805*^-9, 6.497688461665428*^-7, 1.7114968988171577*^-6, 
   1.7443567793342155*^-6, 4.801377710772922*^-7, 3.6359114529741345*^-7, 
   6.017302568083047*^-6, 0.000021221252139570675, 
   0.000044980095722623404, 0.00006957100327482938, 
   0.00008295471690139605, 0.00007548788527375047, 
   0.000047736598953608084, 0.000014369622922721859, 
   1.8696212559469488*^-7, 0.000028330274640953, 0.00010574343689636369, 
   0.00021404791247648267, 0.0003127923378484228, 0.00035632163639522975, 
   0.0003177829666858908, 0.00020822531434285267, 0.00007902935597413609, 
   2.9425195361103005*^-6, 0.00003997337492268886, 
   0.00020380255867630132, 0.00044671026032020177, 0.0006739417267793732, 
   0.0007844353721960547, 0.0007205397953557829, 0.0005023627648174602, 
   0.000227324766367388, 0.00003109897779876672, 0.000025393148250915442, 
   0.000241324298847452, 0.0006070291327154571, 0.000973520030191676, 
   0.0011799169856137697, 0.0011290419530653765, 0.0008373053420582693, 
   0.0004332145587566014, 0.00010249643681033248, 3.6637082127935973*^-6, 
   0.00019317286680137685, 0.0005961375532799638, 0.001037800067692105, 
   0.0013222752661038346, 0.0013222752661038641, 0.0010378000676921804, 
   0.0005961375532800511, 0.00019317286680143822, 3.663708212802614*^-6, 
   0.00010249643681028735, 0.00043321455875652474, 0.0008373053420581969, 
   0.0011290419530653412, 0.0011799169856137857, 0.0009735200301917362, 
   0.0006070291327155329, 0.00024132429884751096, 
   0.000025393148250936317, 0.00003109897779874473, 
   0.00022732476636733843, 0.0005023627648174087, 0.0007205397953557538, 
   0.0007844353721960598, 0.000673941726779409, 0.0004467102603202509, 
   0.00020380255867634347, 0.000039973374922708986, 
   2.9425195361051887*^-6, 0.00007902935597411366, 
   0.00020822531434282792, 0.00031778296668587595, 0.0003563216363952305, 
   0.0003127923378484378, 0.0002140479124765044, 0.00010574343689638278, 
   0.000028330274640963452, 1.8696212559547746*^-7, 
   0.000014369622922716356, 0.00004773659895360138, 
   0.00007548788527374695, 0.00008295471690139685, 
   0.00006957100327483336, 0.0000449800957226284, 
   0.000021221252139574575, 6.0173025680850065*^-6, 
   3.6359114529778964*^-7, 4.801377710770311*^-7, 1.7443567793340677*^-6, 
   1.7114968988173165*^-6, 6.497688461667571*^-7, 2.4578791901633493*^-9, 
   4.782925060861194*^-7, 1.3612724270363905*^-6, 1.4201012583785908*^-6, 
   4.6592299797069166*^-7, 1.0819936704882433*^-7, 2.895018515473508*^-6, 
   0.000010295878731813214, 0.000020967670555128294, 
   0.00003072452182065239, 0.0000345799408480346, 0.00002981640457948271, 
   0.00001819735177320454, 5.762653339182976*^-6, 5.923754300533823*^-9, 
   5.82654840571216*^-6, 0.00002250847236746977, 0.000043544408717358794, 
   0.000059601780251086594, 0.00006316947616963685, 
   0.00005243932911589868, 0.00003233598372838685, 
   0.000012121825353722509, 8.282788888046933*^-7, 
   2.8949686205901616*^-6, 0.000016232042403983526, 
   0.0000335858126525073, 0.00004634533890641223, 
   0.00004872759772858972}, {2.585411169047024*^-7, 
   2.4590121907776956*^-7, 1.7820114103916871*^-7, 8.612471306602168*^-8, 
   1.5360256927517917*^-8, 4.394720014983912*^-9, 6.431653543297035*^-8, 
   1.715697415644056*^-7, 2.782349910798583*^-7, 3.351674961312648*^-7, 
   3.162378519346572*^-7, 2.3103991556178382*^-7, 1.1942648225998988*^-7, 
   3.0914767046456036*^-8, 3.1430526529135406*^-11, 3.05757496797819*^-8, 
   9.655234141351967*^-8, 1.5820124326668068*^-7, 1.834758318919545*^-7, 
   1.630195732635958*^-7, 1.1125122552538009*^-7, 5.462834432482309*^-8, 
   1.536052166206873*^-8, 5.740891508963452*^-10, 2.4721155546767842*^-9, 
   7.534838214352044*^-9, 7.222701510095264*^-9, 2.5377462566381917*^-9, 
   1.304112783431565*^-11, 3.4475732654313642*^-9, 9.080938532282843*^-9, 
   9.255287989392457*^-9, 2.5475369480327514*^-9, 1.929158529945349*^-9, 
   3.192687920654388*^-8, 1.1259669029532054*^-7, 2.386574493448604*^-7, 
   3.691330114618379*^-7, 4.401449314136206*^-7, 4.005270746191288*^-7, 
   2.53283030274578*^-7, 7.624300259235244*^-8, 9.91992197919692*^-10, 
   1.50316067060937*^-7, 5.610583643545319*^-7, 1.1357052049032383*^-6, 
   1.6596278937657752*^-6, 1.8905876370934621*^-6, 
   1.6861074005307633*^-6, 1.1048113973911*^-6, 4.193175718536307*^-7, 
   1.5612554750129115*^-8, 2.1209256110934588*^-7, 
   1.0813449380717664*^-6, 2.370175732431279*^-6, 3.575830841092198*^-6, 
   4.162093079095782*^-6, 3.823073004813281*^-6, 2.6654593364252288*^-6, 
   1.2061501435816178*^-6, 1.6500637892046772*^-7, 
   1.3473212751193155*^-7, 1.280429503374802*^-6, 3.2208029388214098*^-6, 
   5.165347106516254*^-6, 6.2604575135136*^-6, 5.990522438714963*^-6, 
   4.44261298354564*^-6, 2.29856962176068*^-6, 5.43830282775217*^-7, 
   1.9439070619170763*^-8, 1.0249454327030992*^-6, 
   3.1630138984547303*^-6, 5.506407069755247*^-6, 7.015788589827672*^-6, 
   7.015788589827829*^-6, 5.506407069755647*^-6, 3.1630138984551937*^-6, 
   1.0249454327034248*^-6, 1.9439070619218604*^-8, 5.438302827749775*^-7, 
   2.298569621760273*^-6, 4.442612983545256*^-6, 5.990522438714774*^-6, 
   6.260457513513686*^-6, 5.165347106516573*^-6, 3.2208029388218117*^-6, 
   1.2804295033751147*^-6, 1.347321275120423*^-7, 1.6500637892035107*^-7, 
   1.2061501435813548*^-6, 2.6654593364249556*^-6, 3.823073004813126*^-6, 
   4.162093079095809*^-6, 3.575830841092388*^-6, 2.37017573243154*^-6, 
   1.08134493807199*^-6, 2.1209256110945263*^-7, 1.5612554750101993*^-8, 
   4.1931757185351175*^-7, 1.1048113973909687*^-6, 
   1.6861074005306846*^-6, 1.8905876370934662*^-6, 
   1.6596278937658548*^-6, 1.1357052049033535*^-6, 5.610583643546332*^-7, 
   1.5031606706099245*^-7, 9.919921979238442*^-10, 7.624300259232326*^-8, 
   2.532830302745424*^-7, 4.0052707461911007*^-7, 4.401449314136248*^-7, 
   3.6913301146185905*^-7, 2.3865744934488694*^-7, 
   1.1259669029534122*^-7, 3.1926879206554275*^-8, 1.929158529947345*^-9, 
   2.547536948031366*^-9, 9.255287989391672*^-9, 9.080938532283685*^-9, 
   3.4475732654325016*^-9, 1.3041127834398126*^-11, 
   2.5377462566372868*^-9, 7.222701510094619*^-9, 7.534838214352608*^-9, 
   2.472115554677848*^-9, 5.74089150895535*^-10, 1.5360521662063617*^-8, 
   5.462834432481341*^-8, 1.112512255253688*^-7, 1.6301957326358797*^-7, 
   1.8347583189195483*^-7, 1.5820124326669027*^-7, 9.655234141353387*^-8, 
   3.05757496797928*^-8, 3.1430526529537474*^-11, 3.0914767046443383*^-8, 
   1.1942648225996934*^-7, 2.3103991556176362*^-7, 3.162378519346464*^-7, 
   3.3516749613126864*^-7, 2.782349910798752*^-7, 1.7156974156442766*^-7, 
   6.431653543298743*^-8, 4.39472001498876*^-9, 1.5360256927509288*^-8, 
   8.612471306600379*^-8, 1.782011410391512*^-7, 2.459012190777607*^-7, 
   2.5854111690470584*^-7}, {0.00006559256240430969, 
   0.00006238578702976534, 0.00004521009889672319, 
   0.000021850066573428444, 3.896937644296702*^-6, 
   1.1149520443146893*^-6, 0.00001631727446111057, 
   0.000043527695381631094, 0.00007058895015988932, 
   0.00008503287666228208, 0.00008023037606538464, 
   0.00005861543518031083, 0.000030298813141017627, 
   7.843157834955893*^-6, 7.974007374318449*^-9, 7.757148235995607*^-6, 
   0.000024495583353509197, 0.000040136072148377086, 
   0.00004654830186059574, 0.00004135849516097553, 
   0.00002822472897229408, 0.00001385935485646888, 3.897004808149604*^-6, 
   1.4564792984044228*^-7, 6.2718222823556*^-7, 1.911608303152166*^-6, 
   1.8324183990558474*^-6, 6.43832910206695*^-7, 3.308568484332138*^-9, 
   8.74658418991782*^-7, 2.303858026528194*^-6, 2.3480909430659346*^-6, 
   6.463168344040045*^-7, 4.894326008109897*^-7, 8.099933356062631*^-6, 
   0.000028566076928633454, 0.000060548023567083984, 
   0.00009365001737315923, 0.00011166592852358572, 
   0.00010161477389398937, 0.00006425857197546495, 
   0.000019343050595987677, 2.516710337049382*^-7, 
   0.00003813558217395316, 0.0001423419849692589, 0.0002881314021435639, 
   0.000421051968418199, 0.0004796470636915309, 0.0004277698890364426, 
   0.0002802935617976758, 0.00010638197254006151, 3.9609462664927466*^-6, 
   0.00005380844144485711, 0.0002743400592533244, 0.0006013198268033453, 
   0.000907197703791343, 0.0010559339778970767, 0.0009699236920094156, 
   0.00067623405496877, 0.0003060034686513935, 0.00004186255298974109, 
   0.000034181895659363276, 0.0003248483378966303, 0.000817126189775445, 
   0.001310462167412125, 0.0015882945623926848, 0.0015198113228568708, 
   0.0011271026165978234, 0.0005831531679023458, 0.00013797117529060232, 
   4.931743422226046*^-6, 0.0002600313561744633, 0.0008024649580072935, 
   0.0013969899785014966, 0.0017799240461366845, 0.0017799240461367244, 
   0.001396989978501598, 0.000802464958007411, 0.00026003135617454594, 
   4.931743422238184*^-6, 0.00013797117529054157, 0.0005831531679022426, 
   0.001127102616597726, 0.0015198113228568231, 0.0015882945623927067, 
   0.001310462167412206, 0.000817126189775547, 0.00032484833789670967, 
   0.00003418189565939138, 0.0000418625529897115, 0.0003060034686513268, 
   0.0006762340549687007, 0.0009699236920093764, 0.0010559339778970836, 
   0.0009071977037913913, 0.0006013198268034114, 0.00027434005925338115, 
   0.0000538084414448842, 3.960946266485865*^-6, 0.00010638197254003133, 
   0.00028029356179764246, 0.00042776988903642265, 0.0004796470636915319, 
   0.00042105196841821924, 0.0002881314021435932, 0.00014234198496928459, 
   0.00003813558217396723, 2.5167103370599166*^-7, 
   0.00001934305059598027, 0.00006425857197545592, 
   0.00010161477389398463, 0.00011166592852358679, 
   0.00009365001737316458, 0.00006054802356709071, 
   0.000028566076928638702, 8.099933356065267*^-6, 4.894326008114961*^-7, 
   6.46316834403653*^-7, 2.3480909430657356*^-6, 2.303858026528408*^-6, 
   8.746584189920705*^-7, 3.3085684843530625*^-9, 6.438329102064655*^-7, 
   1.8324183990556837*^-6, 1.9116083031523086*^-6, 6.271822282358298*^-7, 
   1.4564792984023674*^-7, 3.897004808148306*^-6, 
   0.000013859354856466423, 0.000028224728972291215, 
   0.00004135849516097354, 0.00004654830186059582, 
   0.00004013607214837952, 0.0000244955833535128, 7.757148235998374*^-6, 
   7.974007374420455*^-9, 7.843157834952684*^-6, 0.000030298813141012413, 
   0.0000586154351803057, 0.00008023037606538192, 0.00008503287666228306, 
   0.0000705889501598936, 0.0000435276953816367, 0.000016317274461114903, 
   1.1149520443159194*^-6, 3.896937644294513*^-6, 
   0.000021850066573423904, 0.00004521009889671874, 
   0.0000623857870297631, 0.00006559256240431057}, 
  {0.00015380173104139142, 0.00014628246993026548, 
   0.00010600884027076309, 0.000051234132944044504, 
   9.137556660140704*^-6, 2.6143444951385274*^-6, 
   0.000038260817476943095, 0.00010206393305191835, 
   0.00016551728319539092, 0.0001993854660757822, 0.0001881245413907967, 
   0.00013744173220291736, 0.00007104479134179986, 
   0.000018390671253419577, 1.8697487833261067*^-8, 
   0.000018188995564570463, 0.00005743735241529258, 
   0.00009411123986241742, 0.0001091466645115614, 0.00009697758276031464, 
   0.00006618146959033452, 0.00003249747669412248, 9.137714146240668*^-6, 
   3.4151591142265424*^-7, 1.4706196685294953*^-6, 
   4.4823476217569215*^-6, 4.2966627836507145*^-6, 
   1.5096622614136544*^-6, 7.757946046118198*^-9, 2.050902937465116*^-6, 
   5.402096511636794*^-6, 5.5058140503812*^-6, 1.5154865778806185*^-6, 
   1.1476237316180016*^-6, 0.000018992759633377072, 
   0.00006698186379126283, 0.00014197327401773555, 
   0.00021959097580706647, 0.00026183476412172213, 
   0.00023826677219806707, 0.00015067378437139687, 
   0.000045355670768682354, 5.901193552739239*^-7, 
   0.00008942048210392602, 0.00033376411723627544, 0.0006756117887864635, 
   0.0009872845217104886, 0.0011246785608093723, 0.0010030367317509464, 
   0.0006572335860049778, 0.000249444920712294, 9.287644361161502*^-6, 
   0.00012617027198673087, 0.0006432737868521946, 0.001409977395025318, 
   0.0021272011966819646, 0.0024759586714258645, 0.002274281371866394, 
   0.0015856366092583487, 0.0007175182895456175, 0.00009815949979126166, 
   0.00008014986044120262, 0.000761705822475047, 0.0019160011114074508, 
   0.0030727774983066642, 0.0037242401294506197, 0.003563660325859376, 
   0.0026428352108811217, 0.0013673801327169827, 0.00032351542332969803, 
   0.000011563973834638977, 0.0006097226764546303, 0.00188162339017678, 
   0.003275668293252853, 0.004173573792263263, 0.0041735737922633555, 
   0.00327566829325309, 0.0018816233901770556, 0.000609722676454824, 
   0.000011563973834667438, 0.0003235154233295556, 0.0013673801327167407, 
   0.002642835210880893, 0.003563660325859264, 0.003724240129450671, 
   0.0030727774983068537, 0.00191600111140769, 0.0007617058224752332, 
   0.0000801498604412685, 0.00009815949979119227, 0.0007175182895454611, 
   0.001585636609258186, 0.002274281371866302, 0.002475958671425881, 
   0.0021272011966820773, 0.0014099773950254728, 0.0006432737868523276, 
   0.00012617027198679438, 9.287644361145366*^-6, 0.00024944492071222324, 
   0.0006572335860048998, 0.0010030367317508996, 0.0011246785608093747, 
   0.000987284521710536, 0.0006756117887865321, 0.0003337641172363357, 
   0.000089420482103959, 5.90119355276394*^-7, 0.000045355670768664986, 
   0.0001506737843713757, 0.0002382667721980559, 0.0002618347641217246, 
   0.00021959097580707902, 0.00014197327401775132, 
   0.00006698186379127514, 0.000018992759633383252, 
   1.147623731619189*^-6, 1.5154865778797943*^-6, 5.5058140503807335*^-6, 
   5.402096511637295*^-6, 2.050902937465793*^-6, 7.757946046167261*^-9, 
   1.509662261413116*^-6, 4.296662783650331*^-6, 4.482347621757257*^-6, 
   1.470619668530128*^-6, 3.415159114221723*^-7, 9.137714146237625*^-6, 
   0.00003249747669411671, 0.00006618146959032781, 0.00009697758276031, 
   0.0001091466645115616, 0.00009411123986242314, 0.00005743735241530102, 
   0.000018188995564576947, 1.869748783350025*^-8, 
   0.000018390671253412055, 0.00007104479134178764, 
   0.00013744173220290532, 0.00018812454139079032, 0.0001993854660757845, 
   0.00016551728319540098, 0.00010206393305193148, 
   0.00003826081747695325, 2.6143444951414116*^-6, 9.137556660135571*^-6, 
   0.000051234132944033865, 0.00010600884027075266, 
   0.00014628246993026023, 0.00015380173104139345}, 
  {0.00012865707024898237, 0.00012236711435287986, 
   0.00008867771979795352, 0.00004285799253815734, 7.643680348509188*^-6, 
   2.1869318445808495*^-6, 0.000032005652007842495, 
   0.00008537775560545665, 0.00013845727604820765, 
   0.00016678843431634975, 0.00015736853007694446, 
   0.00011497172675133102, 0.000059429855883912994, 
   0.00001538402635234565, 1.564068225601422*^-8, 0.00001521532211805592, 
   0.00004804706315445252, 0.00007872522835870632, 
   0.00009130254899229271, 0.00008112296001670169, 
   0.000055361626456421765, 0.000027184545412074563, 
   7.643812087600089*^-6, 2.856823282127096*^-7, 1.2301917327095302*^-6, 
   3.7495398065288387*^-6, 3.594212118741164*^-6, 1.2628513496162337*^-6, 
   6.489618827337057*^-9, 1.7156059396254936*^-6, 4.5189212480475465*^-6, 
   4.605682265481736*^-6, 1.2677234631338692*^-6, 9.600015946403145*^-7, 
   0.000015887680807154354, 0.00005603116620892297, 
   0.00011876241811519068, 0.00018369059573750262, 
   0.00021902805263074868, 0.00019931313283096366, 
   0.00012604050376607162, 0.000037940585458727165, 
   4.936422160705647*^-7, 0.00007480135086806368, 0.00027919785549293123, 
   0.0005651577051987016, 0.0008258758416136105, 0.000940807672487343, 
   0.0008390527621855024, 0.0005497841088789611, 0.00020866379376898272, 
   7.769230586227543*^-6, 0.00010554300940840173, 0.0005381065624163795, 
   0.0011794637130087295, 0.0017794303870453689, 0.0020711703734822453, 
   0.001902464791813175, 0.0013264048411250184, 0.0006002130168363094, 
   0.00008211164838483257, 0.00006704635998183138, 0.0006371764403929719, 
   0.0016027588761087237, 0.0025704167812827775, 0.0031153734142943938, 
   0.0029810464016442792, 0.0022107646843799824, 0.0011438305707020093, 
   0.0002706246949506485, 9.673408640635812*^-6, 0.0005100406392429329, 
   0.0015740014826423, 0.0027401374670092517, 0.003491246639064281, 
   0.0034912466390643595, 0.0027401374670094503, 0.0015740014826425305, 
   0.0005100406392430949, 9.673408640659619*^-6, 0.0002706246949505293, 
   0.0011438305707018068, 0.002210764684379791, 0.0029810464016441856, 
   0.0031153734142944363, 0.0025704167812829366, 0.0016027588761089236, 
   0.0006371764403931276, 0.00006704635998188648, 0.00008211164838477453, 
   0.0006002130168361786, 0.0013264048411248822, 0.001902464791813098, 
   0.002071170373482259, 0.0017794303870454636, 0.0011794637130088592, 
   0.0005381065624164909, 0.00010554300940845485, 7.769230586214046*^-6, 
   0.00020866379376892352, 0.0005497841088788958, 0.0008390527621854633, 
   0.0009408076724873451, 0.0008258758416136502, 0.0005651577051987589, 
   0.00027919785549298165, 0.00007480135086809127, 4.936422160726309*^-7, 
   0.000037940585458712644, 0.00012604050376605392, 
   0.00019931313283095433, 0.00021902805263075077, 0.0001836905957375131, 
   0.00011876241811520386, 0.00005603116620893327, 
   0.000015887680807159524, 9.600015946413077*^-7, 
   1.2677234631331797*^-6, 4.605682265481345*^-6, 4.518921248047966*^-6, 
   1.7156059396260594*^-6, 6.489618827378099*^-9, 1.2628513496157832*^-6, 
   3.594212118740843*^-6, 3.7495398065291195*^-6, 1.2301917327100594*^-6, 
   2.856823282123064*^-7, 7.643812087597544*^-6, 0.000027184545412069745, 
   0.00005536162645641615, 0.0000811229600166978, 0.00009130254899229287, 
   0.0000787252283587111, 0.000048047063154459583, 
   0.000015215322118061344, 1.5640682256214303*^-8, 
   0.000015384026352339355, 0.00005942985588390277, 
   0.00011497172675132097, 0.0001573685300769391, 0.00016678843431635167, 
   0.00013845727604821606, 0.00008537775560546763, 
   0.00003200565200785099, 2.1869318445832623*^-6, 7.643680348504896*^-6, 
   0.00004285799253814844, 0.00008867771979794479, 
   0.00012236711435287547, 0.00012865707024898408}, 
  {0.000026485255751256576, 0.000025190409768443465, 
   0.000018255134239741827, 8.822716786274103*^-6, 
   1.5735227649700124*^-6, 4.502002812764131*^-7, 6.5886614491762205*^-6, 
   0.00001757580588694219, 0.00002850271935823221, 
   0.000034334952060321164, 0.00003239577707016963, 
   0.000023668000377124047, 0.000012234189145607456, 
   3.1669450550788374*^-6, 3.2197800624016144*^-9, 
   3.1322157177572555*^-6, 9.890935284627446*^-6, 
   0.000016206321215937262, 0.000018795479767437287, 
   0.000016699916601422066, 0.00001139670624137705, 
   5.596191770316939*^-6, 1.5735498846884095*^-6, 5.881036706094186*^-8, 
   2.532464216761619*^-7, 7.718776786479707*^-7, 7.399020279639738*^-7, 
   2.5996970788840136*^-7, 1.335948456136644*^-9, 3.5317345553899276*^-7, 
   9.30262011584035*^-7, 9.481225747970536*^-7, 2.6097267781701866*^-7, 
   1.97625266193748*^-7, 3.270627013793219*^-6, 0.000011534537233069227, 
   0.000024448349486983373, 0.00003781441935366097, 
   0.00004508896385871921, 0.000041030464065413455, 
   0.000025946611179637277, 7.810422756263124*^-6, 
   1.0162084615283221*^-7, 0.000015398554501872116, 
   0.000057475477978958165, 0.00011634297542306481, 
   0.00017001423117742536, 0.00019367401861670176, 
   0.00017272682295870224, 0.00011317817748730486, 
   0.00004295538467729626, 1.5993684503191857*^-6, 
   0.000021727011127559148, 0.0001107742458261057, 0.0002428035865258635, 
   0.0003663123122674002, 0.0004263697046726179, 0.0003916400899804539, 
   0.0002730527858198203, 0.0001235594377003829, 0.00001690344730702234, 
   0.000013802117426373337, 0.00013116870258140075, 
   0.0003299428368700309, 0.0005291442258699698, 0.0006413286225045612, 
   0.0006136761563209649, 0.0004551064932408018, 0.00023546817242551117, 
   0.000055710613062327304, 1.9913612313558896*^-6, 
   0.00010499661423768755, 0.00032402285968398295, 0.0005640828091833098, 
   0.0007187056253293147, 0.0007187056253293308, 0.0005640828091833507, 
   0.00032402285968403043, 0.0001049966142377209, 1.9913612313607905*^-6, 
   0.000055710613062302774, 0.00023546817242546948, 
   0.00045510649324076246, 0.0006136761563209456, 0.00064132862250457, 
   0.0005291442258700026, 0.0003299428368700721, 0.0001311687025814328, 
   0.000013802117426384682, 0.00001690344730701039, 
   0.00012355943770035597, 0.0002730527858197923, 0.00039164008998043804, 
   0.0004263697046726207, 0.0003663123122674197, 0.0002428035865258902, 
   0.00011077424582612861, 0.000021727011127570084, 
   1.599368450316407*^-6, 0.00004295538467728407, 0.00011317817748729142, 
   0.00017272682295869416, 0.00019367401861670216, 
   0.00017001423117743352, 0.00011634297542307661, 
   0.00005747547797896855, 0.000015398554501877798, 
   1.0162084615325758*^-7, 7.810422756260134*^-6, 
   0.000025946611179633635, 0.00004103046406541154, 
   0.000045088963858719644, 0.00003781441935366313, 
   0.00002444834948698609, 0.000011534537233071347, 
   3.2706270137942833*^-6, 1.9762526619395245*^-7, 
   2.6097267781687673*^-7, 9.481225747969732*^-7, 9.302620115841213*^-7, 
   3.531734555391093*^-7, 1.335948456145093*^-9, 2.5996970788830866*^-7, 
   7.399020279639078*^-7, 7.718776786480284*^-7, 2.532464216762709*^-7, 
   5.8810367060858864*^-8, 1.5735498846878854*^-6, 5.596191770315947*^-6, 
   0.000011396706241375893, 0.000016699916601421266, 
   0.00001879547976743732, 0.000016206321215938245, 9.8909352846289*^-6, 
   3.1322157177583723*^-6, 3.219780062442803*^-9, 3.166945055077542*^-6, 
   0.000012234189145605352, 0.000023668000377121976, 
   0.000032395777070168524, 0.00003433495206032156, 
   0.000028502719358233943, 0.00001757580588694445, 
   6.5886614491779705*^-6, 4.5020028127690974*^-7, 
   1.5735227649691286*^-6, 8.82271678627227*^-6, 0.00001825513423974003, 
   0.00002519040976844256, 0.00002648525575125693}, 
  {0.0000133819660378451, 0.000012727730899284162, 9.223606851556954*^-6, 
   4.457774450218189*^-6, 7.950396401063938*^-7, 2.2746863125848576*^-7, 
   3.3289934813467806*^-6, 8.880368748399174*^-6, 
   0.000014401311658846157, 0.00001734811121695354, 
   0.00001636832177850663, 0.000011958516851979133, 
   6.181458287006524*^-6, 1.600133733606699*^-6, 1.6268292007089622*^-9, 
   1.5825863549096962*^-6, 4.997503565927563*^-6, 8.188421593768888*^-6, 
   9.49662235755142*^-6, 8.437816077515994*^-6, 5.758310861626066*^-6, 
   2.8275372877264556*^-6, 7.95053342641644*^-7, 2.9714583165593543*^-8, 
   1.279555329162873*^-7, 3.899996654005425*^-7, 3.738436170878528*^-7, 
   1.3135254703613892*^-7, 6.750026141425488*^-10, 1.784447630741481*^-7, 
   4.7002508724970113*^-7, 4.790493327611707*^-7, 1.3185930859614763*^-7, 
   9.985233388955894*^-8, 1.6525201807410554*^-6, 5.827951482321213*^-6, 
   0.000012352796800939215, 0.000019106150240120498, 
   0.000022781693660269026, 0.000020731092113933487, 
   0.000013109809958569291, 3.946301785685676*^-6, 5.134504740018467*^-8, 
   7.780288599485506*^-6, 0.000029040115811864154, 
   0.000058783564730328665, 0.00008590155552712418, 
   0.00009785592270215171, 0.00008727212228443642, 
   0.00005718451585231387, 0.000021703679371375452, 
   8.080984561818647*^-7, 0.000010977810739059397, 
   0.00005596990300697853, 0.0001226791758883406, 0.0001850833145824649, 
   0.00021542797098435861, 0.000197880452142826, 0.00013796291569532858, 
   0.00006242976146769183, 8.540652199454226*^-6, 6.97367125259174*^-6, 
   0.00006627442603000845, 0.00016670723812872902, 
   0.00026735592535774626, 0.0003240383225314651, 0.00031006661061722433, 
   0.00022994754867950421, 0.00011897287743736988, 
   0.000028148398450417946, 1.0061571093502316*^-6, 
   0.00005305069126058169, 0.00016371610470745736, 
   0.00028500902788772107, 0.0003631339021111325, 0.00036313390211114064, 
   0.0002850090278877417, 0.00016371610470748135, 
   0.000053050691260598535, 1.0061571093527079*^-6, 
   0.000028148398450405552, 0.00011897287743734882, 
   0.00022994754867948432, 0.00031006661061721457, 
   0.00032403832253146954, 0.0002673559253577628, 0.00016670723812874983, 
   0.00006627442603002465, 6.973671252597472*^-6, 8.540652199448188*^-6, 
   0.00006242976146767823, 0.00013796291569531443, 
   0.00019788045214281797, 0.00021542797098436002, 
   0.00018508331458247474, 0.0001226791758883541, 
   0.000055969903006990105, 0.000010977810739064923, 
   8.080984561804607*^-7, 0.000021703679371369293, 
   0.00005718451585230707, 0.00008727212228443234, 
   0.00009785592270215193, 0.00008590155552712832, 
   0.00005878356473033463, 0.0000290401158118694, 7.780288599488376*^-6, 
   5.1345047400399594*^-8, 3.946301785684165*^-6, 0.00001310980995856745, 
   0.000020731092113932515, 0.000022781693660269243, 
   0.00001910615024012159, 0.000012352796800940588, 
   5.827951482322284*^-6, 1.6525201807415932*^-6, 9.985233388966225*^-8, 
   1.3185930859607593*^-7, 4.790493327611302*^-7, 4.7002508724974475*^-7, 
   1.7844476307420696*^-7, 6.750026141468177*^-10, 1.313525470360921*^-7, 
   3.738436170878194*^-7, 3.8999966540057165*^-7, 1.2795553291634235*^-7, 
   2.9714583165551605*^-8, 7.950533426413793*^-7, 2.827537287725954*^-6, 
   5.758310861625481*^-6, 8.43781607751559*^-6, 9.496622357551437*^-6, 
   8.188421593769385*^-6, 4.997503565928297*^-6, 1.5825863549102603*^-6, 
   1.6268292007297733*^-9, 1.6001337336060445*^-6, 6.18145828700546*^-6, 
   0.000011958516851978088, 0.000016368321778506076, 
   0.00001734811121695374, 0.000014401311658847031, 
   8.880368748400316*^-6, 3.3289934813476644*^-6, 2.2746863125873672*^-7, 
   7.950396401059472*^-7, 4.457774450217263*^-6, 9.223606851556046*^-6, 
   0.000012727730899283707, 0.000013381966037845278}, 
  {0.00012667072696335502, 0.00012047788202770685, 
   0.00008730861981017574, 0.00004219630573346883, 7.52566916491578*^-6, 
   2.153167688618017*^-6, 0.00003151151506033645, 0.00008405960393869917, 
   0.00013631962686894088, 0.00016421337889200788, 0.0001549389090504245, 
   0.00011319667220495025, 0.00005851231520797223, 
   0.000015146511559013586, 1.5399204938663992*^-8, 
   0.00001498041195828492, 0.0000473052620151427, 0.00007750978541058717, 
   0.0000898929241282994, 0.00007987049836319482, 
   0.000054506895388938974, 0.00002676484178329142, 
   7.525798870079915*^-6, 2.8127166369680295*^-7, 1.2111987377379136*^-6, 
   3.69165046391846*^-6, 3.538720888485683*^-6, 1.2433541210985846*^-6, 
   6.389425260368563*^-9, 1.6891186091401764*^-6, 4.449153384828161*^-6, 
   4.534574894343344*^-6, 1.2481510137989435*^-6, 9.451800794448027*^-7, 
   0.000015642390066160423, 0.00005516609808192788, 
   0.0001169288388851379, 0.00018085458695252132, 0.00021564646698710578, 
   0.0001962359268727527, 0.00012409455778822278, 0.00003735481876100222, 
   4.86020847890049*^-7, 0.0000736464888712446, 0.00027488730509296735, 
   0.0005564322056138789, 0.0008131251009852384, 0.0009262824932671464, 
   0.0008260985823862199, 0.0005412959630576476, 0.0002054422224639279, 
   7.649281025899624*^-6, 0.0001039135253258125, 0.0005297987068501113, 
   0.0011612539106057832, 0.0017519576675538667, 0.002039193464970377, 
   0.0018730925376646286, 0.0013059264069037704, 0.0005909462964482912, 
   0.00008084392231952297, 0.0000660112276978618, 0.0006273390397613147, 
   0.0015780137973821751, 0.0025307319811790287, 0.0030672750000235735, 
   0.002935021869198528, 0.002176632571947903, 0.0011261709102604008, 
   0.00026644650602795754, 9.524060375007882*^-6, 0.0005021660949431394, 
   0.0015497003908285082, 0.0026978323402971596, 0.003437345098274072, 
   0.0034373450982741493, 0.0026978323402973552, 0.0015497003908287353, 
   0.0005021660949432988, 9.524060375031322*^-6, 0.0002664465060278402, 
   0.0011261709102602013, 0.002176632571947715, 0.0029350218691984358, 
   0.0030672750000236156, 0.0025307319811791852, 0.001578013797382372, 
   0.000627339039761468, 0.00006601122769791607, 0.00008084392231946582, 
   0.0005909462964481624, 0.0013059264069036364, 0.0018730925376645529, 
   0.0020391934649703907, 0.0017519576675539598, 0.0011612539106059107, 
   0.0005297987068502209, 0.0001039135253258648, 7.649281025886336*^-6, 
   0.0002054422224638696, 0.0005412959630575833, 0.0008260985823861813, 
   0.0009262824932671483, 0.0008131251009852776, 0.0005564322056139354, 
   0.000274887305093017, 0.00007364648887127177, 4.860208478920835*^-7, 
   0.000037354818760987925, 0.00012409455778820535, 
   0.00019623592687274352, 0.00021564646698710784, 
   0.00018085458695253165, 0.0001169288388851509, 0.00005516609808193802, 
   0.000015642390066165515, 9.451800794457806*^-7, 
   1.2481510137982646*^-6, 4.53457489434296*^-6, 4.4491533848285736*^-6, 
   1.6891186091407336*^-6, 6.389425260408971*^-9, 1.2433541210981414*^-6, 
   3.538720888485367*^-6, 3.691650463918736*^-6, 1.211198737738435*^-6, 
   2.81271663696406*^-7, 7.525798870077409*^-6, 0.000026764841783286678, 
   0.000054506895388933444, 0.000079870498363191, 0.00008989292412829956, 
   0.00007750978541059188, 0.00004730526201514966, 
   0.00001498041195829026, 1.5399204938860983*^-8, 
   0.000015146511559007391, 0.00005851231520796216, 
   0.00011319667220494036, 0.00015493890905041922, 
   0.00016421337889200978, 0.00013631962686894915, 
   0.00008405960393870999, 0.000031511515060344815, 
   2.1531676886203924*^-6, 7.5256691649115525*^-6, 
   0.00004219630573346006, 0.00008730861981016715, 
   0.00012047788202770252, 0.00012667072696335673}, 
  {0.0002010501204667088, 0.00019122091801250713, 0.00013857509901001825, 
   0.00006697342436045403, 0.0000119446436321205, 3.417479583162972*^-6, 
   0.00005001466440468079, 0.00013341830352918402, 
   0.00021636472814990659, 0.000260637326396923, 0.00024591700921223813, 
   0.0001796642770497369, 0.0000928699811184637, 0.000024040344968344868, 
   2.444141659426639*^-8, 0.00002377671385532827, 0.0000750822929247501, 
   0.00012302251725969377, 0.00014267687301050774, 
   0.00012676940997032287, 0.00008651263118891491, 
   0.000042480806685192935, 0.000011944849498459943, 
   4.4643070443949746*^-7, 1.9223987891202314*^-6, 5.859339314492945*^-6, 
   5.616611493308362*^-6, 1.9734353928667808*^-6, 1.0141212173525743*^-8, 
   2.6809469558695693*^-6, 7.06163803933438*^-6, 7.197217941575282*^-6, 
   1.9810489581978776*^-6, 1.5001774552859788*^-6, 
   0.00002482739684677582, 0.0000875589090781682, 0.000185587923172575, 
   0.00028705003409572446, 0.00034227125086698425, 0.0003114630955664819, 
   0.0001969612584587344, 0.000059289079584142723, 7.714059306369533*^-7, 
   0.0001168907435401181, 0.00043629753399692837, 0.0008831619163485994, 
   0.0012905815212924472, 0.0014701834537622727, 0.001311172861226057, 
   0.0008591378702071102, 0.000326075207472916, 0.000012140838760526968, 
   0.00016493018778457677, 0.0008408895755854924, 0.001843127012978071, 
   0.002780684287192708, 0.0032365811866369417, 0.0029729479680945577, 
   0.0020727493061961744, 0.0009379422297359611, 0.00012831441573745304, 
   0.000104772156906069, 0.000995704315756941, 0.002504602852351167, 
   0.004016744688235584, 0.004868338747575545, 0.004658428308740162, 
   0.00345472273896783, 0.0017874437338585532, 0.00042290040816100855, 
   0.000015116464013674483, 0.0007970314555139647, 0.0024596641839239744, 
   0.004281964191873939, 0.005455709165493125, 0.005455709165493247, 
   0.004281964191874249, 0.002459664183924335, 0.0007970314555142178, 
   0.000015116464013711686, 0.00042290040816082234, 
   0.0017874437338582369, 0.0034547227389675316, 0.004658428308740015, 
   0.0048683387475756115, 0.004016744688235832, 0.0025046028523514796, 
   0.0009957043157571843, 0.00010477215690615512, 0.00012831441573736235, 
   0.0009379422297357567, 0.002072749306195962, 0.002972947968094437, 
   0.0032365811866369625, 0.0027806842871928557, 0.0018431270129782738, 
   0.0008408895755856664, 0.0001649301877846598, 0.000012140838760505877, 
   0.00032607520747282353, 0.0008591378702070082, 0.0013111728612259959, 
   0.001470183453762276, 0.0012905815212925092, 0.000883161916348689, 
   0.00043629753399700714, 0.00011689074354016122, 7.714059306401823*^-7, 
   0.00005928907958412002, 0.00019696125845870672, 0.0003114630955664674, 
   0.0003422712508669875, 0.0002870500340957409, 0.0001855879231725956, 
   0.0000875589090781843, 0.000024827396846783904, 1.500177455287531*^-6, 
   1.9810489581968*^-6, 7.197217941574671*^-6, 7.0616380393350345*^-6, 
   2.6809469558704536*^-6, 1.014121217358988*^-8, 1.9734353928660773*^-6, 
   5.61661149330786*^-6, 5.859339314493384*^-6, 1.9223987891210585*^-6, 
   4.464307044388674*^-7, 0.000011944849498455966, 0.0000424808066851854, 
   0.00008651263118890614, 0.0001267694099703168, 0.000142676873010508, 
   0.00012302251725970122, 0.00007508229292476113, 
   0.000023776713855336748, 2.444141659457905*^-8, 
   0.000024040344968335033, 0.00009286998111844772, 
   0.00017966427704972117, 0.0002459170092122298, 0.00026063732639692596, 
   0.00021636472814991973, 0.0001334183035292012, 0.00005001466440469407, 
   3.4174795831667427*^-6, 0.00001194464363211379, 
   0.00006697342436044011, 0.0001385750990100046, 0.00019122091801250028, 
   0.00020105012046671148}, {0.00011838692132157704, 
   0.00011259906596044529, 0.00008159895306476727, 
   0.00003943682054003326, 7.033517724871397*^-6, 2.0123583392580187*^-6, 
   0.000029450776383804635, 0.00007856241103512908, 
   0.00012740481820546263, 0.0001534744201196739, 0.00014480646693304297, 
   0.00010579402082431097, 0.000054685822233210076, 
   0.00001415598469528042, 1.4392152845351985*^-8, 
   0.000014000747405383924, 0.000044211669629901314, 
   0.00007244092685842167, 0.00008401425326328294, 
   0.00007464725775493607, 0.00005094234232792024, 
   0.000025014518305398493, 7.033638947788716*^-6, 
   2.6287751810010233*^-7, 1.131990737772063*^-6, 3.4502299268015697*^-6, 
   3.3073013903628395*^-6, 1.1620432758070437*^-6, 5.971580046336816*^-9, 
   1.5786563847615677*^-6, 4.158194906938969*^-6, 4.238030159870532*^-6, 
   1.1665264691408099*^-6, 8.833687339011232*^-7, 
   0.000014619434548438969, 0.000051558435558145605, 
   0.00010928211735393938, 0.00016902735359202963, 0.0002015439709907414, 
   0.00018340280972629225, 0.00011597922425723727, 
   0.00003491194923764736, 4.542368490270912*^-7, 0.00006883027588633574, 
   0.0002569106733693567, 0.000520043559597308, 0.0007599496715826629, 
   0.0008657069812482854, 0.0007720747344026564, 0.0005058971723493115, 
   0.0001920070470109724, 7.149045818942742*^-6, 0.00009711795804687812, 
   0.0004951517949548217, 0.0010853121210003928, 0.0016373859969038874, 
   0.001905837616032325, 0.0017505990863120734, 0.0012205235613008878, 
   0.0005523005542009736, 0.000075557023318717, 0.0000616943330724569, 
   0.0005863133442319462, 0.0014748174243058635, 0.0023652312979029026, 
   0.0028666863513342007, 0.0027430820950955326, 0.0020342887044117516, 
   0.001052523421502243, 0.00024902187191730814, 8.901221405354313*^-6, 
   0.0004693262555412306, 0.0014483556117437198, 0.0025214039002236298, 
   0.0032125552087674137, 0.0032125552087674857, 0.0025214039002238128, 
   0.001448355611743932, 0.00046932625554137967, 8.90122140537622*^-6, 
   0.00024902187191719853, 0.0010525234215020564, 0.002034288704411576, 
   0.0027430820950954463, 0.00286668635133424, 0.0023652312979030488, 
   0.0014748174243060476, 0.0005863133442320895, 0.0000616943330725076, 
   0.0000755570233186636, 0.0005523005542008532, 0.0012205235613007624, 
   0.0017505990863120027, 0.0019058376160323374, 0.0016373859969039746, 
   0.001085312121000512, 0.0004951517949549241, 0.00009711795804692701, 
   7.149045818930322*^-6, 0.00019200704701091792, 0.0005058971723492515, 
   0.0007720747344026203, 0.0008657069812482872, 0.0007599496715826994, 
   0.0005200435595973608, 0.0002569106733694031, 0.00006883027588636112, 
   4.542368490289926*^-7, 0.000034911949237633997, 
   0.00011597922425722098, 0.00018340280972628365, 0.0002015439709907433, 
   0.00016902735359203928, 0.00010928211735395152, 
   0.000051558435558155085, 0.000014619434548443727, 
   8.833687339020371*^-7, 1.1665264691401754*^-6, 4.238030159870172*^-6, 
   4.158194906939355*^-6, 1.5786563847620884*^-6, 5.971580046374583*^-9, 
   1.1620432758066295*^-6, 3.307301390362544*^-6, 3.450229926801828*^-6, 
   1.13199073777255*^-6, 2.6287751809973133*^-7, 7.033638947786374*^-6, 
   0.00002501451830539406, 0.00005094234232791507, 
   0.00007464725775493249, 0.00008401425326328309, 
   0.00007244092685842606, 0.00004421166962990782, 
   0.000014000747405388916, 1.4392152845536094*^-8, 
   0.000014155984695274629, 0.000054685822233200663, 
   0.00010579402082430173, 0.00014480646693303803, 
   0.00015347442011967566, 0.00012740481820547038, 
   0.00007856241103513919, 0.000029450776383812452, 
   2.0123583392602388*^-6, 7.033517724867446*^-6, 
   0.000039436820540025066, 0.00008159895306475925, 
   0.00011259906596044125, 0.00011838692132157861}, 
  {6.304166934021246*^-6, 5.995960537746845*^-6, 4.3451879313961114*^-6, 
   2.1000318046626584*^-6, 3.745385839584729*^-7, 1.0715915880008728*^-7, 
   1.5682696077188754*^-6, 4.18349044282799*^-6, 6.784374770454301*^-6, 
   8.172595027692412*^-6, 7.711021880466365*^-6, 5.6335882414421755*^-6, 
   2.912049307760261*^-6, 7.538137628572033*^-7, 7.663898432715756*^-10, 
   7.455472940702142*^-7, 2.3542950747203572*^-6, 3.857518133529499*^-6, 
   4.473803959900287*^-6, 3.975006434838847*^-6, 2.7127069988831065*^-6, 
   1.3320364902725194*^-6, 3.7454503914371193*^-7, 
   1.3998368559671242*^-8, 6.027911275179271*^-8, 1.837265905431458*^-7, 
   1.7611556946677568*^-7, 6.187942648956547*^-8, 3.179898341111464*^-10, 
   8.406429755836161*^-8, 2.2142610471586346*^-7, 2.256773746710409*^-7, 
   6.211815893448463*^-8, 4.7039857955937006*^-8, 7.784927156270193*^-7, 
   2.7455142931931852*^-6, 5.819331248856204*^-6, 9.00079706072887*^-6, 
   0.000010732324343665464, 9.766297795197028*^-6, 6.17595577648197*^-6, 
   1.8590799856038772*^-6, 2.4188355368006995*^-8, 
   3.6652490364500465*^-6, 0.000013680630883650184, 
   0.00002769259793283038, 0.00004046772682007869, 
   0.00004609936017266887, 0.000041113392905905034, 
   0.00002693929523917865, 0.000010224478036536468, 
   3.806905168110618*^-7, 5.1715832541647845*^-6, 
   0.000026367098140819138, 0.000057793451421192846, 
   0.00008719168084346125, 0.00010148687326676074, 
   0.00009322033845849289, 0.00006499353299716683, 
   0.000029410300162952207, 4.023451938116359*^-6, 3.285256261672801*^-6, 
   0.00003122149943947216, 0.0000785348173281102, 0.00012594983274418517, 
   0.00015265258277307099, 0.00014607058996182556, 
   0.00010832696248405703, 0.00005604743562081303, 
   0.000013260547983377999, 4.739948047437685*^-7, 
   0.000024991874342388033, 0.0000771257116439156, 0.0001342661074184463, 
   0.00017107028457828528, 0.0001710702845782891, 0.00013426610741845604, 
   0.00007712571164392688, 0.00002499187434239597, 
   4.7399480474493507*^-7, 0.000013260547983372161, 
   0.00005604743562080311, 0.00010832696248404767, 
   0.00014607058996182095, 0.0001526525827730731, 0.00012594983274419295, 
   0.00007853481732812001, 0.00003122149943947979, 
   3.2852562616755013*^-6, 4.023451938113515*^-6, 
   0.000029410300162945793, 0.00006499353299716017, 
   0.00009322033845848912, 0.0001014868732667614, 0.00008719168084346589, 
   0.0000577934514211992, 0.000026367098140824592, 5.171583254167388*^-6, 
   3.806905168104005*^-7, 0.000010224478036533566, 
   0.000026939295239175448, 0.000041113392905903116, 
   0.00004609936017266897, 0.00004046772682008063, 
   0.00002769259793283319, 0.000013680630883652656, 
   3.6652490364513983*^-6, 2.4188355368108242*^-8, 
   1.8590799856031654*^-6, 6.1759557764811015*^-6, 9.76629779519657*^-6, 
   0.000010732324343665568, 9.000797060729385*^-6, 5.819331248856851*^-6, 
   2.74551429319369*^-6, 7.784927156272727*^-7, 4.703985795598567*^-8, 
   6.211815893445084*^-8, 2.2567737467102177*^-7, 2.21426104715884*^-7, 
   8.406429755838935*^-8, 3.179898341131575*^-10, 6.187942648954341*^-8, 
   1.7611556946675995*^-7, 1.8372659054315954*^-7, 6.027911275181865*^-8, 
   1.3998368559651485*^-8, 3.7454503914358726*^-7, 
   1.3320364902722833*^-6, 2.712706998882831*^-6, 3.975006434838656*^-6, 
   4.473803959900294*^-6, 3.857518133529733*^-6, 2.3542950747207033*^-6, 
   7.4554729407048*^-7, 7.663898432813796*^-10, 7.538137628568949*^-7, 
   2.91204930775976*^-6, 5.633588241441683*^-6, 7.711021880466102*^-6, 
   8.172595027692507*^-6, 6.784374770454714*^-6, 4.1834904428285275*^-6, 
   1.568269607719292*^-6, 1.0715915880020549*^-7, 3.745385839582625*^-7, 
   2.100031804662222*^-6, 4.345187931395684*^-6, 5.99596053774663*^-6, 
   6.304166934021331*^-6}, {0.00005547265097934564, 
   0.000052760631131351855, 0.00003823488433613693, 
   0.00001847894139936244, 3.2957008219599737*^-6, 9.429322982038726*^-7, 
   0.00001379977299157784, 0.0000368120494966644, 0.00005969817387345557, 
   0.0000719136273375195, 0.00006785207783137783, 0.00004957198588640898, 
   0.000025624177877058352, 6.633080660465887*^-6, 6.743742152589426*^-9, 
   6.560341003878177*^-6, 0.000020716296117978827, 
   0.00003394370093738662, 0.00003936662341193115, 
   0.00003497752310626317, 0.000023870092612265774, 
   0.000011721072124196857, 3.295757623475784*^-6, 
   1.2317672128894026*^-7, 5.304177725655307*^-7, 1.6166768963276827*^-6, 
   1.5497047618355823*^-6, 5.444995134778535*^-7, 2.7981078653600567*^-9, 
   7.397122390768111*^-7, 1.9484085927883417*^-6, 1.9858170587935576*^-6, 
   5.466002068340174*^-7, 4.1392076856746736*^-7, 6.850239715399496*^-6, 
   0.000024158775892053038, 0.00005120640596601179, 
   0.00007920127736326373, 0.00009443761384242599, 
   0.00008593719592506776, 0.000054344474509992923, 
   0.000016358718965315903, 2.1284211048611033*^-7, 
   0.00003225185542821336, 0.00012038083225405686, 
   0.00024367721158350766, 0.00035609020340230795, 0.0004056449875127924, 
   0.0003617716534341837, 0.00023704862800631355, 0.00008996889002191849, 
   3.3498339100510207*^-6, 0.00004550663646305416, 
   0.00023201365823776325, 0.0005085455371237466, 0.0007672312187086387, 
   0.0008930198008130868, 0.0008202795632802034, 0.0005719016659298172, 
   0.00025879189640947114, 0.000035403812657754776, 
   0.000028908161203345267, 0.00027472929565222035, 
   0.0006910563373343312, 0.0011082782524396895, 0.0013432454333604895, 
   0.001285328091737386, 0.0009532082263084489, 0.0004931817109255227, 
   0.00011668437047677873, 4.170852175198052*^-6, 0.00021991256532774458, 
   0.0006786571054246394, 0.001181456169090985, 0.0015053094704926115, 
   0.0015053094704926453, 0.0011814561690910706, 0.0006786571054247389, 
   0.00021991256532781443, 4.170852175208318*^-6, 0.00011668437047672735, 
   0.0004931817109254355, 0.0009532082263083665, 0.0012853280917373457, 
   0.001343245433360508, 0.001108278252439758, 0.0006910563373344175, 
   0.0002747292956522875, 0.000028908161203369028, 
   0.00003540381265772975, 0.0002587918964094147, 0.0005719016659297586, 
   0.0008202795632801703, 0.0008930198008130927, 0.0007672312187086795, 
   0.0005085455371238026, 0.00023201365823781125, 
   0.000045506636463077074, 3.3498339100452007*^-6, 
   0.00008996889002189297, 0.0002370486280062854, 0.0003617716534341668, 
   0.00040564498751279325, 0.0003560902034023251, 0.00024367721158353238, 
   0.0001203808322540786, 0.00003225185542822526, 2.1284211048700122*^-7, 
   0.000016358718965309642, 0.00005434447450998529, 
   0.00008593719592506373, 0.00009443761384242688, 
   0.00007920127736326826, 0.00005120640596601747, 
   0.000024158775892057476, 6.850239715401725*^-6, 4.139207685678956*^-7, 
   5.466002068337201*^-7, 1.985817058793389*^-6, 1.9484085927885225*^-6, 
   7.397122390770551*^-7, 2.7981078653777526*^-9, 5.444995134776594*^-7, 
   1.5497047618354438*^-6, 1.6166768963278036*^-6, 5.304177725657588*^-7, 
   1.231767212887664*^-7, 3.2957576234746866*^-6, 0.00001172107212419478, 
   0.00002387009261226335, 0.00003497752310626149, 
   0.00003936662341193122, 0.00003394370093738868, 
   0.000020716296117981873, 6.560341003880516*^-6, 6.743742152675694*^-9, 
   6.6330806604631735*^-6, 0.000025624177877053944, 
   0.00004957198588640464, 0.00006785207783137551, 
   0.00007191362733752032, 0.000059698173873459186, 
   0.00003681204949666913, 0.000013799772991581505, 9.42932298204913*^-7, 
   3.2957008219581226*^-6, 0.000018478941399358602, 
   0.000038234884336133165, 0.00005276063113134996, 
   0.00005547265097934638}, {0.00021351306127952638, 
   0.00020307455419949535, 0.0001471652617668626, 0.000071125054918538, 
   0.000012685082813513413, 3.6293264881790044*^-6, 
   0.000053115034604914944, 0.0001416888005394362, 
   0.00022977700959820428, 0.00027679403182418355, 
   0.00026116121361043814, 0.0001908015260394449, 0.00009862691911621315, 
   0.00002553058728088211, 2.5956521025383597*^-8, 
   0.000025250613879930962, 0.00007973658594700542, 
   0.00013064858755347045, 0.00015152130155180916, 
   0.00013462774723303322, 0.00009187548200226273, 
   0.00004511415889691654, 0.000012685301441347342, 
   4.741045970665611*^-7, 2.0415667969374905*^-6, 6.222555207670351*^-6, 
   5.9647808773763715*^-6, 2.09576712011034*^-6, 1.0769858039519168*^-8, 
   2.847136775381956*^-6, 7.499383496643561*^-6, 7.64336789171995*^-6, 
   2.1038526444428822*^-6, 1.5931722905566613*^-6, 
   0.000026366427893956603, 0.0000929866178452305, 
   0.00019709237438456288, 0.00030484404275857763, 0.0003634883798673651, 
   0.0003307704509483693, 0.00020917073389148223, 0.00006296436357794644, 
   8.192247851288946*^-7, 0.00012413670994354515, 0.0004633432792586546, 
   0.0009379084375943289, 0.0013705836674072873, 0.0015613189841747349, 
   0.0013924514485101611, 0.0009123951594919201, 0.0003462883563227079, 
   0.000012893439925545738, 0.00017515408202465227, 
   0.0008930156672600937, 0.0019573810249623844, 0.0029530567464081856, 
   0.0034372143405554663, 0.0031572387035586234, 0.0022012374257902594, 
   0.0009960845400608985, 0.0001362685267076673, 0.00011126690153651448, 
   0.0010574272529307123, 0.002659861237852286, 0.004265739571667991, 
   0.005170123285316358, 0.004947200661414262, 0.0036688783182855784, 
   0.0018982459826192527, 0.00044911567599766614, 
   0.000016053521876978315, 0.0008464388163897779, 0.002612136856272996, 
   0.004547399826341842, 0.005793904339232134, 0.005793904339232264, 
   0.0045473998263421715, 0.0026121368562733787, 0.0008464388163900467, 
   0.000016053521877017824, 0.00044911567599746844, 
   0.0018982459826189166, 0.0036688783182852614, 0.0049472006614141055, 
   0.005170123285316429, 0.0042657395716682546, 0.002659861237852618, 
   0.0010574272529309708, 0.00011126690153660595, 0.00013626852670757097, 
   0.0009960845400606815, 0.0022012374257900334, 0.0031572387035584955, 
   0.003437214340555489, 0.002953056746408342, 0.0019573810249625995, 
   0.0008930156672602784, 0.00017515408202474044, 0.00001289343992552334, 
   0.00034628835632260964, 0.0009123951594918117, 0.001392451448510096, 
   0.0015613189841747384, 0.0013705836674073532, 0.0009379084375944241, 
   0.00046334327925873827, 0.00012413670994359093, 8.192247851323237*^-7, 
   0.00006296436357792233, 0.00020917073389145285, 
   0.00033077045094835383, 0.00036348837986736854, 
   0.00030484404275859503, 0.00019709237438458478, 0.0000929866178452476, 
   0.000026366427893965186, 1.5931722905583096*^-6, 
   2.103852644441738*^-6, 7.6433678917193*^-6, 7.4993834966442575*^-6, 
   2.8471367753828952*^-6, 1.076985803958728*^-8, 2.0957671201095926*^-6, 
   5.964780877375839*^-6, 6.222555207670817*^-6, 2.0415667969383693*^-6, 
   4.74104597065892*^-7, 0.000012685301441343119, 0.00004511415889690854, 
   0.0000918754820022534, 0.00013462774723302677, 0.00015152130155180943, 
   0.00013064858755347836, 0.00007973658594701714, 
   0.000025250613879939964, 2.5956521025715644*^-8, 
   0.000025530587280871663, 0.00009862691911619618, 
   0.00019080152603942824, 0.00026116121361042925, 
   0.00027679403182418675, 0.0002297770095982182, 0.00014168880053945442, 
   0.000053115034604929045, 3.6293264881830083*^-6, 
   0.000012685082813506286, 0.00007112505491852323, 
   0.00014716526176684812, 0.00020307455419948806, 
   0.00021351306127952922}, {0.00024344180999696328, 
   0.00023154010692549623, 0.00016779384585891504, 
   0.00008109486137166173, 0.000014463187879828269, 
   4.138059770477096*^-6, 0.00006056032396698966, 0.0001615497330838306, 
   0.0002619855234010466, 0.0003155930588031789, 0.00029776894285213937, 
   0.0002175467326020638, 0.00011245174210978034, 
   0.000029109284184758034, 2.9594922304875086*^-8, 
   0.00002879006609538165, 0.00009091349582827021, 
   0.00014896198123413523, 0.00017276048444913163, 
   0.00015349891133506008, 0.0001047539363584543, 0.00005143794216868871, 
   0.000014463437153363522, 5.405612216231751*^-7, 2.327739171073478*^-6, 
   7.094788925245746*^-6, 6.800881615025662*^-6, 2.389536911673266*^-6, 
   1.2279500461653016*^-8, 3.246228243622503*^-6, 8.55059396059217*^-6, 
   8.714761068396523*^-6, 2.398755807540773*^-6, 1.8164918985558645*^-6, 
   0.000030062287015106836, 0.00010602082335423603, 
   0.00022471938751307638, 0.00034757492160530375, 0.0004144396065397062, 
   0.00037713551007056875, 0.0002384908059103284, 0.00007179026211728976, 
   9.340579133238954*^-7, 0.00014153731474142111, 0.0005282914585023157, 
   0.001069377799611369, 0.0015627023787040803, 0.0017801736212873275, 
   0.0015876354304827326, 0.00104028825088313, 0.000394828605514247, 
   0.000014700751016129727, 0.00019970594070877398, 0.001018192278686087, 
   0.002231752833831183, 0.0033669953260057847, 0.003919018702639799, 
   0.003599798063784672, 0.0025097912978067605, 0.0011357086160876937, 
   0.000155369683655578, 0.00012686350774270097, 0.0012056499159859748, 
   0.003032701747626594, 0.004863680732594619, 0.0058948345498971546, 
   0.005640664211432701, 0.004183155696000975, 0.0021643286600781203, 
   0.0005120695305836331, 0.000018303790874137932, 0.0009650866147427282, 
   0.002978287700246898, 0.00518482212690136, 0.006606052814002625, 
   0.0066060528140027735, 0.005184822126901736, 0.0029782877002473345, 
   0.0009650866147430348, 0.00001830379087418298, 0.0005120695305834077, 
   0.0021643286600777373, 0.004183155696000613, 0.0056406642114325235, 
   0.005894834549897235, 0.004863680732594919, 0.0030327017476269725, 
   0.0012056499159862695, 0.00012686350774280525, 0.00015536968365546818, 
   0.001135708616087446, 0.002509791297806503, 0.0035997980637845262, 
   0.003919018702639824, 0.0033669953260059638, 0.002231752833831428, 
   0.0010181922786862976, 0.0001997059407088745, 0.000014700751016104188, 
   0.000394828605514135, 0.001040288250883006, 0.0015876354304826584, 
   0.0017801736212873314, 0.0015627023787041555, 0.0010693777996114776, 
   0.0005282914585024111, 0.00014153731474147332, 9.340579133278052*^-7, 
   0.00007179026211726228, 0.0002384908059102949, 0.0003771355100705511, 
   0.0004144396065397102, 0.00034757492160532365, 0.00022471938751310132, 
   0.00010602082335425552, 0.00003006228701511662, 
   1.8164918985577438*^-6, 2.398755807539468*^-6, 8.714761068395784*^-6, 
   8.550593960592962*^-6, 3.2462282436235742*^-6, 1.2279500461730675*^-8, 
   2.3895369116724145*^-6, 6.800881615025055*^-6, 7.094788925246277*^-6, 
   2.3277391710744797*^-6, 5.405612216224121*^-7, 
   0.000014463437153358706, 0.00005143794216867959, 
   0.00010475393635844368, 0.00015349891133505274, 
   0.00017276048444913193, 0.00014896198123414426, 
   0.00009091349582828358, 0.000028790066095391913, 
   2.9594922305253674*^-8, 0.000029109284184746125, 0.000112451742109761, 
   0.0002175467326020448, 0.00029776894285212923, 0.0003155930588031825, 
   0.0002619855234010625, 0.0001615497330838514, 0.00006056032396700574, 
   4.138059770481662*^-6, 0.000014463187879820144, 
   0.00008109486137164489, 0.0001677938458588985, 0.00023154010692548794, 
   0.00024344180999696653}, {0.00009236869850163707, 
   0.00008785285620372588, 0.00006366572430087346, 
   0.00003076968085377165, 5.487741980973004*^-6, 1.5700967525903638*^-6, 
   0.00002297829738342034, 0.00006129653155481564, 
   0.00009940470711718222, 0.00011974492014401256, 
   0.00011298194712651683, 0.00008254337475549888, 
   0.00004266736705191156, 0.000011044884584508829, 
   1.1229149403680825*^-8, 0.000010923764225379706, 
   0.0000344951480848589, 0.00005652038297363133, 0.00006555020726011549, 
   0.000058241822395317184, 0.000039746602132453925, 
   0.000019517008075907418, 5.487836562392779*^-6, 
   2.0510419513562816*^-7, 8.832099863454793*^-7, 2.6919633039901927*^-6, 
   2.5804465693525204*^-6, 9.066577945490718*^-7, 4.659189298285653*^-9, 
   1.231710682345018*^-6, 3.244336852267526*^-6, 3.3066264897166365*^-6, 
   9.10155704020392*^-7, 6.892283314458841*^-7, 0.000011406480775026773, 
   0.00004022729484070509, 0.00008526488261374175, 0.0001318797421892769, 
   0.00015725009218457893, 0.00014309586436448207, 
   0.00009049014771463605, 0.00002723925309686185, 3.544079539170342*^-7, 
   0.000053703254803456814, 0.00020044870045946183, 
   0.00040575214075954643, 0.0005929334195638327, 0.0006754481512740468, 
   0.0006023937236196429, 0.0003947147443646506, 0.0001498091245009319, 
   5.577880144636864*^-6, 0.0000757740744145168, 0.00038633090843279215, 
   0.0008467900589504249, 0.001277533124355792, 0.0014869863848405004, 
   0.001365865058367135, 0.0009522857051220449, 0.0004309199259832329, 
   0.0000589516462519558, 0.000048135597980034, 0.00045745763059197494, 
   0.0011506926989057593, 0.001845417840110775, 0.0022366667223813193, 
   0.0021402273171617515, 0.0015872074204268353, 0.000821207423095079, 
   0.00019429364283376157, 6.9449752312938874*^-6, 0.0003661811196123157, 
   0.0011300464724554563, 0.0019672679554524446, 0.0025065230194850725, 
   0.0025065230194851284, 0.0019672679554525872, 0.0011300464724556217, 
   0.000366181119612432, 6.94497523131098*^-6, 0.00019429364283367602, 
   0.0008212074230949337, 0.001587207420426698, 0.0021402273171616843, 
   0.00223666672238135, 0.001845417840110889, 0.0011506926989059028, 
   0.0004574576305920867, 0.000048135597980073565, 
   0.00005895164625191413, 0.00043091992598313895, 0.0009522857051219472, 
   0.0013658650583670798, 0.00148698638484051, 0.0012775331243558598, 
   0.000846790058950518, 0.00038633090843287205, 0.00007577407441455493, 
   5.577880144627174*^-6, 0.0001498091245008894, 0.0003947147443646037, 
   0.0006023937236196148, 0.0006754481512740482, 0.0005929334195638612, 
   0.00040575214075958763, 0.000200448700459498, 0.00005370325480347662, 
   3.5440795391851765*^-7, 0.00002723925309685142, 
   0.00009049014771462334, 0.00014309586436447538, 
   0.00015725009218458042, 0.00013187974218928443, 
   0.00008526488261375123, 0.000040227294840712486, 
   0.000011406480775030487, 6.892283314465972*^-7, 9.10155704019897*^-7, 
   3.306626489716356*^-6, 3.2443368522678266*^-6, 1.2317106823454243*^-6, 
   4.65918929831512*^-9, 9.066577945487485*^-7, 2.58044656935229*^-6, 
   2.6919633039903943*^-6, 8.832099863458594*^-7, 2.0510419513533871*^-7, 
   5.487836562390952*^-6, 0.000019517008075903956, 
   0.000039746602132449894, 0.00005824182239531439, 
   0.00006555020726011561, 0.00005652038297363476, 
   0.000034495148084863966, 0.0000109237642253836, 
   1.1229149403824472*^-8, 0.00001104488458450431, 
   0.00004266736705190422, 0.00008254337475549167, 
   0.00011298194712651298, 0.00011974492014401395, 
   0.00009940470711718825, 0.00006129653155482353, 
   0.000022978297383426443, 1.570096752592096*^-6, 
   5.4877419809699216*^-6, 0.000030769680853765256, 
   0.0000636657243008672, 0.00008785285620372273, 0.0000923686985016383}, 
  {1.1899520996893826*^-6, 1.1317761579316851*^-6, 8.201821995870932*^-7, 
   3.963945246892143*^-7, 7.069656927878726*^-8, 2.022698119349675*^-8, 
   2.960209861374573*^-7, 7.896607574917452*^-7, 1.2805944207496078*^-6, 
   1.5426299326928353*^-6, 1.4555050292043548*^-6, 
   1.0633760537831183*^-6, 5.496680567686022*^-7, 1.4228720135025222*^-7, 
   1.4466101750257913*^-10, 1.407268521410634*^-7, 4.443883540477355*^-7, 
   7.281313852606532*^-7, 8.444593030924454*^-7, 7.503080586094377*^-7, 
   5.120409124547077*^-7, 2.51430464175795*^-7, 7.069778773656439*^-8, 
   2.642282197495897*^-9, 1.1378070653445521*^-8, 3.4679576932797476*^-8, 
   3.324294769924548*^-8, 1.1680140175454475*^-8, 6.002262864239721*^-11, 
   1.586767743231025*^-8, 4.17956029702742*^-8, 4.2598057547136575*^-8, 
   1.172520246156915*^-8, 8.87907606660609*^-9, 1.4694551258691953*^-7, 
   5.182335004933787*^-7, 1.0984362423834792*^-6, 1.698958399006165*^-6, 
   2.025795322514718*^-6, 1.8434515914973585*^-6, 1.1657514181855136*^-6, 
   3.509133174157131*^-7, 4.565707818246658*^-9, 6.918393552161478*^-7, 
   2.582307165316585*^-6, 5.2271561652644376*^-6, 7.63854399846809*^-6, 
   8.701551054393373*^-6, 7.760417629443975*^-6, 5.08496543151736*^-6, 
   1.9299360621537023*^-6, 7.185778621541059*^-8, 9.761696377044406*^-7, 
   4.97695954497356*^-6, 0.00001090888607276734, 0.00001645799116378119, 
   0.00001915630077670865, 0.000017595939105578363, 
   0.000012267947829686893, 5.55138352103828*^-6, 7.59452459281076*^-7, 
   6.201132723021997*^-7, 5.893259046322957*^-6, 0.000014823952435963822, 
   0.00002377384188871236, 0.000028814157888733804, 
   0.000027571764365869716, 0.000020447411658030532, 
   0.000010579314348303579, 2.503013813085565*^-6, 8.946957132477566*^-8, 
   4.717377198310977*^-6, 0.000014557974665206718, 
   0.000025343592279810955, 0.000032290617691264434, 
   0.00003229061769126516, 0.00002534359227981279, 
   0.00001455797466520885, 4.717377198312474*^-6, 8.946957132499586*^-8, 
   2.503013813084463*^-6, 0.000010579314348301707, 
   0.000020447411658028763, 0.00002757176436586885, 
   0.000028814157888734197, 0.000023773841888713827, 
   0.000014823952435965672, 5.893259046324398*^-6, 6.201132723027094*^-7, 
   7.594524592805392*^-7, 5.551383521037069*^-6, 0.000012267947829685636, 
   0.00001759593910557765, 0.000019156300776708777, 
   0.000016457991163782063, 0.00001090888607276854, 4.97695954497459*^-6, 
   9.76169637704932*^-7, 7.185778621528576*^-8, 1.929936062153155*^-6, 
   5.084965431516755*^-6, 7.760417629443613*^-6, 8.701551054393392*^-6, 
   7.638543998468458*^-6, 5.227156165264968*^-6, 2.582307165317051*^-6, 
   6.918393552164031*^-7, 4.565707818265769*^-9, 3.5091331741557874*^-7, 
   1.16575141818535*^-6, 1.8434515914972724*^-6, 2.0257953225147376*^-6, 
   1.6989583990062623*^-6, 1.0984362423836012*^-6, 5.18233500493474*^-7, 
   1.4694551258696736*^-7, 8.879076066615276*^-9, 1.1725202461562774*^-8, 
   4.259805754713296*^-8, 4.179560297027808*^-8, 1.5867677432315485*^-8, 
   6.002262864277682*^-11, 1.1680140175450311*^-8, 3.324294769924251*^-8, 
   3.467957693280007*^-8, 1.1378070653450416*^-8, 2.642282197492168*^-9, 
   7.069778773654084*^-8, 2.514304641757504*^-7, 5.120409124546557*^-7, 
   7.503080586094017*^-7, 8.444593030924469*^-7, 7.281313852606974*^-7, 
   4.443883540478008*^-7, 1.4072685214111355*^-7, 
   1.4466101750442969*^-10, 1.4228720135019402*^-7, 
   5.496680567685076*^-7, 1.0633760537830253*^-6, 1.4555050292043052*^-6, 
   1.542629932692853*^-6, 1.2805944207496855*^-6, 7.896607574918468*^-7, 
   2.960209861375359*^-7, 2.0226981193519063*^-8, 7.069656927874754*^-8, 
   3.9639452468913194*^-7, 8.201821995870125*^-7, 1.1317761579316445*^-6, 
   1.1899520996893985*^-6}, {0.00014349241432574822, 
   0.00013647716863588797, 0.00009890307688559541, 
   0.00004779991344862559, 8.525067028335628*^-6, 2.4391052099777642*^-6, 
   0.000035696198194062147, 0.00009522259645608215, 
   0.00015442267403319062, 0.00018602067554739614, 
   0.00017551456966908115, 0.00012822902479297824, 
   0.00006628266512917429, 0.000017157946151556112, 
   1.744419684261482*^-8, 0.00001696978876666959, 
   0.000053587331655786913, 0.00008780297160253409, 
   0.00010183057303920394, 0.00009047718378415149, 0.0000617453314136462, 
   0.00003031917364492742, 8.525213958155945*^-6, 3.186241294482358*^-7, 
   1.3720441594733287*^-6, 4.181896248749514*^-6, 4.008657849265084*^-6, 
   1.408469730736747*^-6, 7.237931594325193*^-9, 1.913431091132771*^-6, 
   5.039994450172043*^-6, 5.136759811274215*^-6, 1.4139036437751962*^-6, 
   1.0706986122482188*^-6, 0.0000177196765995335, 0.00006249207526058392, 
   0.00013245681775228733, 0.0002048718117107733, 0.0002442840025521394, 
   0.00022229577108662433, 0.00014057413365022768, 
   0.00004231548408392425, 5.505637059820913*^-7, 0.00008342663493047137, 
   0.0003113919373550243, 0.0006303255890781688, 0.0009211069256987341, 
   0.0010492914542523128, 0.0009358032664639969, 0.0006131792756379524, 
   0.00023272464927374, 8.665094363751504*^-6, 0.0001177130895792065, 
   0.0006001552006137492, 0.001315466732311765, 0.0019846150846401715, 
   0.0023099953760472, 0.0021218364884161016, 0.0014793515246232247, 
   0.0006694231007196764, 0.00009157987701884379, 0.00007477742223515547, 
   0.0007106487471425762, 0.0017875717227960322, 0.0028668094886343943, 
   0.0034746046360160134, 0.0033247884827565877, 0.002465686195510842, 
   0.0012757247608079121, 0.00030183021251367897, 0.00001078884166970502, 
   0.0005688530182412987, 0.0017554983372430508, 0.0030561005311615028, 
   0.0038938195023133625, 0.0038938195023134497, 0.0030561005311617244, 
   0.001755498337243308, 0.0005688530182414793, 0.000010788841669731573, 
   0.0003018302125135461, 0.0012757247608076862, 0.0024656861955106284, 
   0.003324788482756483, 0.003474604636016061, 0.0028668094886345717, 
   0.0017875717227962553, 0.0007106487471427499, 0.00007477742223521694, 
   0.00009157987701877906, 0.0006694231007195304, 0.001479351524623073, 
   0.0021218364884160157, 0.002309995376047215, 0.001984615084640277, 
   0.0013154667323119096, 0.0006001552006138734, 0.00011771308957926575, 
   8.66509436373645*^-6, 0.00023272464927367399, 0.0006131792756378795, 
   0.0009358032664639531, 0.001049291454252315, 0.0009211069256987785, 
   0.0006303255890782327, 0.0003113919373550805, 0.00008342663493050215, 
   5.505637059843959*^-7, 0.00004231548408390805, 0.00014057413365020795, 
   0.00022229577108661392, 0.0002442840025521417, 0.000204871811710785, 
   0.00013245681775230205, 0.00006249207526059541, 
   0.000017719676599539268, 1.0706986122493265*^-6, 
   1.4139036437744273*^-6, 5.1367598112737785*^-6, 5.039994450172511*^-6, 
   1.9134310911334026*^-6, 7.237931594370968*^-9, 1.4084697307362447*^-6, 
   4.008657849264726*^-6, 4.181896248749826*^-6, 1.3720441594739191*^-6, 
   3.186241294477861*^-7, 8.525213958153107*^-6, 0.000030319173644922042, 
   0.00006174533141363994, 0.00009047718378414716, 
   0.00010183057303920413, 0.00008780297160253941, 
   0.00005358733165579479, 0.000016969788766675638, 
   1.744419684283797*^-8, 0.00001715794615154909, 0.00006628266512916289, 
   0.00012822902479296702, 0.0001755145696690752, 0.00018602067554739828, 
   0.0001544226740332, 0.0000952225964560944, 0.000035696198194071627, 
   2.4391052099804553*^-6, 8.525067028330839*^-6, 0.00004779991344861566, 
   0.00009890307688558568, 0.00013647716863588306, 
   0.00014349241432575014}, {0.00032976185407916875, 
   0.0003136400232745273, 0.0002272904958856504, 0.00010984962625173513, 
   0.00001959157160065079, 5.6053406036537785*^-6, 
   0.00008203391486137382, 0.0002188323341351403, 0.0003548808314385612, 
   0.0004274966251965945, 0.0004033524014767241, 0.0002946848525839361, 
   0.00015232508735051002, 0.00003943090763169635, 4.008874420834405*^-8, 
   0.00003899850060592835, 0.00012314977014639815, 
   0.00020178119411652223, 0.0002340182143086748, 0.00020792683722493997, 
   0.00014189777949846018, 0.00006967690217130507, 
   0.000019591909262053975, 7.32234412354978*^-7, 3.1531132013661608*^-6, 
   9.6104722123064*^-6, 9.212350708252494*^-6, 3.23682329832257*^-6, 
   1.6633588287284005*^-8, 4.397281816112333*^-6, 
   0.000011582479270747243, 0.000011804857053138255, 
   3.249311047217757*^-6, 2.4605869320271786*^-6, 0.00004072182795586925, 
   0.00014361388161190973, 0.0003044008006462474, 0.00047081867564744296, 
   0.00056139236336634, 0.0005108609118602721, 0.00032305531387071966, 
   0.00009724578510536991, 1.2652578836759778*^-6, 0.0001917238757430373, 
   0.0007156140140926695, 0.0014485597437652376, 0.002116808258128762, 
   0.002411390853304368, 0.0021505821171979283, 0.0014091555694244779, 
   0.0005348276575806552, 0.000019913370310119012, 0.000270518039935586, 
   0.0013792247668254112, 0.0030230918523806165, 0.0045608707123620746, 
   0.005308631551702475, 0.004876221072456875, 0.0033997177055446817, 
   0.0015384102629677147, 0.0002104609514306373, 0.00017184700330950505, 
   0.0016331514774347452, 0.004108042703013734, 0.00658825357915938, 
   0.007985035810768397, 0.007640741286894238, 0.005666426725270915, 
   0.0029317602912702087, 0.0006936400851801704, 0.000024793982658148924, 
   0.001307288799029716, 0.004034334422779931, 0.007023265878852196, 
   0.008948439153149534, 0.008948439153149733, 0.007023265878852705, 
   0.004034334422780523, 0.0013072887990301313, 0.000024793982658209944, 
   0.0006936400851798649, 0.00293176029126969, 0.005666426725270425, 
   0.007640741286893998, 0.007985035810768506, 0.0065882535791597875, 
   0.004108042703014247, 0.0016331514774351442, 0.0001718470033096463, 
   0.00021046095143048855, 0.0015384102629673792, 0.003399717705544333, 
   0.004876221072456678, 0.0053086315517025095, 0.004560870712362317, 
   0.0030230918523809487, 0.0013792247668256965, 0.0002705180399357222, 
   0.000019913370310084416, 0.0005348276575805034, 0.0014091555694243103, 
   0.002150582117197828, 0.002411390853304373, 0.0021168082581288633, 
   0.0014485597437653847, 0.0007156140140927987, 0.00019172387574310803, 
   1.2652578836812739*^-6, 0.00009724578510533267, 0.0003230553138706743, 
   0.0005108609118602481, 0.0005613923633663453, 0.0004708186756474699, 
   0.00030440080064628123, 0.00014361388161193613, 0.0000407218279558825, 
   2.4605869320297243*^-6, 3.2493110472159895*^-6, 
   0.000011804857053137253, 0.000011582479270748319, 
   4.397281816113783*^-6, 1.6633588287389203*^-8, 3.236823298321416*^-6, 
   9.212350708251671*^-6, 9.61047221230712*^-6, 3.1531132013675173*^-6, 
   7.322344123539446*^-7, 0.000019591909262047453, 
   0.00006967690217129271, 0.00014189777949844579, 0.00020792683722493, 
   0.0002340182143086752, 0.00020178119411653448, 0.00012314977014641625, 
   0.000038998500605942254, 4.008874420885688*^-8, 
   0.00003943090763168022, 0.00015232508735048384, 
   0.00029468485258391034, 0.0004033524014767103, 0.00042749662519659943, 
   0.00035488083143858277, 0.00021883233413516845, 0.0000820339148613956, 
   5.605340603659963*^-6, 0.000019591571600639785, 
   0.00010984962625171231, 0.00022729049588562803, 
   0.00031364002327451606, 0.00032976185407917314}, 
  {0.00027328699171776235, 0.0002599261781879917, 0.00018836483085674072, 
   0.00009103683014970542, 0.00001623632812447613, 4.645372568648279*^-6, 
   0.00006798482460592187, 0.00018135520996922532, 
   0.00029410410465140956, 0.00035428375121103267, 0.0003342744560601754, 
   0.0002442172612485427, 0.000126237963458236, 0.00003267798865777901, 
   3.3223164447064815*^-8, 0.00003231963545892359, 
   0.00010205919756250263, 0.00016722424029094426, 0.0001939403633393762, 
   0.0001723173834076956, 0.00011759643151828773, 0.00005774406818454284, 
   0.00001623660795814383, 6.068322861160082*^-7, 2.613112495237379*^-6, 
   7.964587193453304*^-6, 7.634647793746623*^-6, 2.6824864397692624*^-6, 
   1.3784927663016832*^-8, 3.6442053694059194*^-6, 9.598869236633798*^-6, 
   9.783162703033086*^-6, 2.6928355425738367*^-6, 2.0391879539599684*^-6, 
   0.000033747826565276436, 0.00011901863477880349, 
   0.0002522692605467927, 0.00039018648737139866, 0.0004652485672914698, 
   0.00042337110876071476, 0.00026772901047848524, 
   0.00008059151699910747, 1.0485704046714161*^-6, 
   0.00015888933360286623, 0.0005930582895604, 0.0012004800731197185, 
   0.0017542846564916551, 0.001998417172888246, 0.0017822744201029925, 
   0.001167824239421855, 0.000443233320712057, 0.000016503015736039944, 
   0.00022418924573863237, 0.0011430193722099145, 0.002505358542244338, 
   0.0037797781070694697, 0.004399477771478278, 0.004041121710586239, 
   0.00281748362627432, 0.0012749428340284707, 0.00017441750638849982, 
   0.0001424165651339771, 0.0013534587119964727, 0.0034045012128212935, 
   0.005459952323321151, 0.006617522277029646, 0.006332191473813459, 
   0.004695997109376525, 0.002429668381978688, 0.0005748476055336322, 
   0.00002054777667437892, 0.0010834031249332614, 0.003343416178513627, 
   0.005820464618095955, 0.007415933609308755, 0.007415933609308921, 
   0.005820464618096377, 0.0033434161785141168, 0.0010834031249336053, 
   0.00002054777667442949, 0.0005748476055333792, 0.002429668381978258, 
   0.004695997109376119, 0.00633219147381326, 0.006617522277029737, 
   0.005459952323321488, 0.0034045012128217185, 0.0013534587119968036, 
   0.00014241656513409417, 0.00017441750638837655, 0.0012749428340281927, 
   0.002817483626274031, 0.004041121710586076, 0.004399477771478306, 
   0.003779778107069671, 0.002505358542244614, 0.0011430193722101508, 
   0.00022418924573874523, 0.000016503015736011274, 
   0.00044323332071193126, 0.0011678242394217162, 0.0017822744201029092, 
   0.0019984171728882503, 0.0017542846564917395, 0.0012004800731198403, 
   0.0005930582895605071, 0.00015888933360292483, 1.0485704046758052*^-6, 
   0.00008059151699907661, 0.0002677290104784476, 0.0004233711087606949, 
   0.00046524856729147424, 0.000390186487371421, 0.00025226926054682067, 
   0.00011901863477882537, 0.00003374782656528742, 2.039187953962078*^-6, 
   2.692835542572372*^-6, 9.783162703032256*^-6, 9.598869236634687*^-6, 
   3.644205369407122*^-6, 1.3784927663104012*^-8, 2.682486439768306*^-6, 
   7.63464779374594*^-6, 7.9645871934539*^-6, 2.6131124952385034*^-6, 
   6.068322861151518*^-7, 0.000016236607958138427, 0.0000577440681845326, 
   0.00011759643151827579, 0.00017231738340768734, 
   0.00019394036333937655, 0.0001672242402909544, 0.00010205919756251764, 
   0.00003231963545893512, 3.3223164447489814*^-8, 
   0.00003267798865776564, 0.0001262379634582143, 0.0002442172612485213, 
   0.000334274456060164, 0.00035428375121103673, 0.0002941041046514274, 
   0.00018135520996924865, 0.00006798482460593992, 4.645372568653405*^-6, 
   0.000016236328124467008, 0.0000910368301496865, 
   0.00018836483085672218, 0.0002599261781879824, 0.000273286991717766}, 
  {0.00005315398445023529, 0.0000505553226180711, 0.00003663672839822052, 
   0.000017706551723375143, 3.1579458913602935*^-6, 
   9.035192627627422*^-7, 0.000013222964939682031, 
   0.00003527336573937201, 0.00005720288736441655, 
   0.00006890775475435225, 0.00006501597140738911, 
   0.00004749995755484171, 0.00002455312894518692, 6.355828684207571*^-6, 
   6.461864706062097*^-9, 6.286129426881322*^-6, 0.000019850388656051672, 
   0.00003252490948163027, 0.00003772116262255365, 
   0.000033515519566394974, 0.000022872361589686155, 
   0.000011231150385468658, 3.1580003186651874*^-6, 
   1.1802813480936926*^-7, 5.082471729280465*^-7, 1.549102433205365*^-6, 
   1.4849296249377805*^-6, 5.217403199882897*^-7, 2.681151510512937*^-9, 
   7.087934713662274*^-7, 1.8669682846478237*^-6, 1.9028131376563583*^-6, 
   5.237532077810478*^-7, 3.96619554098046*^-7, 6.563910844071656*^-6, 
   0.0000231489783782108, 0.00004906606153513836, 0.00007589079286968219, 
   0.00009049027528117693, 0.00008234516099832081, 
   0.00005207296392119255, 0.000015674951136406424, 
   2.039456566686589*^-7, 0.00003090378036125924, 0.00011534910938583021, 
   0.00023349190072436034, 0.00034120621243745493, 0.0003886896872226098, 
   0.0003466501871045671, 0.0002271403811526628, 0.00008620833684351165, 
   3.20981630447082*^-6, 0.000043604533121020574, 0.00022231586492601671, 
   0.00048728916133063176, 0.000735162202436627, 0.0008556930265302235, 
   0.0007859932125413642, 0.0005479971070648075, 0.00024797481632377174, 
   0.00003392399090842115, 0.000027699847113123043, 
   0.0002632460582163163, 0.0006621713071290269, 0.0010619540252123011, 
   0.0012870999603800664, 0.0012316034693762446, 0.0009133656737966361, 
   0.0004725675180628424, 0.00011180715369484497, 3.996517342343218*^-6, 
   0.00021072057800508917, 0.000650290342933391, 0.0011320732240447462, 
   0.00144238998451954, 0.0014423899845195723, 0.0011320732240448284, 
   0.0006502903429334862, 0.0002107205780051561, 3.996517342353054*^-6, 
   0.00011180715369479575, 0.0004725675180627588, 0.000913365673796557, 
   0.0012316034693762058, 0.0012870999603800842, 0.0010619540252123666, 
   0.0006621713071291096, 0.0002632460582163806, 0.000027699847113145815, 
   0.000033923990908397166, 0.0002479748163237177, 0.0005479971070647512, 
   0.0007859932125413324, 0.0008556930265302291, 0.0007351622024366661, 
   0.0004872891613306853, 0.00022231586492606269, 0.00004360453312104253, 
   3.2098163044652435*^-6, 0.00008620833684348718, 0.0002271403811526358, 
   0.00034665018710455087, 0.00038868968722261064, 
   0.00034120621243747135, 0.00023349190072438403, 
   0.00011534910938585104, 0.00003090378036127064, 
   2.0394565666951256*^-7, 0.00001567495113640042, 
   0.000052072963921185233, 0.00008234516099831696, 
   0.0000904902752811778, 0.00007589079286968652, 0.00004906606153514381, 
   0.000023148978378215056, 6.5639108440737926*^-6, 
   3.9661955409845634*^-7, 5.237532077807628*^-7, 1.902813137656197*^-6, 
   1.866968284647997*^-6, 7.087934713664612*^-7, 2.6811515105298934*^-9, 
   5.217403199881037*^-7, 1.484929624937648*^-6, 1.5491024332054808*^-6, 
   5.082471729282653*^-7, 1.1802813480920268*^-7, 3.158000318664136*^-6, 
   0.000011231150385466668, 0.000022872361589683834, 
   0.00003351551956639337, 0.000037721162622553716, 
   0.00003252490948163224, 0.00001985038865605459, 
   6.2861294268835634*^-6, 6.461864706144759*^-9, 6.355828684204971*^-6, 
   0.000024553128945182694, 0.00004749995755483755, 
   0.0000650159714073869, 0.00006890775475435303, 0.00005720288736442002, 
   0.00003527336573937654, 0.000013222964939685541, 
   9.035192627637389*^-7, 3.1579458913585194*^-6, 
   0.000017706551723371467, 0.000036636728398216905, 
   0.00005055532261806928, 0.000053153984450236}, 
  {0.00003520245947781428, 0.00003348143538546333, 
   0.00002426352342495627, 0.00001172657470518519, 2.091422937029676*^-6, 
   5.98376595165845*^-7, 8.757215329765465*^-6, 0.00002336060487147298, 
   0.00003788393937514, 0.00004563575937977518, 0.000043058335561318695, 
   0.00003145794898193774, 0.00001626087932421528, 4.209295013682765*^-6, 
   4.279519829397518*^-9, 4.163135063360356*^-6, 0.00001314638045502965, 
   0.00002154037594526178, 0.000024981715151000492, 
   0.000022196430457974596, 0.000015147752145968777, 
   7.438089927272584*^-6, 2.0914589827751612*^-6, 7.816687075940231*^-8, 
   3.365984825928516*^-7, 1.0259290285745262*^-6, 9.834290973655652*^-7, 
   3.4553463230070847*^-7, 1.7756547957581083*^-9, 
   4.6941492179705237*^-7, 1.236443063797234*^-6, 1.260182149372324*^-6, 
   3.468677139443675*^-7, 2.6267050204518447*^-7, 4.3471022519628885*^-6, 
   0.00001533094803221581, 0.00003249513767954237, 
   0.000050260438391695365, 0.00005992928435504686, 
   0.000054534993438759034, 0.00003448652855068048, 
   0.000010381100079386868, 1.3506774306404622*^-7, 
   0.0000204667455719528, 0.000076392624014072, 0.00015463542872016522, 
   0.0002259717308333379, 0.0002574187637186183, 0.00022957712936741553, 
   0.00015042898751622198, 0.00005709347127541722, 
   2.1257753216064207*^-6, 0.000028878113769229254, 
   0.0001472338397069816, 0.0003227185531459013, 0.0004868782257541843, 
   0.0005667025605593168, 0.0005205422415741773, 0.00036292379875057406, 
   0.00016422707560763815, 0.000022466950081559674, 
   0.000018344866440902314, 0.00017434080987343916, 
   0.00043853831180623186, 0.00070330369259218, 0.0008524118119798842, 
   0.0008156579731862569, 0.0006048976093288956, 0.00031296880332109964, 
   0.00007404688167746774, 2.646786336928997*^-6, 0.00013955459191042672, 
   0.0004306698676062339, 0.000749741758920527, 0.0009552562334963303, 
   0.0009552562334963516, 0.0007497417589205814, 0.000430669867606297, 
   0.00013955459191047106, 2.6467863369355113*^-6, 
   0.00007404688167743515, 0.00031296880332104424, 0.0006048976093288432, 
   0.0008156579731862312, 0.0008524118119798959, 0.0007033036925922234, 
   0.0004385383118062866, 0.00017434080987348174, 0.00001834486644091739, 
   0.000022466950081543794, 0.00016422707560760234, 
   0.00036292379875053687, 0.0005205422415741562, 0.0005667025605593206, 
   0.0004868782257542102, 0.00032271855314593677, 0.00014723383970701207, 
   0.000028878113769243792, 2.1257753216027277*^-6, 
   0.000057093471275401025, 0.00015042898751620412, 
   0.0002295771293674048, 0.0002574187637186188, 0.00022597173083334878, 
   0.0001546354287201809, 0.0000763926240140858, 0.000020466745571960348, 
   1.350677430646116*^-7, 0.000010381100079382894, 
   0.000034486528550675634, 0.00005453499343875648, 
   0.00005992928435504744, 0.00005026043839169824, 
   0.00003249513767954598, 0.00001533094803221863, 4.347102251964304*^-6, 
   2.626705020454562*^-7, 3.468677139441789*^-7, 1.2601821493722172*^-6, 
   1.2364430637973487*^-6, 4.694149217972072*^-7, 1.775654795769338*^-9, 
   3.455346323005853*^-7, 9.834290973654773*^-7, 1.0259290285746028*^-6, 
   3.365984825929964*^-7, 7.8166870759292*^-8, 2.091458982774465*^-6, 
   7.438089927271265*^-6, 0.00001514775214596724, 
   0.000022196430457973532, 0.000024981715151000536, 
   0.000021540375945263087, 0.000013146380455031583, 
   4.16313506336184*^-6, 4.279519829452263*^-9, 4.209295013681043*^-6, 
   0.00001626087932421248, 0.000031457948981934986, 
   0.000043058335561317224, 0.0000456357593797757, 0.0000378839393751423, 
   0.000023360604871475986, 8.75721532976779*^-6, 5.983765951665052*^-7, 
   2.091422937028501*^-6, 0.000011726574705182755, 
   0.00002426352342495388, 0.00003348143538546213, 
   0.00003520245947781475}, {0.0003047436794587805, 
   0.0002898449700469914, 0.00021004655682696033, 0.0001015156206729986, 
   0.00001810520999354008, 5.180077983692602*^-6, 0.00007581021499612746, 
   0.00020223009382063227, 0.0003279569453051852, 0.00039506356756274406, 
   0.00037275110333119944, 0.0002723278788808518, 0.0001407685789573772, 
   0.00003643938717422905, 3.7047315399917823*^-8, 
   0.00003603978574542118, 0.00011380671722541479, 0.0001864725794690996, 
   0.00021626386074260017, 0.00019215196861108958, 
   0.00013113236384524295, 0.00006439069673557593, 
   0.00001810552203745039, 6.76681691005479*^-7, 2.9138946996085518*^-6, 
   8.88135066893302*^-6, 8.513433608435407*^-6, 2.991253929121566*^-6, 
   1.537164118458786*^-8, 4.0636714758934645*^-6, 
   0.000010703746678277609, 0.000010909253236411682, 
   3.0027942649712146*^-6, 2.2739085980336954*^-6, 
   0.00003763236872928218, 0.00013271826975252247, 
   0.00028130670322124485, 0.00043509888666584727, 0.000518800984152783, 
   0.0004721032225109677, 0.000298545947021631, 0.00008986800018947479, 
   1.1692660572046571*^-6, 0.0001771782836956158, 0.0006613222391529605, 
   0.001338661281680284, 0.0019562115184372417, 0.0022284448979135053, 
   0.0019874230426173223, 0.0013022465996117038, 0.0004942516735374744, 
   0.000018402594671468563, 0.00024999453948410915, 
   0.0012745865691977428, 0.002793737732367167, 0.004214849307850275, 
   0.004905879476188277, 0.004506274855909176, 0.0031417899611278803, 
   0.0014216950755661921, 0.00019449382615968153, 0.0001588094179017172, 
   0.001509248520380779, 0.0037963761823999365, 0.006088419906926218, 
   0.007379231901696802, 0.007061058108321263, 0.0052365296600620686, 
   0.002709335259372768, 0.0006410154151036483, 0.000022912927648288605, 
   0.0012081081962740346, 0.003728259957775498, 0.006490428954298895, 
   0.008269544336953883, 0.008269544336954067, 0.006490428954299366, 
   0.0037282599577760445, 0.0012081081962744182, 0.000022912927648344997, 
   0.0006410154151033661, 0.002709335259372288, 0.005236529660061616, 
   0.007061058108321041, 0.007379231901696903, 0.006088419906926594, 
   0.0037963761824004105, 0.0015092485203811478, 0.00015880941790184775, 
   0.00019449382615954402, 0.001421695075565882, 0.003141789961127558, 
   0.004506274855908993, 0.004905879476188309, 0.0042148493078505, 
   0.0027937377323674745, 0.0012745865691980065, 0.00024999453948423503, 
   0.000018402594671436593, 0.0004942516735373342, 0.0013022465996115492, 
   0.0019874230426172295, 0.00222844489791351, 0.001956211518437336, 
   0.0013386612816804198, 0.0006613222391530799, 0.00017717828369568115, 
   1.1692660572095515*^-6, 0.0000898680001894404, 0.000298545947021589, 
   0.0004721032225109456, 0.0005188009841527878, 0.00043509888666587215, 
   0.00028130670322127607, 0.00013271826975254686, 
   0.000037632368729294434, 2.2739085980360476*^-6, 
   3.0027942649695815*^-6, 0.000010909253236410757, 
   0.000010703746678278602, 4.063671475894805*^-6, 
   1.5371641184685077*^-8, 2.9912539291204994*^-6, 8.513433608434646*^-6, 
   8.881350668933687*^-6, 2.9138946996098054*^-6, 6.766816910045241*^-7, 
   0.00001810552203744436, 0.00006439069673556452, 
   0.00013113236384522964, 0.00019215196861108036, 
   0.00021626386074260055, 0.0001864725794691109, 0.00011380671722543151, 
   0.00003603978574543403, 3.7047315400391745*^-8, 
   0.000036439387174214145, 0.000140768578957353, 0.00027232787888082803, 
   0.00037275110333118676, 0.00039506356756274856, 0.0003279569453052051, 
   0.0002022300938206583, 0.00007581021499614759, 5.180077983698317*^-6, 
   0.00001810520999352991, 0.00010151562067297751, 
   0.00021004655682693965, 0.000289844970046981, 0.00030474367945878454}, 
  {0.0004811252682321105, 0.00045760338395615176, 0.0003316187104325873, 
   0.0001602715118252418, 0.000028584264750005714, 8.178238228906258*^-6, 
   0.00011968815920816917, 0.0003192781825921908, 0.00051777406362872, 
   0.0006237211063734933, 0.0005884944845863356, 0.00042994763338923914, 
   0.00022224356032520082, 0.00005753001984996392, 5.8489808847622*^-8, 
   0.00005689913442860729, 0.0001796765315984177, 0.0002944004284989252, 
   0.0003414345071684057, 0.00030336697254403007, 0.00020703003206170483, 
   0.00010165917565075143, 0.000028584757400781327, 
   1.0683360543226805*^-6, 4.600418198792919*^-6, 
   0.000014021758319787579, 0.000013440895757737206, 
   4.7225519215194394*^-6, 2.426854266916118*^-8, 6.41567048189057*^-6, 
   0.000016898932902631183, 0.000017223383923506543, 
   4.7407716502797266*^-6, 3.5900166530352693*^-6, 
   0.00005941348326318471, 0.00020953383921657628, 
   0.00044412328184518975, 0.0006869283357291527, 0.0008190760940567844, 
   0.0007453502890272613, 0.0004713403706862445, 0.00014188240351181014, 
   1.8460217006186838*^-6, 0.0002797267179399805, 0.00104408675600888, 
   0.0021134606281718905, 0.0030884407289377964, 0.003518239167923854, 
   0.003137717068219857, 0.002055969612414163, 0.0007803179689475767, 
   0.00002905377172449184, 0.0003946880541688932, 0.0020123003242574406, 
   0.004410715976923581, 0.006654348032414823, 0.007745337271924454, 
   0.007114446811915492, 0.004960216206817379, 0.0022445532776622337, 
   0.0003070642660965288, 0.00025072619691882353, 0.0023827814919302874, 
   0.005993668227380648, 0.009612316376936747, 0.011650233187300733, 
   0.01114790463382883, 0.008267363384786926, 0.004277462475059315, 
   0.00101202661226769, 0.000036174625443730975, 0.0019073451532056335, 
   0.005886127237846116, 0.01024700291446369, 0.013055846619494608, 
   0.013055846619494901, 0.010247002914464433, 0.005886127237846978, 
   0.0019073451532062393, 0.00003617462544382, 0.0010120266122672444, 
   0.004277462475058558, 0.008267363384786211, 0.01114790463382848, 
   0.011650233187300893, 0.00961231637693734, 0.0059936682273813964, 
   0.00238278149193087, 0.0002507261969190296, 0.0003070642660963117, 
   0.002244553277661744, 0.004960216206816871, 0.007114446811915204, 
   0.007745337271924504, 0.0066543480324151765, 0.004410715976924066, 
   0.002012300324257857, 0.0003946880541690919, 0.000029053771724441364, 
   0.0007803179689473553, 0.002055969612413919, 0.00313771706821971, 
   0.0035182391679238613, 0.003088440728937945, 0.002113460628172105, 
   0.0010440867560090686, 0.00027972671794008374, 1.8460217006264109*^-6, 
   0.00014188240351175582, 0.0004713403706861783, 0.0007453502890272264, 
   0.0008190760940567922, 0.0006869283357291919, 0.0004441232818452391, 
   0.0002095338392166148, 0.000059413483263204046, 
   3.5900166530389835*^-6, 4.740771650277148*^-6, 
   0.000017223383923505083, 0.00001689893290263275, 
   6.4156704818926865*^-6, 2.4268542669314662*^-8, 
   4.7225519215177555*^-6, 0.000013440895757736007, 
   0.000014021758319788628, 4.600418198794898*^-6, 
   1.0683360543211728*^-6, 0.000028584757400771806, 
   0.0001016591756507334, 0.00020703003206168382, 0.0003033669725440155, 
   0.0003414345071684063, 0.0002944004284989431, 0.00017967653159844412, 
   0.00005689913442862757, 5.848980884837022*^-8, 0.00005753001984994038, 
   0.00022224356032516258, 0.00042994763338920157, 0.0005884944845863156, 
   0.0006237211063735004, 0.0005177740636287514, 0.00031927818259223185, 
   0.00011968815920820095, 8.17823822891528*^-6, 0.000028584264749989658, 
   0.00016027151182520852, 0.0003316187104325547, 0.00045760338395613533, 
   0.00048112526823211696}, {0.0002813443642505937, 0.000267589631305653, 
   0.00019391842711376258, 0.0000937208863871198, 
   0.000016715026885225408, 4.7823329746453945*^-6, 
   0.00006998923416448158, 0.0001867021402358551, 0.0003027752320977483, 
   0.00036472916666199686, 0.0003441299336434918, 0.0002514175653700777, 
   0.0001299598614270183, 0.00003364144003387409, 3.42026893450006*^-8, 
   0.00003327252143926617, 0.00010506822836193482, 
   0.00017215454448169537, 0.00019965834408465754, 
   0.00017739784970896924, 0.00012106354955167362, 
   0.00005944654756711287, 0.000016715314969282543, 6.24723638219719*^-7, 
   2.6901553896392777*^-6, 8.19940863769587*^-6, 7.859741571699676*^-6, 
   2.7615746994176073*^-6, 1.4191351316118356*^-8, 3.751648171797964*^-6, 
   9.881874530253364*^-6, 0.000010071601556094367, 2.772228926795265*^-6, 
   2.0993097215795784*^-6, 0.00003474282017657368, 0.0001225276839023425, 
   0.0002597069633003383, 0.00040169043004451027, 0.0004789655795922415, 
   0.0004358534399594347, 0.00027562251598971466, 0.00008296761207544554, 
   1.0794856060289136*^-6, 0.00016357389814904036, 0.0006105435402949352, 
   0.0012358740562235895, 0.0018060065658190528, 0.0020573368877885353, 
   0.001834821556972707, 0.0012022554243485424, 0.000456301253296383, 
   0.000016989577298537502, 0.000230799060056601, 0.0011767192305026564, 
   0.0025792245062856187, 0.003891218026359706, 0.004529188414242132, 
   0.004160266873215616, 0.0029005520337362085, 0.0013125322169232128, 
   0.0001795598910164188, 0.00014661545990360368, 0.0013933629935058694, 
   0.003504876771817922, 0.005620929139685431, 0.006812627949257926, 
   0.006518884683515974, 0.0048344500883694755, 0.0025013027585796123, 
   0.0005917959471955508, 0.000021153590695552227, 0.0011153453060299605, 
   0.003441990755785864, 0.005992070487249789, 0.007634578995221068, 
   0.007634578995221239, 0.005992070487250223, 0.003441990755786368, 
   0.0011153453060303148, 0.000021153590695604286, 0.0005917959471952903, 
   0.0025013027585791695, 0.004834450088369057, 0.006518884683515769, 
   0.006812627949258019, 0.005620929139685778, 0.0035048767718183597, 
   0.0013933629935062098, 0.00014661545990372419, 0.00017955989101629187, 
   0.0013125322169229266, 0.002900552033735911, 0.004160266873215448, 
   0.004529188414242162, 0.003891218026359913, 0.0025792245062859023, 
   0.0011767192305028997, 0.00023079906005671718, 
   0.000016989577298507988, 0.00045630125329625354, 
   0.0012022554243483995, 0.0018348215569726214, 0.0020573368877885396, 
   0.0018060065658191396, 0.001235874056223715, 0.0006105435402950454, 
   0.0001635738981491007, 1.079485606033432*^-6, 0.00008296761207541378, 
   0.00027562251598967595, 0.00043585343995941427, 0.0004789655795922461, 
   0.00040169043004453325, 0.00025970696330036716, 0.000122527683902365, 
   0.00003474282017658498, 2.0993097215817507*^-6, 2.772228926793757*^-6, 
   0.000010071601556093513, 9.88187453025428*^-6, 3.7516481717992016*^-6, 
   1.4191351316208107*^-8, 2.761574699416623*^-6, 7.859741571698973*^-6, 
   8.199408637696483*^-6, 2.690155389640435*^-6, 6.247236382188373*^-7, 
   0.000016715314969276977, 0.00005944654756710233, 
   0.00012106354955166134, 0.00017739784970896073, 0.0001996583440846579, 
   0.0001721545444817058, 0.00010506822836195027, 0.00003327252143927804, 
   3.420268934543813*^-8, 0.00003364144003386033, 0.00012995986142699594, 
   0.0002514175653700557, 0.0003441299336434801, 0.00036472916666200104, 
   0.00030277523209776665, 0.0001867021402358791, 0.00006998923416450018, 
   4.782332974650671*^-6, 0.00001671502688521602, 0.00009372088638710033, 
   0.0001939184271137435, 0.0002675896313056434, 0.00028134436425059745}, 
  {0.000012317925830670882, 0.00001171571088782755, 
   8.490210240216832*^-6, 4.103323449809739*^-6, 7.318236566718142*^-7, 
   2.0938191897380192*^-7, 3.064295237190704*^-6, 8.174264026857697*^-6, 
   0.000013256220227757254, 0.00001596871092545937, 
   0.000015066827480356325, 0.000011007659353709376, 
   5.689952021204914*^-6, 1.4729023070287029*^-6, 1.497475137571751*^-9, 
   1.4567501729774657*^-6, 4.600137086696852*^-6, 7.537335663314179*^-6, 
   8.741517465474478*^-6, 7.766900044563349*^-6, 5.300450315212304*^-6, 
   2.6027113277055795*^-6, 7.318362696774388*^-7, 2.7351887644008953*^-8, 
   1.1778140518585569*^-7, 3.589896237073346*^-7, 3.4411819119363394*^-7, 
   1.2090831253681862*^-7, 6.213311342296441*^-10, 1.642560854064871*^-7, 
   4.326519845381965*^-7, 4.409586852556904*^-7, 1.2137477996711763*^-7, 
   9.191277570070971*^-8, 1.5211233508206563*^-6, 5.364553601538*^-6, 
   0.000011370588922808257, 0.000017586962999448556, 
   0.00002097025295166925, 0.000019082700877139577, 
   0.000012067409696538962, 3.6325195090203604*^-6, 
   4.7262448870300784*^-8, 7.16165454602434*^-6, 0.000026731049210033575, 
   0.000054109507404431425, 0.00007907126551733222, 
   0.00009007510514733533, 0.00008033285440605082, 
   0.00005263760369287668, 0.000019977954808224498, 
   7.438441271616591*^-7, 0.00001010493212166686, 
   0.000051519568353412455, 0.00011292458711124843, 
   0.0001703667857976908, 0.00019829864766751133, 0.00018214638461505592, 
   0.00012699307098165485, 0.000057465784116527025, 
   7.861559358386637*^-6, 6.419173760714419*^-6, 0.00006100474788227656, 
   0.0001534518462308358, 0.0002460976548313984, 0.0002982730648059801, 
   0.00028541228556021, 0.00021166373024473982, 0.00010951298755283712, 
   0.00002591023496725698, 9.261545435048896*^-7, 
   0.000048832471877868725, 0.0001506985467882377, 0.0002623471062969376, 
   0.0003342600377371252, 0.00033426003773713266, 0.0002623471062969566, 
   0.00015069854678825977, 0.000048832471877884236, 9.26154543507169*^-7, 
   0.000025910234967245572, 0.00010951298755281774, 
   0.00021166373024472153, 0.00028541228556020105, 0.0002982730648059842, 
   0.00024609765483141357, 0.00015345184623085495, 
   0.00006100474788229147, 6.419173760719695*^-6, 7.861559358381079*^-6, 
   0.000057465784116514495, 0.0001269930709816418, 
   0.00018214638461504855, 0.00019829864766751263, 
   0.00017036678579769986, 0.00011292458711126084, 
   0.000051519568353423115, 0.000010104932121671947, 
   7.438441271603668*^-7, 0.00001997795480821883, 0.00005263760369287042, 
   0.00008033285440604707, 0.00009007510514733552, 
   0.00007907126551733601, 0.000054109507404436914, 
   0.000026731049210038404, 7.161654546026982*^-6, 4.726244887049862*^-8, 
   3.6325195090189696*^-6, 0.000012067409696537268, 
   0.000019082700877138683, 0.00002097025295166945, 
   0.00001758696299944956, 0.00001137058892280952, 5.364553601538986*^-6, 
   1.5211233508211516*^-6, 9.19127757008048*^-8, 1.2137477996705165*^-7, 
   4.40958685255653*^-7, 4.3265198453823665*^-7, 1.6425608540654127*^-7, 
   6.213311342335736*^-10, 1.209083125367755*^-7, 3.441181911936032*^-7, 
   3.589896237073614*^-7, 1.1778140518590637*^-7, 2.735188764397035*^-8, 
   7.318362696771952*^-7, 2.602711327705118*^-6, 5.3004503152117665*^-6, 
   7.766900044562976*^-6, 8.741517465474494*^-6, 7.5373356633146364*^-6, 
   4.600137086697528*^-6, 1.4567501729779851*^-6, 1.4974751375909073*^-9, 
   1.4729023070281004*^-6, 5.689952021203935*^-6, 
   0.000011007659353708413, 0.000015066827480355811, 
   0.000015968710925459554, 0.000013256220227758059, 
   8.17426402685875*^-6, 3.0642952371915176*^-6, 2.0938191897403292*^-7, 
   7.318236566714031*^-7, 4.103323449808887*^-6, 8.490210240215997*^-6, 
   0.000011715710887827129, 0.000012317925830671047}, 
  {0.00015723387056940864, 0.00014954681451146229, 
   0.00010837446469221147, 0.000052377440575696724, 
   9.341464439269184*^-6, 2.6726845087447744*^-6, 0.00003911462102744754, 
   0.00010434152548628516, 0.0001692108593754408, 0.00020383482262591534, 
   0.00019232260646019248, 0.00014050879262349116, 
   0.00007263018075824477, 0.000018801065527451803, 
   1.911472882679635*^-8, 0.00001859488937492876, 0.00005871908706336444, 
   0.00009621136516123859, 0.00011158231058059393, 
   0.00009914167150541246, 0.000067658332277544, 0.00003322266927529505, 
   9.341625439726659*^-6, 3.491369586703284*^-7, 1.503437061811508*^-6, 
   4.5823727797754985*^-6, 4.392544319433686*^-6, 1.5433509038383566*^-6, 
   7.931067330910118*^-9, 2.096669555253744*^-6, 5.522646188459111*^-6, 
   5.628678220428418*^-6, 1.5493051919684132*^-6, 1.1732333573738831*^-6, 
   0.000019416589720609966, 0.00006847658755556422, 
   0.00014514145738198623, 0.00022449122538787566, 
   0.00026767769864311175, 0.00024358377872027572, 
   0.00015403612267328402, 0.00004636779845678384, 6.032880754942353*^-7, 
   0.00009141593149949001, 0.0003412121804800637, 0.0006906883026214372, 
   0.0010093161218063954, 0.0011497761570375222, 0.0010254198479342693, 
   0.0006718999838042401, 0.00025501137153598067, 9.494901399936508*^-6, 
   0.00012898580582249638, 0.0006576286668411498, 0.0014414415347219953, 
   0.002174670436863747, 0.002531210556878641, 0.0023250327577016756, 
   0.0016210206458804216, 0.0007335299616311683, 0.00010034996342910799, 
   0.00008193843266547287, 0.0007787035548434423, 0.001958757347671246, 
   0.00314134760503649, 0.003807347853099553, 0.0036431846549159655, 
   0.0027018110047937385, 0.0013978936995770357, 0.00033073478337730547, 
   0.000011822027963354473, 0.0006233288516570746, 0.0019236124755436378, 
   0.0033487659791749977, 0.004266708554066877, 0.004266708554066972, 
   0.0033487659791752405, 0.0019236124755439197, 0.0006233288516572726, 
   0.000011822027963383568, 0.00033073478337715986, 
   0.0013978936995767883, 0.002701811004793505, 0.003643184654915851, 
   0.003807347853099605, 0.003141347605036684, 0.0019587573476714908, 
   0.0007787035548436327, 0.00008193843266554021, 0.00010034996342903705, 
   0.0007335299616310083, 0.0016210206458802552, 0.0023250327577015815, 
   0.0025312105568786577, 0.0021746704368638624, 0.0014414415347221538, 
   0.0006576286668412858, 0.0001289858058225613, 9.494901399920012*^-6, 
   0.0002550113715359083, 0.0006718999838041603, 0.0010254198479342214, 
   0.0011497761570375248, 0.001009316121806444, 0.0006906883026215073, 
   0.00034121218048012534, 0.00009141593149952373, 6.032880754967606*^-7, 
   0.00004636779845676609, 0.0001540361226732624, 0.00024358377872026434, 
   0.0002676776986431143, 0.0002244912253878885, 0.00014514145738200233, 
   0.0000684765875555768, 0.000019416589720616288, 1.173233357375097*^-6, 
   1.5493051919675706*^-6, 5.628678220427941*^-6, 5.5226461884596235*^-6, 
   2.0966695552544355*^-6, 7.931067330960277*^-9, 1.5433509038378064*^-6, 
   4.392544319433293*^-6, 4.5823727797758415*^-6, 1.5034370618121548*^-6, 
   3.491369586698357*^-7, 9.341625439723548*^-6, 0.00003322266927528916, 
   0.00006765833227753713, 0.00009914167150540772, 
   0.00011158231058059414, 0.00009621136516124443, 
   0.00005871908706337307, 0.000018594889374935387, 
   1.911472882704087*^-8, 0.000018801065527444112, 
   0.00007263018075823228, 0.00014050879262347889, 
   0.00019232260646018592, 0.00020383482262591768, 
   0.00016921085937545108, 0.00010434152548629858, 
   0.00003911462102745792, 2.6726845087477234*^-6, 9.341464439263936*^-6, 
   0.00005237744057568584, 0.00010837446469220079, 
   0.00014954681451145692, 0.00015723387056941073}, 
  {0.0005919828679480209, 0.0005630412316785537, 0.00040802802976542006, 
   0.00019720017942374945, 0.000035170455892020346, 
   0.000010062612049663604, 0.0001472658877548068, 0.0003928440817474873, 
   0.0006370760285825574, 0.0007674346656275876, 0.0007240913661365673, 
   0.000529013231868829, 0.00027345140426260134, 0.00007078569427257374, 
   7.196663129869658*^-8, 0.0000700094445394146, 0.00022107637137709082, 
   0.00036223416539378603, 0.0004201055153737238, 0.0003732667193041382, 
   0.00025473247867774146, 0.0001250827888880083, 
   0.000035171062056024394, 1.3144947545450988*^-6, 
   5.660415153601657*^-6, 0.0000172525561468066, 0.000016537855198694424, 
   5.810690094925117*^-6, 2.9860334592275154*^-8, 7.893925475239803*^-6, 
   0.000020792669654869557, 0.00002119187846498301, 
   5.833107889202233*^-6, 4.417203781572524*^-6, 0.00007310313246726798, 
   0.00025781319598401793, 0.0005464551364663821, 0.0008452056732624642, 
   0.0010078020159055056, 0.0009170888141991711, 0.0005799434011100729, 
   0.00017457397831318903, 2.2713694182848913*^-6, 0.0003441794386236832, 
   0.0012846580984611675, 0.0026004297977482954, 0.003800058157249058, 
   0.004328887818358858, 0.003860688414224256, 0.0025296920946246146, 
   0.0009601135082061594, 0.000035748143458294266, 0.000485629381117862, 
   0.002475960827216324, 0.005427003040845723, 0.008187597477530048, 
   0.009529965009542032, 0.008753709076758693, 0.006103115362333055, 
   0.002761727920578874, 0.0003778159179959808, 0.0003084968155322493, 
   0.0029318057363095142, 0.007374688342209421, 0.011827120694266976, 
   0.014334600383437538, 0.013716528714017306, 0.010172272815514503, 
   0.005263046176789128, 0.0012452108752702639, 0.00004450973567822285, 
   0.0023468226021683522, 0.007242368492037039, 0.01260804737083458, 
   0.016064085666706758, 0.01606408566670712, 0.012608047370835495, 
   0.007242368492038099, 0.0023468226021690977, 0.00004450973567833239, 
   0.0012452108752697155, 0.0052630461767881965, 0.010172272815513623, 
   0.013716528714016874, 0.014334600383437734, 0.011827120694267706, 
   0.007374688342210342, 0.0029318057363102307, 0.0003084968155325029, 
   0.0003778159179957137, 0.0027617279205782714, 0.006103115362332429, 
   0.00875370907675834, 0.009529965009542094, 0.008187597477530483, 
   0.00542700304084632, 0.002475960827216836, 0.0004856293811181065, 
   0.000035748143458232155, 0.0009601135082058871, 0.0025296920946243136, 
   0.0038606884142240758, 0.004328887818358868, 0.0038000581572492412, 
   0.002600429797748559, 0.0012846580984613996, 0.00034417943862381014, 
   2.271369418294399*^-6, 0.0001745739783131222, 0.0005799434011099914, 
   0.0009170888141991282, 0.001007802015905515, 0.0008452056732625126, 
   0.0005464551364664427, 0.0002578131959840653, 0.00007310313246729178, 
   4.417203781577094*^-6, 5.833107889199061*^-6, 0.000021191878464981216, 
   0.000020792669654871485, 7.893925475242407*^-6, 2.9860334592464*^-8, 
   5.810690094923045*^-6, 0.000016537855198692947, 
   0.00001725255614680789, 5.660415153604093*^-6, 1.3144947545432438*^-6, 
   0.000035171062056012685, 0.0001250827888879861, 0.0002547324786777156, 
   0.0003732667193041203, 0.00042010551537372454, 0.00036223416539380804, 
   0.00022107637137712332, 0.00007000944453943956, 7.19666312996172*^-8, 
   0.00007078569427254478, 0.0002734514042625543, 0.0005290132318687828, 
   0.0007240913661365427, 0.0007674346656275963, 0.0006370760285825961, 
   0.0003928440817475378, 0.00014726588775484592, 
   0.000010062612049674707, 0.000035170455892000586, 
   0.0001972001794237085, 0.0004080280297653799, 0.0005630412316785336, 
   0.0005919828679480288}, {0.0006807016570609836, 0.0006474226200595068, 
   0.0004691780303565089, 0.00022675400957423655, 0.00004044135210918061, 
   0.000011570667104456254, 0.00016933620760129119, 
   0.00045171850722476484, 0.000732552801457178, 0.0008824479167606748, 
   0.0008326088802218362, 0.0006082949406770955, 0.0003144327886589272, 
   0.00008139414499370935, 8.275206569393658*^-8, 0.00008050156092031187, 
   0.00025420845852354743, 0.000416521169746593, 0.0004830655343905351, 
   0.0004292071411403644, 0.00029290851092402795, 0.0001438285907850842, 
   0.00004044204911726032, 1.5114943456360055*^-6, 6.508725477251595*^-6, 
   0.00001983814767879411, 0.000019016336531844278, 
   6.681521696723613*^-6, 3.433541802960053*^-8, 9.07696563979527*^-6, 
   0.000023908807931979032, 0.00002436784503131183, 
   6.707299182083924*^-6, 5.079197551974548*^-6, 0.00008405889106099471, 
   0.0002964509265729602, 0.0006283508139205361, 0.0009718742441675201, 
   0.001158838438338916, 0.001054530307036321, 0.0006668578695623197, 
   0.0002007368840409586, 2.6117730943523273*^-6, 0.00039576063241416557, 
   0.0014771861547454642, 0.0029901488172009876, 0.004369562067790563, 
   0.004977645926480958, 0.004439278808976177, 0.0029088098556531924, 
   0.001104002989593192, 0.00004110561606835436, 0.0005584092755762895, 
   0.0028470260359835637, 0.006240332554865502, 0.009414649430010868, 
   0.010958193767016329, 0.01006560256487459, 0.007017771907445188, 
   0.0031756202310481217, 0.00043443811530448297, 0.0003547303560637455, 
   0.003371187125405147, 0.008479911914091151, 0.013599617642236696, 
   0.016482886182391528, 0.015772185869365338, 0.01169676241746426, 
   0.006051803941804953, 0.001431827088383327, 0.00005118028320064996, 
   0.0026985342323528764, 0.008327761664225625, 0.014497579579252365, 
   0.018471564507263782, 0.018471564507264195, 0.014497579579253416, 
   0.008327761664226845, 0.0026985342323537337, 0.00005118028320077592, 
   0.0014318270883826967, 0.006051803941803881, 0.01169676241746325, 
   0.01577218586936484, 0.016482886182391753, 0.013599617642237535, 
   0.00847991191409221, 0.003371187125405971, 0.0003547303560640371, 
   0.00043443811530417587, 0.003175620231047429, 0.007017771907444468, 
   0.010065602564874182, 0.010958193767016402, 0.009414649430011367, 
   0.006240332554866188, 0.0028470260359841526, 0.0005584092755765706, 
   0.00004110561606828295, 0.001104002989592879, 0.002908809855652847, 
   0.00443927880897597, 0.0049776459264809685, 0.004369562067790773, 
   0.0029901488172012908, 0.0014771861547457311, 0.00039576063241431156, 
   2.61177309436326*^-6, 0.00020073688404088176, 0.000666857869562226, 
   0.0010545303070362715, 0.0011588384383389271, 0.0009718742441675757, 
   0.0006283508139206059, 0.0002964509265730147, 0.00008405889106102207, 
   5.079197551979803*^-6, 6.707299182080276*^-6, 0.000024367845031309767, 
   0.000023908807931981248, 9.076965639798263*^-6, 3.433541802981768*^-8, 
   6.68152169672123*^-6, 0.000019016336531842577, 
   0.000019838147678795593, 6.508725477254395*^-6, 
   1.5114943456338724*^-6, 0.000040442049117246854, 
   0.00014382859078505868, 0.00029290851092399824, 
   0.00042920714114034385, 0.00048306553439053597, 0.0004165211697466183, 
   0.0002542084585235848, 0.00008050156092034058, 8.275206569499518*^-8, 
   0.00008139414499367606, 0.0003144327886588731, 0.0006082949406770423, 
   0.0008326088802218077, 0.000882447916760685, 0.0007325528014572224, 
   0.00045171850722482295, 0.00016933620760133613, 
   0.00001157066710446902, 0.00004044135210915789, 
   0.00022675400957418944, 0.00046917803035646273, 0.0006474226200594836, 
   0.0006807016570609927}, {0.00025634513058382766, 
   0.00024381259302151155, 0.00017668754323015744, 
   0.00008539319038194525, 0.000015229790584284844, 
   4.357392315805849*^-6, 0.0000637702461861852, 0.0001701124692741713, 
   0.00027587172970884285, 0.00033232066369889233, 
   0.00031355180336603707, 0.00022907751785799133, 
   0.00011841210232486415, 0.00003065218441990975, 3.116356316507864*^-8, 
   0.00003031604658554625, 0.00009573224895189906, 
   0.00015685751979894666, 0.00018191743212224066, 
   0.00016163492405496082, 0.0001103062842628097, 0.00005416434425278207, 
   0.000015230053070243792, 5.692129751552322*^-7, 
   2.4511179972797806*^-6, 7.470839103313855*^-6, 7.161353613459631*^-6, 
   2.5161912477786815*^-6, 1.2930359618119336*^-8, 
   3.4182904038821454*^-6, 9.003807215468164*^-6, 9.176675790049503*^-6, 
   2.5258987793856153*^-6, 1.912772719466622*^-6, 0.00003165569994173227, 
   0.0001116403209772618, 0.00023663035013367635, 0.0003659976840777132, 
   0.0004364064457902954, 0.000397125093582094, 0.0002511317048821156, 
   0.00007559541279015886, 9.83566453793859*^-7, 0.00014903931839122664, 
   0.0005562928689931536, 0.0011260587969184183, 0.0016455314119524194, 
   0.0018745294385400673, 0.0016717860081293524, 0.0010954273940075622, 
   0.0004157559888338111, 0.000015479945449621494, 
   0.00021029109769597673, 0.0010721602531729693, 0.0023500440274676665, 
   0.003545458590415742, 0.004126741257392038, 0.0037906007384179517, 
   0.002642819563256015, 0.0011959053931607296, 0.00016360485426046562, 
   0.00013358774509206442, 0.001269553841863322, 0.0031934462101100842, 
   0.005121473885404346, 0.006207282686906964, 0.005939640375978457, 
   0.004404878492964001, 0.0022790461219499123, 0.0005392111186122802, 
   0.000019273959809403695, 0.0010162397916940187, 0.0031361480160105714, 
   0.005459636967006726, 0.0069561981619767335, 0.006956198161976889, 
   0.005459636967007121, 0.0031361480160110307, 0.0010162397916943415, 
   0.000019273959809451132, 0.0005392111186120429, 0.0022790461219495085, 
   0.0044048784929636205, 0.00593964037597827, 0.006207282686907049, 
   0.005121473885404662, 0.003193446210110483, 0.001269553841863632, 
   0.00013358774509217422, 0.00016360485426034999, 0.001195905393160469, 
   0.002642819563255744, 0.003790600738417798, 0.004126741257392066, 
   0.00354545859041593, 0.0023500440274679246, 0.0010721602531731911, 
   0.0002102910976960826, 0.0000154799454495946, 0.0004157559888336931, 
   0.0010954273940074319, 0.0016717860081292744, 0.0018745294385400714, 
   0.0016455314119524984, 0.0011260587969185326, 0.0005562928689932541, 
   0.0001490393183912816, 9.83566453797976*^-7, 0.00007559541279012992, 
   0.0002511317048820803, 0.00039712509358207543, 0.00043640644579029955, 
   0.00036599768407773414, 0.00023663035013370265, 
   0.00011164032097728232, 0.000031655699941742574, 
   1.912772719468601*^-6, 2.5258987793842414*^-6, 9.176675790048726*^-6, 
   9.003807215469*^-6, 3.4182904038832732*^-6, 1.2930359618201113*^-8, 
   2.516191247777784*^-6, 7.161353613458992*^-6, 7.470839103314414*^-6, 
   2.4511179972808356*^-6, 5.692129751544288*^-7, 
   0.000015230053070238721, 0.000054164344252772466, 
   0.0001103062842627985, 0.00016163492405495307, 0.00018191743212224098, 
   0.00015685751979895618, 0.00009573224895191313, 
   0.00003031604658555706, 3.116356316547729*^-8, 0.00003065218441989721, 
   0.00011841210232484378, 0.0002290775178579713, 0.0003135518033660264, 
   0.0003323206636988962, 0.00027587172970885954, 0.00017011246927419317, 
   0.00006377024618620214, 4.357392315810656*^-6, 
   0.000015229790584276289, 0.00008539319038192751, 
   0.00017668754323014004, 0.00024381259302150282, 
   0.0002563451305838311}, {6.521981428097236*^-6, 6.203126230644489*^-6, 
   4.495317983605632*^-6, 2.1725897444925147*^-6, 3.8747922037096946*^-7, 
   1.1086160167698634*^-7, 1.6224546974785696*^-6, 
   4.3280337050564646*^-6, 7.018780866250024*^-6, 8.454965350349666*^-6, 
   7.977444446251962*^-6, 5.8282336538312565*^-6, 3.0126631641718238*^-6, 
   7.798586891896865*^-7, 7.928692842071117*^-10, 7.713066066593626*^-7, 
   2.4356380334288933*^-6, 3.9907987667102786*^-6, 
   4.6283778086450024*^-6, 4.112346391825194*^-6, 2.806433403770869*^-6, 
   1.378059518732268*^-6, 3.8748589858851747*^-7, 1.448202446498356*^-8, 
   6.236180894064605*^-8, 1.9007450530909176*^-7, 1.8220051678238262*^-7, 
   6.401741492096314*^-8, 3.289766616433365*^-10, 8.696879273340425*^-8, 
   2.2907657074550243*^-7, 2.334747258044785*^-7, 6.426439578113744*^-8, 
   4.866512628548983*^-8, 8.053903214123376*^-7, 2.840374218859655*^-6, 
   6.020394244981798*^-6, 9.311782489665278*^-6, 0.000011103135558159082, 
   0.000010103731945580382, 6.3893404626695274*^-6, 
   1.9233128288564607*^-6, 2.5024084250530733*^-8, 3.791886603775319*^-6, 
   0.000014153308673713378, 0.000028649401467939452, 
   0.000041865922257473034, 0.00004769213347932872, 
   0.00004253389667258351, 0.000027870071505844312, 
   0.000010577742715918727, 3.9384370789666594*^-7, 
   5.350265989229866*^-6, 0.00002727810449612374, 
   0.000059790265832035667, 0.0000902042298526036, 0.0001049933337059124, 
   0.00009644118287321675, 0.00006723911653836264, 
   0.000030426451815924097, 4.1624657297103685*^-6, 
   3.3987647455114087*^-6, 0.00003230022961522348, 
   0.00008124826411381597, 0.0001303015098785708, 0.0001579268633297409, 
   0.00015111745689680718, 0.0001120697540019845, 0.00005798392365511971, 
   0.00001371871154097394, 4.903717407720243*^-7, 
   0.000025855365509876145, 0.00007979047259294941, 
   0.00013890511913323392, 0.00017698091287807977, 
   0.00017698091287808373, 0.000138905119133244, 0.00007979047259296111, 
   0.000025855365509884355, 4.903717407732312*^-7, 
   0.000013718711540967898, 0.00005798392365510945, 
   0.00011206975400197482, 0.0001511174568968024, 0.00015792686332974305, 
   0.00013030150987857885, 0.00008124826411382612, 
   0.000032300229615231375, 3.3987647455142027*^-6, 
   4.162465729707426*^-6, 0.000030426451815917463, 
   0.00006723911653835575, 0.00009644118287321285, 0.0001049933337059131, 
   0.00009020422985260839, 0.00005979026583204224, 
   0.000027278104496129383, 5.350265989232559*^-6, 3.938437078959817*^-7, 
   0.000010577742715915725, 0.000027870071505841, 0.00004253389667258152, 
   0.000047692133479328824, 0.000041865922257475046, 
   0.00002864940146794236, 0.000014153308673715934, 
   3.791886603776718*^-6, 2.502408425063548*^-8, 1.923312828855724*^-6, 
   6.3893404626686304*^-6, 0.000010103731945579909, 
   0.000011103135558159187, 9.31178248966581*^-6, 6.020394244982467*^-6, 
   2.840374218860177*^-6, 8.053903214125998*^-7, 4.866512628554017*^-8, 
   6.426439578110249*^-8, 2.3347472580445872*^-7, 2.2907657074552368*^-7, 
   8.696879273343294*^-8, 3.2897666164541707*^-10, 6.401741492094031*^-8, 
   1.8220051678236635*^-7, 1.90074505309106*^-7, 6.236180894067288*^-8, 
   1.4482024464963122*^-8, 3.874858985883884*^-7, 1.3780595187320238*^-6, 
   2.806433403770584*^-6, 4.112346391824996*^-6, 4.62837780864501*^-6, 
   3.990798766710521*^-6, 2.435638033429251*^-6, 7.713066066596376*^-7, 
   7.928692842172544*^-10, 7.798586891893675*^-7, 3.0126631641713054*^-6, 
   5.8282336538307466*^-6, 7.977444446251691*^-6, 8.454965350349763*^-6, 
   7.01878086625045*^-6, 4.328033705057022*^-6, 1.6224546974790005*^-6, 
   1.1086160167710865*^-7, 3.8747922037075183*^-7, 
   2.1725897444920637*^-6, 4.495317983605189*^-6, 6.203126230644266*^-6, 
   6.521981428097324*^-6}, {0.00048651162909753016, 
   0.00046272640933430734, 0.0003353312945807416, 0.0001620658058607832, 
   0.000028904275306886188, 8.269796384864526*^-6, 
   0.00012102810882083842, 0.00032285261033782986, 0.0005235707202119564, 
   0.0006307038761013256, 0.0005950828803131672, 0.0004347610432423054, 
   0.00022473165250195526, 0.0000581740879710279, 5.9144622132653456*^-8, 
   0.00005753613957300275, 0.0001816880714241937, 0.0002976963413339675, 
   0.0003452569824964496, 0.00030676326888651125, 0.00020934780361995473, 
   0.00010279728466620199, 0.000028904773473054637, 
   1.0802964394740678*^-6, 4.651921443761936*^-6, 
   0.000014178736668805904, 0.000013591371152994837, 
   4.775422495015723*^-6, 2.454023725085352*^-8, 6.4874960929961*^-6, 
   0.000017088122198775516, 0.000017416205559078833, 
   4.7938461998305905*^-6, 3.6302081093625746*^-6, 
   0.000060078637397165244, 0.00021187964174672488, 0.000449095392899641, 
   0.0006946187318675952, 0.0008282459292538412, 0.000753694738784801, 
   0.0004766171862987057, 0.00014347082523111798, 1.866688540839869*^-6, 
   0.00028285835359915216, 0.0010557756620256725, 0.002137121538063446, 
   0.003123016872358086, 0.0035576270509151695, 0.0031728448770026313, 
   0.0020789868908487204, 0.0007890538937639288, 0.000029379038571491322, 
   0.0003991067210512951, 0.002034828710172151, 0.004460095441057485, 
   0.006728845719801696, 0.007832048954568491, 0.007194095461481584, 
   0.005015747512746487, 0.002269681814310441, 0.00031050195489667977, 
   0.0002535331618907142, 0.0024094575404075163, 0.006060769379849526, 
   0.009719929525065533, 0.011780661506610739, 0.011272709214290228, 
   0.00835991932715023, 0.004325350120959978, 0.0010233565940811833, 
   0.00003657961266780112, 0.001928698530316391, 0.005952024432394459, 
   0.010361721594048154, 0.01320201125880896, 0.013202011258809255, 
   0.010361721594048905, 0.005952024432395331, 0.0019286985303170036, 
   0.00003657961266789115, 0.0010233565940807327, 0.004325350120959212, 
   0.008359919327149506, 0.011272709214289873, 0.0117806615066109, 
   0.009719929525066133, 0.006060769379850282, 0.002409457540408105, 
   0.0002535331618909226, 0.00031050195489646027, 0.0022696818143099463, 
   0.0050157475127459725, 0.007194095461481293, 0.007832048954568542, 
   0.006728845719802054, 0.004460095441057975, 0.002034828710172572, 
   0.000399106721051496, 0.000029379038571440283, 0.0007890538937637049, 
   0.0020789868908484737, 0.003172844877002483, 0.003557627050915177, 
   0.003123016872358236, 0.0021371215380636627, 0.001055775662025863, 
   0.0002828583535992565, 1.8666885408476826*^-6, 0.00014347082523106307, 
   0.00047661718629863877, 0.0007536947387847657, 0.0008282459292538491, 
   0.0006946187318676349, 0.00044909539289969086, 0.00021187964174676383, 
   0.0000600786373971848, 3.6302081093663304*^-6, 4.793846199827983*^-6, 
   0.00001741620555907736, 0.0000170881221987771, 6.48749609299824*^-6, 
   2.4540237251008717*^-8, 4.77542249501402*^-6, 0.000013591371152993624, 
   0.000014178736668806966, 4.6519214437639384*^-6, 
   1.0802964394725431*^-6, 0.000028904773473045012, 
   0.00010279728466618376, 0.00020934780361993348, 
   0.00030676326888649655, 0.0003452569824964502, 0.00029769634133398556, 
   0.0001816880714242204, 0.000057536139573023264, 5.914462213341005*^-8, 
   0.0000581740879710041, 0.0002247316525019166, 0.0004347610432422674, 
   0.000595082880313147, 0.0006307038761013329, 0.0005235707202119881, 
   0.0003228526103378714, 0.00012102810882087055, 8.26979638487365*^-6, 
   0.000028904275306869952, 0.00016206580586074952, 
   0.0003353312945807086, 0.00046272640933429075, 
   0.00048651162909753667}, {0.0011338486001143087, 0.001078415519959641, 
   0.0007815124987663382, 0.00037770543623492437, 0.00006736338893856435, 
   0.000019273325637873464, 0.00028206427874199916, 
   0.0007524300723373132, 0.0012202173445974485, 0.0014698984859430708, 
   0.0013868813208981127, 0.0010132403231119947, 0.0005237524744544916, 
   0.00013557868766925942, 1.3784058385982642*^-7, 
   0.00013409190532987782, 0.00042343646712809143, 0.0006938016682289909, 
   0.0008046449927814831, 0.0007149327625295726, 0.00048789936329334064, 
   0.00023957609714393756, 0.00006736454994886489, 2.517704680314212*^-6, 
   0.000010841620839845989, 0.000033044514790194573, 
   0.000031675619314678016, 0.000011129448479930372, 
   5.719270000794834*^-8, 0.000015119553004181248, 
   0.00003982503659697663, 0.00004058965728958117, 
   0.000011172386183088686, 8.460448089513638*^-6, 
   0.00014001737026494602, 0.0004937999850751458, 0.0010466475046066446, 
   0.0016188564252867259, 0.0019302837409598316, 0.0017565370966977458, 
   0.0011107889249793712, 0.00033436856308513183, 4.350445215064751*^-6, 
   0.0006592207237758399, 0.0024605573327057873, 0.004980707796650852, 
   0.0072784042499151, 0.008291292972568, 0.007394531820015549, 
   0.004845221028359562, 0.0018389440238428967, 0.00006846985717233871, 
   0.0009301454886076434, 0.004742307370495721, 0.010394557231036827, 
   0.015682034803432908, 0.018253125335641232, 0.016766331121870003, 
   0.011689542357710728, 0.005289648579694891, 0.0007236460257803606, 
   0.0005908763603977746, 0.005615405461722799, 0.014125037236428389, 
   0.022652960024098303, 0.02745563673877435, 0.026271819207750836, 
   0.019483363313927332, 0.010080524053971937, 0.0023850024793222093, 
   0.00008525128719542972, 0.004494963733340422, 0.013871599704688087, 
   0.02414870030132512, 0.03076818947218434, 0.030768189472185032, 
   0.024148700301326872, 0.013871599704690119, 0.004494963733341849, 
   0.00008525128719563954, 0.002385002479321159, 0.010080524053970153, 
   0.019483363313925646, 0.02627181920775001, 0.027455636738774724, 
   0.0226529600240997, 0.014125037236430153, 0.0056154054617241714, 
   0.0005908763603982603, 0.0007236460257798491, 0.0052896485796937375, 
   0.01168954235770953, 0.016766331121869323, 0.018253125335641354, 
   0.015682034803433744, 0.01039455723103797, 0.004742307370496702, 
   0.0009301454886081117, 0.00006846985717221976, 0.001838944023842375, 
   0.004845221028358986, 0.0073945318200152035, 0.008291292972568018, 
   0.00727840424991545, 0.004980707796651358, 0.002460557332706232, 
   0.0006592207237760831, 4.350445215082961*^-6, 0.0003343685630850038, 
   0.001110788924979215, 0.0017565370966976636, 0.00193028374095985, 
   0.0016188564252868182, 0.0010466475046067608, 0.0004937999850752365, 
   0.00014001737026499158, 8.460448089522391*^-6, 
   0.000011172386183082609, 0.00004058965728957773, 
   0.00003982503659698032, 0.000015119553004186235, 
   5.719270000831004*^-8, 0.000011129448479926405, 
   0.00003167561931467519, 0.00003304451479019705, 
   0.000010841620839850654, 2.5177046803106587*^-6, 
   0.00006736454994884246, 0.00023957609714389509, 
   0.00048789936329329115, 0.0007149327625295384, 0.0008046449927814845, 
   0.000693801668229033, 0.0004234364671281537, 0.00013409190532992564, 
   1.3784058386158973*^-7, 0.00013557868766920396, 0.0005237524744544015, 
   0.001013240323111906, 0.0013868813208980655, 0.0014698984859430877, 
   0.0012202173445975226, 0.00075243007233741, 0.000282064278742074, 
   0.000019273325637894728, 0.00006736338893852651, 
   0.00037770543623484587, 0.0007815124987662613, 0.0010784155199596022, 
   0.001133848600114324}, {0.0009659165783781631, 0.0009186935795522518, 
   0.0006657642640225927, 0.00032176424838914925, 0.0000573863337176901, 
   0.00001641879237865272, 0.00024028830919552152, 0.0006409891769215227, 
   0.001039493422889469, 0.0012521947956387093, 0.001181473134917166, 
   0.0008631713492228631, 0.00044618055531503626, 0.00011549840259210113, 
   1.1742529391499805*^-7, 0.00011423182457639094, 
   0.00036072214883686406, 0.0005910441071067574, 0.0006854706511594728, 
   0.0006090455177908174, 0.0004156375758965324, 0.00020409296619596035, 
   0.000057387322773104425, 2.1448125348751326*^-6, 9.23589031608072*^-6, 
   0.00002815035857264675, 0.00002698420743594737, 9.481088386832795*^-6, 
   4.872200494344382*^-8, 0.000012880226604269481, 
   0.00003392663101551537, 0.00003457800528460497, 9.517666673663959*^-6, 
   7.207388243320327*^-6, 0.00011927968089054422, 0.0004206642685265803, 
   0.0008916306606682511, 0.0013790908760136199, 0.0016443933221586661, 
   0.0014963799417890096, 0.0009462722250644974, 0.0002848459118261937, 
   3.7061095777102476*^-6, 0.0005615848763594552, 0.0020961291652790925, 
   0.004243025243720737, 0.006200414524851301, 0.0070632863484475766, 
   0.006299342675536929, 0.0041276051465135395, 0.0015665817457112248, 
   0.00005832892518038072, 0.0007923835225083873, 0.004039933822262488, 
   0.008855040393705894, 0.013359400362457642, 0.015549691878733082, 
   0.014283103747325082, 0.009958227893766628, 0.004506209432552724, 
   0.000616468277253466, 0.0005033628583414241, 0.0047837191219767036, 
   0.01203300655440204, 0.01929787595487478, 0.02338923793991289, 
   0.022380753227866645, 0.01659772179953307, 0.008587518035026647, 
   0.0020317645883393036, 0.00007262489156122073, 0.0038292237506880548, 
   0.011817105142638142, 0.02057208516638298, 0.02621117519117381, 
   0.026211175191174396, 0.020572085166384473, 0.011817105142639873, 
   0.0038292237506892713, 0.00007262489156139947, 0.002031764588338409, 
   0.008587518035025127, 0.016597721799531635, 0.02238075322786594, 
   0.02338923793991321, 0.01929787595487597, 0.012033006554403543, 
   0.004783719121977873, 0.000503362858341838, 0.0006164682772530302, 
   0.0045062094325517416, 0.009958227893765607, 0.014283103747324504, 
   0.015549691878733184, 0.013359400362458352, 0.008855040393706869, 
   0.004039933822263324, 0.0007923835225087861, 0.00005832892518027939, 
   0.0015665817457107803, 0.004127605146513049, 0.006299342675536634, 
   0.007063286348447591, 0.006200414524851599, 0.0042430252437211675, 
   0.002096129165279471, 0.0005615848763596624, 3.706109577725761*^-6, 
   0.0002848459118260846, 0.0009462722250643645, 0.0014963799417889395, 
   0.001644393322158682, 0.0013790908760136988, 0.0008916306606683502, 
   0.0004206642685266577, 0.00011927968089058305, 7.2073882433277844*^-6, 
   9.517666673658783*^-6, 0.00003457800528460204, 0.00003392663101551852, 
   0.00001288022660427373, 4.872200494375195*^-8, 9.481088386829415*^-6, 
   0.000026984207435944962, 0.000028150358572648854, 
   9.235890316084695*^-6, 2.1448125348721053*^-6, 0.00005738732277308532, 
   0.00020409296619592417, 0.0004156375758964902, 0.0006090455177907882, 
   0.0006854706511594741, 0.0005910441071067933, 0.0003607221488369171, 
   0.00011423182457643167, 1.174252939165002*^-7, 0.00011549840259205389, 
   0.0004461805553149595, 0.0008631713492227877, 0.0011814731349171256, 
   0.0012521947956387238, 0.001039493422889532, 0.0006409891769216051, 
   0.00024028830919558533, 0.000016418792378670833, 
   0.00005738633371765787, 0.0003217642483890824, 0.0006657642640225273, 
   0.0009186935795522189, 0.000965916578378176}, 
  {0.00018412619133729196, 0.00017512438816714667, 
   0.00012691017113380834, 0.00006133575806709626, 
   0.000010939171455148486, 3.129804141176574*^-6, 0.0000458045468785063, 
   0.00012218746264108408, 0.00019815165114794135, 
   0.00023869748557423315, 0.0002252162902772539, 0.0001645405582237084, 
   0.00008505240321773614, 0.00002201668493000945, 
   2.2383995284079156*^-8, 0.000021775245667774363, 
   0.00006876204103242162, 0.00011266676935667138, 
   0.00013066666738799248, 0.00011609825739834028, 0.0000792302001431548, 
   0.00003890487168932354, 0.000010939359992140747, 
   4.0885121139770765*^-7, 1.7605757532025048*^-6, 5.366113828860349*^-6, 
   5.1438182682182105*^-6, 1.807316214958153*^-6, 9.287548640707576*^-9, 
   2.4552711085955788*^-6, 6.467205857757655*^-6, 6.591372960784252*^-6, 
   1.8142888881585384*^-6, 1.3738960241887374*^-6, 
   0.00002273748462127026, 0.00008018840480566098, 
   0.00016996556566412278, 0.00026288683328611767, 0.0003134596571247718, 
   0.0002852448603146968, 0.00018038152017427845, 
   0.000054298263469727434, 7.064707827752866*^-7, 
   0.00010705115401405577, 0.0003995710275538446, 0.0008088194108709238, 
   0.0011819433859290565, 0.0013464268475938423, 0.001200801395005131, 
   0.0007868176527706284, 0.00029862695880078803, 
   0.000011118851336307253, 0.00015104675014779217, 0.000770105456929713, 
   0.0016879768898558135, 0.002546612784532132, 0.002964133348768983, 
   0.0027226921582463493, 0.0018982701152378157, 0.0008589884455418002, 
   0.00011751320819188101, 0.00009595268167224012, 0.0009118882541967329, 
   0.002293771239457181, 0.003678624510655701, 0.004458533372922187, 
   0.004266292704102998, 0.00316391225519218, 0.0016369808989971765, 
   0.00038730164045122504, 0.000013843995412009712, 
   0.0007299392108750571, 0.0022526154030813534, 0.003921518456503316, 
   0.0049964603222038, 0.004996460322203912, 0.0039215184565036, 
   0.0022526154030816834, 0.0007299392108752889, 0.000013843995412043783, 
   0.00038730164045105455, 0.0016369808989968866, 0.0031639122551919063, 
   0.004266292704102863, 0.004458533372922248, 0.0036786245106559283, 
   0.0022937712394574673, 0.0009118882541969557, 0.000095952681672319, 
   0.00011751320819179793, 0.0008589884455416129, 0.001898270115237621, 
   0.002722692158246239, 0.0029641333487690023, 0.0025466127845322675, 
   0.001687976889855999, 0.0007701054569298723, 0.0001510467501478682, 
   0.000011118851336287937, 0.0002986269588007033, 0.000786817652770535, 
   0.001200801395005075, 0.0013464268475938453, 0.0011819433859291133, 
   0.0008088194108710058, 0.00039957102755391676, 0.00010705115401409526, 
   7.064707827782438*^-7, 0.00005429826346970665, 0.0001803815201742531, 
   0.0002852448603146834, 0.00031345965712477477, 0.0002628868332861327, 
   0.00016996556566414164, 0.00008018840480567571, 
   0.00002273748462127766, 1.3738960241901588*^-6, 
   1.8142888881575518*^-6, 6.591372960783694*^-6, 6.467205857758255*^-6, 
   2.455271108596389*^-6, 9.287548640766313*^-9, 1.807316214957509*^-6, 
   5.143818268217751*^-6, 5.366113828860751*^-6, 1.7605757532032622*^-6, 
   4.0885121139713067*^-7, 0.000010939359992137103, 
   0.00003890487168931664, 0.00007923020014314676, 
   0.00011609825739833471, 0.00013066666738799273, 
   0.00011266676935667821, 0.00006876204103243173, 
   0.000021775245667782125, 2.23839952843655*^-8, 0.00002201668493000044, 
   0.0000850524032177215, 0.00016454055822369402, 0.00022521629027724623, 
   0.00023869748557423589, 0.00019815165114795338, 0.0001221874626410998, 
   0.000045804546878518454, 3.129804141180027*^-6, 
   0.000010939171455142342, 0.00006133575806708352, 
   0.00012691017113379584, 0.00017512438816714038, 
   0.00018412619133729443}, {0.00016696261079963309, 
   0.00015879992330647432, 0.00011508006197072361, 
   0.000055618259563613396, 9.919461282890809*^-6, 
   2.8380550692274465*^-6, 0.00004153481195578654, 
   0.00011079758735772085, 0.00017968066775092065, 0.0002164469654932247, 
   0.00020422243867748152, 0.00014920267987911904, 
   0.00007712412445442371, 0.000019964368840571374, 
   2.0297439846080168*^-8, 0.000019745435676964776, 
   0.0000623522911721651, 0.00010216437881827865, 0.00011848639117083561, 
   0.00010527599590112612, 0.00007184464618532171, 
   0.00003527829964274394, 9.919632245143552*^-6, 3.707395737008783*^-7, 
   1.5964612211347332*^-6, 4.8659040205383335*^-6, 4.664330051596618*^-6, 
   1.6388447053529446*^-6, 8.421796799894242*^-9, 2.226399577022047*^-6, 
   5.86435621541695*^-6, 5.97694890821192*^-6, 1.6451674110654434*^-6, 
   1.2458263840671108*^-6, 0.000020617978180135767, 
   0.00007271353045958199, 0.00015412198766081195, 
   0.00023838146931467202, 0.00028424007662243887, 
   0.00025865536157252094, 0.0001635670043982737, 0.00004923677487134282, 
   6.406161203310161*^-7, 0.00009707223091666895, 0.0003623244551779866, 
   0.0007334241778620864, 0.0010717668795449922, 0.001220917785200813, 
   0.0010888670129206772, 0.0007134733444259131, 0.00027079002902525006, 
   0.00001008239205253607, 0.00013696671600227407, 0.0006983189993024505, 
   0.0015306297624084462, 0.002309226710839441, 0.0026878275115252135, 
   0.002468892599379089, 0.001721320210563844, 0.0007789166357742939, 
   0.00010655905007678006, 0.00008700831820214054, 0.0008268853147529903, 
   0.0020799541441409034, 0.003335716380107424, 0.004042924946602172, 
   0.0038686042606921353, 0.0028689837476742032, 0.0014843874341865198, 
   0.0003511987761603171, 0.000012553508010455102, 0.0006618969060706359, 
   0.002042634706634247, 0.0035559686269583525, 0.004530708282689403, 
   0.004530708282689504, 0.0035559686269586105, 0.0020426347066345462, 
   0.0006618969060708461, 0.000012553508010485998, 
   0.00035119877616016245, 0.0014843874341862572, 0.0028689837476739556, 
   0.003868604260692014, 0.004042924946602228, 0.00333571638010763, 
   0.002079954144141163, 0.0008268853147531924, 0.00008700831820221207, 
   0.00010655905007670475, 0.0007789166357741242, 0.0017213202105636676, 
   0.002468892599378989, 0.0026878275115252313, 0.0023092267108395636, 
   0.0015306297624086145, 0.0006983189993025951, 0.000136966716002343, 
   0.000010082392052518553, 0.0002707900290251732, 0.0007134733444258283, 
   0.0010888670129206262, 0.0012209177852008156, 0.0010717668795450436, 
   0.0007334241778621609, 0.000362324455178052, 0.00009707223091670475, 
   6.406161203336976*^-7, 0.000049236774871323967, 0.0001635670043982507, 
   0.0002586553615725088, 0.0002842400766224416, 0.00023838146931468566, 
   0.00015412198766082905, 0.00007271353045959536, 
   0.00002061797818014248, 1.2458263840683998*^-6, 
   1.6451674110645488*^-6, 5.976948908211414*^-6, 5.8643562154174934*^-6, 
   2.2263995770227814*^-6, 8.421796799947504*^-9, 1.6388447053523604*^-6, 
   4.664330051596201*^-6, 4.865904020538698*^-6, 1.5964612211354202*^-6, 
   3.707395737003551*^-7, 9.919632245140249*^-6, 0.00003527829964273769, 
   0.00007184464618531442, 0.00010527599590112106, 
   0.00011848639117083583, 0.00010216437881828484, 
   0.00006235229117217426, 0.000019745435676971813, 
   2.0297439846339817*^-8, 0.000019964368840563205, 
   0.00007712412445441044, 0.000149202679879106, 0.00020422243867747455, 
   0.0002164469654932272, 0.00017968066775093155, 0.00011079758735773511, 
   0.00004153481195579757, 2.8380550692305776*^-6, 9.919461282885237*^-6, 
   0.00005561825956360184, 0.0001150800619707123, 0.00015879992330646863, 
   0.00016696261079963534}, {0.0014088958858217723, 
   0.0013400159325718708, 0.000971090623668083, 0.0004693286520883426, 
   0.00008370429837015901, 0.000023948619943231995, 
   0.00035048700665752416, 0.0009349534260374321, 0.0015162158302602273, 
   0.0018264642468245444, 0.0017233089029165156, 0.0012590306346343724, 
   0.0006508035608753351, 0.00016846716152674827, 1.7127774508854349*^-7, 
   0.00016661971776674715, 0.0005261530475793067, 0.000862103031961729, 
   0.0009998345632411872, 0.0008883600752918527, 0.0006062532560076803, 
   0.0002976921059595629, 0.00008370574101658964, 3.1284456897078722*^-6, 
   0.000013471564894430071, 0.00004106040341910576, 
   0.000039359443340854676, 0.00001382921332994412, 7.10664190369982*^-8, 
   0.00001878723140012488, 0.000049485733993520157, 
   0.00005043583522212875, 0.000013882566796465389, 
   0.000010512770844646046, 0.00017398257306132272, 
   0.0006135852417342908, 0.0013005416799008816, 0.0020115561787461492, 
   0.002398529063609369, 0.0021826352200649017, 0.0013802424294231627, 
   0.00041547918552026, 5.405769663057146*^-6, 0.0008191334940860691, 
   0.0030574356245871683, 0.00618892039243543, 0.009043988590733614, 
   0.010302582334199076, 0.009188286211887362, 0.006020567447950918, 
   0.0022850322954824777, 0.00008507917200161211, 0.00115577878032647, 
   0.0058926891499624405, 0.012916053268725932, 0.019486159187075802, 
   0.022680940988224936, 0.020833482473362617, 0.014525173937029717, 
   0.006572803565329432, 0.0008991869888188258, 0.0007342102579743371, 
   0.006977582061171803, 0.0175514674952873, 0.028148080948743603, 
   0.03411578374747436, 0.032644797542742465, 0.024209608242401762, 
   0.012525842396539241, 0.002963552788664225, 0.00010593141604491323, 
   0.005585345265834381, 0.017236551468803922, 0.030006655649660752, 
   0.03823189053386409, 0.03823189053386495, 0.030006655649662928, 
   0.017236551468806448, 0.0055853452658361545, 0.00010593141604517394, 
   0.00296355278866292, 0.012525842396537024, 0.02420960824239967, 
   0.03264479754274144, 0.03411578374747482, 0.02814808094874534, 
   0.01755146749528949, 0.0069775820611735085, 0.0007342102579749406, 
   0.0008991869888181903, 0.006572803565327999, 0.014525173937028226, 
   0.02083348247336177, 0.022680940988225085, 0.019486159187076836, 
   0.012916053268727353, 0.00589268914996366, 0.0011557787803270518, 
   0.0000850791720014643, 0.0022850322954818293, 0.006020567447950202, 
   0.009188286211886932, 0.010302582334199097, 0.009043988590734048, 
   0.006188920392436059, 0.0030574356245877204, 0.0008191334940863713, 
   5.405769663079773*^-6, 0.0004154791855201009, 0.0013802424294229688, 
   0.0021826352200647993, 0.0023985290636093916, 0.002011556178746264, 
   0.0013005416799010262, 0.0006135852417344037, 0.00017398257306137937, 
   0.000010512770844656922, 0.000013882566796457838, 
   0.000050435835222124475, 0.00004948573399352475, 
   0.000018787231400131077, 7.106641903744764*^-8, 
   0.000013829213329939191, 0.00003935944334085116, 
   0.00004106040341910883, 0.000013471564894435869, 
   3.128445689703457*^-6, 0.00008370574101656178, 0.00029769210595951016, 
   0.0006062532560076188, 0.00088836007529181, 0.000999834563241189, 
   0.0008621030319617812, 0.0005261530475793841, 0.00016661971776680653, 
   1.7127774509073452*^-7, 0.00016846716152667937, 0.0006508035608752233, 
   0.0012590306346342622, 0.0017233089029164569, 0.0018264642468245654, 
   0.0015162158302603195, 0.0009349534260375524, 0.00035048700665761724, 
   0.000023948619943258416, 0.00008370429837011198, 
   0.00046932865208824514, 0.0009710906236679873, 0.0013400159325718227, 
   0.0014088958858217912}, {0.0023571898791995864, 0.0022419484832140297, 
   0.0016247084067257953, 0.000785222499301821, 0.0001400436518760627, 
   0.00004006786102441997, 0.0005863913957007504, 0.0015642481290183898, 
   0.0025367443015045644, 0.0030558134782425945, 0.0028832267490936686, 
   0.0021064539256790784, 0.0010888438120092959, 0.0002818583630803277, 
   2.865606829558976*^-7, 0.00027876744928230415, 0.0008802940310529469, 
   0.0014423638838168447, 0.0016727992018880835, 0.0014862939125849903, 
   0.0010143077665810416, 0.0004980615149402608, 0.0001400460655331681, 
   5.234127369960844*^-6, 0.000022538951774714797, 0.0000686971751066721, 
   0.0000658513396395344, 0.00002313732478509062, 1.1889951939724817*^-7, 
   0.000031432465777075295, 0.00008279339339986172, 
   0.00008438298495366555, 0.000023226589188919005, 
   0.000017588664490201326, 0.00029108606569465997, 
   0.0010265747358604086, 0.0021759050588408013, 0.003365486345512432, 
   0.0040129213880189295, 0.0036517145819619386, 0.0023092504692640583, 
   0.0006951282497039922, 9.044263431580779*^-6, 0.0013704725816889303, 
   0.005115322134947899, 0.01035453411357764, 0.015131280166411543, 
   0.017237003139965606, 0.01537270105180067, 0.010072866844288344, 
   0.003823032670305395, 0.00014234391993834703, 0.0019337057272973237, 
   0.009858916734261662, 0.021609538611496042, 0.03260182507627655, 
   0.037946937801570164, 0.03485599931754264, 0.024301719766900716, 
   0.010996799833171938, 0.0015044081616544767, 0.0012283895543439452, 
   0.011674025015897732, 0.029364938858388704, 0.047093878404342614, 
   0.057078298673292616, 0.05461722697230331, 0.04050451428147286, 
   0.02095668617014221, 0.00495824901627736, 0.00017723130878809145, 
   0.009344707061005366, 0.028838060415563676, 0.05020341511236059, 
   0.06396485811052416, 0.06396485811052559, 0.05020341511236423, 
   0.0288380604155679, 0.009344707061008335, 0.00017723130878852765, 
   0.004958249016275177, 0.0209566861701385, 0.04050451428146935, 
   0.05461722697230159, 0.0570782986732934, 0.04709387840434552, 
   0.02936493885839237, 0.011674025015900584, 0.001228389554344955, 
   0.0015044081616534134, 0.01099679983316954, 0.024301719766898225, 
   0.03485599931754123, 0.03794693780157041, 0.03260182507627828, 
   0.02160953861149842, 0.009858916734263702, 0.001933705727298297, 
   0.00014234391993809975, 0.0038230326703043104, 0.010072866844287147, 
   0.015372701051799952, 0.01723700313996564, 0.015131280166412272, 
   0.010354534113578692, 0.005115322134948822, 0.0013704725816894357, 
   9.044263431618636*^-6, 0.0006951282497037261, 0.002309250469263734, 
   0.0036517145819617678, 0.004012921388018968, 0.0033654863455126246, 
   0.0021759050588410433, 0.0010265747358605972, 0.00029108606569475473, 
   0.000017588664490219523, 0.00002322658918890637, 
   0.00008438298495365841, 0.00008279339339986941, 
   0.00003143246577708566, 1.1889951939800014*^-7, 
   0.00002313732478508237, 0.00006585133963952851, 
   0.00006869717510667724, 0.000022538951774724497, 
   5.234127369953457*^-6, 0.00014004606553312144, 0.0004980615149401726, 
   0.0010143077665809386, 0.0014862939125849192, 0.0016727992018880865, 
   0.001442363883816932, 0.0008802940310530763, 0.0002787674492824035, 
   2.8656068295956337*^-7, 0.0002818583630802124, 0.0010888438120091085, 
   0.002106453925678894, 0.0028832267490935706, 0.00305581347824263, 
   0.0025367443015047184, 0.001564248129018591, 0.0005863913957009061, 
   0.00004006786102446417, 0.00014004365187598403, 0.0007852224993016579, 
   0.0016247084067256353, 0.0022419484832139494, 0.002357189879199618}, 
  {0.0014716941283777622, 0.0013997440121335883, 0.0010143747194927976, 
   0.0004902478802789542, 0.00008743522191456429, 
   0.000025016073726872717, 0.0003661091461486649, 0.0009766267907038398, 
   0.0015837976086117032, 0.0019078746235217765, 0.0018001213711572937, 
   0.001315148983743664, 0.0006798116091516017, 0.00017597619166782584, 
   1.7891205042561932*^-7, 0.00017404640241834132, 0.0005496050904420668, 
   0.0009005292605100573, 0.0010443998530189052, 0.000927956650203203, 
   0.0006332755785258007, 0.00031096103609498454, 0.00008743672886358916, 
   3.267888847447612*^-6, 0.000014072028426450206, 
   0.00004289057497351825, 0.00004111379857367307, 
   0.000014445618205415678, 7.42340386355663*^-8, 
   0.000019624628347829355, 0.00005169144497448003, 
   0.00005268389474566535, 0.00001450134977805928, 
   0.000010981353044424812, 0.00018173743978608956, 
   0.0006409343703867113, 0.0013585102868721149, 0.002101216595884936, 
   0.0025054378930196254, 0.0022799210857844506, 0.0014417635111022592, 
   0.0004339981995452374, 5.64671921647604*^-6, 0.0008556444558718286, 
   0.0031937136745725007, 0.006464777059968518, 0.00944710325300919, 
   0.010761795872180784, 0.009597832603508346, 0.006288920176300744, 
   0.0023868822716120344, 0.00008887137732606991, 0.0012072949192537075, 
   0.006155342001937056, 0.013491756167852819, 0.02035470920800291, 
   0.023691890944080526, 0.021762086282071366, 0.015172599630613523, 
   0.006865770928441348, 0.000939266148106099, 0.0007669359649136225, 
   0.0072885914800659545, 0.018333783154005925, 0.029402715895650137, 
   0.035636415104497575, 0.034099863126303726, 0.02528869496974008, 
   0.01308415255767451, 0.003095646230573501, 0.00011065306143122778, 
   0.005834298982210827, 0.018004830481369423, 0.03134413222173716, 
   0.039935987734573325, 0.03993598773457422, 0.03134413222173943, 
   0.018004830481372063, 0.005834298982212681, 0.00011065306143150012, 
   0.003095646230572138, 0.013084152557672195, 0.025288694969737895, 
   0.03409986312630266, 0.03563641510449806, 0.029402715895651955, 
   0.018333783154008212, 0.007288591480067735, 0.0007669359649142528, 
   0.000939266148105435, 0.006865770928439851, 0.015172599630611967, 
   0.021762086282070485, 0.02369189094408068, 0.020354709208003988, 
   0.013491756167854302, 0.006155342001938329, 0.001207294919254315, 
   0.0000888713773259155, 0.0023868822716113574, 0.006288920176299996, 
   0.009597832603507899, 0.010761795872180806, 0.009447103253009645, 
   0.006464777059969174, 0.0031937136745730775, 0.0008556444558721442, 
   5.6467192164996765*^-6, 0.0004339981995450712, 0.0014417635111020567, 
   0.002279921085784344, 0.0025054378930196492, 0.002101216595885056, 
   0.0013585102868722658, 0.0006409343703868292, 0.00018173743978614873, 
   0.000010981353044436173, 0.000014501349778051392, 
   0.00005268389474566089, 0.00005169144497448483, 
   0.00001962462834783583, 7.423403863603578*^-8, 
   0.000014445618205410528, 0.000041113798573669395, 
   0.000042890574973521456, 0.00001407202842645626, 3.267888847443*^-6, 
   0.00008743672886356005, 0.0003109610360949294, 0.0006332755785257364, 
   0.0009279566502031585, 0.0010443998530189071, 0.0009005292605101118, 
   0.0005496050904421476, 0.00017404640241840336, 1.7891205042790803*^-7, 
   0.00017597619166775385, 0.0006798116091514847, 0.001315148983743549, 
   0.0018001213711572323, 0.0019078746235217984, 0.0015837976086117993, 
   0.0009766267907039656, 0.0003661091461487621, 0.000025016073726900313, 
   0.00008743522191451517, 0.0004902478802788524, 0.0010143747194926976, 
   0.001399744012133538, 0.0014716941283777817}, 
  {0.000055484312043999776, 0.000052771722094555415, 
   0.00003824292180055257, 0.000018482825910497094, 
   3.296393620657838*^-6, 9.431305146997443*^-7, 0.000013802673881335698, 
   0.00003681978786289809, 0.00005971072319736532, 
   0.00007192874450684694, 0.00006786634121076462, 
   0.00004958240655537377, 0.00002562956440879351, 
   6.6344750193269165*^-6, 6.7451597739192855*^-9, 
   6.5617200719279075*^-6, 0.00002072065094984933, 
   0.00003395083633986412, 0.00003937489878245549, 
   0.000034984875831456265, 0.00002387511041271947, 
   0.0000117235360442988, 3.2964504341140573*^-6, 1.232026146198966*^-7, 
   5.305292732028788*^-7, 1.6170167426029211*^-6, 1.5500305297068406*^-6, 
   5.446139742782428*^-7, 2.7986960636190393*^-9, 7.398677361026977*^-7, 
   1.948818173332485*^-6, 1.986234503078355*^-6, 5.467151092271667*^-7, 
   4.140077800363397*^-7, 6.851679723886694*^-6, 0.00002416385437744482, 
   0.00005121717021109714, 0.00007921792649035102, 
   0.00009445746584339146, 0.0000859552610288655, 0.00005435589841744404, 
   0.000016362157778427334, 2.1288685263503747*^-7, 
   0.00003225863518300648, 0.00012040613785318095, 
   0.00024372843566724712, 0.0003561650581426399, 0.0004057302593060545, 
   0.00036184770248837985, 0.00023709845867653673, 
   0.00008998780263966589, 3.350538088220192*^-6, 0.00004551620254328685, 
   0.00023206243049258773, 0.0005086524399359123, 0.0007673925005779578, 
   0.0008932075250600962, 0.0008204519965937915, 0.0005720218870150634, 
   0.00025884629779434677, 0.000035411254994493996, 
   0.000028914238070610004, 0.00027478704728338323, 
   0.0006912016062639216, 0.0011085112267816095, 0.0013435278008256865, 
   0.0012855982842325151, 0.0009534086029365638, 0.0004932853840638316, 
   0.00011670889903209807, 4.171728941965445*^-6, 0.0002199587937772106, 
   0.0006787997678762193, 0.0011817045263721058, 0.001505625905902674, 
   0.001505625905902708, 0.0011817045263721915, 0.0006787997678763188, 
   0.00021995879377728045, 4.171728941975712*^-6, 0.00011670889903204668, 
   0.0004932853840637443, 0.0009534086029364813, 0.0012855982842324748, 
   0.001343527800825705, 0.001108511226781678, 0.0006912016062640079, 
   0.0002747870472834504, 0.00002891423807063377, 
   0.000035411254994468964, 0.00025884629779429033, 
   0.0005720218870150048, 0.0008204519965937583, 0.000893207525060102, 
   0.0007673925005779985, 0.0005086524399359683, 0.00023206243049263574, 
   0.000045516202543309763, 3.3505380882143714*^-6, 
   0.00008998780263964036, 0.00023709845867650854, 
   0.00036184770248836294, 0.0004057302593060554, 0.000356165058142657, 
   0.00024372843566727187, 0.00012040613785320269, 
   0.00003225863518301838, 2.1288685263592858*^-7, 
   0.00001636215777842107, 0.000054355898417436404, 
   0.00008595526102886148, 0.00009445746584339236, 
   0.00007921792649035554, 0.00005121717021110283, 
   0.00002416385437744926, 6.851679723888924*^-6, 4.1400778003676804*^-7, 
   5.467151092268693*^-7, 1.9862345030781863*^-6, 1.948818173332666*^-6, 
   7.398677361029418*^-7, 2.7986960636367394*^-9, 5.446139742780486*^-7, 
   1.5500305297067021*^-6, 1.617016742603042*^-6, 5.305292732031071*^-7, 
   1.2320261461972276*^-7, 3.29645043411296*^-6, 0.000011723536044296722, 
   0.000023875110412717046, 0.00003498487583145459, 
   0.000039374898782455565, 0.00003395083633986618, 
   0.000020720650949852376, 6.561720071930246*^-6, 6.745159774005572*^-9, 
   6.634475019324202*^-6, 0.000025629564408789103, 
   0.00004958240655536944, 0.00006786634121076231, 
   0.00007192874450684777, 0.00005971072319736894, 
   0.00003681978786290283, 0.000013802673881339362, 
   9.431305147007847*^-7, 3.2963936206559864*^-6, 
   0.000018482825910493256, 0.0000382429218005488, 
   0.00005277172209455352, 0.00005548431204400052}, 
  {0.001182477079294784, 0.0011246665861557555, 0.0008150299933169412, 
   0.0003939044604613075, 0.00007025246880001586, 
   0.000020099919694985996, 0.00029416144665752003, 0.000784700280285473, 
   0.0012725500049997542, 0.0015329394668234888, 0.0014463618630377643, 
   0.0010566961565912638, 0.0005462151615338468, 0.00014139338408461513, 
   1.4375228843994088*^-7, 0.0001398428366499384, 0.0004415968030176595, 
   0.0007235574221942479, 0.0008391545933359163, 0.0007455947865022654, 
   0.000508824382760389, 0.000249851032660839, 0.00007025367960370612, 
   2.625683955163519*^-6, 0.000011306596087193745, 
   0.00003446172736984752, 0.00003303412272881743, 
   0.000011606768074135369, 5.964557953818835*^-8, 
   0.000015768000132314402, 0.00004153305207878126, 
   0.000042330465810445456, 0.000011651547288765216, 
   8.823299641067282*^-6, 0.0001460224328228108, 0.0005149780703072701, 
   0.001091536104708924, 0.001688285911697255, 0.0020130697167066924, 
   0.0018318714293660467, 0.001158428421210893, 0.00034870895624428155, 
   4.537027034317556*^-6, 0.0006874933707925929, 0.0025660856730977816, 
   0.005194320306618276, 0.007590560325689588, 0.008646889802387338, 
   0.007711668373011017, 0.005053022784148324, 0.001917812623379456, 
   0.00007140639122429195, 0.0009700375522597129, 0.004945695367103308, 
   0.010840358822050632, 0.016354605641258475, 0.019035965059810183, 
   0.017485405241475224, 0.012190883248473316, 0.005516510936630192, 
   0.0007546817440368777, 0.0006162178555382559, 0.005856238874188789, 
   0.01473083158948915, 0.023624499782401966, 0.028633153613076244, 
   0.02739856453622637, 0.020318965463263172, 0.010512857395511041, 
   0.0024872904244670987, 0.00008890754292840301, 0.0046877436603092425, 
   0.014466524633264359, 0.0251843893428075, 0.03208777505090993, 
   0.03208777505091064, 0.025184389342809324, 0.014466524633266479, 
   0.004687743660310731, 0.00008890754292862183, 0.0024872904244660032, 
   0.01051285739550918, 0.020318965463261417, 0.02739856453622551, 
   0.028633153613076636, 0.023624499782403427, 0.014730831589490989, 
   0.00585623887419022, 0.0006162178555387624, 0.0007546817440363441, 
   0.005516510936628989, 0.012190883248472065, 0.017485405241474516, 
   0.019035965059810308, 0.016354605641259345, 0.010840358822051824, 
   0.00494569536710433, 0.0009700375522602012, 0.0000714063912241679, 
   0.001917812623378912, 0.005053022784147724, 0.007711668373010656, 
   0.008646889802387358, 0.007590560325689953, 0.005194320306618803, 
   0.002566085673098245, 0.0006874933707928465, 4.537027034336548*^-6, 
   0.0003487089562441481, 0.0011584284212107303, 0.001831871429365961, 
   0.0020130697167067115, 0.0016882859116973516, 0.0010915361047090452, 
   0.0005149780703073648, 0.00014602243282285833, 8.823299641076411*^-6, 
   0.000011651547288758879, 0.000042330465810441864, 
   0.00004153305207878511, 0.000015768000132319603, 
   5.964557953856557*^-8, 0.000011606768074131232, 
   0.00003303412272881448, 0.0000344617273698501, 0.00001130659608719861, 
   2.625683955159813*^-6, 0.00007025367960368273, 0.0002498510326607947, 
   0.0005088243827603374, 0.0007455947865022296, 0.0008391545933359178, 
   0.0007235574221942918, 0.00044159680301772446, 0.00013984283664998827, 
   1.4375228844177982*^-7, 0.00014139338408455728, 0.0005462151615337528, 
   0.0010566961565911714, 0.0014463618630377148, 0.0015329394668235064, 
   0.0012725500049998316, 0.000784700280285574, 0.0002941614466575981, 
   0.00002009991969500817, 0.0000702524687999764, 0.0003939044604612257, 
   0.0008150299933168609, 0.0011246665861557152, 0.0011824770792947998}, 
  {0.004942247756680214, 0.0047006246546076255, 0.0034064763086148306, 
   0.0016463519421638692, 0.0002936252316494746, 0.00008400905587213709, 
   0.0012294688626962444, 0.0032797110978422675, 0.005318714009428642, 
   0.006407030439484959, 0.006045173135372195, 0.004416537369604145, 
   0.0022829454405706912, 0.0005909637890980264, 6.008229990247717*^-7, 
   0.0005844831648941074, 0.0018456855082322518, 0.0030241601374645893, 
   0.0035073068045392798, 0.0031162668820447032, 0.0021266679991306784, 
   0.0010442703095849457, 0.00029363029229033334, 0.00001097423439691308, 
   0.000047256729222141685, 0.00014403526103569806, 
   0.00013806848505491955, 0.00004851131956901356, 2.492929772848604*^-7, 
   0.00006590348738745985, 0.00017359036979123338, 
   0.00017692321767088425, 0.00004869847750799217, 
   0.000036877613630861076, 0.0006103112302810344, 0.002152387777557185, 
   0.004562153431380203, 0.0070563120468236, 0.008413769252396883, 
   0.0076564380154500455, 0.00484173466551978, 0.0014574540910005794, 
   0.000018962829872124303, 0.0028734278482239993, 0.010725139102806364, 
   0.021710034242839547, 0.03172529125381304, 0.03614029605850505, 
   0.03223147102310482, 0.02111947111423492, 0.008015635399277986, 
   0.0002984481331776486, 0.004054341517900979, 0.02067088847748955, 
   0.04530805713531485, 0.06835524718170816, 0.07956218117073215, 
   0.07308150520842538, 0.0509526708311761, 0.02305665308753583, 
   0.003154246472750402, 0.0025755267205488158, 0.024476570366847427, 
   0.06156856708005361, 0.09874029111997804, 0.11967431901115773, 
   0.11451426542337728, 0.08492457336996784, 0.043939241435656494, 
   0.010395808710191648, 0.0003715954518559503, 0.019592760819408334, 
   0.06046387720119694, 0.10525996140837035, 0.13411315706584154, 
   0.13411315706584453, 0.10525996140837798, 0.0604638772012058, 
   0.019592760819414558, 0.0003715954518568648, 0.01039580871018707, 
   0.043939241435648715, 0.0849245733699605, 0.11451426542337369, 
   0.11967431901115937, 0.09874029111998414, 0.061568567080061296, 
   0.02447657036685341, 0.002575526720550933, 0.0031542464727481725, 
   0.023056653087530802, 0.05095267083117087, 0.07308150520842242, 
   0.07956218117073267, 0.06835524718171179, 0.04530805713531983, 
   0.020670888477493828, 0.00405434151790302, 0.0002984481331771301, 
   0.008015635399275712, 0.021119471114232412, 0.032231471023103316, 
   0.03614029605850513, 0.03172529125381457, 0.02171003424284175, 
   0.0107251391028083, 0.002873427848225059, 0.000018962829872203677, 
   0.0014574540910000215, 0.0048417346655191, 0.007656438015449687, 
   0.008413769252396962, 0.007056312046824003, 0.004562153431380709, 
   0.0021523877775575804, 0.0006103112302812331, 0.000036877613630899226, 
   0.000048698477507965684, 0.00017692321767086926, 
   0.0001735903697912495, 0.00006590348738748159, 2.49292977286437*^-7, 
   0.00004851131956899627, 0.00013806848505490722, 
   0.00014403526103570882, 0.00004725672922216202, 
   0.000010974234396897591, 0.0002936302922902356, 0.0010442703095847605, 
   0.0021266679991304624, 0.0031162668820445536, 0.003507306804539286, 
   0.0030241601374647728, 0.0018456855082325232, 0.0005844831648943158, 
   6.008229990324576*^-7, 0.0005909637890977846, 0.0022829454405702983, 
   0.004416537369603759, 0.006045173135371989, 0.006407030439485033, 
   0.005318714009428965, 0.0032797110978426895, 0.0012294688626965707, 
   0.00008400905587222978, 0.00029362523164930965, 0.0016463519421635272, 
   0.0034064763086144954, 0.004700624654607456, 0.00494224775668028}, 
  {0.006677968167364947, 0.006351486885247969, 0.0046028328549625585, 
   0.0022245517431191695, 0.00039674659115176855, 0.00011351308726403348, 
   0.0016612590732130615, 0.004431547625256245, 0.007186649596486559, 
   0.008657183417077172, 0.008168241608215547, 0.005967627973391088, 
   0.003084717264397652, 0.0007985106303761827, 8.118324008109371*^-7, 
   0.0007897540070199517, 0.0024938913785295456, 0.0040862470125471815, 
   0.004739075082231106, 0.004210701701706426, 0.00287355509070795, 
   0.00141101867588623, 0.00039675342909276725, 0.00001482839217534778, 
   0.00006385332119635104, 0.00019462053209987006, 0.0001865582207745063, 
   0.00006554852443422381, 3.3684482215723304*^-7, 
   0.00008904883214260738, 0.00023455541298189391, 
   0.00023905875905896887, 0.00006580141235492333, 
   0.00004982905391224169, 0.0008246529046410569, 0.002908307670922436, 
   0.006164384484410429, 0.009534493118842401, 0.011368690118603437, 
   0.010345383691756221, 0.006542154817606113, 0.001969312852020066, 
   0.000025622587228258407, 0.0038825774518736695, 0.014491814462820794, 
   0.0293346114407405, 0.042867232790380204, 0.04883278996113218, 
   0.0435511832017544, 0.028536642183066084, 0.010830731414715179, 
   0.00040326329862276666, 0.005478228718819911, 0.027930517052133674, 
   0.06122027429034093, 0.0923616514641165, 0.10750446746950702, 
   0.09874777417731112, 0.06884727974086363, 0.031154163640708728, 
   0.004262019747710776, 0.0034800532674177107, 0.03307275673000047, 
   0.08319148519317643, 0.1334179412685859, 0.16170401245614846, 
   0.15473174491765468, 0.11475013506256108, 0.059370729686480765, 
   0.014046823036509915, 0.0005021000000005047, 0.0264737503064175, 
   0.08169882755863275, 0.14222732371784702, 0.181213779195905, 
   0.18121377919590906, 0.14222732371785735, 0.08169882755864472, 
   0.02647375030642591, 0.0005021000000017405, 0.014046823036503729, 
   0.05937072968647025, 0.11475013506255118, 0.15473174491764982, 
   0.16170401245615065, 0.13341794126859413, 0.08319148519318681, 
   0.033072756730008555, 0.0034800532674205712, 0.004262019747707763, 
   0.031154163640701938, 0.06884727974085657, 0.09874777417730712, 
   0.10750446746950772, 0.09236165146412141, 0.06122027429034766, 
   0.02793051705213945, 0.005478228718822668, 0.00040326329862206604, 
   0.010830731414712106, 0.028536642183062694, 0.043551183201752365, 
   0.048832789961132286, 0.042867232790382265, 0.029334611440743476, 
   0.01449181446282341, 0.0038825774518751015, 0.000025622587228365658, 
   0.001969312852019312, 0.006542154817605194, 0.010345383691755737, 
   0.011368690118603546, 0.009534493118842946, 0.006164384484411114, 
   0.00290830767092297, 0.0008246529046413253, 0.00004982905391229324, 
   0.00006580141235488756, 0.0002390587590589486, 0.00023455541298191568, 
   0.00008904883214263674, 3.3684482215936333*^-7, 
   0.00006554852443420044, 0.00018655822077448962, 0.0001946205320998846, 
   0.00006385332119637851, 0.000014828392175326853, 
   0.00039675342909263514, 0.0014110186758859798, 0.0028735550907076587, 
   0.004210701701706224, 0.004739075082231114, 0.004086247012547429, 
   0.002493891378529912, 0.0007897540070202333, 8.118324008213223*^-7, 
   0.000798510630375856, 0.0030847172643971212, 0.005967627973390567, 
   0.00816824160821527, 0.008657183417077273, 0.007186649596486995, 
   0.004431547625256815, 0.0016612590732135025, 0.0001135130872641587, 
   0.00039674659115154564, 0.0022245517431187076, 0.004602832854962106, 
   0.0063514868852477405, 0.006677968167365036}, 
  {0.00302135643191782, 0.0028736443888377856, 0.0020824895092111917, 
   0.001006468367137964, 0.00017950263238389536, 0.00005135746198792768, 
   0.0007516142126078243, 0.0020049938222753408, 0.0032515024687295195, 
   0.003916825618801871, 0.003695610506358393, 0.0026999726127494316, 
   0.0013956386304718445, 0.0003612753413279315, 3.673025962921402*^-7, 
   0.00035731352545277894, 0.0011283274445433368, 0.0018487672274478664, 
   0.002144130463366722, 0.001905075069316779, 0.0013001011592432457, 
   0.0006383963273109214, 0.00017950572611787248, 6.708905605889585*^-6, 
   0.000028889572076537052, 0.00008805342908294161, 
   0.0000844057453012108, 0.00002965654386762539, 1.524008866883465*^-7, 
   0.00004028894043904983, 0.00010612142614235033, 
   0.00010815890420365877, 0.00002977095958908597, 
   0.000022544481908415137, 0.00037310305995665087, 
   0.0013158244944142497, 0.002788992436622681, 0.004313752534860862, 
   0.005143610174751213, 0.004680629013851542, 0.002959909517594466, 
   0.0008909889808979212, 0.000011592593253558592, 0.001756619687701566, 
   0.00655662556934295, 0.013272048433447972, 0.019394700044046448, 
   0.02209373575013264, 0.019704144162785587, 0.012911018028881277, 
   0.004900218030709246, 0.0001824510285934862, 0.0024785505351779128, 
   0.012636784906321741, 0.027698285594536035, 0.0417877807620298, 
   0.048638943179787765, 0.04467709566305313, 0.03114902111717958, 
   0.014095280231624317, 0.001928293225570716, 0.001574503061322322, 
   0.014963321741449606, 0.03763886298493395, 0.06036314413043032, 
   0.07316079469933831, 0.07000628649496748, 0.051917147543324084, 
   0.026861484138623014, 0.006355295213411772, 0.00022716835816635273, 
   0.0119776904831882, 0.03696353021428384, 0.06434883014408521, 
   0.08198772494923785, 0.08198772494923968, 0.06434883014408989, 
   0.036963530214289254, 0.011977690483192005, 0.0002271683581669118, 
   0.006355295213408974, 0.026861484138618257, 0.051917147543319594, 
   0.07000628649496528, 0.07316079469933931, 0.060363144130434046, 
   0.03763886298493865, 0.014963321741453263, 0.0015745030613236162, 
   0.0019282932255693529, 0.014095280231621243, 0.031149021117176386, 
   0.04467709566305133, 0.048638943179788084, 0.04178778076203202, 
   0.02769828559453908, 0.012636784906324356, 0.0024785505351791605, 
   0.00018245102859316923, 0.004900218030707856, 0.012911018028879742, 
   0.019704144162784664, 0.022093735750132685, 0.019394700044047378, 
   0.01327204843344932, 0.006556625569344134, 0.0017566196877022138, 
   0.000011592593253607117, 0.00089098898089758, 0.0029599095175940502, 
   0.004680629013851323, 0.005143610174751263, 0.004313752534861108, 
   0.002788992436622991, 0.0013158244944144917, 0.0003731030599567723, 
   0.00002254448190843846, 0.00002977095958906978, 0.0001081589042036496, 
   0.00010612142614236016, 0.00004028894043906312, 
   1.5240088668931033*^-7, 0.00002965654386761482, 
   0.00008440574530120327, 0.0000880534290829482, 0.00002888957207654948, 
   6.7089056058801165*^-6, 0.0001795057261178127, 0.0006383963273108082, 
   0.0013001011592431138, 0.0019050750693166878, 0.002144130463366726, 
   0.0018487672274479785, 0.0011283274445435026, 0.0003573135254529063, 
   3.6730259629683884*^-7, 0.00036127534132778373, 0.0013956386304716044, 
   0.0026999726127491957, 0.0036956105063582667, 0.0039168256188019165, 
   0.003251502468729717, 0.002004993822275599, 0.0007516142126080238, 
   0.000051357461987984336, 0.00017950263238379453, 0.001006468367137755, 
   0.0020824895092109866, 0.0028736443888376824, 0.0030213564319178606}, 
  {0.00017200396377986394, 0.00016359480799824677, 
   0.00011855484719720459, 0.00005729762524472846, 
   0.000010218974482051301, 2.9237487302979434*^-6, 
   0.00004278893494196767, 0.00011414306539351029, 
   0.00018510603613440283, 0.00022298247394823256, 
   0.00021038883362618218, 0.0001537077805795968, 0.00007945284902817037, 
   0.000020567183026758403, 2.091031094559772*^-8, 
   0.00002034163928518148, 0.00006423498758796472, 0.0001052491814166703, 
   0.00012206402881309032, 0.0001084547522295105, 0.00007401395953892433, 
   0.00003634351035183412, 0.000010219150606424223, 
   3.8193387071034114*^-7, 1.6446655735729514*^-6, 
   5.0128275719728324*^-6, 4.8051671773086495*^-6, 
   1.6883288060141494*^-6, 8.67608876497975*^-9, 2.293624604763584*^-6, 
   6.041427534211831*^-6, 6.157419907358323*^-6, 1.694842422680509*^-6, 
   1.2834434920177297*^-6, 0.000021240527775203494, 
   0.00007490907934163341, 0.00015877562441272744, 
   0.00024557927920160254, 0.0002928225643454011, 0.0002664653315512557, 
   0.00016850582873230525, 0.00005072345479654165, 6.599592054202305*^-7, 
   0.00010000327864217852, 0.00037326466186961597, 0.0007555695560825767, 
   0.0011041283473396653, 0.0012577827903990455, 0.0011217448107364429, 
   0.0007350163171550192, 0.0002789663992515249, 0.00001038682486523871, 
   0.00014110235786007384, 0.0007194043941188388, 0.001576846366697224, 
   0.0023789526626855693, 0.002768985126219173, 0.002543439583306445, 
   0.0017732946180787793, 0.0008024356361319522, 0.00010977654758776367, 
   0.00008963549108936639, 0.0008518527055111629, 0.0021427573248835184, 
   0.003436436676906331, 0.004164999054276867, 0.003985414841968796, 
   0.002955611284805427, 0.0015292077743771387, 0.00036180304850829797, 
   0.00001293255494029024, 0.0006818825538994737, 0.002104311045525302, 
   0.0036633393307899872, 0.00466751076555728, 0.004667510765557384, 
   0.0036633393307902527, 0.0021043110455256104, 0.0006818825538996902, 
   0.000012932554940322067, 0.00036180304850813865, 0.001529207774376868, 
   0.002955611284805171, 0.003985414841968671, 0.004164999054276924, 
   0.0034364366769065436, 0.002142757324883786, 0.0008518527055113711, 
   0.00008963549108944006, 0.00010977654758768608, 0.0008024356361317772, 
   0.0017732946180785973, 0.0025434395833063422, 0.0027689851262191908, 
   0.0023789526626856955, 0.0015768463666973973, 0.0007194043941189876, 
   0.00014110235786014488, 0.000010386824865220665, 
   0.00027896639925144577, 0.0007350163171549318, 0.0011217448107363904, 
   0.0012577827903990481, 0.0011041283473397184, 0.0007555695560826533, 
   0.0003732646618696834, 0.0001000032786422154, 6.59959205422993*^-7, 
   0.00005072345479652223, 0.00016850582873228158, 
   0.00026646533155124324, 0.00029282256434540394, 0.0002455792792016166, 
   0.00015877562441274508, 0.00007490907934164718, 
   0.000021240527775210406, 1.2834434920190575*^-6, 
   1.6948424226795872*^-6, 6.1574199073578*^-6, 6.041427534212391*^-6, 
   2.2936246047643408*^-6, 8.676088765034618*^-9, 1.6883288060135475*^-6, 
   4.80516717730822*^-6, 5.012827571973208*^-6, 1.644665573573659*^-6, 
   3.819338707098021*^-7, 0.00001021915060642082, 0.00003634351035182767, 
   0.00007401395953891683, 0.00010845475222950529, 
   0.00012206402881309053, 0.00010524918141667668, 
   0.00006423498758797416, 0.000020341639285188734, 
   2.091031094586521*^-8, 0.000020567183026749987, 0.0000794528490281567, 
   0.0001537077805795834, 0.000210388833626175, 0.00022298247394823514, 
   0.00018510603613441408, 0.00011414306539352498, 
   0.000042788934941979024, 2.923748730301169*^-6, 
   0.00001021897448204556, 0.00005729762524471656, 
   0.00011855484719719292, 0.0001635948079982409, 
   0.00017200396377986624}, {0.012703898615801078, 0.01208281372829892, 
   0.008756244484764555, 0.0042318979518796915, 0.0007547547912534551, 
   0.00021594274126914302, 0.0031603125848690566, 0.008430398338446096, 
   0.013671593750210754, 0.01646907826940715, 0.015538934996314032, 
   0.011352575940878358, 0.005868242316102885, 0.001519054574340869, 
   1.5443973757356347*^-6, 0.0015023963255223203, 0.004744278864114616, 
   0.007773512311755005, 0.009015426229725388, 0.008010269917319327, 
   0.005466535872044667, 0.0026842652966004967, 0.0007547677994779646, 
   0.000028208938124556565, 0.00012147199543790439, 
   0.00037023828901023437, 0.00035490087153241775, 
   0.00012469688203924485, 6.408000701254579*^-7, 0.00016940292421932252, 
   0.0004462088035806131, 0.00045477578841210864, 0.0001251779658697171, 
   0.00009479279223222001, 0.0015687865876604945, 0.005532647785821058, 
   0.011726877630455707, 0.01813803703449242, 0.02162733978981915, 
   0.01968064271463762, 0.012445532750201367, 0.0037463417296774563, 
   0.00004874338155923791, 0.007386059513976546, 0.027568646193071023, 
   0.05580498743589171, 0.0815489031484586, 0.0928975396775097, 
   0.08285002296013955, 0.05428696274725025, 0.020603948742961124, 
   0.0007671519139928198, 0.010421562441427352, 0.05313389462549954, 
   0.11646299268343331, 0.17570509873380896, 0.20451218413297748, 
   0.1878538022710559, 0.13097230173631483, 0.0592664305118738, 
   0.00810789530834564, 0.006620313661109701, 0.06291628500061666, 
   0.15826014247220554, 0.2538089366295703, 0.30761922317184953, 
   0.29435546124436246, 0.218296051351122, 0.11294449326205723, 
   0.026722112363757367, 0.0009551748878008009, 0.050362600036991306, 
   0.15542057049730248, 0.2705675522291698, 0.34473382037688444, 
   0.34473382037689215, 0.27056755222918943, 0.15542057049732524, 
   0.0503626000370073, 0.0009551748878031517, 0.026722112363745602, 
   0.11294449326203725, 0.21829605135110314, 0.2943554612443532, 
   0.30761922317185375, 0.253808936629586, 0.1582601424722253, 
   0.06291628500063204, 0.006620313661115143, 0.008107895308339908, 
   0.05926643051186088, 0.13097230173630137, 0.18785380227104828, 
   0.2045121841329788, 0.1757050987338183, 0.11646299268344612, 
   0.05313389462551053, 0.010421562441432598, 0.000767151913991487, 
   0.020603948742955278, 0.054286962747243796, 0.08285002296013567, 
   0.0928975396775099, 0.08154890314846253, 0.055804987435897374, 
   0.027568646193076002, 0.00738605951397927, 0.00004874338155944194, 
   0.0037463417296760217, 0.012445532750199618, 0.019680642714636702, 
   0.021627339789819358, 0.018138037034493456, 0.01172687763045701, 
   0.005532647785822076, 0.0015687865876610051, 0.00009479279223231809, 
   0.00012517796586964902, 0.00045477578841207004, 0.0004462088035806545, 
   0.0001694029242193784, 6.408000701295104*^-7, 0.0001246968820392004, 
   0.00035490087153238603, 0.00037023828901026207, 
   0.00012147199543795666, 0.000028208938124516755, 
   0.0007547677994777132, 0.002684265296600021, 0.005466535872044113, 
   0.008010269917318943, 0.009015426229725404, 0.007773512311755476, 
   0.004744278864115313, 0.0015023963255228559, 1.544397375755391*^-6, 
   0.0015190545743402476, 0.005868242316101876, 0.011352575940877366, 
   0.015538934996313503, 0.01646907826940734, 0.013671593750211583, 
   0.00843039833844718, 0.0031603125848698958, 0.00021594274126938125, 
   0.000754754791253031, 0.004231897951878812, 0.008756244484763693, 
   0.012082813728298487, 0.012703898615801248}, 
  {0.049656063601930304, 0.04722841272020449, 0.034225763775280464, 
   0.01654133114649118, 0.002950129960241336, 0.0008440610885778536, 
   0.012352797157956782, 0.03295212034853678, 0.05343851909805324, 
   0.0643731206256389, 0.060737445080324644, 0.044374113019513606, 
   0.02293735352370561, 0.0059375686818260165, 6.036626758088082*^-6, 
   0.005872456145285321, 0.018544087932876957, 0.03038453260976016, 
   0.035238834298074694, 0.031309953307428515, 0.021367192950269523, 
   0.010492058565916352, 0.0029501808058315857, 0.00011026102049599597, 
   0.00047480079255478346, 0.0014471601657852782, 0.0013872103975447988, 
   0.00048740599187414824, 2.504712136059869*^-6, 0.0006621496781251844, 
   0.0017441081199106362, 0.001777594119487207, 0.0004892864169315457, 
   0.0003705190872849915, 0.006131957514036926, 0.021625606331437616, 
   0.0458371559062732, 0.07089662377175145, 0.08453535348653271, 
   0.07692624728202684, 0.04864618212831481, 0.014643424733573319, 
   0.00019052454117259574, 0.028870085639496786, 0.10775829453484077, 
   0.21812642632198967, 0.3187523486979725, 0.3631110636345696, 
   0.32383807002466825, 0.21219288318156154, 0.08053519790836859, 
   0.0029985869208834144, 0.0407350359974809, 0.20768585540035778, 
   0.4552219713692229, 0.686783153878255, 0.7993821684034625, 
   0.7342691118326266, 0.5119348903666889, 0.2316562601732802, 
   0.031691544248333564, 0.025876994626823215, 0.2459225426832322, 
   0.6185955932044288, 0.9920696851547974, 1.202399371481015, 
   1.1505549553855527, 0.8532595337669916, 0.4414691198757533, 
   0.10444942542773843, 0.0037335172779645468, 0.19685362314564747, 
   0.6074964833286095, 1.057574527979894, 1.3474701765235682, 
   1.3474701765235984, 1.0575745279799709, 0.6074964833286984, 
   0.19685362314571, 0.003733517277973735, 0.10444942542769244, 
   0.44146911987567516, 0.8532595337669179, 1.1505549553855166, 
   1.2023993714810315, 0.9920696851548587, 0.6185955932045061, 
   0.24592254268329228, 0.025876994626844486, 0.031691544248311165, 
   0.23165626017322968, 0.5119348903666364, 0.7342691118325968, 
   0.7993821684034678, 0.6867831538782914, 0.45522197136927295, 
   0.20768585540040074, 0.040735035997501404, 0.002998586920878205, 
   0.08053519790834573, 0.2121928831815363, 0.32383807002465315, 
   0.36311106363457035, 0.3187523486979878, 0.21812642632201182, 
   0.10775829453486023, 0.028870085639507437, 0.00019052454117339323, 
   0.014643424733567712, 0.04864618212830798, 0.07692624728202323, 
   0.08453535348653353, 0.0708966237717555, 0.04583715590627829, 
   0.02162560633144159, 0.006131957514038922, 0.0003705190872853748, 
   0.0004892864169312797, 0.0017775941194870563, 0.001744108119910798, 
   0.0006621496781254028, 2.50471213607571*^-6, 0.0004874059918739745, 
   0.0013872103975446747, 0.0014471601657853864, 0.0004748007925549878, 
   0.00011026102049584036, 0.0029501808058306034, 0.010492058565914493, 
   0.021367192950267355, 0.031309953307427016, 0.035238834298074756, 
   0.030384532609762004, 0.01854408793287968, 0.005872456145287415, 
   6.036626758165304*^-6, 0.005937568681823588, 0.022937353523701662, 
   0.04437411301950973, 0.060737445080322576, 0.06437312062563963, 
   0.05343851909805648, 0.03295212034854102, 0.012352797157960062, 
   0.0008440610885787848, 0.0029501299602396787, 0.01654133114648774, 
   0.03422576377527709, 0.0472284127202028, 0.04965606360193097}, 
  {0.10051642405641131, 0.09560224504607617, 0.06928159696405974, 
   0.03348383531379232, 0.005971808729792559, 0.001708592992572806, 
   0.025005183805261372, 0.06670342073556279, 0.10817307005377984, 
   0.130307467432632, 0.12294794115656758, 0.08982442098417087, 
   0.0464310012973116, 0.012019139822901516, 0.0000122196584076929, 
   0.011887335590758179, 0.03753792127670749, 0.061505974155385626, 
   0.0713323077711942, 0.06337925956163754, 0.043252599414685844, 
   0.02123857856496208, 0.005971911654119221, 0.00022319617563558447, 
   0.0009611168172601894, 0.002929417967314768, 0.002808064483179361, 
   0.0009866329268386298, 5.070170467512584*^-6, 0.0013403583169379538, 
   0.0035305156845810226, 0.0035982998118202296, 0.0009904393824608656, 
   0.0007500242870054022, 0.012412631954033368, 0.04377569341608658, 
   0.0927859895933372, 0.14351268671510634, 0.17112092305441293, 
   0.15571816877904884, 0.09847216869089533, 0.029641993009304497, 
   0.00038566982931191043, 0.058440350688042896, 0.21813002568811488, 
   0.44154302165100257, 0.6452353232739332, 0.7350285746461812, 
   0.6555301087326624, 0.4295320305414072, 0.16302359706398276, 
   0.006069897866366701, 0.08245800925945326, 0.4204086670923582, 
   0.9214843343354665, 1.3902226983482173, 1.6181515648625138, 
   1.4863462800467269, 1.036285617440086, 0.4689308252375164, 
   0.06415169607894951, 0.0523815779290674, 0.49780938705777217, 
   1.2521938401002564, 2.0081998034708017, 2.43396025262562, 
   2.329014049982889, 1.727212970682692, 0.8936450866700778, 
   0.21143203824829437, 0.007557582673936207, 0.3984814909971981, 
   1.2297264362425895, 2.140798162695153, 2.72762023088647, 
   2.727620230886531, 2.1407981626953085, 1.2297264362427696, 
   0.3984814909973246, 0.007557582673954808, 0.21143203824820128, 
   0.8936450866699196, 1.7272129706825428, 2.3290140499828156, 
   2.433960252625653, 2.008199803470926, 1.2521938401004127, 
   0.49780938705789385, 0.052381577929110454, 0.06415169607890416, 
   0.46893082523741414, 1.0362856174399797, 1.4863462800466667, 
   1.6181515648625244, 1.3902226983482913, 0.9214843343355679, 
   0.4204086670924452, 0.08245800925949477, 0.0060698978663561555, 
   0.1630235970639365, 0.42953203054135614, 0.6555301087326318, 
   0.7350285746461828, 0.6452353232739642, 0.44154302165104736, 
   0.2181300256881543, 0.058440350688064455, 0.00038566982931352475, 
   0.029641993009293148, 0.0984721686908815, 0.15571816877904154, 
   0.17112092305441456, 0.14351268671511455, 0.09278598959334751, 
   0.04377569341609462, 0.012412631954037408, 0.0007500242870061781, 
   0.000990439382460327, 0.0035982998118199248, 0.00353051568458135, 
   0.001340358316938396, 5.07017046754465*^-6, 0.000986632926838278, 
   0.0028080644831791103, 0.002929417967314987, 0.000961116817260603, 
   0.00022319617563526948, 0.005971911654117233, 0.021238578564958317, 
   0.04325259941468145, 0.0633792595616345, 0.07133230777119433, 
   0.06150597415538935, 0.03753792127671301, 0.011887335590762417, 
   0.000012219658407849218, 0.0120191398228966, 0.04643100129730361, 
   0.08982442098416302, 0.1229479411565634, 0.1303074674326335, 
   0.1081730700537864, 0.06670342073557137, 0.02500518380526801, 
   0.0017085929925746907, 0.005971808729789204, 0.03348383531378537, 
   0.06928159696405292, 0.09560224504607275, 0.10051642405641266}, 
  {0.13784619872475232, 0.13110699264189868, 0.09501138617621593, 
   0.045919057109926054, 0.008189618170769871, 0.0023431300049207007, 
   0.03429160526079383, 0.09147572724209616, 0.1483463687778176, 
   0.17870103537464704, 0.16860832932094713, 0.1231834011362252, 
   0.0636745396774808, 0.01648280618895127, 0.000016757793336043244, 
   0.016302052520609497, 0.05147874891688492, 0.08434805372129615, 
   0.09782368965896428, 0.08691703958407873, 0.059315743374762434, 
   0.029126158724607863, 0.008189759319117714, 0.00030608673826280116, 
   0.0013180562384053401, 0.004017344777841558, 0.0038509230547539726, 
   0.001353048516977231, 6.953129624277869*^-6, 0.001838140390025334, 
   0.004841678076256326, 0.0049346358626232165, 0.0013582686135242908, 
   0.0010285681955509525, 0.01702243336942266, 0.06003310394887462, 
   0.12724483665652403, 0.19681040703707622, 0.23467178609620568, 
   0.21354875922092814, 0.13504274810457398, 0.04065043197980424, 
   0.000528899833360914, 0.08014391946501354, 0.299139122298704, 
   0.6055232035898268, 0.8848627219998607, 1.0080033777583068, 
   0.8989807833564433, 0.5890515723821217, 0.2235672763795695, 
   0.008324135636346942, 0.11308125251697175, 0.5765399755675558, 
   1.2637050498460387, 1.906523398013247, 2.2191004531918552, 
   2.0383453412362913, 1.4211412164551371, 0.6430822856131021, 
   0.08797634346070575, 0.07183504057679187, 0.6826857634420183, 
   1.7172334028466758, 2.7540047488447033, 3.3378840505038774, 
   3.1939629426779637, 2.3686650677413343, 1.2255268665087855, 
   0.28995363727620427, 0.010364316607259037, 0.5464694880640433, 
   1.686422057874285, 2.9358474670651407, 3.740603427967342, 
   3.7406034279674256, 2.935847467065354, 1.6864220578745321, 
   0.5464694880642168, 0.010364316607284544, 0.2899536372760766, 
   1.2255268665085686, 2.368665067741129, 3.193962942677863, 
   3.337884050503923, 2.7540047488448733, 1.7172334028468903, 
   0.6826857634421851, 0.07183504057685092, 0.08797634346064356, 
   0.6430822856129619, 1.4211412164549913, 2.0383453412362087, 
   2.2191004531918694, 1.9065233980133482, 1.2637050498461777, 
   0.576539975567675, 0.11308125251702868, 0.00832413563633248, 
   0.22356727637950607, 0.5890515723820516, 0.8989807833564013, 
   1.008003377758309, 0.8848627219999032, 0.6055232035898883, 
   0.299139122298758, 0.0801439194650431, 0.000528899833363128, 
   0.040650431979788675, 0.135042748104555, 0.21354875922091815, 
   0.23467178609620792, 0.19681040703708746, 0.12724483665653816, 
   0.06003310394888566, 0.0170224333694282, 0.0010285681955520167, 
   0.001358268613523552, 0.004934635862622798, 0.0048416780762567755, 
   0.0018381403900259402, 6.953129624321842*^-6, 0.0013530485169767487, 
   0.0038509230547536283, 0.004017344777841858, 0.0013180562384059072, 
   0.00030608673826236916, 0.008189759319114987, 0.0291261587246027, 
   0.05931574337475642, 0.08691703958407457, 0.09782368965896444, 
   0.08434805372130127, 0.05147874891689248, 0.01630205252061531, 
   0.000016757793336257614, 0.01648280618894453, 0.06367453967746985, 
   0.12318340113621443, 0.16860832932094139, 0.1787010353746491, 
   0.14834636877782661, 0.09147572724210792, 0.03429160526080293, 
   0.0023431300049232854, 0.008189618170765271, 0.04591905710991651, 
   0.09501138617620658, 0.13110699264189396, 0.13784619872475418}, 
  {0.13784619872475645, 0.1311069926419026, 0.09501138617621877, 
   0.04591905710992743, 0.008189618170770116, 0.0023431300049207705, 
   0.034291605260794854, 0.09147572724209889, 0.14834636877782204, 
   0.17870103537465237, 0.16860832932095215, 0.12318340113622887, 
   0.0636745396774827, 0.016482806188951763, 0.000016757793336043742, 
   0.016302052520609983, 0.05147874891688645, 0.08434805372129868, 
   0.09782368965896719, 0.08691703958408133, 0.05931574337476421, 
   0.029126158724608733, 0.008189759319117959, 0.0003060867382628103, 
   0.0013180562384053794, 0.004017344777841677, 0.0038509230547540876, 
   0.0013530485169772715, 6.953129624278076*^-6, 0.0018381403900253888, 
   0.004841678076256471, 0.004934635862623364, 0.0013582686135243313, 
   0.0010285681955509833, 0.017022433369423166, 0.06003310394887642, 
   0.12724483665652783, 0.1968104070370821, 0.23467178609621267, 
   0.21354875922093453, 0.135042748104578, 0.04065043197980545, 
   0.0005288998333609298, 0.08014391946501592, 0.2991391222987129, 
   0.6055232035898449, 0.8848627219998871, 1.008003377758337, 
   0.8989807833564701, 0.5890515723821392, 0.22356727637957619, 
   0.00832413563634719, 0.11308125251697514, 0.576539975567573, 
   1.2637050498460765, 1.9065233980133038, 2.2191004531919214, 
   2.038345341236352, 1.4211412164551795, 0.6430822856131213, 
   0.08797634346070837, 0.07183504057679402, 0.6826857634420387, 
   1.717233402846727, 2.7540047488447854, 3.337884050503977, 
   3.1939629426780587, 2.368665067741405, 1.225526866508822, 
   0.2899536372762129, 0.010364316607259345, 0.5464694880640596, 
   1.6864220578743354, 2.9358474670652286, 3.7406034279674536, 
   3.7406034279675375, 2.9358474670654413, 1.6864220578745825, 
   0.5464694880642331, 0.010364316607284855, 0.28995363727608525, 
   1.225526866508605, 2.3686650677412002, 3.1939629426779583, 
   3.3378840505040226, 2.7540047488449555, 1.7172334028469416, 
   0.6826857634422056, 0.07183504057685305, 0.08797634346064619, 
   0.6430822856129811, 1.4211412164550337, 2.03834534123627, 
   2.219100453191936, 1.9065233980134053, 1.2637050498462155, 
   0.5765399755676922, 0.11308125251703206, 0.008324135636332728, 
   0.22356727637951274, 0.5890515723820693, 0.8989807833564282, 
   1.008003377758339, 0.8848627219999297, 0.6055232035899064, 
   0.29913912229876694, 0.0801439194650455, 0.0005288998333631437, 
   0.04065043197978989, 0.13504274810455902, 0.21354875922092453, 
   0.23467178609621492, 0.19681040703709335, 0.12724483665654196, 
   0.06003310394888745, 0.017022433369428706, 0.0010285681955520473, 
   0.0013582686135235925, 0.004934635862622946, 0.00484167807625692, 
   0.001838140390025995, 6.95312962432205*^-6, 0.001353048516976789, 
   0.0038509230547537437, 0.004017344777841978, 0.0013180562384059466, 
   0.0003060867382623783, 0.008189759319115232, 0.02912615872460357, 
   0.05931574337475819, 0.08691703958407716, 0.09782368965896737, 
   0.0843480537213038, 0.051478748916894024, 0.016302052520615794, 
   0.000016757793336258112, 0.016482806188945022, 0.06367453967747175, 
   0.1231834011362181, 0.1686083293209464, 0.17870103537465445, 
   0.14834636877783103, 0.09147572724211066, 0.03429160526080396, 
   0.0023431300049233557, 0.008189618170765516, 0.045919057109917887, 
   0.09501138617620941, 0.13110699264189787, 0.13784619872475828}, 
  {0.10051642405642078, 0.09560224504608517, 0.06928159696406626, 
   0.03348383531379547, 0.005971808729793121, 0.0017085929925729666, 
   0.025005183805263724, 0.06670342073556906, 0.10817307005379001, 
   0.13030746743264426, 0.12294794115657916, 0.08982442098417932, 
   0.04643100129731597, 0.012019139822902647, 0.00001221965840769405, 
   0.011887335590759298, 0.037537921276711024, 0.06150597415539141, 
   0.07133230777120092, 0.06337925956164349, 0.04325259941468991, 
   0.02123857856496408, 0.005971911654119783, 0.00022319617563560547, 
   0.0009611168172602799, 0.0029294179673150433, 0.002808064483179625, 
   0.0009866329268387226, 5.070170467513061*^-6, 0.00134035831693808, 
   0.003530515684581355, 0.0035982998118205684, 0.0009904393824609588, 
   0.0007500242870054727, 0.012412631954034536, 0.043775693416090694, 
   0.09278598959334593, 0.14351268671511985, 0.17112092305442902, 
   0.1557181687790635, 0.0984721686909046, 0.029641993009307286, 
   0.00038566982931194675, 0.05844035068804839, 0.21813002568813541, 
   0.4415430216510441, 0.6452353232739938, 0.7350285746462504, 
   0.6555301087327241, 0.4295320305414476, 0.1630235970639981, 
   0.006069897866367272, 0.08245800925946102, 0.42040866709239777, 
   0.9214843343355532, 1.390222698348348, 1.618151564862666, 
   1.4863462800468668, 1.0362856174401835, 0.4689308252375605, 
   0.06415169607895554, 0.052381577929072325, 0.497809387057819, 
   1.2521938401003743, 2.008199803470991, 2.433960252625849, 
   2.329014049983108, 1.7272129706828545, 0.8936450866701618, 
   0.21143203824831425, 0.007557582673936919, 0.39848149099723557, 
   1.2297264362427052, 2.1407981626953547, 2.7276202308867266, 
   2.727620230886788, 2.1407981626955097, 1.2297264362428852, 
   0.39848149099736213, 0.007557582673955519, 0.21143203824822118, 
   0.8936450866700036, 1.7272129706827053, 2.3290140499830345, 
   2.4339602526258823, 2.008199803471115, 1.2521938401005306, 
   0.4978093870579407, 0.05238157792911538, 0.06415169607891019, 
   0.46893082523745827, 1.0362856174400774, 1.4863462800468066, 
   1.6181515648626768, 1.390222698348422, 0.9214843343356546, 
   0.42040866709248476, 0.08245800925950253, 0.006069897866356727, 
   0.16302359706395184, 0.4295320305413966, 0.6555301087326935, 
   0.7350285746462519, 0.6452353232740249, 0.44154302165108894, 
   0.2181300256881748, 0.05844035068806995, 0.00038566982931356107, 
   0.029641993009295937, 0.09847216869089076, 0.1557181687790562, 
   0.17112092305443066, 0.14351268671512804, 0.09278598959335624, 
   0.04377569341609874, 0.012412631954038576, 0.0007500242870062487, 
   0.0009904393824604202, 0.003598299811820263, 0.0035305156845816823, 
   0.0013403583169385221, 5.0701704675451266*^-6, 0.000986632926838371, 
   0.0028080644831793744, 0.0029294179673152627, 0.0009611168172606934, 
   0.00022319617563529046, 0.005971911654117795, 0.021238578564960316, 
   0.043252599414685525, 0.06337925956164045, 0.07133230777120105, 
   0.06150597415539514, 0.03753792127671654, 0.011887335590763536, 
   0.000012219658407850368, 0.01201913982289773, 0.04643100129730798, 
   0.08982442098417147, 0.12294794115657497, 0.13030746743264576, 
   0.10817307005379657, 0.06670342073557765, 0.025005183805270365, 
   0.0017085929925748516, 0.005971808729789766, 0.03348383531378852, 
   0.06928159696405944, 0.09560224504608174, 0.10051642405642211}, 
  {0.04965606360193942, 0.047228412720213164, 0.03422576377528675, 
   0.016541331146494215, 0.0029501299602418775, 0.0008440610885780085, 
   0.012352797157959049, 0.03295212034854283, 0.053438519098063055, 
   0.06437312062565072, 0.060737445080335795, 0.04437411301952176, 
   0.022937353523709823, 0.005937568681827107, 6.03662675808919*^-6, 
   0.005872456145286399, 0.01854408793288036, 0.03038453260976574, 
   0.03523883429808116, 0.03130995330743427, 0.021367192950273447, 
   0.010492058565918278, 0.0029501808058321273, 0.00011026102049601621, 
   0.00047480079255487063, 0.0014471601657855438, 0.0013872103975450533, 
   0.00048740599187423775, 2.504712136060329*^-6, 0.000662149678125306, 
   0.0017441081199109565, 0.0017775941194875333, 0.0004892864169316356, 
   0.00037051908728505953, 0.006131957514038052, 0.021625606331441588, 
   0.04583715590628162, 0.07089662377176446, 0.08453535348654824, 
   0.07692624728204096, 0.048646182128323744, 0.014643424733576008, 
   0.0001905245411726307, 0.028870085639502087, 0.10775829453486055, 
   0.21812642632202972, 0.318752348698031, 0.36311106363463624, 
   0.3238380700247277, 0.21219288318160048, 0.08053519790838337, 
   0.002998586920883965, 0.04073503599748837, 0.2076858554003959, 
   0.4552219713693065, 0.686783153878381, 0.7993821684036093, 
   0.7342691118327613, 0.5119348903667829, 0.23165626017332272, 
   0.031691544248339386, 0.02587699462682797, 0.24592254268327735, 
   0.6185955932045424, 0.9920696851549796, 1.2023993714812358, 
   1.150554955385764, 0.8532595337671484, 0.4414691198758344, 
   0.1044494254277576, 0.003733517277965232, 0.1968536231456836, 
   0.607496483328721, 1.0575745279800883, 1.3474701765238155, 
   1.3474701765238457, 1.057574527980165, 0.60749648332881, 
   0.19685362314574614, 0.003733517277974421, 0.10444942542771161, 
   0.44146911987575627, 0.8532595337670745, 1.1505549553857277, 
   1.2023993714812522, 0.9920696851550409, 0.6185955932046197, 
   0.24592254268333744, 0.02587699462684924, 0.03169154424831698, 
   0.2316562601732722, 0.5119348903667303, 0.7342691118327316, 
   0.7993821684036145, 0.6867831538784175, 0.45522197136935655, 
   0.20768585540043888, 0.040735035997508884, 0.0029985869208787558, 
   0.08053519790836053, 0.21219288318157528, 0.3238380700247126, 
   0.363111063634637, 0.3187523486980463, 0.21812642632205187, 
   0.10775829453488002, 0.028870085639512738, 0.00019052454117342822, 
   0.014643424733570401, 0.04864618212831691, 0.07692624728203735, 
   0.08453535348654904, 0.07089662377176852, 0.04583715590628671, 
   0.021625606331445564, 0.006131957514040048, 0.00037051908728544285, 
   0.0004892864169313694, 0.0017775941194873826, 0.0017441081199111182, 
   0.0006621496781255244, 2.5047121360761698*^-6, 0.000487405991874064, 
   0.0013872103975449295, 0.001447160165785652, 0.00047480079255507495, 
   0.0001102610204958606, 0.002950180805831145, 0.010492058565916418, 
   0.02136719295027128, 0.03130995330743277, 0.03523883429808122, 
   0.030384532609767582, 0.018544087932883088, 0.005872456145288493, 
   6.036626758166412*^-6, 0.005937568681824678, 0.022937353523705874, 
   0.04437411301951788, 0.06073744508033373, 0.06437312062565145, 
   0.053438519098066295, 0.03295212034854707, 0.01235279715796233, 
   0.0008440610885789398, 0.0029501299602402204, 0.01654133114649078, 
   0.03422576377528338, 0.04722841272021147, 0.04965606360194009}, 
  {0.012703898615805818, 0.01208281372830343, 0.008756244484767821, 
   0.00423189795188127, 0.0007547547912537366, 0.00021594274126922357, 
   0.0031603125848702358, 0.008430398338449241, 0.013671593750215854, 
   0.016469078269413295, 0.01553893499631983, 0.011352575940882594, 
   0.0058682423161050745, 0.0015190545743414359, 1.5443973757362109*^-6, 
   0.0015023963255228808, 0.004744278864116386, 0.007773512311757905, 
   0.009015426229728752, 0.008010269917322316, 0.005466535872046707, 
   0.0026842652966014985, 0.0007547677994782461, 0.00002820893812456709, 
   0.00012147199543794971, 0.0003702382890103725, 0.00035490087153255013, 
   0.0001246968820392914, 6.408000701256968*^-7, 0.00016940292421938573, 
   0.0004462088035807796, 0.00045477578841227826, 0.0001251779658697638, 
   0.00009479279223225538, 0.0015687865876610797, 0.005532647785823123, 
   0.011726877630460082, 0.018138037034499187, 0.02162733978982722, 
   0.019680642714644966, 0.012445532750206009, 0.0037463417296788536, 
   0.00004874338155925609, 0.007386059513979301, 0.027568646193081307, 
   0.055804987435912536, 0.08154890314848902, 0.09289753967754436, 
   0.08285002296017045, 0.0542869627472705, 0.020603948742968812, 
   0.0007671519139931059, 0.01042156244143124, 0.05313389462551936, 
   0.11646299268347676, 0.1757050987338745, 0.20451218413305378, 
   0.18785380227112597, 0.13097230173636368, 0.059266430511895916, 
   0.008107895308348665, 0.006620313661112171, 0.06291628500064014, 
   0.15826014247226458, 0.253808936629665, 0.3076192231719643, 
   0.29435546124447226, 0.21829605135120345, 0.11294449326209938, 
   0.02672211236376734, 0.0009551748878011572, 0.0503626000370101, 
   0.15542057049736047, 0.27056755222927076, 0.34473382037701306, 
   0.34473382037702077, 0.27056755222929035, 0.15542057049738323, 
   0.05036260003702609, 0.000955174887803508, 0.026722112363755574, 
   0.11294449326207938, 0.21829605135118457, 0.29435546124446305, 
   0.3076192231719685, 0.2538089366296807, 0.15826014247228434, 
   0.0629162850006555, 0.006620313661117613, 0.008107895308342933, 
   0.059266430511882996, 0.13097230173635024, 0.18785380227111836, 
   0.2045121841330551, 0.17570509873388385, 0.11646299268348957, 
   0.05313389462553036, 0.010421562441436485, 0.0007671519139917732, 
   0.020603948742962966, 0.05428696274726405, 0.08285002296016658, 
   0.09289753967754455, 0.08154890314849295, 0.0558049874359182, 
   0.027568646193086285, 0.007386059513982026, 0.000048743381559460125, 
   0.0037463417296774194, 0.012445532750204262, 0.019680642714644044, 
   0.021627339789827428, 0.018138037034500225, 0.011726877630461385, 
   0.00553264778582414, 0.0015687865876615904, 0.00009479279223235345, 
   0.00012517796586969572, 0.0004547757884122397, 0.00044620880358082094, 
   0.00016940292421944162, 6.408000701297495*^-7, 0.00012469688203924694, 
   0.0003549008715325184, 0.0003702382890104002, 0.00012147199543800197, 
   0.000028208938124527278, 0.0007547677994779948, 0.0026842652966010223, 
   0.005466535872046152, 0.008010269917321932, 0.009015426229728767, 
   0.007773512311758377, 0.004744278864117084, 0.0015023963255234164, 
   1.5443973757559673*^-6, 0.0015190545743408144, 0.005868242316104065, 
   0.0113525759408816, 0.0155389349963193, 0.016469078269413483, 
   0.013671593750216683, 0.008430398338450325, 0.003160312584871075, 
   0.0002159427412694618, 0.0007547547912533126, 0.004231897951880391, 
   0.008756244484766959, 0.012082813728302996, 0.012703898615805988}, 
  {0.0001720039637802988, 0.0001635948079986604, 0.00011855484719750433, 
   0.00005729762524487332, 0.000010218974482077137, 
   2.9237487303053355*^-6, 0.000042788934942075844, 
   0.00011414306539379888, 0.00018510603613487082, 
   0.00022298247394879632, 0.0002103888336267141, 0.00015370778057998544, 
   0.00007945284902837125, 0.0000205671830268104, 2.0910310945650587*^-8, 
   0.00002034163928523291, 0.00006423498758812712, 
   0.00010524918141693639, 0.00012206402881339892, 
   0.00010845475222978469, 0.00007401395953911147, 
   0.000036343510351926004, 0.00001021915060645006, 
   3.8193387071130676*^-7, 1.6446655735771097*^-6, 5.012827571985507*^-6, 
   4.805167177320798*^-6, 1.688328806018418*^-6, 8.676088765001685*^-9, 
   2.2936246047693827*^-6, 6.041427534227105*^-6, 6.15741990737389*^-6, 
   1.694842422684794*^-6, 1.2834434920209745*^-6, 
   0.000021240527775257196, 0.0000749090793418228, 
   0.00015877562441312887, 0.0002455792792022234, 0.00029282256434614147, 
   0.00026646533155192943, 0.00016850582873273128, 
   0.00005072345479666989, 6.59959205421899*^-7, 0.00010000327864243135, 
   0.0003732646618705597, 0.0007555695560844869, 0.0011041283473424567, 
   0.0012577827904022255, 0.001121744810739279, 0.0007350163171568775, 
   0.00027896639925223025, 0.00001038682486526497, 0.0001411023578604306, 
   0.0007194043941206576, 0.0015768463667012106, 0.0023789526626915836, 
   0.0027689851262261735, 0.0025434395833128756, 0.0017732946180832624, 
   0.000802435636133981, 0.00010977654758804121, 0.000089635491089593, 
   0.0008518527055133166, 0.0021427573248889355, 0.003436436676915019, 
   0.004164999054287397, 0.0039854148419788725, 0.0029556112848128993, 
   0.001529207774381005, 0.0003618030485092127, 0.000012932554940322935, 
   0.0006818825539011976, 0.0021043110455306224, 0.003663339330799249, 
   0.00466751076556908, 0.004667510765569184, 0.0036633393307995148, 
   0.002104311045530931, 0.0006818825539014142, 0.000012932554940354763, 
   0.0003618030485090534, 0.001529207774380734, 0.002955611284812644, 
   0.003985414841978747, 0.004164999054287454, 0.0034364366769152315, 
   0.002142757324889203, 0.0008518527055135247, 0.00008963549108966669, 
   0.00010977654758796362, 0.000802435636133806, 0.0017732946180830805, 
   0.0025434395833127724, 0.0027689851262261917, 0.0023789526626917103, 
   0.001576846366701384, 0.0007194043941208065, 0.0001411023578605016, 
   0.000010386824865246925, 0.0002789663992521511, 0.0007350163171567901, 
   0.0011217448107392264, 0.001257782790402228, 0.0011041283473425098, 
   0.0007555695560845636, 0.0003732646618706271, 0.00010000327864246824, 
   6.599592054246615*^-7, 0.00005072345479665047, 0.00016850582873270762, 
   0.00026646533155191696, 0.00029282256434614423, 
   0.00024557927920223745, 0.0001587756244131465, 0.00007490907934183656, 
   0.000021240527775264108, 1.2834434920223025*^-6, 
   1.6948424226838722*^-6, 6.157419907373368*^-6, 6.041427534227665*^-6, 
   2.2936246047701396*^-6, 8.676088765056555*^-9, 1.688328806017816*^-6, 
   4.805167177320369*^-6, 5.012827571985882*^-6, 1.6446655735778171*^-6, 
   3.8193387071076773*^-7, 0.000010219150606446656, 
   0.00003634351035191956, 0.00007401395953910396, 0.0001084547522297795, 
   0.00012206402881339914, 0.00010524918141694277, 
   0.00006423498758813656, 0.000020341639285240163, 
   2.0910310945918078*^-8, 0.000020567183026801988, 
   0.00007945284902835757, 0.000153707780579972, 0.0002103888336267069, 
   0.0002229824739487989, 0.00018510603613488207, 0.00011414306539381355, 
   0.00004278893494208721, 2.923748730308561*^-6, 
   0.000010218974482071396, 0.000057297625244861416, 
   0.00011855484719749266, 0.0001635948079986545, 
   0.00017200396378030112}, {0.0030213564319168072, 0.002873644388836822, 
   0.0020824895092104935, 0.0010064683671376267, 0.0001795026323838352, 
   0.000051357461987910455, 0.0007516142126075722, 0.0020049938222746685, 
   0.003251502468728429, 0.003916825618800558, 0.003695610506357154, 
   0.0026999726127485265, 0.0013956386304713765, 0.0003612753413278104, 
   3.6730259629201705*^-7, 0.00035731352545265914, 0.0011283274445429586, 
   0.0018487672274472464, 0.0021441304633660033, 0.0019050750693161405, 
   0.0013001011592428098, 0.0006383963273107074, 0.0001795057261178123, 
   6.708905605887336*^-6, 0.000028889572076527366, 0.0000880534290829121, 
   0.00008440574530118251, 0.00002965654386761545, 1.524008866882954*^-7, 
   0.00004028894043903632, 0.00010612142614231474, 0.0001081589042036225, 
   0.00002977095958907599, 0.000022544481908407578, 
   0.00037310305995652576, 0.0013158244944138087, 0.002788992436621746, 
   0.004313752534859416, 0.005143610174749489, 0.004680629013849973, 
   0.002959909517593474, 0.0008909889808976224, 0.000011592593253554706, 
   0.001756619687700977, 0.006556625569340752, 0.013272048433443522, 
   0.019394700044039943, 0.022093735750125233, 0.019704144162778978, 
   0.012911018028876948, 0.004900218030707604, 0.00018245102859342502, 
   0.002478550535177082, 0.012636784906317504, 0.027698285594526747, 
   0.04178778076201579, 0.04863894317977145, 0.04467709566303816, 
   0.031149021117169138, 0.014095280231619592, 0.0019282932255700693, 
   0.001574503061321794, 0.01496332174144459, 0.03763886298492133, 
   0.06036314413041008, 0.07316079469931379, 0.07000628649494402, 
   0.05191714754330668, 0.026861484138614007, 0.006355295213409641, 
   0.00022716835816627656, 0.011977690483184185, 0.03696353021427145, 
   0.06434883014406365, 0.08198772494921036, 0.08198772494921219, 
   0.06434883014406831, 0.03696353021427686, 0.011977690483187989, 
   0.00022716835816683563, 0.006355295213406843, 0.02686148413860925, 
   0.05191714754330219, 0.07000628649494181, 0.07316079469931479, 
   0.060363144130413805, 0.037638862984926025, 0.014963321741448246, 
   0.0015745030613230884, 0.0019282932255687063, 0.014095280231616518, 
   0.031149021117165943, 0.04467709566303635, 0.04863894317977177, 
   0.04178778076201801, 0.027698285594529793, 0.012636784906320118, 
   0.0024785505351783295, 0.00018245102859310806, 0.004900218030706213, 
   0.012911018028875414, 0.019704144162778058, 0.022093735750125278, 
   0.019394700044040876, 0.01327204843344487, 0.0065566255693419355, 
   0.0017566196877016249, 0.00001159259325360323, 0.0008909889808972813, 
   0.002959909517593058, 0.004680629013849753, 0.0051436101747495385, 
   0.004313752534859662, 0.002788992436622056, 0.0013158244944140504, 
   0.00037310305995664724, 0.0000225444819084309, 
   0.000029770959589059798, 0.00010815890420361333, 
   0.00010612142614232459, 0.00004028894043904961, 
   1.5240088668925924*^-7, 0.000029656543867604874, 
   0.00008440574530117496, 0.00008805342908291868, 
   0.000028889572076539797, 6.708905605877867*^-6, 
   0.00017950572611775254, 0.0006383963273105942, 0.0013001011592426778, 
   0.001905075069316049, 0.002144130463366007, 0.0018487672274473588, 
   0.0011283274445431245, 0.0003573135254527865, 3.673025962967157*^-7, 
   0.00036127534132766257, 0.0013956386304711365, 0.00269997261274829, 
   0.0036956105063570277, 0.003916825618800603, 0.0032515024687286265, 
   0.0020049938222749266, 0.0007516142126077718, 0.00005135746198796712, 
   0.00017950263238373433, 0.0010064683671374176, 0.0020824895092102884, 
   0.002873644388836719, 0.0030213564319168476}, 
  {0.006677968167364749, 0.00635148688524778, 0.004602832854962422, 
   0.0022245517431191035, 0.0003967465911517568, 0.00011351308726403012, 
   0.0016612590732130123, 0.004431547625256114, 0.007186649596486346, 
   0.008657183417076917, 0.008168241608215306, 0.005967627973390912, 
   0.0030847172643975605, 0.000798510630376159, 8.11832400810913*^-7, 
   0.0007897540070199284, 0.0024938913785294715, 0.00408624701254706, 
   0.004739075082230966, 0.004210701701706301, 0.002873555090707865, 
   0.0014110186758861882, 0.0003967534290927555, 0.000014828392175347341, 
   0.00006385332119634915, 0.00019462053209986428, 
   0.00018655822077450076, 0.00006554852443422187, 3.368448221572231*^-7, 
   0.00008904883214260473, 0.00023455541298188698, 0.0002390587590589618, 
   0.0000658014123549214, 0.00004982905391224021, 0.0008246529046410325, 
   0.0029083076709223495, 0.0061643844844102465, 0.00953449311884212, 
   0.0113686901186031, 0.010345383691755914, 0.006542154817605919, 
   0.0019693128520200075, 0.000025622587228257648, 0.0038825774518735545, 
   0.014491814462820364, 0.02933461144073963, 0.042867232790378934, 
   0.04883278996113074, 0.04355118320175311, 0.028536642183065238, 
   0.010830731414714858, 0.00040326329862275473, 0.005478228718819748, 
   0.027930517052132845, 0.06122027429033911, 0.09236165146411376, 
   0.10750446746950383, 0.09874777417730819, 0.06884727974086159, 
   0.03115416364070781, 0.004262019747710649, 0.003480053267417608, 
   0.03307275672999949, 0.08319148519317396, 0.13341794126858195, 
   0.16170401245614366, 0.1547317449176501, 0.1147501350625577, 
   0.05937072968647901, 0.014046823036509498, 0.0005021000000004898, 
   0.02647375030641672, 0.08169882755863032, 0.1422273237178428, 
   0.18121377919589965, 0.1812137791959037, 0.14222732371785313, 
   0.0816988275586423, 0.026473750306425126, 0.0005021000000017256, 
   0.014046823036503314, 0.0593707296864685, 0.11475013506254778, 
   0.15473174491764524, 0.16170401245614588, 0.13341794126859016, 
   0.08319148519318435, 0.03307275673000758, 0.0034800532674204685, 
   0.004262019747707637, 0.031154163640701015, 0.06884727974085453, 
   0.0987477741773042, 0.10750446746950454, 0.09236165146411868, 
   0.06122027429034584, 0.027930517052138625, 0.005478228718822506, 
   0.0004032632986220541, 0.010830731414711785, 0.028536642183061848, 
   0.043551183201751074, 0.04883278996113084, 0.042867232790380995, 
   0.029334611440742606, 0.014491814462822982, 0.0038825774518749866, 
   0.0000256225872283649, 0.0019693128520192537, 0.006542154817605, 
   0.01034538369175543, 0.01136869011860321, 0.009534493118842665, 
   0.006164384484410931, 0.0029083076709228843, 0.0008246529046413008, 
   0.000049829053912291766, 0.0000658014123548856, 
   0.00023905875905894152, 0.00023455541298190874, 
   0.00008904883214263412, 3.368448221593534*^-7, 0.0000655485244341985, 
   0.0001865582207744841, 0.00019462053209987886, 0.00006385332119637662, 
   0.000014828392175326413, 0.00039675342909262337, 0.001411018675885938, 
   0.0028735550907075737, 0.0042107017017061, 0.004739075082230974, 
   0.004086247012547308, 0.0024938913785298384, 0.0007897540070202099, 
   8.118324008212983*^-7, 0.0007985106303758324, 0.0030847172643970297, 
   0.00596762797339039, 0.008168241608215027, 0.008657183417077016, 
   0.007186649596486782, 0.004431547625256684, 0.0016612590732134533, 
   0.00011351308726415534, 0.00039674659115153393, 0.0022245517431186417, 
   0.0046028328549619696, 0.006351486885247553, 0.006677968167364838}, 
  {0.004942247756680928, 0.004700624654608305, 0.003406476308615323, 
   0.0016463519421641073, 0.00029362523164951705, 0.00008400905587214923, 
   0.001229468862696422, 0.0032797110978427415, 0.005318714009429411, 
   0.006407030439485885, 0.006045173135373069, 0.004416537369604783, 
   0.0022829454405710213, 0.0005909637890981118, 6.008229990248585*^-7, 
   0.0005844831648941918, 0.0018456855082325187, 0.0030241601374650265, 
   0.0035073068045397868, 0.003116266882045154, 0.002126667999130986, 
   0.0010442703095850966, 0.0002936302922903758, 0.000010974234396914666, 
   0.000047256729222148516, 0.00014403526103571888, 
   0.0001380684850549395, 0.000048511319569020575, 
   2.4929297728489644*^-7, 0.00006590348738746938, 
   0.00017359036979125848, 0.00017692321767090983, 
   0.00004869847750799921, 0.0000368776136308664, 0.0006103112302811226, 
   0.002152387777557496, 0.004562153431380863, 0.00705631204682462, 
   0.008413769252398099, 0.007656438015451152, 0.00484173466552048, 
   0.0014574540910007902, 0.000018962829872127044, 0.0028734278482244148, 
   0.010725139102807915, 0.021710034242842687, 0.03172529125381763, 
   0.036140296058510275, 0.03223147102310948, 0.021119471114237974, 
   0.008015635399279145, 0.00029844813317769173, 0.004054341517901566, 
   0.02067088847749254, 0.0453080571353214, 0.06835524718171804, 
   0.07956218117074365, 0.07308150520843594, 0.05095267083118346, 
   0.023056653087539163, 0.003154246472750858, 0.0025755267205491883, 
   0.024476570366850962, 0.06156856708006251, 0.09874029111999232, 
   0.11967431901117502, 0.11451426542339384, 0.0849245733699801, 
   0.04393924143566284, 0.01039580871019315, 0.000371595451856004, 
   0.019592760819411168, 0.06046387720120568, 0.10525996140838556, 
   0.13411315706586094, 0.13411315706586394, 0.1052599614083932, 
   0.06046387720121454, 0.01959276081941739, 0.00037159545185691854, 
   0.010395808710188574, 0.043939241435655065, 0.08492457336997276, 
   0.11451426542339024, 0.11967431901117667, 0.09874029111999841, 
   0.0615685670800702, 0.024476570366856944, 0.0025755267205513055, 
   0.0031542464727486283, 0.023056653087534136, 0.050952670831178236, 
   0.07308150520843298, 0.07956218117074418, 0.06835524718172167, 
   0.04530805713532638, 0.020670888477496815, 0.004054341517903607, 
   0.0002984481331771732, 0.00801563539927687, 0.021119471114235466, 
   0.03223147102310797, 0.03614029605851035, 0.03172529125381915, 
   0.02171003424284489, 0.01072513910280985, 0.0028734278482254747, 
   0.000018962829872206418, 0.001457454091000232, 0.0048417346655198, 
   0.007656438015450794, 0.008413769252398179, 0.007056312046825023, 
   0.004562153431381369, 0.0021523877775578917, 0.0006103112302813212, 
   0.00003687761363090456, 0.000048698477507972725, 
   0.00017692321767089484, 0.00017359036979127458, 
   0.00006590348738749112, 2.4929297728647303*^-7, 
   0.00004851131956900328, 0.00013806848505492717, 
   0.00014403526103572967, 0.00004725672922216885, 
   0.000010974234396899177, 0.00029363029229027805, 
   0.0010442703095849114, 0.00212666799913077, 0.0031162668820450042, 
   0.003507306804539793, 0.00302416013746521, 0.00184568550823279, 
   0.0005844831648944002, 6.008229990325444*^-7, 0.0005909637890978701, 
   0.0022829454405706284, 0.004416537369604397, 0.006045173135372863, 
   0.006407030439485959, 0.0053187140094297335, 0.0032797110978431635, 
   0.0012294688626967485, 0.00008400905587224192, 0.0002936252316493521, 
   0.0016463519421637653, 0.0034064763086149876, 0.004700624654608136, 
   0.004942247756680994}, {0.0011824770792953393, 0.001124666586156284, 
   0.000815029993317324, 0.00039390446046149255, 0.00007025246880004886, 
   0.00002009991969499544, 0.0002941614466576582, 0.0007847002802858416, 
   0.001272550005000352, 0.001532939466824209, 0.0014463618630384436, 
   0.0010566961565917602, 0.0005462151615341033, 0.00014139338408468153, 
   1.437522884400084*^-7, 0.0001398428366500041, 0.00044159680301786693, 
   0.0007235574221945878, 0.0008391545933363105, 0.0007455947865026156, 
   0.0005088243827606279, 0.00024985103266095634, 0.00007025367960373912, 
   2.625683955164752*^-6, 0.000011306596087199055, 
   0.00003446172736986371, 0.000033034122728832945, 
   0.000011606768074140822, 5.964557953821637*^-8, 
   0.00001576800013232181, 0.00004153305207880077, 
   0.00004233046581046534, 0.000011651547288770688, 
   8.823299641071427*^-6, 0.0001460224328228794, 0.000514978070307512, 
   0.0010915361047094368, 0.0016882859116980483, 0.002013069716707638, 
   0.0018318714293669074, 0.0011584284212114372, 0.00034870895624444537, 
   4.5370270343196875*^-6, 0.0006874933707929158, 0.002566085673098987, 
   0.0051943203066207155, 0.0075905603256931535, 0.008646889802391401, 
   0.007711668373014639, 0.005053022784150698, 0.001917812623380357, 
   0.00007140639122432549, 0.0009700375522601686, 0.004945695367105631, 
   0.010840358822055723, 0.016354605641266156, 0.019035965059819124, 
   0.017485405241483436, 0.012190883248479042, 0.005516510936632783, 
   0.0007546817440372321, 0.0006162178555385453, 0.00585623887419154, 
   0.014730831589496068, 0.023624499782413065, 0.028633153613089695, 
   0.02739856453623924, 0.020318965463272717, 0.01051285739551598, 
   0.002487290424468267, 0.00008890754292844478, 0.004687743660311444, 
   0.014466524633271154, 0.02518438934281933, 0.032087775050925, 
   0.03208777505092572, 0.025184389342821155, 0.014466524633273274, 
   0.004687743660312933, 0.00008890754292866358, 0.0024872904244671716, 
   0.010512857395514118, 0.02031896546327096, 0.027398564536238377, 
   0.028633153613090087, 0.023624499782414522, 0.014730831589497909, 
   0.00585623887419297, 0.0006162178555390519, 0.0007546817440366987, 
   0.00551651093663158, 0.012190883248477792, 0.01748540524148273, 
   0.01903596505981925, 0.016354605641267027, 0.010840358822056915, 
   0.004945695367106654, 0.0009700375522606568, 0.00007140639122420145, 
   0.0019178126233798127, 0.005053022784150098, 0.007711668373014279, 
   0.008646889802391419, 0.007590560325693519, 0.005194320306621243, 
   0.0025660856730994504, 0.0006874933707931693, 4.537027034338679*^-6, 
   0.00034870895624431185, 0.0011584284212112744, 0.0018318714293668215, 
   0.002013069716707657, 0.0016882859116981448, 0.001091536104709558, 
   0.0005149780703076067, 0.0001460224328229269, 8.823299641080555*^-6, 
   0.000011651547288764352, 0.000042330465810461746, 
   0.00004153305207880462, 0.00001576800013232701, 5.964557953859359*^-8, 
   0.000011606768074136684, 0.00003303412272883, 0.000034461727369866284, 
   0.00001130659608720392, 2.625683955161047*^-6, 0.00007025367960371573, 
   0.00024985103266091205, 0.0005088243827605763, 0.0007455947865025798, 
   0.0008391545933363119, 0.0007235574221946317, 0.00044159680301793187, 
   0.00013984283665005395, 1.4375228844184734*^-7, 0.0001413933840846237, 
   0.0005462151615340093, 0.0010566961565916678, 0.0014463618630383944, 
   0.0015329394668242265, 0.0012725500050004292, 0.0007847002802859425, 
   0.0002941614466577363, 0.000020099919695017614, 0.0000702524688000094, 
   0.00039390446046141074, 0.0008150299933172438, 0.0011246665861562436, 
   0.0011824770792953551}, {0.00005548431204388892, 
   0.000052771722094449976, 0.00003824292180047615, 
   0.000018482825910460164, 3.296393620651252*^-6, 9.431305146978598*^-7, 
   0.00001380267388130812, 0.00003681978786282453, 
   0.000059710723197246015, 0.00007192874450670322, 
   0.00006786634121062902, 0.00004958240655527471, 
   0.000025629564408742302, 6.63447501931366*^-6, 6.745159773905808*^-9, 
   6.561720071914796*^-6, 0.000020720650949807927, 
   0.00003395083633979629, 0.00003937489878237682, 
   0.00003498487583138637, 0.000023875110412671767, 
   0.000011723536044275377, 3.2964504341074712*^-6, 
   1.2320261461965047*^-7, 5.305292732018189*^-7, 1.6170167425996903*^-6, 
   1.5500305297037436*^-6, 5.446139742771547*^-7, 2.7986960636134476*^-9, 
   7.398677361012194*^-7, 1.9488181733285912*^-6, 1.986234503074386*^-6, 
   5.467151092260743*^-7, 4.140077800355125*^-7, 6.851679723873004*^-6, 
   0.00002416385437739654, 0.0000512171702109948, 0.00007921792649019274, 
   0.00009445746584320272, 0.00008595526102869376, 
   0.00005435589841733544, 0.000016362157778394642, 
   2.1288685263461213*^-7, 0.000032258635182942026, 
   0.00012040613785294037, 0.00024372843566676015, 0.0003561650581419282, 
   0.00040573025930524387, 0.00036184770248765685, 0.000237098458676063, 
   0.00008998780263948609, 3.3505380882134977*^-6, 
   0.00004551620254319591, 0.00023206243049212407, 0.000508652439934896, 
   0.0007673925005764245, 0.0008932075250583115, 0.0008204519965921523, 
   0.0005720218870139206, 0.0002588462977938296, 0.00003541125499442324, 
   0.000028914238070552233, 0.0002747870472828342, 0.0006912016062625405, 
   0.0011085112267793947, 0.001343527800823002, 0.0012855982842299464, 
   0.0009534086029346589, 0.0004932853840628461, 0.00011670889903186487, 
   4.17172894195711*^-6, 0.00021995879377677112, 0.0006787997678748631, 
   0.0011817045263697449, 0.0015056259058996658, 0.0015056259058996995, 
   0.0011817045263698305, 0.0006787997678749625, 0.00021995879377684097, 
   4.171728941967377*^-6, 0.0001167088990318135, 0.0004932853840627587, 
   0.0009534086029345765, 0.001285598284229906, 0.0013435278008230205, 
   0.0011085112267794632, 0.0006912016062626268, 0.00027478704728290136, 
   0.000028914238070576, 0.000035411254994398206, 0.00025884629779377317, 
   0.0005720218870138618, 0.000820451996592119, 0.0008932075250583174, 
   0.0007673925005764654, 0.0005086524399349519, 0.00023206243049217208, 
   0.00004551620254321882, 3.350538088207677*^-6, 0.00008998780263946056, 
   0.00023709845867603483, 0.00036184770248763994, 
   0.00040573025930524474, 0.00035616505814194534, 0.0002437284356667849, 
   0.00012040613785296212, 0.00003225863518295393, 
   2.1288685263550324*^-7, 0.000016362157778388377, 
   0.0000543558984173278, 0.00008595526102868974, 0.00009445746584320363, 
   0.00007921792649019726, 0.000051217170211000494, 
   0.000024163854377400983, 6.851679723875234*^-6, 
   4.1400778003594086*^-7, 5.467151092257769*^-7, 1.986234503074218*^-6, 
   1.948818173328772*^-6, 7.398677361014635*^-7, 2.7986960636311476*^-9, 
   5.446139742769605*^-7, 1.5500305297036052*^-6, 1.6170167425998112*^-6, 
   5.305292732020471*^-7, 1.232026146194766*^-7, 3.2964504341063735*^-6, 
   0.000011723536044273298, 0.000023875110412669344, 
   0.00003498487583138469, 0.00003937489878237689, 
   0.00003395083633979835, 0.000020720650949810973, 
   6.561720071917136*^-6, 6.745159773992095*^-9, 6.6344750193109465*^-6, 
   0.000025629564408737894, 0.00004958240655527037, 
   0.0000678663412106267, 0.00007192874450670404, 0.00005971072319724964, 
   0.000036819787862829265, 0.000013802673881311785, 
   9.431305146989003*^-7, 3.2963936206494003*^-6, 
   0.000018482825910456325, 0.00003824292180047239, 
   0.00005277172209444808, 0.00005548431204388966}, 
  {0.0014716941283774462, 0.0013997440121332877, 0.0010143747194925796, 
   0.0004902478802788489, 0.00008743522191454552, 
   0.000025016073726867346, 0.0003661091461485863, 0.0009766267907036301, 
   0.0015837976086113632, 0.0019078746235213669, 0.0018001213711569073, 
   0.0013151489837433816, 0.0006798116091514556, 0.00017597619166778806, 
   1.789120504255809*^-7, 0.00017404640241830394, 0.0005496050904419488, 
   0.0009005292605098639, 0.001044399853018681, 0.0009279566502030037, 
   0.0006332755785256647, 0.00031096103609491775, 0.00008743672886357039, 
   3.2678888474469102*^-6, 0.000014072028426447184, 
   0.00004289057497350904, 0.00004111379857366424, 
   0.000014445618205412576, 7.423403863555036*^-8, 
   0.000019624628347825144, 0.00005169144497446893, 
   0.00005268389474565404, 0.000014501349778056166, 
   0.000010981353044422454, 0.00018173743978605055, 
   0.0006409343703865737, 0.0013585102868718232, 0.002101216595884485, 
   0.002505437893019087, 0.002279921085783961, 0.0014417635111019496, 
   0.0004339981995451442, 5.646719216474828*^-6, 0.0008556444558716448, 
   0.003193713674571815, 0.00646477705996713, 0.009447103253007162, 
   0.010761795872178473, 0.009597832603506287, 0.006288920176299393, 
   0.0023868822716115222, 0.00008887137732605083, 0.0012072949192534481, 
   0.006155342001935734, 0.013491756167849922, 0.020354709207998537, 
   0.02369189094407544, 0.021762086282066693, 0.015172599630610266, 
   0.006865770928439874, 0.0009392661481058974, 0.0007669359649134578, 
   0.00728859148006439, 0.018333783154001988, 0.029402715895643826, 
   0.03563641510448992, 0.034099863126296405, 0.02528869496973465, 
   0.0130841525576717, 0.003095646230572836, 0.00011065306143120402, 
   0.005834298982209575, 0.018004830481365558, 0.03134413222173043, 
   0.039935987734564755, 0.03993598773456565, 0.0313441322217327, 
   0.018004830481368198, 0.0058342989822114276, 0.00011065306143147636, 
   0.003095646230571473, 0.013084152557669385, 0.025288694969732465, 
   0.03409986312629533, 0.03563641510449041, 0.02940271589564564, 
   0.018333783154004277, 0.0072885914800661705, 0.0007669359649140882, 
   0.0009392661481052334, 0.006865770928438377, 0.01517259963060871, 
   0.02176208628206581, 0.023691890944075592, 0.02035470920799962, 
   0.013491756167851405, 0.006155342001937008, 0.001207294919254056, 
   0.00008887137732589642, 0.002386882271610845, 0.006288920176298646, 
   0.009597832603505838, 0.010761795872178495, 0.009447103253007617, 
   0.0064647770599677865, 0.003193713674572392, 0.0008556444558719605, 
   5.646719216498464*^-6, 0.00043399819954497804, 0.001441763511101747, 
   0.0022799210857838543, 0.0025054378930191115, 0.002101216595884605, 
   0.0013585102868719741, 0.0006409343703866916, 0.0001817374397861097, 
   0.000010981353044433816, 0.000014501349778048279, 
   0.00005268389474564957, 0.00005169144497447373, 
   0.00001962462834783162, 7.423403863601984*^-8, 
   0.000014445618205407426, 0.000041113798573660565, 
   0.00004289057497351225, 0.000014072028426453239, 
   3.267888847442298*^-6, 0.00008743672886354128, 0.0003109610360948627, 
   0.0006332755785256005, 0.0009279566502029593, 0.001044399853018683, 
   0.0009005292605099185, 0.0005496050904420296, 0.00017404640241836598, 
   1.7891205042786962*^-7, 0.00017597619166771607, 0.0006798116091513387, 
   0.0013151489837432667, 0.001800121371156846, 0.0019078746235213888, 
   0.0015837976086114593, 0.000976626790703756, 0.00036610914614868353, 
   0.000025016073726894943, 0.0000874352219144964, 0.0004902478802787471, 
   0.0010143747194924799, 0.0013997440121332374, 0.0014716941283774657}, 
  {0.0023571898791996068, 0.002241948483214049, 0.0016247084067258094, 
   0.0007852224993018278, 0.0001400436518760639, 0.000040067861024420315, 
   0.0005863913957007555, 0.0015642481290184032, 0.002536744301504586, 
   0.003055813478242621, 0.0028832267490936938, 0.0021064539256790966, 
   0.0010888438120093052, 0.00028185836308033014, 2.8656068295590006*^-7, 
   0.0002787674492823066, 0.0008802940310529545, 0.001442363883816857, 
   0.001672799201888098, 0.001486293912585003, 0.0010143077665810503, 
   0.0004980615149402652, 0.00014004606553316928, 5.2341273699608895*^-6, 
   0.000022538951774714994, 0.00006869717510667269, 
   0.00006585133963953497, 0.00002313732478509082, 1.188995193972492*^-7, 
   0.000031432465777075566, 0.00008279339339986244, 
   0.00008438298495366628, 0.000023226589188919205, 
   0.000017588664490201478, 0.00029108606569466246, 
   0.0010265747358604175, 0.0021759050588408204, 0.003365486345512461, 
   0.004012921388018964, 0.00365171458196197, 0.0023092504692640782, 
   0.0006951282497039982, 9.044263431580857*^-6, 0.0013704725816889422, 
   0.005115322134947943, 0.01035453411357773, 0.015131280166411675, 
   0.017237003139965755, 0.015372701051800804, 0.01007286684428843, 
   0.003823032670305428, 0.00014234391993834828, 0.0019337057272973404, 
   0.009858916734261747, 0.02160953861149623, 0.03260182507627683, 
   0.03794693780157049, 0.03485599931754294, 0.024301719766900928, 
   0.010996799833172033, 0.0015044081616544898, 0.0012283895543439558, 
   0.011674025015897833, 0.029364938858388957, 0.047093878404343016, 
   0.057078298673293115, 0.054617226972303784, 0.040504514281473204, 
   0.020956686170142392, 0.004958249016277403, 0.000177231308788093, 
   0.009344707061005448, 0.028838060415563926, 0.05020341511236102, 
   0.06396485811052471, 0.06396485811052614, 0.05020341511236466, 
   0.02883806041556815, 0.009344707061008414, 0.00017723130878852917, 
   0.0049582490162752195, 0.02095668617013868, 0.04050451428146971, 
   0.05461722697230206, 0.05707829867329389, 0.04709387840434593, 
   0.029364938858392624, 0.011674025015900686, 0.0012283895543449656, 
   0.0015044081616534264, 0.010996799833169636, 0.024301719766898433, 
   0.034855999317541526, 0.03794693780157074, 0.03260182507627857, 
   0.021609538611498603, 0.009858916734263787, 0.0019337057272983138, 
   0.00014234391993810097, 0.0038230326703043434, 0.010072866844287234, 
   0.015372701051800086, 0.01723700313996579, 0.015131280166412402, 
   0.01035453411357878, 0.005115322134948867, 0.0013704725816894477, 
   9.044263431618714*^-6, 0.0006951282497037321, 0.002309250469263754, 
   0.003651714581961799, 0.004012921388019002, 0.0033654863455126536, 
   0.002175905058841062, 0.001026574735860606, 0.0002910860656947572, 
   0.000017588664490219676, 0.00002322658918890657, 
   0.00008438298495365913, 0.00008279339339987011, 
   0.000031432465777085934, 1.1889951939800116*^-7, 
   0.00002313732478508257, 0.00006585133963952908, 
   0.00006869717510667784, 0.00002253895177472469, 
   5.2341273699535025*^-6, 0.00014004606553312266, 0.0004980615149401768, 
   0.0010143077665809475, 0.001486293912584932, 0.001672799201888101, 
   0.0014423638838169447, 0.0008802940310530839, 0.00027876744928240595, 
   2.8656068295956586*^-7, 0.00028185836308021483, 0.0010888438120091179, 
   0.0021064539256789123, 0.0028832267490935953, 0.003055813478242656, 
   0.00253674430150474, 0.0015642481290186045, 0.0005863913957009112, 
   0.00004006786102446452, 0.00014004365187598523, 0.0007852224993016647, 
   0.0016247084067256494, 0.002241948483213969, 0.0023571898791996384}, 
  {0.0014088958858220558, 0.0013400159325721403, 0.0009710906236682783, 
   0.00046932865208843704, 0.00008370429837017584, 
   0.000023948619943236813, 0.0003504870066575947, 0.0009349534260376202, 
   0.0015162158302605324, 0.001826464246824912, 0.0017233089029168624, 
   0.0012590306346346256, 0.0006508035608754661, 0.00016846716152678218, 
   1.7127774508857795*^-7, 0.00016661971776678067, 0.0005261530475794125, 
   0.0008621030319619024, 0.0009998345632413882, 0.0008883600752920314, 
   0.0006062532560078023, 0.0002976921059596228, 0.00008370574101660649, 
   3.1284456897085016*^-6, 0.000013471564894432782, 
   0.00004106040341911402, 0.0000393594433408626, 
   0.000013829213329946904, 7.106641903701249*^-8, 
   0.000018787231400128657, 0.00004948573399353012, 
   0.000050435835222138895, 0.00001388256679646818, 
   0.000010512770844648162, 0.00017398257306135774, 
   0.0006135852417344143, 0.0013005416799011433, 0.002011556178746554, 
   0.0023985290636098513, 0.0021826352200653406, 0.0013802424294234402, 
   0.00041547918552034356, 5.405769663058233*^-6, 0.0008191334940862339, 
   0.0030574356245877832, 0.006188920392436676, 0.009043988590735434, 
   0.010302582334201147, 0.00918828621188921, 0.006020567447952129, 
   0.0022850322954829374, 0.00008507917200162922, 0.0011557787803267024, 
   0.005892689149963626, 0.012916053268728531, 0.019486159187079723, 
   0.022680940988229502, 0.020833482473366808, 0.014525173937032638, 
   0.006572803565330754, 0.0008991869888190068, 0.0007342102579744848, 
   0.006977582061173207, 0.01755146749529083, 0.028148080948749266, 
   0.03411578374748122, 0.03264479754274903, 0.024209608242406633, 
   0.012525842396541762, 0.0029635527886648213, 0.00010593141604493455, 
   0.005585345265835504, 0.017236551468807388, 0.03000665564966679, 
   0.038231890533871785, 0.03823189053387264, 0.030006655649668965, 
   0.017236551468809914, 0.005585345265837279, 0.00010593141604519526, 
   0.0029635527886635164, 0.012525842396539543, 0.02420960824240454, 
   0.032644797542748, 0.034115783747481684, 0.028148080948751004, 
   0.01755146749529302, 0.006977582061174912, 0.0007342102579750882, 
   0.0008991869888183711, 0.006572803565329321, 0.01452517393703115, 
   0.02083348247336596, 0.022680940988229648, 0.019486159187080757, 
   0.012916053268729952, 0.005892689149964845, 0.0011557787803272842, 
   0.00008507917200148142, 0.002285032295482289, 0.006020567447951413, 
   0.009188286211888781, 0.01030258233420117, 0.009043988590735868, 
   0.006188920392437304, 0.0030574356245883353, 0.0008191334940865361, 
   5.405769663080861*^-6, 0.0004154791855201845, 0.0013802424294232464, 
   0.0021826352200652386, 0.0023985290636098743, 0.002011556178746669, 
   0.0013005416799012877, 0.0006135852417345271, 0.00017398257306141436, 
   0.000010512770844659037, 0.00001388256679646063, 
   0.00005043583522213462, 0.000049485733993534705, 
   0.000018787231400134854, 7.106641903746193*^-8, 
   0.000013829213329941973, 0.00003935944334085908, 
   0.00004106040341911709, 0.000013471564894438579, 
   3.1284456897040864*^-6, 0.00008370574101657861, 
   0.00029769210595957007, 0.0006062532560077408, 0.0008883600752919888, 
   0.00099983456324139, 0.0008621030319619547, 0.00052615304757949, 
   0.00016661971776684006, 1.7127774509076899*^-7, 
   0.00016846716152671325, 0.0006508035608753541, 0.0012590306346345155, 
   0.0017233089029168036, 0.001826464246824933, 0.0015162158302606246, 
   0.0009349534260377404, 0.00035048700665768777, 
   0.000023948619943263234, 0.00008370429837012883, 
   0.0004693286520883395, 0.0009710906236681827, 0.0013400159325720922, 
   0.0014088958858220746}, {0.0001669626107997701, 
   0.00015879992330660462, 0.00011508006197081805, 
   0.000055618259563659034, 9.919461282898949*^-6, 
   2.8380550692297754*^-6, 0.000041534811955820625, 
   0.00011079758735781176, 0.00017968066775106808, 0.0002164469654934023, 
   0.00020422243867764908, 0.00014920267987924147, 0.000077124124454487, 
   0.000019964368840587756, 2.029743984609682*^-8, 
   0.000019745435676980978, 0.00006235229117221626, 
   0.00010216437881836247, 0.00011848639117093283, 
   0.00010527599590121249, 0.00007184464618538066, 
   0.00003527829964277289, 9.91963224515169*^-6, 3.7073957370118254*^-7, 
   1.5964612211360432*^-6, 4.8659040205423264*^-6, 4.664330051600445*^-6, 
   1.6388447053542893*^-6, 8.421796799901153*^-9, 2.2263995770238737*^-6, 
   5.864356215421762*^-6, 5.976948908216825*^-6, 1.6451674110667934*^-6, 
   1.2458263840681332*^-6, 0.000020617978180152684, 
   0.00007271353045964166, 0.0001541219876609384, 0.00023838146931486761, 
   0.0002842400766226721, 0.0002586553615727332, 0.0001635670043984079, 
   0.00004923677487138322, 6.406161203315417*^-7, 0.0000970722309167486, 
   0.00036232445517828387, 0.0007334241778626882, 0.0010717668795458715, 
   0.0012209177852018148, 0.0010888670129215706, 0.0007134733444264986, 
   0.0002707900290254722, 0.000010082392052544342, 
   0.00013696671600238645, 0.0006983189993030235, 0.0015306297624097021, 
   0.0023092267108413356, 0.002687827511527419, 0.002468892599381115, 
   0.0017213202105652566, 0.0007789166357749331, 0.0001065590500768675, 
   0.00008700831820221194, 0.0008268853147536688, 0.00207995414414261, 
   0.003335716380110161, 0.00404292494660549, 0.00386860426069531, 
   0.0028689837476765577, 0.0014843874341877378, 0.0003511987761606053, 
   0.000012553508010465403, 0.000661896906071179, 0.0020426347066359227, 
   0.0035559686269612703, 0.00453070828269312, 0.004530708282693222, 
   0.0035559686269615283, 0.0020426347066362224, 0.0006618969060713892, 
   0.000012553508010496298, 0.00035119877616045063, 0.001484387434187475, 
   0.0028689837476763096, 0.003868604260695188, 0.004042924946605545, 
   0.0033357163801103675, 0.0020799541441428697, 0.0008268853147538709, 
   0.00008700831820228346, 0.00010655905007679218, 0.0007789166357747633, 
   0.00172132021056508, 0.0024688925993810147, 0.0026878275115274366, 
   0.0023092267108414583, 0.0015306297624098704, 0.0006983189993031681, 
   0.0001369667160024554, 0.000010082392052526825, 0.0002707900290253954, 
   0.0007134733444264138, 0.0010888670129215196, 0.0012209177852018172, 
   0.0010717668795459231, 0.0007334241778627626, 0.00036232445517834935, 
   0.0000970722309167844, 6.406161203342232*^-7, 0.000049236774871364367, 
   0.00016356700439838494, 0.00025865536157272103, 0.0002842400766226748, 
   0.00023838146931488125, 0.00015412198766095553, 
   0.00007271353045965502, 0.000020617978180159396, 
   1.2458263840694222*^-6, 1.6451674110658985*^-6, 5.976948908216318*^-6, 
   5.8643562154223054*^-6, 2.226399577024608*^-6, 8.421796799954415*^-9, 
   1.638844705353705*^-6, 4.664330051600028*^-6, 4.86590402054269*^-6, 
   1.59646122113673*^-6, 3.707395737006593*^-7, 9.919632245148389*^-6, 
   0.00003527829964276664, 0.00007184464618537337, 
   0.00010527599590120745, 0.00011848639117093304, 
   0.00010216437881836866, 0.00006235229117222543, 
   0.000019745435676988015, 2.0297439846356473*^-8, 
   0.000019964368840579587, 0.00007712412445447373, 
   0.00014920267987922844, 0.00020422243867764211, 
   0.00021644696549340478, 0.00017968066775107897, 
   0.00011079758735782602, 0.00004153481195583165, 2.838055069232906*^-6, 
   9.919461282893375*^-6, 0.00005561825956364748, 0.00011508006197080672, 
   0.00015879992330659892, 0.00016696261079977232}, 
  {0.0001841261913371693, 0.00017512438816703, 0.0001269101711337238, 
   0.0000613357580670554, 0.0000109391714551412, 3.129804141174489*^-6, 
   0.000045804546878475783, 0.00012218746264100268, 
   0.00019815165114780934, 0.00023869748557407415, 
   0.00022521629027710387, 0.0001645405582235988, 0.00008505240321767947, 
   0.00002201668492999478, 2.2383995284064247*^-8, 
   0.000021775245667759858, 0.00006876204103237581, 
   0.00011266676935659633, 0.00013066666738790545, 
   0.00011609825739826294, 0.00007923020014310203, 
   0.000038904871689297626, 0.000010939359992133459, 
   4.0885121139743533*^-7, 1.760575753201332*^-6, 5.366113828856775*^-6, 
   5.143818268214784*^-6, 1.8073162149569492*^-6, 9.28754864070139*^-9, 
   2.455271108593943*^-6, 6.467205857753347*^-6, 6.591372960779862*^-6, 
   1.8142888881573299*^-6, 1.3738960241878222*^-6, 
   0.000022737484621255112, 0.00008018840480560756, 
   0.00016996556566400956, 0.00026288683328594257, 
   0.00031345965712456297, 0.0002852448603145068, 0.0001803815201741583, 
   0.00005429826346969127, 7.06470782774816*^-7, 0.00010705115401398447, 
   0.00039957102755357844, 0.000808819410870385, 0.0011819433859282691, 
   0.0013464268475929454, 0.0012008013950043311, 0.0007868176527701043, 
   0.0002986269588005891, 0.000011118851336299846, 
   0.00015104675014769155, 0.0007701054569292, 0.001687976889854689, 
   0.002546612784530436, 0.0029641333487670086, 0.0027226921582445356, 
   0.001898270115236551, 0.000858988445541228, 0.00011751320819180273, 
   0.0000959526816721762, 0.0009118882541961254, 0.0022937712394556532, 
   0.0036786245106532503, 0.004458533372919217, 0.004266292704100156, 
   0.0031639122551900723, 0.001636980898996086, 0.00038730164045096705, 
   0.00001384399541200049, 0.0007299392108745708, 0.002252615403079853, 
   0.003921518456500704, 0.0049964603222004715, 0.004996460322200583, 
   0.003921518456500988, 0.002252615403080183, 0.0007299392108748027, 
   0.00001384399541203456, 0.0003873016404507965, 0.0016369808989957961, 
   0.003163912255189799, 0.004266292704100022, 0.004458533372919278, 
   0.003678624510653478, 0.0022937712394559395, 0.0009118882541963483, 
   0.00009595268167225508, 0.00011751320819171967, 0.0008589884455410407, 
   0.0018982701152363563, 0.0027226921582444255, 0.0029641333487670277, 
   0.0025466127845305713, 0.0016879768898548746, 0.0007701054569293594, 
   0.00015104675014776758, 0.00001111885133628053, 
   0.00029862695880050435, 0.0007868176527700108, 0.001200801395004275, 
   0.0013464268475929483, 0.001181943385928326, 0.0008088194108704671, 
   0.0003995710275536506, 0.00010705115401402396, 7.064707827777732*^-7, 
   0.00005429826346967048, 0.00018038152017413295, 0.0002852448603144934, 
   0.000313459657124566, 0.0002628868332859576, 0.00016996556566402843, 
   0.0000801884048056223, 0.000022737484621262515, 
   1.3738960241892435*^-6, 1.814288888156343*^-6, 6.591372960779303*^-6, 
   6.467205857753947*^-6, 2.4552711085947533*^-6, 9.287548640760126*^-9, 
   1.8073162149563048*^-6, 5.143818268214324*^-6, 5.366113828857176*^-6, 
   1.7605757532020895*^-6, 4.088512113968583*^-7, 
   0.000010939359992129817, 0.00003890487168929073, 
   0.00007923020014309398, 0.00011609825739825737, 
   0.00013066666738790567, 0.00011266676935660316, 
   0.00006876204103238592, 0.00002177524566776762, 2.238399528435059*^-8, 
   0.000022016684929985776, 0.00008505240321766485, 
   0.00016454055822358443, 0.0002252162902770962, 0.0002386974855740769, 
   0.00019815165114782138, 0.0001221874626410184, 0.00004580454687848794, 
   3.129804141177942*^-6, 0.000010939171455135054, 
   0.00006133575806704266, 0.00012691017113371133, 
   0.00017512438816702372, 0.00018412619133717178}, 
  {0.0009659165783780378, 0.0009186935795521327, 0.0006657642640225063, 
   0.0003217642483891075, 0.00005738633371768266, 0.00001641879237865059, 
   0.00024028830919549035, 0.0006409891769214395, 0.001039493422889334, 
   0.001252194795638547, 0.0011814731349170126, 0.0008631713492227511, 
   0.0004461805553149784, 0.00011549840259208616, 1.1742529391498282*^-7, 
   0.00011423182457637613, 0.0003607221488368173, 0.0005910441071066807, 
   0.0006854706511593839, 0.0006090455177907384, 0.00041563757589647846, 
   0.00020409296619593387, 0.000057387322773096985, 
   2.144812534874854*^-6, 9.235890316079523*^-6, 0.000028150358572643098, 
   0.00002698420743594387, 9.481088386831565*^-6, 4.87220049434375*^-8, 
   0.00001288022660426781, 0.00003392663101551097, 
   0.00003457800528460048, 9.517666673662724*^-6, 7.207388243319392*^-6, 
   0.00011927968089052874, 0.0004206642685265258, 0.0008916306606681355, 
   0.001379090876013441, 0.0016443933221584528, 0.0014963799417888155, 
   0.0009462722250643745, 0.0002848459118261567, 3.706109577709767*^-6, 
   0.0005615848763593824, 0.0020961291652788205, 0.0042430252437201865, 
   0.006200414524850497, 0.00706328634844666, 0.006299342675536111, 
   0.004127605146513004, 0.0015665817457110214, 0.00005832892518037316, 
   0.0007923835225082844, 0.004039933822261964, 0.008855040393704746, 
   0.013359400362455908, 0.015549691878731065, 0.01428310374732323, 
   0.009958227893765336, 0.00450620943255214, 0.000616468277253386, 
   0.0005033628583413589, 0.004783719121976083, 0.01203300655440048, 
   0.019297875954872274, 0.023389237939909855, 0.02238075322786374, 
   0.016597721799530916, 0.008587518035025533, 0.00203176458833904, 
   0.00007262489156121131, 0.003829223750687558, 0.011817105142636609, 
   0.02057208516638031, 0.026211175191170406, 0.026211175191170995, 
   0.0205720851663818, 0.01181710514263834, 0.0038292237506887743, 
   0.00007262489156139005, 0.0020317645883381453, 0.008587518035024014, 
   0.016597721799529484, 0.022380753227863037, 0.023389237939910178, 
   0.019297875954873468, 0.012033006554401982, 0.004783719121977252, 
   0.0005033628583417726, 0.0006164682772529502, 0.004506209432551157, 
   0.009958227893764314, 0.01428310374732265, 0.015549691878731167, 
   0.013359400362456619, 0.008855040393705719, 0.0040399338222628, 
   0.0007923835225086833, 0.00005832892518027182, 0.001566581745710577, 
   0.004127605146512513, 0.006299342675535817, 0.0070632863484466745, 
   0.006200414524850794, 0.004243025243720618, 0.002096129165279199, 
   0.0005615848763595896, 3.70610957772528*^-6, 0.00028484591182604765, 
   0.0009462722250642416, 0.0014963799417887455, 0.0016443933221584686, 
   0.0013790908760135199, 0.0008916306606682346, 0.0004206642685266031, 
   0.00011927968089056757, 7.207388243326849*^-6, 9.517666673657548*^-6, 
   0.000034578005284597555, 0.00003392663101551412, 
   0.00001288022660427206, 4.8722004943745626*^-8, 9.481088386828184*^-6, 
   0.00002698420743594146, 0.000028150358572645202, 
   9.235890316083495*^-6, 2.144812534871827*^-6, 0.000057387322773077876, 
   0.0002040929661958977, 0.0004156375758964363, 0.0006090455177907092, 
   0.0006854706511593851, 0.0005910441071067165, 0.0003607221488368703, 
   0.00011423182457641686, 1.1742529391648496*^-7, 0.0001154984025920389, 
   0.00044618055531490166, 0.0008631713492226757, 0.0011814731349169723, 
   0.0012521947956385614, 0.0010394934228893972, 0.0006409891769215219, 
   0.00024028830919555416, 0.000016418792378668702, 
   0.00005738633371765042, 0.00032176424838904066, 0.0006657642640224409, 
   0.0009186935795520997, 0.0009659165783780507}, 
  {0.001133848600114376, 0.001078415519959705, 0.0007815124987663846, 
   0.00037770543623494676, 0.00006736338893856835, 
   0.00001927332563787461, 0.0002820642787420159, 0.0007524300723373579, 
   0.001220217344597521, 0.0014698984859431582, 0.0013868813208981951, 
   0.0010132403231120548, 0.0005237524744545227, 0.00013557868766926747, 
   1.378405838598346*^-7, 0.0001340919053298858, 0.0004234364671281166, 
   0.0006938016682290321, 0.0008046449927815309, 0.000714932762529615, 
   0.00048789936329336964, 0.00023957609714395176, 0.0000673645499488689, 
   2.5177046803143615*^-6, 0.000010841620839846633, 
   0.00003304451479019653, 0.0000316756193146799, 
   0.000011129448479931033, 5.719270000795173*^-8, 
   0.000015119553004182144, 0.00003982503659697899, 
   0.00004058965728958358, 0.000011172386183089348, 8.46044808951414*^-6, 
   0.00014001737026495434, 0.000493799985075175, 0.0010466475046067066, 
   0.001618856425286822, 0.0019302837409599463, 0.00175653709669785, 
   0.0011107889249794372, 0.0003343685630851517, 4.350445215065009*^-6, 
   0.000659220723775879, 0.0024605573327059335, 0.004980707796651148, 
   0.007278404249915532, 0.008291292972568491, 0.007394531820015988, 
   0.0048452210283598494, 0.001838944023843006, 0.00006846985717234277, 
   0.0009301454886076986, 0.004742307370496002, 0.010394557231037445, 
   0.01568203480343384, 0.018253125335642315, 0.016766331121871, 
   0.011689542357711422, 0.005289648579695205, 0.0007236460257804035, 
   0.0005908763603978097, 0.005615405461723132, 0.014125037236429229, 
   0.02265296002409965, 0.02745563673877598, 0.026271819207752393, 
   0.019483363313928487, 0.010080524053972535, 0.0023850024793223507, 
   0.00008525128719543479, 0.004494963733340688, 0.01387159970468891, 
   0.024148700301326553, 0.030768189472186167, 0.030768189472186857, 
   0.024148700301328305, 0.013871599704690943, 0.004494963733342116, 
   0.0000852512871956446, 0.0023850024793213007, 0.010080524053970752, 
   0.0194833633139268, 0.026271819207751568, 0.027455636738776355, 
   0.022652960024101047, 0.014125037236430991, 0.0056154054617245045, 
   0.0005908763603982955, 0.000723646025779892, 0.0052896485796940515, 
   0.011689542357710223, 0.01676633112187032, 0.018253125335642436, 
   0.015682034803434674, 0.010394557231038588, 0.004742307370496984, 
   0.0009301454886081669, 0.00006846985717222382, 0.001838944023842484, 
   0.0048452210283592735, 0.007394531820015642, 0.008291292972568509, 
   0.007278404249915882, 0.0049807077966516535, 0.0024605573327063776, 
   0.0006592207237761222, 4.350445215083219*^-6, 0.00033436856308502363, 
   0.001110788924979281, 0.001756537096697768, 0.0019302837409599647, 
   0.0016188564252869145, 0.0010466475046068228, 0.0004937999850752658, 
   0.0001400173702649999, 8.460448089522893*^-6, 0.000011172386183083273, 
   0.00004058965728958014, 0.000039825036596982686, 
   0.000015119553004187133, 5.7192700008313435*^-8, 
   0.000011129448479927066, 0.00003167561931467707, 
   0.000033044514790199005, 0.000010841620839851298, 
   2.5177046803108082*^-6, 0.00006736454994884646, 
   0.00023957609714390932, 0.00048789936329332015, 0.0007149327625295808, 
   0.0008046449927815323, 0.0006938016682290741, 0.0004234364671281788, 
   0.00013409190532993358, 1.378405838615979*^-7, 0.00013557868766921202, 
   0.0005237524744544325, 0.0010132403231119663, 0.0013868813208981479, 
   0.001469898485943175, 0.001220217344597595, 0.0007524300723374547, 
   0.00028206427874209077, 0.000019273325637895873, 
   0.00006736338893853051, 0.0003777054362348683, 0.0007815124987663077, 
   0.0010784155199596664, 0.0011338486001143911}, 
  {0.00048651162909767566, 0.00046272640933444573, 0.0003353312945808419, 
   0.00016206580586083165, 0.000028904275306894835, 8.269796384867*^-6, 
   0.00012102810882087461, 0.0003228526103379264, 0.0005235707202121129, 
   0.0006307038761015143, 0.0005950828803133451, 0.00043476104324243544, 
   0.00022473165250202248, 0.0000581740879710453, 5.9144622132671144*^-8, 
   0.000057536139573019964, 0.00018168807142424803, 
   0.0002976963413340566, 0.00034525698249655287, 0.00030676326888660297, 
   0.00020934780362001735, 0.00010279728466623272, 
   0.00002890477347306328, 1.080296439474391*^-6, 4.651921443763328*^-6, 
   0.000014178736668810146, 0.000013591371152998903, 
   4.775422495017151*^-6, 2.4540237250860857*^-8, 6.48749609299804*^-6, 
   0.000017088122198780625, 0.000017416205559084044, 
   4.793846199832024*^-6, 3.6302081093636605*^-6, 
   0.000060078637397183214, 0.00021187964174678825, 
   0.00044909539289977526, 0.0006946187318678029, 0.000828245929254089, 
   0.0007536947387850264, 0.00047661718629884824, 0.0001434708252311609, 
   1.8666885408404274*^-6, 0.0002828583535992368, 0.0010557756620259882, 
   0.002137121538064085, 0.0031230168723590203, 0.0035576270509162333, 
   0.00317284487700358, 0.0020789868908493423, 0.0007890538937641647, 
   0.000029379038571500107, 0.0003991067210514144, 0.00203482871017276, 
   0.004460095441058819, 0.006728845719803709, 0.007832048954570833, 
   0.007194095461483735, 0.005015747512747987, 0.0022696818143111202, 
   0.00031050195489677263, 0.00025353316189079007, 0.0024094575404082367, 
   0.0060607693798513385, 0.00971992952506844, 0.011780661506614262, 
   0.011272709214293599, 0.008359919327152729, 0.004325350120961271, 
   0.0010233565940814893, 0.00003657961266781206, 0.0019286985303169678, 
   0.005952024432396239, 0.010361721594051252, 0.013202011258812908, 
   0.013202011258813203, 0.010361721594052005, 0.0059520244323971105, 
   0.0019286985303175804, 0.000036579612667902085, 0.0010233565940810387, 
   0.004325350120960506, 0.008359919327152006, 0.011272709214293245, 
   0.011780661506614424, 0.00971992952506904, 0.006060769379852095, 
   0.0024094575404088256, 0.00025353316189099845, 0.00031050195489655313, 
   0.002269681814310625, 0.005015747512747473, 0.0071940954614834445, 
   0.007832048954570885, 0.006728845719804066, 0.004460095441059309, 
   0.0020348287101731805, 0.00039910672105161537, 0.00002937903857144907, 
   0.0007890538937639408, 0.002078986890849095, 0.003172844877003432, 
   0.003557627050916241, 0.0031230168723591703, 0.002137121538064302, 
   0.0010557756620261788, 0.00028285835359934114, 1.8666885408482408*^-6, 
   0.00014347082523110598, 0.0004766171862987813, 0.0007536947387849911, 
   0.0008282459292540969, 0.0006946187318678426, 0.0004490953928998252, 
   0.0002118796417468272, 0.00006007863739720277, 3.6302081093674163*^-6, 
   4.7938461998294165*^-6, 0.000017416205559082567, 
   0.00001708812219878221, 6.487496093000181*^-6, 2.4540237251016056*^-8, 
   4.775422495015448*^-6, 0.000013591371152997688, 
   0.000014178736668811207, 4.651921443765329*^-6, 
   1.0802964394728663*^-6, 0.000028904773473053658, 
   0.0001027972846662145, 0.0002093478036199961, 0.0003067632688865883, 
   0.00034525698249655346, 0.00029769634133407463, 
   0.00018168807142427475, 0.00005753613957304047, 
   5.9144622133427737*^-8, 0.0000581740879710215, 0.0002247316525019838, 
   0.00043476104324239744, 0.0005950828803133249, 0.0006307038761015216, 
   0.0005235707202121447, 0.00032285261033796793, 0.00012102810882090675, 
   8.269796384876124*^-6, 0.000028904275306878595, 0.000162065805860798, 
   0.0003353312945808089, 0.00046272640933442915, 
   0.00048651162909768217}, {6.5219814281173805*^-6, 
   6.203126230663649*^-6, 4.495317983619516*^-6, 2.1725897444992254*^-6, 
   3.8747922037216627*^-7, 1.1086160167732876*^-7, 
   1.6224546974835809*^-6, 4.3280337050698324*^-6, 7.018780866271703*^-6, 
   8.45496535037578*^-6, 7.977444446276603*^-6, 5.828233653849258*^-6, 
   3.012663164181129*^-6, 7.798586891920952*^-7, 7.928692842095607*^-10, 
   7.713066066617449*^-7, 2.435638033436416*^-6, 3.990798766722605*^-6, 
   4.628377808659298*^-6, 4.112346391837895*^-6, 2.806433403779537*^-6, 
   1.3780595187365245*^-6, 3.8748589858971427*^-7, 1.448202446502829*^-8, 
   6.236180894083866*^-8, 1.9007450530967884*^-7, 1.8220051678294537*^-7, 
   6.401741492116085*^-8, 3.2897666164435265*^-10, 8.696879273367286*^-8, 
   2.2907657074621*^-7, 2.3347472580519963*^-7, 6.426439578133594*^-8, 
   4.8665126285640136*^-8, 8.053903214148252*^-7, 2.840374218868428*^-6, 
   6.020394245000393*^-6, 9.311782489694038*^-6, 0.000011103135558193375, 
   0.00001010373194561159, 6.3893404626892625*^-6, 1.923312828862401*^-6, 
   2.5024084250608025*^-8, 3.791886603787031*^-6, 
   0.000014153308673757093, 0.00002864940146802794, 
   0.000041865922257602345, 0.000047692133479476024, 
   0.00004253389667271488, 0.000027870071505930394, 
   0.000010577742715951397, 3.938437078978824*^-7, 
   5.3502659892463905*^-6, 0.000027278104496207994, 
   0.00005979026583222034, 0.00009020422985288222, 0.0001049933337062367, 
   0.00009644118287351462, 0.00006723911653857032, 
   0.000030426451816018074, 4.162465729723225*^-6, 
   3.3987647455219064*^-6, 0.00003230022961532325, 
   0.00008124826411406693, 0.00013030150987897326, 0.0001579268633302287, 
   0.00015111745689727393, 0.00011206975400233065, 
   0.00005798392365529881, 0.000013718711541016311, 
   4.903717407735389*^-7, 0.000025855365509956004, 
   0.00007979047259319587, 0.00013890511913366296, 0.0001769809128786264, 
   0.00017698091287863038, 0.00013890511913367305, 
   0.00007979047259320755, 0.000025855365509964217, 
   4.903717407747458*^-7, 0.000013718711541010272, 
   0.00005798392365528854, 0.00011206975400232096, 
   0.00015111745689726916, 0.00015792686333023084, 0.0001303015098789813, 
   0.00008124826411407706, 0.00003230022961533114, 
   3.3987647455247004*^-6, 4.162465729720282*^-6, 0.00003042645181601144, 
   0.00006723911653856342, 0.00009644118287351072, 0.0001049933337062374, 
   0.000090204229852887, 0.00005979026583222691, 0.000027278104496213635, 
   5.350265989249084*^-6, 3.938437078971982*^-7, 0.000010577742715948397, 
   0.00002787007150592708, 0.000042533896672712894, 
   0.000047692133479476126, 0.00004186592225760436, 
   0.000028649401468030847, 0.00001415330867375965, 3.79188660378843*^-6, 
   2.5024084250712772*^-8, 1.923312828861665*^-6, 6.389340462688365*^-6, 
   0.000010103731945611117, 0.000011103135558193482, 
   9.31178248969457*^-6, 6.0203942450010615*^-6, 2.84037421886895*^-6, 
   8.053903214150873*^-7, 4.866512628569049*^-8, 6.426439578130098*^-8, 
   2.3347472580517983*^-7, 2.2907657074623122*^-7, 8.696879273370156*^-8, 
   3.2897666164643316*^-10, 6.401741492113804*^-8, 1.822005167829291*^-7, 
   1.9007450530969308*^-7, 6.23618089408655*^-8, 1.4482024465007853*^-8, 
   3.8748589858958526*^-7, 1.37805951873628*^-6, 2.806433403779252*^-6, 
   4.1123463918376985*^-6, 4.628377808659306*^-6, 3.990798766722847*^-6, 
   2.435638033436774*^-6, 7.713066066620198*^-7, 7.928692842197033*^-10, 
   7.798586891917761*^-7, 3.0126631641806105*^-6, 5.8282336538487486*^-6, 
   7.977444446276332*^-6, 8.454965350375879*^-6, 7.018780866272129*^-6, 
   4.328033705070389*^-6, 1.6224546974840116*^-6, 1.1086160167745106*^-7, 
   3.8747922037194863*^-7, 2.172589744498774*^-6, 4.495317983619073*^-6, 
   6.203126230663426*^-6, 6.521981428117468*^-6}, 
  {0.00025634513058373214, 0.00024381259302142072, 0.0001766875432300916, 
   0.00008539319038191343, 0.000015229790584279169, 
   4.357392315804225*^-6, 0.00006377024618616144, 0.0001701124692741079, 
   0.00027587172970874, 0.0003323206636987685, 0.00031355180336592025, 
   0.00022907751785790597, 0.00011841210232482004, 
   0.00003065218441989833, 3.116356316506703*^-8, 
   0.000030316046585534955, 0.0000957322489518634, 
   0.00015685751979888822, 0.00018191743212217287, 0.0001616349240549006, 
   0.00011030628426276861, 0.00005416434425276189, 
   0.000015230053070238117, 5.692129751550201*^-7, 
   2.4511179972788675*^-6, 7.470839103311072*^-6, 7.161353613456963*^-6, 
   2.516191247777744*^-6, 1.2930359618114519*^-8, 3.418290403880872*^-6, 
   9.00380721546481*^-6, 9.176675790046085*^-6, 2.5258987793846742*^-6, 
   1.912772719465909*^-6, 0.00003165569994172047, 0.0001116403209772202, 
   0.00023663035013358818, 0.0003659976840775769, 0.0004364064457901328, 
   0.00039712509358194603, 0.00025113170488202203, 
   0.00007559541279013069, 9.835664537934924*^-7, 0.0001490393183911711, 
   0.0005562928689929463, 0.001126058796917999, 0.0016455314119518062, 
   0.0018745294385393689, 0.0016717860081287297, 0.001095427394007154, 
   0.00041575598883365614, 0.000015479945449615728, 
   0.00021029109769589836, 0.0010721602531725697, 0.002350044027466791, 
   0.003545458590414421, 0.004126741257390501, 0.003790600738416539, 
   0.00264281956325503, 0.001195905393160284, 0.00016360485426040466, 
   0.00013358774509201465, 0.0012695538418628488, 0.0031934462101088942, 
   0.005121473885402438, 0.006207282686904652, 0.0059396403759762436, 
   0.00440487849296236, 0.002279046121949063, 0.0005392111186120793, 
   0.000019273959809396515, 0.00101623979169364, 0.0031361480160094026, 
   0.005459636967004691, 0.006956198161974142, 0.006956198161974297, 
   0.0054596369670050875, 0.0031361480160098623, 0.0010162397916939627, 
   0.00001927395980944395, 0.000539211118611842, 0.0022790461219486594, 
   0.0044048784929619795, 0.005939640375976057, 0.006207282686904737, 
   0.005121473885402754, 0.003193446210109293, 0.0012695538418631591, 
   0.00013358774509212445, 0.00016360485426028903, 0.0011959053931600233, 
   0.002642819563254759, 0.0037906007384163856, 0.004126741257390528, 
   0.003545458590414609, 0.002350044027467049, 0.0010721602531727915, 
   0.00021029109769600424, 0.000015479945449588833, 
   0.00041575598883353824, 0.0010954273940070238, 0.0016717860081286516, 
   0.001874529438539373, 0.0016455314119518854, 0.0011260587969181132, 
   0.0005562928689930468, 0.00014903931839122607, 9.835664537976094*^-7, 
   0.00007559541279010175, 0.00025113170488198674, 0.0003971250935819275, 
   0.000436406445790137, 0.0003659976840775978, 0.00023663035013361447, 
   0.00011164032097724071, 0.000031655699941730777, 
   1.9127727194678883*^-6, 2.5258987793833004*^-6, 9.176675790045307*^-6, 
   9.003807215465645*^-6, 3.4182904038819993*^-6, 1.2930359618196294*^-8, 
   2.516191247776847*^-6, 7.161353613456324*^-6, 7.470839103311631*^-6, 
   2.451117997279922*^-6, 5.692129751542167*^-7, 0.000015230053070233046, 
   0.000054164344252752286, 0.00011030628426275741, 
   0.00016163492405489284, 0.0001819174321221732, 0.00015685751979889774, 
   0.00009573224895187746, 0.000030316046585545763, 
   3.116356316546568*^-8, 0.000030652184419885786, 
   0.00011841210232479967, 0.00022907751785788594, 
   0.00031355180336590957, 0.00033232066369877236, 
   0.00027587172970875676, 0.0001701124692741298, 0.00006377024618617838, 
   4.357392315809032*^-6, 0.000015229790584270613, 0.0000853931903818957, 
   0.00017668754323007423, 0.00024381259302141197, 
   0.00025634513058373556}, {0.0006807016570609403, 
   0.0006474226200594657, 0.0004691780303564791, 0.00022675400957422216, 
   0.000040441352109178045, 0.00001157066710445552, 
   0.00016933620760128042, 0.00045171850722473616, 0.0007325528014571315, 
   0.0008824479167606188, 0.0008326088802217832, 0.0006082949406770569, 
   0.0003144327886589072, 0.00008139414499370419, 8.275206569393133*^-8, 
   0.00008050156092030676, 0.0002542084585235313, 0.00041652116974656657, 
   0.0004830655343905044, 0.0004292071411403372, 0.00029290851092400935, 
   0.00014382859078507506, 0.00004044204911725775, 
   1.5114943456359095*^-6, 6.508725477251182*^-6, 0.00001983814767879285, 
   0.000019016336531843068, 6.6815216967231885*^-6, 
   3.433541802959835*^-8, 9.076965639794692*^-6, 0.000023908807931977514, 
   0.000024367845031310285, 6.707299182083498*^-6, 5.079197551974226*^-6, 
   0.00008405889106098939, 0.0002964509265729414, 0.0006283508139204962, 
   0.0009718742441674585, 0.0011588384383388426, 0.001054530307036254, 
   0.0006668578695622774, 0.00020073688404094586, 2.6117730943521617*^-6, 
   0.0003957606324141404, 0.0014771861547453705, 0.0029901488172007977, 
   0.004369562067790285, 0.004977645926480642, 0.0044392788089758954, 
   0.0029088098556530077, 0.001104002989593122, 0.00004110561606835175, 
   0.000558409275576254, 0.002847026035983383, 0.006240332554865106, 
   0.00941464943001027, 0.010958193767015633, 0.010065602564873951, 
   0.007017771907444743, 0.00317562023104792, 0.00043443811530445537, 
   0.000354730356063723, 0.0033711871254049333, 0.008479911914090614, 
   0.013599617642235832, 0.016482886182390483, 0.015772185869364335, 
   0.011696762417463518, 0.006051803941804569, 0.0014318270883832362, 
   0.000051180283200646705, 0.002698534232352705, 0.008327761664225096, 
   0.014497579579251444, 0.01847156450726261, 0.018471564507263023, 
   0.014497579579252495, 0.008327761664226316, 0.0026985342323535624, 
   0.00005118028320077267, 0.0014318270883826058, 0.006051803941803497, 
   0.011696762417462507, 0.01577218586936384, 0.01648288618239071, 
   0.013599617642236671, 0.008479911914091672, 0.003371187125405757, 
   0.0003547303560640146, 0.0004344381153041483, 0.0031756202310472274, 
   0.0070177719074440235, 0.010065602564873544, 0.010958193767015706, 
   0.00941464943001077, 0.006240332554865792, 0.0028470260359839718, 
   0.0005584092755765352, 0.000041105616068280334, 0.001104002989592809, 
   0.002908809855652662, 0.004439278808975688, 0.004977645926480653, 
   0.004369562067790495, 0.002990148817201101, 0.0014771861547456372, 
   0.00039576063241428646, 2.611773094363094*^-6, 0.00020073688404086902, 
   0.0006668578695621837, 0.0010545303070362045, 0.0011588384383388536, 
   0.000971874244167514, 0.000628350813920566, 0.00029645092657299587, 
   0.00008405889106101673, 5.079197551979481*^-6, 6.7072991820798506*^-6, 
   0.00002436784503130822, 0.00002390880793197973, 9.076965639797687*^-6, 
   3.43354180298155*^-8, 6.681521696720806*^-6, 0.00001901633653184137, 
   0.000019838147678794336, 6.508725477253982*^-6, 
   1.5114943456337763*^-6, 0.000040442049117244285, 
   0.00014382859078504955, 0.00029290851092397965, 0.0004292071411403166, 
   0.0004830655343905053, 0.00041652116974659183, 0.00025420845852356863, 
   0.00008050156092033547, 8.275206569498992*^-8, 0.00008139414499367089, 
   0.00031443278865885314, 0.0006082949406770037, 0.0008326088802217548, 
   0.000882447916760629, 0.0007325528014571759, 0.00045171850722479427, 
   0.0001693362076013254, 0.000011570667104468284, 
   0.000040441352109155324, 0.00022675400957417505, 
   0.00046917803035643297, 0.0006474226200594425, 0.0006807016570609494}, 
  {0.0005919828679480924, 0.0005630412316786218, 0.00040802802976546934, 
   0.0001972001794237733, 0.000035170455892024595, 
   0.00001006261204966482, 0.00014726588775482462, 
   0.00039284408174753473, 0.0006370760285826344, 0.0007674346656276803, 
   0.0007240913661366548, 0.000529013231868893, 0.0002734514042626344, 
   0.00007078569427258229, 7.196663129870528*^-8, 0.00007000944453942307, 
   0.00022107637137711752, 0.00036223416539382983, 
   0.00042010551537377457, 0.00037326671930418336, 
   0.00025473247867777225, 0.0001250827888880234, 0.00003517106205602865, 
   1.3144947545452579*^-6, 5.6604151536023415*^-6, 
   0.000017252556146808687, 0.000016537855198696423, 
   5.810690094925819*^-6, 2.986033459227877*^-8, 7.893925475240757*^-6, 
   0.00002079266965487207, 0.000021191878464985573, 
   5.833107889202938*^-6, 4.4172037815730575*^-6, 0.00007310313246727682, 
   0.0002578131959840491, 0.0005464551364664481, 0.0008452056732625664, 
   0.0010078020159056272, 0.0009170888141992819, 0.000579943401110143, 
   0.00017457397831321012, 2.2713694182851657*^-6, 
   0.00034417943862372476, 0.0012846580984613228, 0.0026004297977486094, 
   0.0038000581572495175, 0.004328887818359382, 0.0038606884142247224, 
   0.00252969209462492, 0.0009601135082062754, 0.00003574814345829858, 
   0.0004856293811179207, 0.002475960827216623, 0.005427003040846379, 
   0.008187597477531039, 0.009529965009543184, 0.008753709076759751, 
   0.006103115362333792, 0.0027617279205792073, 0.00037781591799602646, 
   0.0003084968155322866, 0.0029318057363098685, 0.007374688342210313, 
   0.011827120694268405, 0.014334600383439271, 0.013716528714018962, 
   0.010172272815515733, 0.005263046176789764, 0.0012452108752704144, 
   0.000044509735678228226, 0.002346822602168636, 0.007242368492037914, 
   0.012608047370836104, 0.016064085666708697, 0.01606408566670906, 
   0.01260804737083702, 0.0072423684920389746, 0.0023468226021693813, 
   0.00004450973567833777, 0.001245210875269866, 0.005263046176788832, 
   0.010172272815514853, 0.013716528714018532, 0.014334600383439467, 
   0.011827120694269135, 0.007374688342211233, 0.002931805736310585, 
   0.00030849681553254016, 0.0003778159179957594, 0.0027617279205786054, 
   0.006103115362333166, 0.008753709076759396, 0.009529965009543246, 
   0.008187597477531474, 0.005427003040846976, 0.002475960827217135, 
   0.00048562938111816514, 0.00003574814345823648, 0.0009601135082060031, 
   0.0025296920946246194, 0.003860688414224542, 0.004328887818359391, 
   0.0038000581572497005, 0.0026004297977488735, 0.0012846580984615548, 
   0.0003441794386238517, 2.2713694182946732*^-6, 0.00017457397831314328, 
   0.0005799434011100615, 0.0009170888141992391, 0.001007802015905637, 
   0.0008452056732626147, 0.0005464551364665088, 0.0002578131959840965, 
   0.00007310313246730062, 4.417203781577628*^-6, 5.833107889199765*^-6, 
   0.000021191878464983777, 0.000020792669654874, 7.89392547524336*^-6, 
   2.986033459246761*^-8, 5.810690094923747*^-6, 0.000016537855198694946, 
   0.000017252556146809978, 5.6604151536047776*^-6, 
   1.3144947545434027*^-6, 0.000035171062056016934, 
   0.00012508278888800122, 0.0002547324786777464, 0.0003732667193041654, 
   0.0004201055153737753, 0.0003622341653938518, 0.00022107637137715002, 
   0.00007000944453944802, 7.196663129962591*^-8, 0.00007078569427255333, 
   0.00027345140426258735, 0.0005290132318688467, 0.0007240913661366302, 
   0.0007674346656276891, 0.0006370760285826731, 0.0003928440817475853, 
   0.0001472658877548637, 0.000010062612049675921, 
   0.000035170455892004835, 0.00019720017942373232, 
   0.0004080280297654292, 0.0005630412316786017, 0.0005919828679481003}, 
  {0.0001572338705694825, 0.00014954681451153254, 0.00010837446469226237, 
   0.00005237744057572133, 9.341464439273572*^-6, 2.67268450874603*^-6, 
   0.000039114621027465915, 0.00010434152548633418, 
   0.0001692108593755203, 0.0002038348226260111, 0.00019232260646028282, 
   0.00014050879262355717, 0.00007263018075827888, 
   0.000018801065527460636, 1.911472882680533*^-8, 
   0.000018594889374937495, 0.00005871908706339203, 
   0.00009621136516128378, 0.00011158231058064637, 
   0.00009914167150545904, 0.00006765833227757578, 
   0.000033222669275310656, 9.341625439731048*^-6, 3.491369586704925*^-7, 
   1.5034370618122141*^-6, 4.582372779777652*^-6, 4.3925443194357496*^-6, 
   1.5433509038390819*^-6, 7.931067330913845*^-9, 2.096669555254729*^-6, 
   5.5226461884617055*^-6, 5.628678220431062*^-6, 1.5493051919691412*^-6, 
   1.1732333573744343*^-6, 0.00001941658972061909, 
   0.00006847658755559638, 0.0001451414573820544, 0.00022449122538798112, 
   0.0002676776986432375, 0.00024358377872039016, 0.0001540361226733564, 
   0.00004636779845680562, 6.032880754945187*^-7, 0.00009141593149953296, 
   0.000341212180480224, 0.0006906883026217617, 0.0010093161218068696, 
   0.0011497761570380626, 0.001025419847934751, 0.0006718999838045558, 
   0.00025501137153610047, 9.494901399940969*^-6, 0.00012898580582255698, 
   0.0006576286668414587, 0.0014414415347226725, 0.0021746704368647684, 
   0.0025312105568798303, 0.002325032757702768, 0.001621020645881183, 
   0.0007335299616315128, 0.00010034996342915512, 0.00008193843266551136, 
   0.0007787035548438082, 0.0019587573476721664, 0.003141347605037966, 
   0.0038073478531013413, 0.003643184654917677, 0.002701811004795008, 
   0.0013978936995776925, 0.00033073478337746084, 
   0.000011822027963360028, 0.0006233288516573675, 0.0019236124755445416, 
   0.0033487659791765706, 0.004266708554068881, 0.004266708554068977, 
   0.0033487659791768135, 0.0019236124755448235, 0.0006233288516575655, 
   0.000011822027963389123, 0.00033073478337731523, 
   0.0013978936995774451, 0.0027018110047947745, 0.0036431846549175627, 
   0.0038073478531013938, 0.00314134760503816, 0.001958757347672411, 
   0.0007787035548439985, 0.00008193843266557871, 0.00010034996342908419, 
   0.0007335299616313529, 0.0016210206458810168, 0.002325032757702674, 
   0.002531210556879847, 0.002174670436864884, 0.001441441534722831, 
   0.0006576286668415948, 0.0001289858058226219, 9.494901399924474*^-6, 
   0.0002550113715360281, 0.0006718999838044759, 0.001025419847934703, 
   0.001149776157038065, 0.0010093161218069182, 0.0006906883026218318, 
   0.00034121218048028564, 0.00009141593149956668, 6.032880754970441*^-7, 
   0.000046367798456787875, 0.00015403612267333473, 
   0.00024358377872037878, 0.00026767769864324007, 
   0.00022449122538799397, 0.00014514145738207053, 
   0.00006847658755560897, 0.00001941658972062541, 
   1.1732333573756481*^-6, 1.5493051919682984*^-6, 5.628678220430585*^-6, 
   5.522646188462218*^-6, 2.0966695552554206*^-6, 7.931067330964004*^-9, 
   1.5433509038385315*^-6, 4.392544319435357*^-6, 4.582372779777995*^-6, 
   1.503437061812861*^-6, 3.491369586699997*^-7, 9.341625439727938*^-6, 
   0.00003322266927530477, 0.00006765833227756891, 
   0.00009914167150545429, 0.00011158231058064656, 
   0.00009621136516128962, 0.000058719087063400656, 
   0.000018594889374944122, 1.9114728827049854*^-8, 
   0.000018801065527452945, 0.00007263018075826639, 
   0.0001405087926235449, 0.0001923226064602763, 0.00020383482262601344, 
   0.00016921085937553058, 0.0001043415254863476, 
   0.000039114621027476296, 2.6726845087489787*^-6, 
   9.341464439268325*^-6, 0.00005237744057571045, 0.00010837446469225171, 
   0.00014954681451152718, 0.00015723387056948461}, 
  {0.00001231792583064931, 0.00001171571088780703, 8.490210240201963*^-6, 
   4.103323449802553*^-6, 7.318236566705325*^-7, 2.0938191897343523*^-7, 
   3.064295237185337*^-6, 8.174264026843381*^-6, 0.000013256220227734039, 
   0.000015968710925431402, 0.000015066827480329938, 
   0.000011007659353690097, 5.689952021194949*^-6, 
   1.4729023070261235*^-6, 1.4974751375691285*^-9, 
   1.4567501729749147*^-6, 4.600137086688796*^-6, 7.537335663300979*^-6, 
   8.74151746545917*^-6, 7.766900044549745*^-6, 5.300450315203022*^-6, 
   2.602711327701021*^-6, 7.318362696761572*^-7, 2.7351887643961053*^-8, 
   1.1778140518564941*^-7, 3.5898962370670587*^-7, 3.441181911930313*^-7, 
   1.2090831253660687*^-7, 6.213311342285559*^-10, 
   1.6425608540619942*^-7, 4.326519845374388*^-7, 4.409586852549181*^-7, 
   1.2137477996690508*^-7, 9.191277570054874*^-8, 1.5211233508179924*^-6, 
   5.3645536015286045*^-6, 0.000011370588922788345, 
   0.000017586962999417755, 0.000020970252951632528, 
   0.000019082700877106157, 0.000012067409696517829, 
   3.632519509013999*^-6, 4.726244887021801*^-8, 7.161654546011798*^-6, 
   0.00002673104920998676, 0.00005410950740433666, 
   0.00007907126551719374, 0.00009007510514717758, 
   0.00008033285440591013, 0.00005263760369278449, 
   0.00001997795480818951, 7.438441271603563*^-7, 
   0.000010104932121649162, 0.00005151956835332223, 
   0.00011292458711105066, 0.00017036678579739243, 
   0.00019829864766716406, 0.00018214638461473692, 
   0.00012699307098143245, 0.000057465784116426384, 7.86155935837287*^-6, 
   6.419173760703176*^-6, 0.00006100474788216973, 0.00015345184623056704, 
   0.00024609765483096736, 0.0002982730648054577, 0.0002854122855597102, 
   0.00021166373024436913, 0.00010951298755264534, 
   0.000025910234967211602, 9.261545435032677*^-7, 0.0000488324718777832, 
   0.00015069854678797378, 0.00026234710629647814, 0.0003342600377365398, 
   0.0003342600377365473, 0.00026234710629649717, 0.00015069854678799588, 
   0.00004883247187779871, 9.26154543505547*^-7, 0.000025910234967200195, 
   0.00010951298755262594, 0.00021166373024435084, 0.0002854122855597012, 
   0.00029827306480546183, 0.0002460976548309826, 0.0001534518462305862, 
   0.000061004747882184636, 6.419173760708453*^-6, 7.861559358367311*^-6, 
   0.000057465784116413854, 0.00012699307098141941, 
   0.00018214638461472955, 0.00019829864766716536, 0.0001703667857974015, 
   0.00011292458711106307, 0.00005151956835333289, 
   0.00001010493212165425, 7.438441271590641*^-7, 0.00001997795480818384, 
   0.00005263760369277823, 0.00008033285440590638, 
   0.00009007510514717777, 0.00007907126551719753, 
   0.000054109507404342155, 0.000026731049209991586, 
   7.16165454601444*^-6, 4.726244887041585*^-8, 3.632519509012608*^-6, 
   0.000012067409696516133, 0.000019082700877105262, 
   0.000020970252951632728, 0.00001758696299941876, 
   0.000011370588922789607, 5.36455360152959*^-6, 1.5211233508184874*^-6, 
   9.191277570064383*^-8, 1.2137477996683907*^-7, 4.4095868525488073*^-7, 
   4.3265198453747893*^-7, 1.6425608540625363*^-7, 
   6.213311342324854*^-10, 1.2090831253656377*^-7, 3.441181911930005*^-7, 
   3.589896237067327*^-7, 1.177814051857001*^-7, 2.735188764392245*^-8, 
   7.318362696759135*^-7, 2.60271132770056*^-6, 5.300450315202484*^-6, 
   7.766900044549373*^-6, 8.741517465459184*^-6, 7.537335663301436*^-6, 
   4.6001370866894716*^-6, 1.4567501729754339*^-6, 
   1.4974751375882848*^-9, 1.4729023070255208*^-6, 5.689952021193971*^-6, 
   0.000011007659353689135, 0.000015066827480329425, 
   0.00001596871092543159, 0.000013256220227734843, 
   8.174264026844433*^-6, 3.0642952371861508*^-6, 2.0938191897366623*^-7, 
   7.318236566701214*^-7, 4.103323449801701*^-6, 8.490210240201127*^-6, 
   0.00001171571088780661, 0.000012317925830649475}, 
  {0.0002813443642505274, 0.00026758963130558993, 0.0001939184271137169, 
   0.00009372088638709772, 0.00001671502688522147, 4.782332974644268*^-6, 
   0.0000699892341644651, 0.00018670214023581113, 0.000302775232097677, 
   0.00036472916666191094, 0.0003441299336434108, 0.00025141756537001847, 
   0.0001299598614269877, 0.00003364144003386617, 3.4202689344992544*^-8, 
   0.00003327252143925834, 0.00010506822836191007, 
   0.00017215454448165482, 0.0001996583440846105, 0.00017739784970892744, 
   0.0001210635495516451, 0.00005944654756709887, 
   0.000016715314969278606, 6.247236382195719*^-7, 2.690155389638644*^-6, 
   8.199408637693938*^-6, 7.859741571697824*^-6, 2.7615746994169572*^-6, 
   1.4191351316115014*^-8, 3.7516481717970806*^-6, 9.881874530251036*^-6, 
   0.000010071601556091995, 2.7722289267946118*^-6, 
   2.099309721579084*^-6, 0.00003474282017656549, 0.00012252768390231362, 
   0.0002597069633002772, 0.00040169043004441567, 0.00047896557959212866, 
   0.00043585343995933203, 0.0002756225159896497, 0.00008296761207542601, 
   1.0794856060286592*^-6, 0.00016357389814900184, 0.0006105435402947914, 
   0.0012358740562232985, 0.0018060065658186274, 0.0020573368877880504, 
   0.0018348215569722749, 0.0012022554243482592, 0.0004563012532962755, 
   0.0000169895772985335, 0.00023079906005654663, 0.0011767192305023792, 
   0.0025792245062850115, 0.00389121802635879, 0.004529188414241066, 
   0.004160266873214637, 0.0029005520337355255, 0.0013125322169229036, 
   0.00017955989101637652, 0.00014661545990356914, 0.001393362993505541, 
   0.0035048767718170964, 0.0056209291396841065, 0.006812627949256321, 
   0.006518884683514439, 0.004834450088368337, 0.0025013027585790233, 
   0.0005917959471954115, 0.000021153590695547243, 0.001115345306029698, 
   0.0034419907557850533, 0.0059920704872483774, 0.00763457899521927, 
   0.007634578995219441, 0.005992070487248812, 0.0034419907557855576, 
   0.0011153453060300522, 0.000021153590695599305, 0.000591795947195151, 
   0.0025013027585785805, 0.004834450088367919, 0.006518884683514233, 
   0.006812627949256415, 0.005620929139684454, 0.003504876771817534, 
   0.0013933629935058817, 0.00014661545990368968, 0.00017955989101624959, 
   0.0013125322169226176, 0.002900552033735228, 0.004160266873214469, 
   0.004529188414241095, 0.0038912180263589967, 0.0025792245062852947, 
   0.0011767192305026225, 0.0002307990600566628, 0.000016989577298503987, 
   0.00045630125329614604, 0.0012022554243481163, 0.0018348215569721892, 
   0.0020573368877880548, 0.0018060065658187143, 0.0012358740562234238, 
   0.0006105435402949017, 0.00016357389814906218, 1.0794856060331777*^-6, 
   0.00008296761207539424, 0.000275622515989611, 0.00043585343995931165, 
   0.00047896557959213327, 0.0004016904300444386, 0.000259706963300306, 
   0.00012252768390233614, 0.0000347428201765768, 2.099309721581256*^-6, 
   2.772228926793104*^-6, 0.000010071601556091141, 9.881874530251952*^-6, 
   3.751648171798318*^-6, 1.4191351316204763*^-8, 2.7615746994159726*^-6, 
   7.859741571697121*^-6, 8.199408637694551*^-6, 2.6901553896398016*^-6, 
   6.247236382186902*^-7, 0.00001671531496927304, 0.00005944654756708833, 
   0.00012106354955163283, 0.00017739784970891893, 
   0.00019965834408461087, 0.00017215454448166526, 
   0.00010506822836192552, 0.000033272521439270197, 
   3.4202689345430077*^-8, 0.000033641440033852406, 
   0.00012995986142696534, 0.0002514175653699965, 0.00034412993364339907, 
   0.00036472916666191517, 0.00030277523209769537, 
   0.00018670214023583514, 0.00006998923416448369, 4.782332974649544*^-6, 
   0.000016715026885212083, 0.00009372088638707826, 
   0.00019391842711369783, 0.00026758963130558034, 
   0.0002813443642505312}, {0.00048112526823210867, 
   0.00045760338395614997, 0.000331618710432586, 0.00016027151182524118, 
   0.000028584264750005603, 8.178238228906227*^-6, 
   0.00011968815920816871, 0.00031927818259218957, 0.0005177740636287179, 
   0.0006237211063734908, 0.0005884944845863334, 0.00042994763338923746, 
   0.00022224356032519996, 0.00005753001984996369, 
   5.8489808847621775*^-8, 0.000056899134428607066, 
   0.00017967653159841698, 0.00029440042849892406, 0.0003414345071684044, 
   0.0003033669725440289, 0.00020703003206170404, 0.00010165917565075103, 
   0.000028584757400781215, 1.0683360543226765*^-6, 
   4.600418198792901*^-6, 0.000014021758319787525, 
   0.000013440895757737155, 4.722551921519421*^-6, 
   2.4268542669161087*^-8, 6.415670481890545*^-6, 0.00001689893290263112, 
   0.000017223383923506475, 4.740771650279709*^-6, 
   3.5900166530352553*^-6, 0.000059413483263184477, 
   0.00020953383921657547, 0.0004441232818451881, 0.0006869283357291499, 
   0.0008190760940567811, 0.0007453502890272584, 0.00047134037068624266, 
   0.0001418824035118096, 1.8460217006186766*^-6, 0.00027972671793997944, 
   0.001044086756008876, 0.0021134606281718823, 0.0030884407289377847, 
   0.0035182391679238405, 0.0031377170682198446, 0.0020559696124141554, 
   0.0007803179689475736, 0.000029053771724491725, 0.0003946880541688916, 
   0.002012300324257433, 0.004410715976923564, 0.006654348032414797, 
   0.007745337271924424, 0.0071144468119154645, 0.00496021620681736, 
   0.002244553277662225, 0.0003070642660965276, 0.00025072619691882255, 
   0.0023827814919302782, 0.005993668227380625, 0.009612316376936708, 
   0.011650233187300688, 0.011147904633828786, 0.008267363384786893, 
   0.004277462475059298, 0.001012026612267686, 0.00003617462544373083, 
   0.001907345153205626, 0.005886127237846093, 0.01024700291446365, 
   0.013055846619494558, 0.013055846619494849, 0.010247002914464393, 
   0.005886127237846955, 0.001907345153206232, 0.000036174625443819866, 
   0.0010120266122672405, 0.004277462475058541, 0.008267363384786178, 
   0.011147904633828436, 0.011650233187300848, 0.009612316376937304, 
   0.005993668227381373, 0.0023827814919308602, 0.00025072619691902866, 
   0.0003070642660963105, 0.0022445532776617354, 0.004960216206816851, 
   0.0071144468119151765, 0.007745337271924475, 0.0066543480324151505, 
   0.0044107159769240485, 0.002012300324257849, 0.00039468805416909036, 
   0.000029053771724441252, 0.0007803179689473522, 0.0020559696124139108, 
   0.003137717068219698, 0.003518239167923848, 0.003088440728937933, 
   0.002113460628172097, 0.0010440867560090644, 0.00027972671794008265, 
   1.8460217006264037*^-6, 0.00014188240351175528, 
   0.00047134037068617647, 0.0007453502890272235, 0.000819076094056789, 
   0.0006869283357291892, 0.0004441232818452374, 0.00020953383921661398, 
   0.000059413483263203816, 3.5900166530389695*^-6, 4.74077165027713*^-6, 
   0.000017223383923505015, 0.000016898932902632687, 
   6.415670481892661*^-6, 2.426854266931457*^-8, 4.722551921517738*^-6, 
   0.000013440895757735954, 0.000014021758319788574, 
   4.6004181987948805*^-6, 1.0683360543211686*^-6, 
   0.000028584757400771698, 0.00010165917565073301, 
   0.00020703003206168304, 0.00030336697254401435, 0.000341434507168405, 
   0.00029440042849894195, 0.0001796765315984434, 
   0.000056899134428627354, 5.8489808848369997*^-8, 
   0.00005753001984994016, 0.00022224356032516174, 0.0004299476333891999, 
   0.0005884944845863133, 0.0006237211063734979, 0.0005177740636287493, 
   0.00031927818259223066, 0.0001196881592082005, 8.178238228915248*^-6, 
   0.000028584264749989546, 0.0001602715118252079, 0.0003316187104325534, 
   0.0004576033839561336, 0.00048112526823211507}, 
  {0.0003047436794588384, 0.0002898449700470464, 0.0002100465568270002, 
   0.00010151562067301787, 0.00001810520999354352, 5.180077983693585*^-6, 
   0.00007581021499614186, 0.00020223009382067068, 0.0003279569453052475, 
   0.0003950635675628191, 0.00037275110333127024, 0.0002723278788809036, 
   0.00014076857895740396, 0.00003643938717423597, 3.704731539992486*^-8, 
   0.00003603978574542803, 0.0001138067172254364, 0.000186472579469135, 
   0.00021626386074264126, 0.00019215196861112606, 
   0.00013113236384526786, 0.00006439069673558817, 
   0.00001810552203745383, 6.766816910056076*^-7, 2.9138946996091053*^-6, 
   8.881350668934708*^-6, 8.513433608437023*^-6, 2.991253929122134*^-6, 
   1.537164118459078*^-8, 4.063671475894236*^-6, 0.000010703746678279642, 
   0.000010909253236413754, 3.002794264971785*^-6, 2.273908598034127*^-6, 
   0.00003763236872928933, 0.00013271826975254768, 
   0.00028130670322129824, 0.0004350988866659299, 0.0005188009841528815, 
   0.00047210322251105735, 0.0002985459470216877, 0.00008986800018949187, 
   1.1692660572048792*^-6, 0.00017717828369564947, 0.0006613222391530861, 
   0.0013386612816805382, 0.0019562115184376134, 0.0022284448979139285, 
   0.0019874230426177, 0.0013022465996119512, 0.0004942516735375683, 
   0.00001840259467147206, 0.00024999453948415664, 0.0012745865691979848, 
   0.002793737732367698, 0.004214849307851076, 0.00490587947618921, 
   0.0045062748559100314, 0.003141789961128477, 0.001421695075566462, 
   0.00019449382615971845, 0.00015880941790174738, 0.0015092485203810656, 
   0.0037963761824006577, 0.006088419906927374, 0.007379231901698204, 
   0.007061058108322604, 0.005236529660063063, 0.0027093352593732826, 
   0.0006410154151037699, 0.000022912927648292956, 0.001208108196274264, 
   0.0037282599577762063, 0.006490428954300127, 0.008269544336955453, 
   0.008269544336955639, 0.006490428954300598, 0.0037282599577767527, 
   0.0012081081962746476, 0.000022912927648349348, 0.0006410154151034877, 
   0.002709335259372803, 0.005236529660062611, 0.007061058108322382, 
   0.0073792319016983045, 0.00608841990692775, 0.0037963761824011317, 
   0.0015092485203814345, 0.00015880941790187791, 0.00019449382615958097, 
   0.0014216950755661522, 0.0031417899611281544, 0.004506274855909849, 
   0.004905879476189242, 0.0042148493078513006, 0.002793737732368005, 
   0.0012745865691982485, 0.0002499945394842825, 0.00001840259467144009, 
   0.0004942516735374281, 0.0013022465996117964, 0.001987423042617607, 
   0.0022284448979139333, 0.0019562115184377075, 0.0013386612816806741, 
   0.0006613222391532055, 0.00017717828369571482, 1.1692660572097736*^-6, 
   0.00008986800018945746, 0.0002985459470216457, 0.0004721032225110353, 
   0.0005188009841528864, 0.00043509888666595477, 0.0002813067032213295, 
   0.00013271826975257207, 0.00003763236872930158, 
   2.2739085980364796*^-6, 3.002794264970152*^-6, 
   0.000010909253236412829, 0.000010703746678280635, 
   4.063671475895577*^-6, 1.5371641184687995*^-8, 2.9912539291210674*^-6, 
   8.513433608436262*^-6, 8.881350668935372*^-6, 2.913894699610359*^-6, 
   6.766816910046525*^-7, 0.0000181055220374478, 0.00006439069673557674, 
   0.00013113236384525455, 0.00019215196861111685, 
   0.00021626386074264164, 0.00018647257946914633, 
   0.00011380671722545313, 0.00003603978574544088, 3.704731540039878*^-8, 
   0.00003643938717422107, 0.00014076857895737972, 
   0.00027232787888087975, 0.00037275110333125755, 
   0.00039506356756282364, 0.0003279569453052674, 0.0002022300938206967, 
   0.00007581021499616198, 5.1800779836993*^-6, 0.00001810520999353335, 
   0.0001015156206729968, 0.00021004655682697955, 0.000289844970047036, 
   0.00030474367945884244}, {0.00003520245947784604, 
   0.00003348143538549354, 0.000024263523424978163, 
   0.000011726574705195772, 2.091422937031563*^-6, 5.983765951663849*^-7, 
   8.757215329773366*^-6, 0.000023360604871494058, 
   0.00003788393937517419, 0.00004563575937981636, 
   0.00004305833556135755, 0.00003145794898196612, 
   0.00001626087932422995, 4.2092950136865635*^-6, 4.27951982940138*^-9, 
   4.163135063364112*^-6, 0.000013146380455041514, 
   0.000021540375945281217, 0.000024981715151023033, 
   0.000022196430457994626, 0.000015147752145982445, 
   7.438089927279295*^-6, 2.0914589827770484*^-6, 7.816687075947285*^-8, 
   3.365984825931553*^-7, 1.025929028575452*^-6, 9.834290973664525*^-7, 
   3.4553463230102023*^-7, 1.7756547957597105*^-9, 
   4.6941492179747594*^-7, 1.2364430637983497*^-6, 
   1.2601821493734612*^-6, 3.4686771394468054*^-7, 2.626705020454215*^-7, 
   4.347102251966811*^-6, 0.000015330948032229645, 
   0.00003249513767957169, 0.00005026043839174072, 
   0.00005992928435510094, 0.000054534993438808244, 
   0.0000344865285507116, 0.000010381100079396236, 1.350677430641681*^-7, 
   0.000020466745571971264, 0.00007639262401414095, 
   0.00015463542872030475, 0.00022597173083354182, 
   0.00025741876371885057, 0.0002295771293676227, 0.00015042898751635773, 
   0.00005709347127546874, 2.1257753216083393*^-6, 
   0.000028878113769255312, 0.00014723383970711447, 
   0.00032271855314619253, 0.00048687822575462365, 0.0005667025605598282, 
   0.0005205422415746469, 0.00036292379875090154, 0.00016422707560778636, 
   0.00002246695008157995, 0.00001834486644091887, 
   0.00017434080987359648, 0.00043853831180662754, 0.0007033036925928145, 
   0.0008524118119806534, 0.0008156579731869928, 0.0006048976093294414, 
   0.0003129688033213821, 0.00007404688167753456, 2.6467863369313854*^-6, 
   0.00013955459191055265, 0.00043066986760662246, 0.0007497417589212035, 
   0.0009552562334971922, 0.0009552562334972136, 0.0007497417589212579, 
   0.00043066986760668556, 0.000139554591910597, 2.6467863369378995*^-6, 
   0.00007404688167750196, 0.00031296880332132667, 0.0006048976093293891, 
   0.0008156579731869672, 0.0008524118119806651, 0.000703303692592858, 
   0.0004385383118066823, 0.00017434080987363906, 
   0.000018344866440933946, 0.00002246695008156407, 
   0.00016422707560775055, 0.00036292379875086435, 0.0005205422415746259, 
   0.0005667025605598319, 0.0004868782257546495, 0.000322718553146228, 
   0.00014723383970714491, 0.00002887811376926985, 2.125775321604646*^-6, 
   0.000057093471275452545, 0.00015042898751633984, 
   0.00022957712936761196, 0.0002574187637188511, 0.0002259717308335527, 
   0.00015463542872032045, 0.00007639262401415474, 
   0.000020466745571978816, 1.3506774306473346*^-7, 
   0.000010381100079392262, 0.00003448652855070676, 
   0.00005453499343880569, 0.00005992928435510151, 
   0.00005026043839174359, 0.0000324951376795753, 
   0.000015330948032232464, 4.3471022519682265*^-6, 
   2.626705020456932*^-7, 3.4686771394449187*^-7, 1.2601821493733543*^-6, 
   1.2364430637984643*^-6, 4.694149217976308*^-7, 1.7756547957709403*^-9, 
   3.4553463230089704*^-7, 9.834290973663648*^-7, 1.0259290285755287*^-6, 
   3.3659848259330013*^-7, 7.816687075936253*^-8, 2.091458982776352*^-6, 
   7.438089927277977*^-6, 0.000015147752145980909, 
   0.00002219643045799356, 0.000024981715151023077, 
   0.000021540375945282524, 0.000013146380455043445, 
   4.163135063365596*^-6, 4.279519829456124*^-9, 4.2092950136848415*^-6, 
   0.000016260879324227154, 0.00003145794898196337, 
   0.00004305833556135608, 0.00004563575937981688, 
   0.000037883939375176485, 0.000023360604871497063, 
   8.757215329775692*^-6, 5.98376595167045*^-7, 2.0914229370303882*^-6, 
   0.000011726574705193336, 0.000024263523424975774, 
   0.00003348143538549234, 0.00003520245947784652}, 
  {0.000053153984450201, 0.000050555322618038485, 0.00003663672839819688, 
   0.00001770655172336372, 3.1579458913582564*^-6, 9.035192627621593*^-7, 
   0.000013222964939673502, 0.00003527336573934925, 
   0.00005720288736437965, 0.0000689077547543078, 0.00006501597140734718, 
   0.000047499957554811065, 0.000024553128945171083, 
   6.3558286842034705*^-6, 6.4618647060579285*^-9, 
   6.2861294268772674*^-6, 0.000019850388656038865, 
   0.00003252490948160929, 0.000037721162622529314, 
   0.00003351551956637335, 0.0000228723615896714, 
   0.000011231150385461413, 3.1580003186631503*^-6, 
   1.1802813480929313*^-7, 5.082471729277187*^-7, 1.5491024332043657*^-6, 
   1.4849296249368227*^-6, 5.217403199879532*^-7, 2.6811515105112074*^-9, 
   7.087934713657702*^-7, 1.8669682846466195*^-6, 1.9028131376551308*^-6, 
   5.237532077807099*^-7, 3.9661955409779015*^-7, 6.563910844067422*^-6, 
   0.00002314897837819587, 0.00004906606153510671, 
   0.00007589079286963324, 0.00009049027528111856, 0.0000823451609982677, 
   0.000052072963921158955, 0.00001567495113639631, 
   2.0394565666852733*^-7, 0.000030903780361239304, 
   0.0001153491093857558, 0.00023349190072420971, 0.00034120621243723484, 
   0.00038868968722235905, 0.00034665018710434346, 
   0.00022714038115251626, 0.00008620833684345603, 
   3.2098163044687493*^-6, 0.00004360453312099245, 0.0002223158649258733, 
   0.00048728916133031745, 0.0007351622024361527, 0.0008556930265296715, 
   0.0007859932125408572, 0.0005479971070644539, 0.0002479748163236118, 
   0.000033923990908399266, 0.000027699847113105174, 
   0.00026324605821614644, 0.0006621713071285997, 0.0010619540252116162, 
   0.0012870999603792363, 0.0012316034693754501, 0.0009133656737960468, 
   0.0004725675180625376, 0.00011180715369477285, 3.99651734234064*^-6, 
   0.00021072057800495324, 0.0006502903429329715, 0.0011320732240440161, 
   0.0014423899845186095, 0.0014423899845186418, 0.001132073224044098, 
   0.0006502903429330667, 0.00021072057800502016, 3.996517342350475*^-6, 
   0.00011180715369472362, 0.00047256751806245396, 0.0009133656737959679, 
   0.0012316034693754113, 0.0012870999603792539, 0.0010619540252116816, 
   0.0006621713071286824, 0.0002632460582162108, 0.000027699847113127946, 
   0.000033923990908375285, 0.0002479748163235577, 0.0005479971070643978, 
   0.0007859932125408253, 0.0008556930265296771, 0.0007351622024361919, 
   0.000487289161330371, 0.00022231586492591927, 0.0000436045331210144, 
   3.209816304463173*^-6, 0.00008620833684343156, 0.0002271403811524893, 
   0.00034665018710432725, 0.0003886896872223599, 0.0003412062124372512, 
   0.0002334919007242334, 0.00011534910938577664, 0.0000309037803612507, 
   2.03945656669381*^-7, 0.00001567495113639031, 0.000052072963921151644, 
   0.00008234516099826385, 0.00009049027528111943, 
   0.00007589079286963757, 0.00004906606153511216, 
   0.00002314897837820012, 6.563910844069559*^-6, 3.966195540982005*^-7, 
   5.23753207780425*^-7, 1.9028131376549696*^-6, 1.8669682846467927*^-6, 
   7.08793471366004*^-7, 2.681151510528164*^-9, 5.217403199877672*^-7, 
   1.4849296249366902*^-6, 1.5491024332044815*^-6, 5.082471729279374*^-7, 
   1.1802813480912655*^-7, 3.1580003186620987*^-6, 
   0.000011231150385459422, 0.00002287236158966908, 
   0.000033515519566371745, 0.00003772116262252938, 
   0.00003252490948161126, 0.000019850388656041786, 
   6.286129426879508*^-6, 6.461864706140591*^-9, 6.355828684200871*^-6, 
   0.000024553128945166858, 0.00004749995755480692, 
   0.00006501597140734496, 0.00006890775475430858, 
   0.000057202887364383123, 0.000035273365739353793, 
   0.000013222964939677012, 9.03519262763156*^-7, 3.1579458913564823*^-6, 
   0.000017706551723360042, 0.000036636728398193276, 
   0.000050555322618036676, 0.000053153984450201714}, 
  {0.0002732869917177251, 0.0002599261781879563, 0.00018836483085671508, 
   0.00009103683014969302, 0.000016236328124473916, 
   4.6453725686476465*^-6, 0.00006798482460591261, 
   0.00018135520996920062, 0.0002941041046513695, 0.0003542837512109844, 
   0.00033427445606012984, 0.0002442172612485094, 0.00012623796345821882, 
   0.00003267798865777456, 3.322316444706029*^-8, 
   0.000032319635458919195, 0.00010205919756248873, 
   0.00016722424029092146, 0.0001939403633393498, 0.00017231738340767213, 
   0.00011759643151827171, 0.00005774406818453497, 
   0.00001623660795814162, 6.068322861159255*^-7, 2.613112495237023*^-6, 
   7.964587193452218*^-6, 7.634647793745583*^-6, 2.6824864397688973*^-6, 
   1.3784927663014952*^-8, 3.644205369405423*^-6, 9.59886923663249*^-6, 
   9.783162703031753*^-6, 2.69283554257347*^-6, 2.0391879539596906*^-6, 
   0.000033747826565271835, 0.00011901863477878728, 
   0.00025226926054675833, 0.00039018648737134553, 0.0004652485672914064, 
   0.0004233711087606571, 0.00026772901047844875, 0.00008059151699909649, 
   1.0485704046712732*^-6, 0.00015888933360284457, 0.0005930582895603192, 
   0.001200480073119555, 0.0017542846564914162, 0.0019984171728879736, 
   0.0017822744201027496, 0.0011678242394216958, 0.00044323332071199664, 
   0.000016503015736037694, 0.00022418924573860182, 
   0.0011430193722097588, 0.0025053585422439967, 0.003779778107068955, 
   0.004399477771477678, 0.004041121710585689, 0.0028174836262739363, 
   0.001274942834028297, 0.00017441750638847608, 0.0001424165651339577, 
   0.0013534587119962884, 0.00340450121282083, 0.005459952323320407, 
   0.006617522277028744, 0.006332191473812597, 0.0046959971093758855, 
   0.0024296683819783568, 0.0005748476055335539, 0.00002054777667437612, 
   0.0010834031249331137, 0.0033434161785131714, 0.005820464618095162, 
   0.0074159336093077444, 0.007415933609307911, 0.005820464618095584, 
   0.0033434161785136614, 0.0010834031249334578, 0.00002054777667442669, 
   0.0005748476055333008, 0.002429668381977927, 0.0046959971093754795, 
   0.006332191473812397, 0.0066175222770288354, 0.005459952323320744, 
   0.003404501212821255, 0.001353458711996619, 0.00014241656513407476, 
   0.00017441750638835278, 0.001274942834028019, 0.002817483626273647, 
   0.004041121710585525, 0.004399477771477707, 0.0037797781070691558, 
   0.0025053585422442726, 0.0011430193722099951, 0.0002241892457387147, 
   0.000016503015736009024, 0.00044323332071187087, 0.001167824239421557, 
   0.0017822744201026663, 0.001998417172887978, 0.0017542846564915005, 
   0.0012004800731196768, 0.0005930582895604263, 0.0001588893336029032, 
   1.0485704046756623*^-6, 0.00008059151699906563, 
   0.00026772901047841113, 0.00042337110876063724, 
   0.00046524856729141087, 0.0003901864873713678, 0.00025226926054678636, 
   0.00011901863477880915, 0.00003374782656528282, 
   2.0391879539618005*^-6, 2.6928355425720054*^-6, 9.783162703030925*^-6, 
   9.59886923663338*^-6, 3.644205369406625*^-6, 1.3784927663102134*^-8, 
   2.6824864397679406*^-6, 7.6346477937449*^-6, 7.964587193452814*^-6, 
   2.6131124952381473*^-6, 6.068322861150691*^-7, 
   0.000016236607958136215, 0.00005774406818452473, 
   0.00011759643151825977, 0.00017231738340766386, 
   0.00019394036333935012, 0.00016722424029093163, 
   0.00010205919756250373, 0.000032319635458930715, 
   3.322316444748529*^-8, 0.00003267798865776119, 0.0001262379634581971, 
   0.0002442172612484881, 0.00033427445606011845, 0.0003542837512109885, 
   0.00029410410465138733, 0.00018135520996922393, 
   0.00006798482460593066, 4.645372568652772*^-6, 
   0.000016236328124464796, 0.0000910368301496741, 
   0.00018836483085669654, 0.000259926178187947, 0.00027328699171772874}, 
  {0.000329761854079187, 0.00031364002327454474, 0.00022729049588566302, 
   0.00010984962625174123, 0.00001959157160065188, 5.60534060365409*^-6, 
   0.00008203391486137838, 0.00021883233413515246, 0.0003548808314385809, 
   0.00042749662519661825, 0.0004033524014767465, 0.00029468485258395247, 
   0.0001523250873505185, 0.00003943090763169854, 4.0088744208346276*^-8, 
   0.00003899850060593052, 0.00012314977014640498, 
   0.00020178119411653345, 0.0002340182143086878, 0.00020792683722495152, 
   0.00014189777949846807, 0.00006967690217130893, 
   0.000019591909262055063, 7.322344123550188*^-7, 
   3.1531132013663357*^-6, 9.610472212306934*^-6, 9.212350708253006*^-6, 
   3.23682329832275*^-6, 1.663358828728493*^-8, 4.397281816112577*^-6, 
   0.000011582479270747887, 0.00001180485705313891, 
   3.2493110472179372*^-6, 2.460586932027315*^-6, 0.00004072182795587151, 
   0.0001436138816119177, 0.0003044008006462643, 0.00047081867564746914, 
   0.0005613923633663711, 0.0005108609118603004, 0.0003230553138707376, 
   0.0000972457851053753, 1.2652578836760481*^-6, 0.00019172387574304796, 
   0.0007156140140927093, 0.001448559743765318, 0.0021168082581288794, 
   0.002411390853304502, 0.002150582117198048, 0.0014091555694245562, 
   0.0005348276575806849, 0.00001991337031012012, 0.000270518039935601, 
   0.0013792247668254877, 0.0030230918523807843, 0.004560870712362328, 
   0.00530863155170277, 0.004876221072457146, 0.003399717705544871, 
   0.0015384102629678001, 0.00021046095143064902, 0.0001718470033095146, 
   0.0016331514774348358, 0.004108042703013962, 0.006588253579159746, 
   0.00798503581076884, 0.007640741286894662, 0.00566642672527123, 
   0.002931760291270372, 0.0006936400851802088, 0.0000247939826581503, 
   0.0013072887990297887, 0.004034334422780155, 0.007023265878852586, 
   0.00894843915315003, 0.008948439153150231, 0.007023265878853095, 
   0.004034334422780747, 0.001307288799030204, 0.000024793982658211323, 
   0.0006936400851799034, 0.0029317602912698527, 0.00566642672527074, 
   0.007640741286894422, 0.00798503581076895, 0.0065882535791601535, 
   0.004108042703014475, 0.001633151477435235, 0.00017184700330965586, 
   0.00021046095143050024, 0.0015384102629674647, 0.003399717705544522, 
   0.0048762210724569485, 0.005308631551702804, 0.004560870712362571, 
   0.003023091852381117, 0.001379224766825773, 0.0002705180399357372, 
   0.000019913370310085524, 0.0005348276575805332, 0.0014091555694243885, 
   0.0021505821171979474, 0.002411390853304507, 0.0021168082581289813, 
   0.001448559743765465, 0.0007156140140928385, 0.00019172387574311868, 
   1.2652578836813442*^-6, 0.00009724578510533808, 
   0.00032305531387069223, 0.0005108609118602765, 0.0005613923633663766, 
   0.00047081867564749603, 0.00030440080064629815, 0.0001436138816119441, 
   0.000040721827955884766, 2.4605869320298607*^-6, 3.24931104721617*^-6, 
   0.00001180485705313791, 0.000011582479270748963, 
   4.397281816114028*^-6, 1.6633588287390126*^-8, 3.236823298321596*^-6, 
   9.212350708252182*^-6, 9.610472212307654*^-6, 3.1531132013676926*^-6, 
   7.322344123539853*^-7, 0.00001959190926204854, 0.00006967690217129659, 
   0.00014189777949845367, 0.00020792683722494154, 0.0002340182143086882, 
   0.0002017811941165457, 0.00012314977014642308, 
   0.000038998500605944415, 4.00887442088591*^-8, 0.00003943090763168241, 
   0.0001523250873504923, 0.0002946848525839267, 0.00040335240147673277, 
   0.0004274966251966232, 0.00035488083143860245, 0.0002188323341351806, 
   0.00008203391486140016, 5.605340603660274*^-6, 
   0.000019591571600640873, 0.00010984962625171841, 
   0.00022729049588564066, 0.00031364002327453346, 
   0.00032976185407919146}, {0.00014349241432579145, 
   0.00013647716863592906, 0.00009890307688562521, 
   0.00004779991344863999, 8.525067028338196*^-6, 2.439105209978499*^-6, 
   0.0000356961981940729, 0.00009522259645611082, 0.00015442267403323714, 
   0.0001860206755474522, 0.00017551456966913404, 0.00012822902479301686, 
   0.00006628266512919425, 0.00001715794615156128, 
   1.7444196842620075*^-8, 0.000016969788766674703, 
   0.000053587331655803055, 0.00008780297160256053, 
   0.00010183057303923463, 0.00009047718378417875, 
   0.00006174533141366481, 0.00003031917364493655, 8.525213958158513*^-6, 
   3.1862412944833176*^-7, 1.372044159473742*^-6, 4.181896248750773*^-6, 
   4.008657849266292*^-6, 1.4084697307371711*^-6, 7.237931594327374*^-9, 
   1.9134310911333475*^-6, 5.039994450173562*^-6, 5.1367598112757614*^-6, 
   1.413903643775622*^-6, 1.0706986122485413*^-6, 
   0.000017719676599538838, 0.00006249207526060275, 
   0.00013245681775232723, 0.00020487181171083502, 
   0.00024428400255221294, 0.00022229577108669128, 
   0.00014057413365027002, 0.000042315484083936995, 
   5.505637059822571*^-7, 0.0000834266349304965, 0.00031139193735511806, 
   0.0006303255890783586, 0.0009211069256990117, 0.001049291454252629, 
   0.0009358032664642787, 0.0006131792756381371, 0.0002327246492738101, 
   8.665094363754115*^-6, 0.00011771308957924195, 0.00060015520061393, 
   0.0013154667323121612, 0.001984615084640769, 0.002309995376047896, 
   0.002121836488416741, 0.0014793515246236703, 0.000669423100719878, 
   0.00009157987701887138, 0.000074777422235178, 0.0007106487471427904, 
   0.0017875717227965706, 0.002866809488635258, 0.00347460463601706, 
   0.0033247884827575895, 0.0024656861955115843, 0.0012757247608082964, 
   0.0003018302125137699, 0.00001078884166970827, 0.00056885301824147, 
   0.0017554983372435795, 0.0030561005311624235, 0.003893819502314535, 
   0.003893819502314623, 0.003056100531162645, 0.0017554983372438369, 
   0.0005688530182416507, 0.000010788841669734822, 0.000301830212513637, 
   0.0012757247608080706, 0.0024656861955113713, 0.0033247884827574846, 
   0.0034746046360171075, 0.002866809488635435, 0.001787571722796794, 
   0.000710648747142964, 0.00007477742223523947, 0.00009157987701880664, 
   0.0006694231007197321, 0.0014793515246235185, 0.002121836488416655, 
   0.002309995376047911, 0.001984615084640875, 0.0013154667323123058, 
   0.0006001552006140541, 0.00011771308957930121, 8.665094363739061*^-6, 
   0.00023272464927374408, 0.0006131792756380643, 0.000935803266464235, 
   0.0010492914542526311, 0.0009211069256990559, 0.0006303255890784226, 
   0.0003113919373551743, 0.00008342663493052727, 5.505637059845617*^-7, 
   0.00004231548408392079, 0.0001405741336502503, 0.0002222957710866809, 
   0.00024428400255221527, 0.00020487181171084673, 
   0.00013245681775234195, 0.00006249207526061423, 
   0.000017719676599544608, 1.070698612249649*^-6, 
   1.4139036437748531*^-6, 5.136759811275326*^-6, 5.03999445017403*^-6, 
   1.9134310911339786*^-6, 7.237931594373148*^-9, 1.408469730736669*^-6, 
   4.008657849265934*^-6, 4.181896248751086*^-6, 1.3720441594743325*^-6, 
   3.186241294478821*^-7, 8.525213958155675*^-6, 0.000030319173644931176, 
   0.00006174533141365853, 0.00009047718378417441, 0.0001018305730392348, 
   0.00008780297160256586, 0.00005358733165581093, 
   0.00001696978876668075, 1.7444196842843225*^-8, 
   0.00001715794615155426, 0.00006628266512918285, 
   0.00012822902479300564, 0.00017551456966912805, 
   0.00018602067554745433, 0.00015442267403324651, 
   0.00009522259645612308, 0.000035696198194082374, 2.43910520998119*^-6, 
   8.525067028333407*^-6, 0.00004779991344863006, 0.00009890307688561547, 
   0.00013647716863592418, 0.00014349241432579337}, 
  {1.1899520996943356*^-6, 1.1317761579363961*^-6, 8.201821995905071*^-7, 
   3.963945246908643*^-7, 7.069656927908153*^-8, 2.0226981193580943*^-8, 
   2.9602098613868947*^-7, 7.896607574950321*^-7, 1.2805944207549382*^-6, 
   1.5426299326992564*^-6, 1.4555050292104132*^-6, 
   1.0633760537875445*^-6, 5.496680567708902*^-7, 1.4228720135084448*^-7, 
   1.446610175031813*^-10, 1.4072685214164914*^-7, 4.443883540495852*^-7, 
   7.28131385263684*^-7, 8.444593030959604*^-7, 7.503080586125608*^-7, 
   5.12040912456839*^-7, 2.5143046417684154*^-7, 7.069778773685867*^-8, 
   2.6422821975068954*^-9, 1.137807065349288*^-8, 3.467957693294183*^-8, 
   3.324294769938385*^-8, 1.1680140175503094*^-8, 6.002262864264706*^-11, 
   1.58676774323763*^-8, 4.179560297044817*^-8, 4.259805754731389*^-8, 
   1.1725202461617955*^-8, 8.87907606664305*^-9, 1.4694551258753117*^-7, 
   5.182335004955359*^-7, 1.0984362423880513*^-6, 1.698958399013237*^-6, 
   2.0257953225231503*^-6, 1.8434515915050318*^-6, 1.165751418190366*^-6, 
   3.5091331741717376*^-7, 4.565707818265662*^-9, 6.918393552190276*^-7, 
   2.5823071653273332*^-6, 5.2271561652861945*^-6, 7.638543998499886*^-6, 
   8.701551054429593*^-6, 7.760417629476278*^-6, 5.084965431538526*^-6, 
   1.9299360621617355*^-6, 7.18577862157097*^-8, 9.76169637708504*^-7, 
   4.976959544994277*^-6, 0.000010908886072812748, 
   0.000016457991163849694, 0.000019156300776788388, 
   0.000017595939105651607, 0.00001226794782973796, 
   5.551383521061388*^-6, 7.594524592842373*^-7, 6.201132723047808*^-7, 
   5.893259046347488*^-6, 0.000014823952436025525, 
   0.000023773841888811317, 0.00002881415788885374, 
   0.000027571764365984482, 0.000020447411658115642, 
   0.000010579314348347614, 2.5030138130959837*^-6, 
   8.946957132514807*^-8, 4.717377198330612*^-6, 0.000014557974665267314, 
   0.000025343592279916444, 0.00003229061769139884, 
   0.000032290617691399566, 0.000025343592279918284, 
   0.000014557974665269447, 4.71737719833211*^-6, 8.946957132536826*^-8, 
   2.5030138130948817*^-6, 0.000010579314348345742, 
   0.000020447411658113873, 0.000027571764365983615, 
   0.000028814157888854134, 0.000023773841888812784, 
   0.000014823952436027377, 5.893259046348928*^-6, 6.201132723052907*^-7, 
   7.594524592837004*^-7, 5.551383521060177*^-6, 0.0000122679478297367, 
   0.000017595939105650893, 0.000019156300776788513, 
   0.000016457991163850568, 0.000010908886072813947, 
   4.976959544995306*^-6, 9.761696377089953*^-7, 7.185778621558487*^-8, 
   1.929936062161188*^-6, 5.084965431537921*^-6, 7.760417629475915*^-6, 
   8.701551054429611*^-6, 7.638543998500252*^-6, 5.2271561652867256*^-6, 
   2.5823071653277995*^-6, 6.918393552192828*^-7, 4.565707818284773*^-9, 
   3.509133174170394*^-7, 1.1657514181902024*^-6, 1.8434515915049456*^-6, 
   2.02579532252317*^-6, 1.698958399013334*^-6, 1.0984362423881733*^-6, 
   5.182335004956311*^-7, 1.46945512587579*^-7, 8.879076066652236*^-9, 
   1.172520246161158*^-8, 4.2598057547310276*^-8, 4.1795602970452045*^-8, 
   1.5867677432381534*^-8, 6.002262864302665*^-11, 1.168014017549893*^-8, 
   3.324294769938088*^-8, 3.467957693294442*^-8, 1.1378070653497777*^-8, 
   2.6422821975031665*^-9, 7.069778773683512*^-8, 2.5143046417679696*^-7, 
   5.120409124567871*^-7, 7.503080586125248*^-7, 8.444593030959618*^-7, 
   7.281313852637283*^-7, 4.443883540496505*^-7, 1.4072685214169933*^-7, 
   1.4466101750503182*^-10, 1.4228720135078628*^-7, 
   5.496680567707956*^-7, 1.0633760537874515*^-6, 1.4555050292103636*^-6, 
   1.5426299326992742*^-6, 1.2805944207550159*^-6, 7.896607574951337*^-7, 
   2.960209861387681*^-7, 2.0226981193603257*^-8, 7.069656927904181*^-8, 
   3.963945246907819*^-7, 8.201821995904264*^-7, 1.1317761579363555*^-6, 
   1.1899520996943515*^-6}, {0.00009236869850160253, 
   0.00008785285620369303, 0.00006366572430084967, 
   0.00003076968085376014, 5.4877419809709516*^-6, 
   1.5700967525897766*^-6, 0.00002297829738341175, 
   0.00006129653155479271, 0.00009940470711714504, 
   0.00011974492014396779, 0.00011298194712647457, 0.000082543374755468, 
   0.00004266736705189561, 0.000011044884584504699, 
   1.1229149403676626*^-8, 0.000010923764225375621, 
   0.000034495148084845995, 0.00005652038297361019, 
   0.00006555020726009099, 0.000058241822395295405, 
   0.00003974660213243906, 0.000019517008075900117, 
   5.487836562390727*^-6, 2.0510419513555148*^-7, 8.832099863451491*^-7, 
   2.691963303989186*^-6, 2.5804465693515553*^-6, 9.066577945487328*^-7, 
   4.659189298283911*^-9, 1.2317106823445573*^-6, 3.2443368522663125*^-6, 
   3.3066264897154*^-6, 9.101557040200516*^-7, 6.892283314456264*^-7, 
   0.000011406480775022508, 0.00004022729484069005, 
   0.00008526488261370986, 0.00013187974218922756, 0.0001572500921845201, 
   0.00014309586436442857, 0.00009049014771460221, 
   0.00002723925309685166, 3.544079539169016*^-7, 0.00005370325480343673, 
   0.00020044870045938685, 0.0004057521407593947, 0.000592933419563611, 
   0.0006754481512737942, 0.0006023937236194176, 0.000394714744364503, 
   0.00014980912450087588, 5.577880144634779*^-6, 0.00007577407441448846, 
   0.0003863309084326477, 0.0008467900589501082, 0.0012775331243553142, 
   0.0014869863848399442, 0.0013658650583666242, 0.0009522857051216888, 
   0.0004309199259830717, 0.000058951646251933754, 
   0.000048135597980015994, 0.00045745763059180385, 
   0.0011506926989053288, 0.0018454178401100848, 0.0022366667223804827, 
   0.0021402273171609513, 0.0015872074204262415, 0.0008212074230947719, 
   0.0001942936428336889, 6.9449752312912904*^-6, 0.0003661811196121787, 
   0.0011300464724550336, 0.0019672679554517086, 0.002506523019484135, 
   0.0025065230194841913, 0.0019672679554518513, 0.001130046472455199, 
   0.00036618111961229504, 6.944975231308383*^-6, 0.00019429364283360336, 
   0.0008212074230946265, 0.0015872074204261045, 0.002140227317160884, 
   0.0022366667223805135, 0.0018454178401101989, 0.0011506926989054726, 
   0.00045745763059191563, 0.00004813559798005556, 
   0.00005895164625189208, 0.0004309199259829778, 0.0009522857051215911, 
   0.001365865058366569, 0.001486986384839954, 0.001277533124355382, 
   0.0008467900589502013, 0.0003863309084327276, 0.0000757740744145266, 
   5.577880144625088*^-6, 0.00014980912450083338, 0.0003947147443644561, 
   0.0006023937236193895, 0.0006754481512737956, 0.0005929334195636395, 
   0.0004057521407594359, 0.00020044870045942306, 
   0.000053703254803456536, 3.5440795391838514*^-7, 
   0.000027239253096841233, 0.0000904901477145895, 
   0.00014309586436442187, 0.0001572500921845216, 0.0001318797421892351, 
   0.00008526488261371934, 0.00004022729484069744, 
   0.000011406480775026221, 6.892283314463395*^-7, 9.101557040195566*^-7, 
   3.3066264897151195*^-6, 3.2443368522666132*^-6, 
   1.2317106823449637*^-6, 4.659189298313377*^-9, 9.066577945484095*^-7, 
   2.580446569351325*^-6, 2.6919633039893876*^-6, 8.832099863455291*^-7, 
   2.05104195135262*^-7, 5.4878365623888996*^-6, 0.000019517008075896657, 
   0.000039746602132435026, 0.00005824182239529261, 
   0.0000655502072600911, 0.00005652038297361362, 
   0.000034495148084851064, 0.000010923764225379516, 
   1.1229149403820273*^-8, 0.00001104488458450018, 
   0.00004266736705188826, 0.0000825433747554608, 0.00011298194712647072, 
   0.00011974492014396917, 0.00009940470711715107, 0.0000612965315548006, 
   0.00002297829738341785, 1.5700967525915088*^-6, 5.487741980967869*^-6, 
   0.00003076968085375375, 0.00006366572430084339, 
   0.00008785285620368987, 0.00009236869850160376}, 
  {0.00024344180999694723, 0.00023154010692548097, 
   0.00016779384585890395, 0.00008109486137165638, 
   0.000014463187879827315, 4.1380597704768234*^-6, 
   0.00006056032396698567, 0.00016154973308381995, 
   0.00026198552340102934, 0.00031559305880315806, 
   0.00029776894285211974, 0.00021754673260204947, 
   0.00011245174210977292, 0.000029109284184756113, 
   2.9594922304873134*^-8, 0.00002879006609537975, 
   0.00009091349582826422, 0.0001489619812341254, 0.00017276048444912024, 
   0.00015349891133504997, 0.0001047539363584474, 
   0.000051437942168685316, 0.000014463437153362568, 
   5.405612216231394*^-7, 2.3277391710733248*^-6, 7.0947889252452785*^-6, 
   6.800881615025214*^-6, 2.3895369116731086*^-6, 1.2279500461652206*^-8, 
   3.2462282436222893*^-6, 8.550593960591605*^-6, 8.714761068395949*^-6, 
   2.3987558075406147*^-6, 1.8164918985557448*^-6, 
   0.000030062287015104854, 0.00010602082335422904, 
   0.00022471938751306156, 0.0003475749216052809, 0.0004144396065396789, 
   0.00037713551007054387, 0.0002384908059103127, 0.00007179026211728503, 
   9.340579133238338*^-7, 0.00014153731474141176, 0.0005282914585022808, 
   0.0010693777996112984, 0.0015627023787039773, 0.0017801736212872102, 
   0.001587635430482628, 0.0010402882508830612, 0.00039482860551422097, 
   0.000014700751016128757, 0.0001997059407087608, 0.0010181922786860198, 
   0.0022317528338310355, 0.0033669953260055626, 0.00391901870263954, 
   0.0035997980637844343, 0.002509791297806595, 0.0011357086160876187, 
   0.00015536968365556777, 0.0001268635077426926, 0.0012056499159858955, 
   0.003032701747626394, 0.004863680732594298, 0.005894834549896766, 
   0.005640664211432329, 0.004183155696000699, 0.0021643286600779776, 
   0.0005120695305835994, 0.000018303790874136726, 0.0009650866147426646, 
   0.002978287700246702, 0.005184822126901018, 0.00660605281400219, 
   0.006606052814002337, 0.005184822126901394, 0.002978287700247138, 
   0.0009650866147429711, 0.00001830379087418177, 0.0005120695305833739, 
   0.0021643286600775947, 0.004183155696000337, 0.005640664211432151, 
   0.005894834549896847, 0.004863680732594598, 0.0030327017476267726, 
   0.00120564991598619, 0.00012686350774279687, 0.00015536968365545794, 
   0.001135708616087371, 0.0025097912978063372, 0.0035997980637842886, 
   0.003919018702639565, 0.0033669953260057417, 0.002231752833831281, 
   0.0010181922786862306, 0.00019970594070886134, 
   0.000014700751016103219, 0.00039482860551410897, 
   0.0010402882508829376, 0.001587635430482554, 0.0017801736212872139, 
   0.0015627023787040525, 0.001069377799611407, 0.0005282914585023762, 
   0.000141537314741464, 9.340579133277436*^-7, 0.00007179026211725755, 
   0.0002384908059102792, 0.0003771355100705262, 0.00041443960653968285, 
   0.0003475749216053007, 0.00022471938751308652, 0.00010602082335424853, 
   0.00003006228701511464, 1.8164918985576242*^-6, 
   2.3987558075393102*^-6, 8.71476106839521*^-6, 8.550593960592398*^-6, 
   3.24622824362336*^-6, 1.2279500461729865*^-8, 2.3895369116722565*^-6, 
   6.800881615024606*^-6, 7.094788925245809*^-6, 2.3277391710743264*^-6, 
   5.405612216223765*^-7, 0.000014463437153357752, 0.0000514379421686762, 
   0.00010475393635843677, 0.0001534989113350426, 0.00017276048444912054, 
   0.00014896198123413444, 0.00009091349582827758, 
   0.000028790066095390012, 2.959492230525172*^-8, 
   0.000029109284184744203, 0.00011245174210975358, 
   0.00021754673260203044, 0.0002977689428521096, 0.0003155930588031617, 
   0.0002619855234010452, 0.00016154973308384074, 0.00006056032396700174, 
   4.138059770481389*^-6, 0.00001446318787981919, 0.00008109486137163954, 
   0.00016779384585888745, 0.00023154010692547268, 
   0.00024344180999695048}, {0.0002135130612795511, 
   0.00020307455419951885, 0.00014716526176687962, 
   0.00007112505491854624, 0.00001268508281351488, 
   3.6293264881794245*^-6, 0.00005311503460492109, 0.0001416888005394526, 
   0.00022977700959823087, 0.0002767940318242156, 0.0002611612136104684, 
   0.000190801526039467, 0.00009862691911622456, 0.000025530587280885063, 
   2.5956521025386605*^-8, 0.000025250613879933886, 
   0.00007973658594701465, 0.00013064858755348557, 
   0.00015152130155182672, 0.0001346277472330488, 0.00009187548200227335, 
   0.00004511415889692176, 0.00001268530144134881, 4.74104597066616*^-7, 
   2.0415667969377268*^-6, 6.222555207671071*^-6, 5.964780877377062*^-6, 
   2.0957671201105828*^-6, 1.0769858039520414*^-8, 
   2.8471367753822854*^-6, 7.4993834966444294*^-6, 7.643367891720834*^-6, 
   2.1038526444431258*^-6, 1.5931722905568457*^-6, 
   0.000026366427893959653, 0.00009298661784524127, 
   0.0001970923743845857, 0.0003048440427586129, 0.00036348837986740714, 
   0.0003307704509484076, 0.00020917073389150644, 0.00006296436357795373, 
   8.192247851289894*^-7, 0.0001241367099435595, 0.00046334327925870824, 
   0.0009379084375944375, 0.001370583667407446, 0.0015613189841749157, 
   0.0013924514485103223, 0.0009123951594920257, 0.00034628835632274793, 
   0.00001289343992554723, 0.00017515408202467255, 0.000893015667260197, 
   0.0019573810249626108, 0.0029530567464085273, 0.003437214340555864, 
   0.003157238703558989, 0.002201237425790514, 0.0009960845400610139, 
   0.00013626852670768307, 0.00011126690153652736, 0.0010574272529308346, 
   0.002659861237852594, 0.004265739571668484, 0.005170123285316956, 
   0.004947200661414834, 0.003668878318286003, 0.0018982459826194723, 
   0.00044911567599771813, 0.000016053521876980172, 
   0.0008464388163898759, 0.002612136856273298, 0.0045473998263423675, 
   0.005793904339232804, 0.005793904339232934, 0.004547399826342698, 
   0.002612136856273681, 0.0008464388163901448, 0.00001605352187701968, 
   0.0004491156759975204, 0.0018982459826191362, 0.003668878318285686, 
   0.004947200661414679, 0.005170123285317027, 0.004265739571668748, 
   0.0026598612378529256, 0.001057427252931093, 0.00011126690153661882, 
   0.00013626852670758674, 0.0009960845400607968, 0.0022012374257902884, 
   0.003157238703558861, 0.0034372143405558865, 0.0029530567464086843, 
   0.001957381024962826, 0.0008930156672603818, 0.00017515408202476072, 
   0.000012893439925524832, 0.0003462883563226497, 0.0009123951594919173, 
   0.0013924514485102572, 0.001561318984174919, 0.001370583667407512, 
   0.0009379084375945327, 0.00046334327925879194, 0.0001241367099436053, 
   8.192247851324185*^-7, 0.00006296436357792962, 0.00020917073389147705, 
   0.0003307704509483921, 0.0003634883798674106, 0.0003048440427586303, 
   0.0001970923743846076, 0.00009298661784525836, 
   0.000026366427893968235, 1.593172290558494*^-6, 
   2.1038526444419814*^-6, 7.643367891720186*^-6, 7.499383496645126*^-6, 
   2.8471367753832247*^-6, 1.0769858039588528*^-8, 
   2.0957671201098353*^-6, 5.964780877376529*^-6, 6.222555207671537*^-6, 
   2.0415667969386056*^-6, 4.741045970659469*^-7, 
   0.000012685301441344587, 0.00004511415889691376, 
   0.00009187548200226403, 0.00013462774723304235, 
   0.00015152130155182697, 0.0001306485875534935, 0.00007973658594702637, 
   0.000025250613879942885, 2.5956521025718648*^-8, 
   0.00002553058728087462, 0.0000986269191162076, 0.00019080152603945033, 
   0.0002611612136104595, 0.0002767940318242188, 0.00022977700959824483, 
   0.00014168880053947082, 0.00005311503460493519, 
   3.6293264881834285*^-6, 0.000012685082813507755, 
   0.00007112505491853147, 0.00014716526176686515, 0.0002030745541995116, 
   0.00021351306127955394}, {0.00005547265097937182, 
   0.00005276063113137676, 0.00003823488433615498, 
   0.00001847894139937116, 3.2957008219615293*^-6, 9.429322982043178*^-7, 
   0.000013799772991584354, 0.00003681204949668178, 
   0.00005969817387348374, 0.00007191362733755345, 
   0.00006785207783140986, 0.00004957198588643238, 
   0.000025624177877070448, 6.633080660469018*^-6, 6.743742152592609*^-9, 
   6.560341003881274*^-6, 0.000020716296117988606, 
   0.00003394370093740264, 0.00003936662341194973, 
   0.000034977523106279675, 0.00002387009261227704, 
   0.00001172107212420239, 3.2957576234773395*^-6, 1.231767212889984*^-7, 
   5.30417772565781*^-7, 1.6166768963284459*^-6, 1.5497047618363137*^-6, 
   5.444995134781106*^-7, 2.7981078653613773*^-9, 7.397122390771603*^-7, 
   1.9484085927892616*^-6, 1.985817058794495*^-6, 5.466002068342755*^-7, 
   4.139207685676627*^-7, 6.850239715402729*^-6, 0.00002415877589206444, 
   0.00005120640596603596, 0.00007920127736330111, 
   0.00009443761384247056, 0.00008593719592510832, 
   0.00005434447451001857, 0.000016358718965323625, 
   2.1284211048621078*^-7, 0.000032251855428228585, 
   0.00012038083225411367, 0.0002436772115836227, 0.00035609020340247606, 
   0.00040564498751298386, 0.00036177165343435447, 
   0.00023704862800642544, 0.00008996889002196096, 
   3.3498339100526017*^-6, 0.000045506636463075644, 
   0.00023201365823787275, 0.0005085455371239867, 0.0007672312187090008, 
   0.0008930198008135084, 0.0008202795632805907, 0.0005719016659300872, 
   0.00025879189640959333, 0.00003540381265777149, 
   0.00002890816120335891, 0.00027472929565235, 0.0006910563373346574, 
   0.0011082782524402127, 0.0013432454333611235, 0.0012853280917379927, 
   0.0009532082263088987, 0.0004931817109257555, 0.0001166843704768338, 
   4.170852175200021*^-6, 0.0002199125653278484, 0.0006786571054249598, 
   0.0011814561690915426, 0.001505309470493322, 0.001505309470493356, 
   0.0011814561690916283, 0.0006786571054250592, 0.00021991256532791822, 
   4.170852175210286*^-6, 0.00011668437047678243, 0.0004931817109256682, 
   0.0009532082263088163, 0.0012853280917379524, 0.001343245433361142, 
   0.001108278252440281, 0.0006910563373347437, 0.0002747292956524172, 
   0.000028908161203382676, 0.00003540381265774646, 
   0.0002587918964095369, 0.0005719016659300286, 0.0008202795632805574, 
   0.0008930198008135142, 0.0007672312187090416, 0.0005085455371240426, 
   0.00023201365823792076, 0.000045506636463098554, 
   3.349833910046782*^-6, 0.00008996889002193543, 0.00023704862800639728, 
   0.00036177165343433755, 0.0004056449875129847, 0.0003560902034024932, 
   0.00024367721158364742, 0.00012038083225413542, 
   0.000032251855428240484, 2.128421104871017*^-7, 
   0.000016358718965317364, 0.00005434447451001094, 
   0.00008593719592510431, 0.00009443761384247146, 
   0.00007920127736330564, 0.000051206405966041644, 
   0.00002415877589206888, 6.850239715404959*^-6, 4.13920768568091*^-7, 
   5.466002068339781*^-7, 1.9858170587943263*^-6, 1.9484085927894424*^-6, 
   7.397122390774043*^-7, 2.798107865379073*^-9, 5.444995134779164*^-7, 
   1.5497047618361752*^-6, 1.6166768963285668*^-6, 5.304177725660093*^-7, 
   1.2317672128882456*^-7, 3.295757623476242*^-6, 
   0.000011721072124200313, 0.000023870092612274617, 
   0.000034977523106278, 0.0000393666234119498, 0.0000339437009374047, 
   0.00002071629611799165, 6.560341003883612*^-6, 6.743742152678877*^-9, 
   6.633080660466304*^-6, 0.00002562417787706604, 0.00004957198588642804, 
   0.00006785207783140754, 0.00007191362733755427, 
   0.00005969817387348737, 0.000036812049496686513, 
   0.000013799772991588018, 9.42932298205358*^-7, 3.295700821959678*^-6, 
   0.000018478941399367323, 0.00003823488433615122, 
   0.00005276063113137486, 0.00005547265097937257}, 
  {6.304166934011842*^-6, 5.9959605377379005*^-6, 4.345187931389629*^-6, 
   2.1000318046595257*^-6, 3.745385839579142*^-7, 1.0715915879992741*^-7, 
   1.568269607716536*^-6, 4.183490442821749*^-6, 6.784374770444181*^-6, 
   8.17259502768022*^-6, 7.711021880454862*^-6, 5.633588241433771*^-6, 
   2.912049307755917*^-6, 7.538137628560788*^-7, 7.663898432704324*^-10, 
   7.455472940691019*^-7, 2.354295074716845*^-6, 3.8575181335237446*^-6, 
   4.473803959893612*^-6, 3.9750064348329175*^-6, 2.7127069988790598*^-6, 
   1.3320364902705323*^-6, 3.745450391431532*^-7, 1.3998368559650359*^-8, 
   6.027911275170279*^-8, 1.837265905428717*^-7, 1.7611556946651296*^-7, 
   6.187942648947316*^-8, 3.17989834110672*^-10, 8.406429755823621*^-8, 
   2.2142610471553314*^-7, 2.2567737467070424*^-7, 6.211815893439196*^-8, 
   4.7039857955866835*^-8, 7.784927156258579*^-7, 2.7455142931890894*^-6, 
   5.819331248847523*^-6, 9.000797060715442*^-6, 0.000010732324343649454, 
   9.766297795182459*^-6, 6.175955776472756*^-6, 1.8590799856011038*^-6, 
   2.418835536797091*^-8, 3.6652490364445784*^-6, 
   0.000013680630883629776, 0.000027692597932789068, 
   0.00004046772682001832, 0.0000460993601726001, 0.0000411133929058437, 
   0.000026939295239138463, 0.000010224478036521215, 
   3.806905168104939*^-7, 5.17158325415707*^-6, 0.000026367098140779805, 
   0.00005779345142110663, 0.00008719168084333118, 
   0.00010148687326660934, 0.00009322033845835382, 
   0.00006499353299706987, 0.00002941030016290833, 4.023451938110357*^-6, 
   3.2852562616679*^-6, 0.000031221499439425585, 0.00007853481732799304, 
   0.00012594983274399728, 0.00015265258277284328, 
   0.00014607058996160763, 0.00010832696248389543, 
   0.000056047435620729424, 0.000013260547983358217, 
   4.7399480474306143*^-7, 0.00002499187434235075, 
   0.00007712571164380053, 0.000134266107418246, 0.00017107028457803006, 
   0.0001710702845780339, 0.00013426610741825573, 0.00007712571164381184, 
   0.00002499187434235869, 4.7399480474422796*^-7, 
   0.000013260547983352378, 0.0000560474356207195, 
   0.00010832696248388607, 0.00014607058996160305, 
   0.00015265258277284536, 0.00012594983274400506, 
   0.00007853481732800285, 0.000031221499439433215, 
   3.2852562616706004*^-6, 4.023451938107513*^-6, 0.00002941030016290192, 
   0.0000649935329970632, 0.00009322033845835006, 0.00010148687326661001, 
   0.00008719168084333581, 0.00005779345142111299, 
   0.00002636709814078526, 5.171583254159673*^-6, 3.8069051680983255*^-7, 
   0.000010224478036518314, 0.00002693929523913526, 
   0.00004111339290584178, 0.0000460993601726002, 
   0.000040467726820020264, 0.000027692597932791877, 
   0.000013680630883632248, 3.6652490364459307*^-6, 
   2.4188355368072157*^-8, 1.859079985600392*^-6, 6.175955776471888*^-6, 
   9.766297795182002*^-6, 0.000010732324343649557, 9.000797060715957*^-6, 
   5.81933124884817*^-6, 2.7455142931895942*^-6, 7.784927156261113*^-7, 
   4.70398579559155*^-8, 6.211815893435818*^-8, 2.2567737467068513*^-7, 
   2.2142610471555368*^-7, 8.406429755826394*^-8, 3.179898341126831*^-10, 
   6.18794264894511*^-8, 1.7611556946649721*^-7, 1.8372659054288547*^-7, 
   6.027911275172872*^-8, 1.3998368559630604*^-8, 3.745450391430285*^-7, 
   1.3320364902702962*^-6, 2.7127069988787845*^-6, 3.975006434832727*^-6, 
   4.4738039598936205*^-6, 3.857518133523978*^-6, 2.354295074717191*^-6, 
   7.455472940693677*^-7, 7.663898432802363*^-10, 7.538137628557703*^-7, 
   2.912049307755416*^-6, 5.633588241433279*^-6, 7.7110218804546*^-6, 
   8.172595027680315*^-6, 6.784374770444593*^-6, 4.1834904428222866*^-6, 
   1.5682696077169522*^-6, 1.0715915880004564*^-7, 
   3.7453858395770374*^-7, 2.1000318046590894*^-6, 4.345187931389201*^-6, 
   5.995960537737685*^-6, 6.3041669340119265*^-6}, 
  {0.00011838692132155125, 0.00011259906596042077, 0.0000815989530647495, 
   0.000039436820540024666, 7.033517724869865*^-6, 
   2.0123583392575803*^-6, 0.000029450776383798218, 
   0.00007856241103511196, 0.00012740481820543487, 
   0.00015347442011964048, 0.00014480646693301144, 
   0.00010579402082428793, 0.00005468582223319816, 
   0.000014155984695277336, 1.439215284534885*^-8, 
   0.000014000747405380875, 0.000044211669629891685, 
   0.0000724409268584059, 0.00008401425326326465, 0.0000746472577549198, 
   0.00005094234232790914, 0.000025014518305393045, 
   7.033638947787184*^-6, 2.628775181000451*^-7, 1.1319907377718163*^-6, 
   3.4502299268008183*^-6, 3.307301390362119*^-6, 1.1620432758067906*^-6, 
   5.971580046335516*^-9, 1.5786563847612238*^-6, 4.158194906938064*^-6, 
   4.238030159869609*^-6, 1.1665264691405558*^-6, 8.833687339009308*^-7, 
   0.000014619434548435784, 0.000051558435558134376, 
   0.00010928211735391558, 0.00016902735359199282, 0.0002015439709906975, 
   0.0001834028097262523, 0.00011597922425721201, 
   0.000034911949237639756, 4.5423684902699227*^-7, 
   0.00006883027588632074, 0.00025691067336930075, 0.0005200435595971947, 
   0.0007599496715824973, 0.0008657069812480967, 0.0007720747344024882, 
   0.0005058971723492014, 0.00019200704701093058, 7.1490458189411845*^-6, 
   0.00009711795804685696, 0.0004951517949547138, 0.0010853121210001565, 
   0.0016373859969035307, 0.0019058376160319098, 0.0017505990863116922, 
   0.001220523561300622, 0.0005523005542008533, 0.00007555702331870055, 
   0.00006169433307244346, 0.0005863133442318185, 0.001474817424305542, 
   0.0023652312979023874, 0.002866686351333576, 0.002743082095094935, 
   0.0020342887044113088, 0.0010525234215020135, 0.00024902187191725393, 
   8.901221405352373*^-6, 0.0004693262555411284, 0.0014483556117434043, 
   0.0025214039002230807, 0.0032125552087667137, 0.0032125552087667857, 
   0.0025214039002232633, 0.0014483556117436164, 0.00046932625554127743, 
   8.901221405374281*^-6, 0.00024902187191714427, 0.0010525234215018272, 
   0.0020342887044111327, 0.0027430820950948486, 0.0028666863513336156, 
   0.0023652312979025336, 0.0014748174243057264, 0.0005863133442319618, 
   0.00006169433307249417, 0.00007555702331864714, 0.0005523005542007329, 
   0.0012205235613004966, 0.0017505990863116213, 0.0019058376160319224, 
   0.001637385996903618, 0.0010853121210002757, 0.0004951517949548163, 
   0.00009711795804690586, 7.1490458189287645*^-6, 0.0001920070470108761, 
   0.0005058971723491412, 0.0007720747344024521, 0.0008657069812480986, 
   0.0007599496715825338, 0.0005200435595972475, 0.00025691067336934716, 
   0.00006883027588634613, 4.5423684902889364*^-7, 
   0.000034911949237626394, 0.00011597922425719572, 
   0.00018340280972624373, 0.00020154397099069943, 
   0.00016902735359200247, 0.00010928211735392771, 
   0.000051558435558143856, 0.000014619434548440542, 
   8.833687339018446*^-7, 1.1665264691399213*^-6, 4.2380301598692495*^-6, 
   4.158194906938449*^-6, 1.5786563847617446*^-6, 5.971580046373282*^-9, 
   1.1620432758063764*^-6, 3.3073013903618235*^-6, 
   3.4502299268010763*^-6, 1.1319907377723033*^-6, 2.628775180996741*^-7, 
   7.033638947784842*^-6, 0.00002501451830538861, 
   0.000050942342327903974, 0.00007464725775491623, 
   0.0000840142532632648, 0.00007244092685841028, 0.00004421166962989818, 
   0.000014000747405385865, 1.4392152845532959*^-8, 
   0.000014155984695271544, 0.00005468582223318875, 
   0.00010579402082427867, 0.0001448064669330065, 0.00015347442011964224, 
   0.00012740481820544262, 0.00007856241103512207, 
   0.000029450776383806038, 2.0123583392598004*^-6, 
   7.033517724865913*^-6, 0.000039436820540016473, 
   0.00008159895306474147, 0.00011259906596041673, 
   0.00011838692132155284}, {0.0002010501204667081, 
   0.00019122091801250648, 0.00013857509901001776, 0.0000669734243604538, 
   0.00001194464363212046, 3.4174795831629607*^-6, 
   0.00005001466440468062, 0.0001334183035291836, 0.00021636472814990585, 
   0.00026063732639692206, 0.0002459170092122373, 0.00017966427704973627, 
   0.00009286998111846339, 0.000024040344968344787, 
   2.4441416594266306*^-8, 0.00002377671385532819, 
   0.00007508229292474984, 0.00012302251725969333, 
   0.00014267687301050726, 0.00012676940997032244, 
   0.00008651263118891463, 0.000042480806685192786, 
   0.000011944849498459903, 4.4643070443949593*^-7, 
   1.922398789120225*^-6, 5.859339314492926*^-6, 5.616611493308343*^-6, 
   1.9734353928667744*^-6, 1.0141212173525708*^-8, 2.68094695586956*^-6, 
   7.061638039334355*^-6, 7.197217941575257*^-6, 1.981048958197871*^-6, 
   1.5001774552859737*^-6, 0.000024827396846775735, 
   0.0000875589090781679, 0.00018558792317257435, 0.0002870500340957235, 
   0.00034227125086698306, 0.0003114630955664809, 0.00019696125845873372, 
   0.00005928907958414253, 7.714059306369506*^-7, 0.0001168907435401177, 
   0.00043629753399692685, 0.0008831619163485964, 0.0012905815212924429, 
   0.0014701834537622677, 0.0013111728612260527, 0.0008591378702071074, 
   0.00032607520747291493, 0.000012140838760526927, 
   0.0001649301877845762, 0.0008408895755854896, 0.0018431270129780648, 
   0.0027806842871926987, 0.0032365811866369304, 0.0029729479680945473, 
   0.0020727493061961674, 0.000937942229735958, 0.0001283144157374526, 
   0.00010477215690606864, 0.0009957043157569378, 0.0025046028523511583, 
   0.00401674468823557, 0.004868338747575528, 0.004658428308740146, 
   0.0034547227389678183, 0.0017874437338585472, 0.0004229004081610071, 
   0.00001511646401367443, 0.000797031455513962, 0.002459664183923966, 
   0.004281964191873924, 0.005455709165493107, 0.005455709165493229, 
   0.0042819641918742345, 0.0024596641839243266, 0.0007970314555142151, 
   0.000015116464013711634, 0.00042290040816082093, 
   0.0017874437338582308, 0.00345472273896752, 0.00465842830874, 
   0.004868338747575595, 0.004016744688235819, 0.002504602852351471, 
   0.000995704315757181, 0.00010477215690615477, 0.0001283144157373619, 
   0.0009379422297357535, 0.002072749306195955, 0.002972947968094427, 
   0.0032365811866369516, 0.002780684287192846, 0.0018431270129782675, 
   0.0008408895755856635, 0.00016493018778465922, 
   0.000012140838760505834, 0.0003260752074728224, 0.0008591378702070052, 
   0.0013111728612259913, 0.001470183453762271, 0.0012905815212925049, 
   0.000883161916348686, 0.00043629753399700567, 0.00011689074354016082, 
   7.714059306401796*^-7, 0.000059289079584119826, 
   0.00019696125845870607, 0.0003114630955664663, 0.00034227125086698637, 
   0.0002870500340957399, 0.00018558792317259498, 0.000087558909078184, 
   0.00002482739684678382, 1.5001774552875259*^-6, 
   1.9810489581967934*^-6, 7.197217941574647*^-6, 7.061638039335011*^-6, 
   2.6809469558704447*^-6, 1.0141212173589845*^-8, 
   1.9734353928660705*^-6, 5.616611493307841*^-6, 5.859339314493364*^-6, 
   1.922398789121052*^-6, 4.464307044388659*^-7, 0.000011944849498455925, 
   0.00004248080668518526, 0.00008651263118890584, 
   0.00012676940997031637, 0.00014267687301050753, 
   0.00012302251725970079, 0.00007508229292476089, 
   0.000023776713855336666, 2.4441416594578967*^-8, 
   0.00002404034496833495, 0.00009286998111844741, 
   0.00017966427704972057, 0.0002459170092122289, 0.0002606373263969251, 
   0.000216364728149919, 0.00013341830352920075, 0.00005001466440469389, 
   3.417479583166731*^-6, 0.00001194464363211375, 0.00006697342436043988, 
   0.00013857509901000413, 0.00019122091801249962, 
   0.0002010501204667108}, {0.00012667072696337947, 
   0.00012047788202773009, 0.00008730861981019259, 
   0.00004219630573347697, 7.525669164917232*^-6, 2.1531676886184324*^-6, 
   0.00003151151506034253, 0.00008405960393871539, 
   0.00013631962686896717, 0.00016421337889203956, 0.0001549389090504544, 
   0.00011319667220497208, 0.00005851231520798351, 
   0.000015146511559016509, 1.5399204938666963*^-8, 
   0.00001498041195828781, 0.000047305262015151826, 
   0.00007750978541060214, 0.00008989292412831673, 
   0.00007987049836321023, 0.00005450689538894949, 
   0.000026764841783296585, 7.525798870081367*^-6, 2.812716636968572*^-7, 
   1.2111987377381474*^-6, 3.691650463919172*^-6, 3.5387208884863655*^-6, 
   1.2433541210988245*^-6, 6.389425260369795*^-9, 1.6891186091405021*^-6, 
   4.449153384829019*^-6, 4.534574894344219*^-6, 1.2481510137991843*^-6, 
   9.451800794449852*^-7, 0.00001564239006616344, 0.00005516609808193852, 
   0.00011692883888516046, 0.0001808545869525562, 0.00021564646698714739, 
   0.00019623592687279058, 0.00012409455778824674, 
   0.00003735481876100943, 4.860208478901428*^-7, 0.00007364648887125882, 
   0.00027488730509302037, 0.0005564322056139863, 0.0008131251009853953, 
   0.000926282493267325, 0.0008260985823863793, 0.0005412959630577522, 
   0.00020544222246396754, 7.6492810259011*^-6, 0.00010391352532583255, 
   0.0005297987068502135, 0.0011612539106060072, 0.0017519576675542046, 
   0.0020391934649707706, 0.00187309253766499, 0.0013059264069040224, 
   0.0005909462964484053, 0.00008084392231953857, 0.00006601122769787454, 
   0.0006273390397614358, 0.0015780137973824793, 0.002530731981179517, 
   0.0030672750000241655, 0.002935021869199094, 0.002176632571948323, 
   0.0011261709102606179, 0.00026644650602800893, 9.524060375009719*^-6, 
   0.0005021660949432362, 0.001549700390828807, 0.00269783234029768, 
   0.003437345098274735, 0.0034373450982748124, 0.0026978323402978757, 
   0.0015497003908290343, 0.0005021660949433957, 9.52406037503316*^-6, 
   0.0002664465060278916, 0.0011261709102604186, 0.0021766325719481346, 
   0.0029350218691990017, 0.003067275000024207, 0.002530731981179673, 
   0.0015780137973826765, 0.0006273390397615891, 0.00006601122769792879, 
   0.00008084392231948142, 0.0005909462964482764, 0.0013059264069038884, 
   0.0018730925376649141, 0.002039193464970784, 0.0017519576675542978, 
   0.0011612539106061349, 0.0005297987068503231, 0.00010391352532588486, 
   7.649281025887812*^-6, 0.00020544222246390924, 0.0005412959630576878, 
   0.0008260985823863407, 0.000926282493267327, 0.0008131251009854345, 
   0.0005564322056140428, 0.00027488730509307003, 0.00007364648887128597, 
   4.860208478921772*^-7, 0.00003735481876099513, 0.0001240945577882293, 
   0.0001962359268727814, 0.00021564646698714945, 0.00018085458695256653, 
   0.00011692883888517345, 0.000055166098081948664, 
   0.00001564239006616853, 9.45180079445963*^-7, 1.2481510137985054*^-6, 
   4.534574894343835*^-6, 4.4491533848294324*^-6, 1.6891186091410595*^-6, 
   6.389425260410204*^-9, 1.2433541210983813*^-6, 3.5387208884860496*^-6, 
   3.691650463919448*^-6, 1.2111987377386685*^-6, 2.8127166369646027*^-7, 
   7.525798870078861*^-6, 0.00002676484178329184, 0.00005450689538894396, 
   0.00007987049836320641, 0.00008989292412831689, 
   0.00007750978541060684, 0.00004730526201515878, 
   0.00001498041195829315, 1.5399204938863955*^-8, 
   0.000015146511559010313, 0.00005851231520797345, 
   0.00011319667220496219, 0.00015493890905044912, 
   0.00016421337889204143, 0.00013631962686897544, 
   0.00008405960393872621, 0.0000315115150603509, 2.153167688620808*^-6, 
   7.525669164913004*^-6, 0.000042196305733468206, 0.000087308619810184, 
   0.00012047788202772576, 0.00012667072696338118}, 
  {0.000013381966037858072, 0.0000127277308992965, 9.223606851565894*^-6, 
   4.45777445022251*^-6, 7.950396401071644*^-7, 2.2746863125870625*^-7, 
   3.3289934813500073*^-6, 8.880368748407781*^-6, 
   0.000014401311658860116, 0.000017348111216970357, 
   0.000016368321778522498, 0.000011958516851990724, 
   6.181458287012516*^-6, 1.6001337336082501*^-6, 1.6268292007105393*^-9, 
   1.5825863549112302*^-6, 4.997503565932407*^-6, 8.188421593776825*^-6, 
   9.496622357560625*^-6, 8.437816077524173*^-6, 5.758310861631647*^-6, 
   2.827537287729196*^-6, 7.950533426424147*^-7, 2.9714583165622345*^-8, 
   1.2795553291641133*^-7, 3.899996654009205*^-7, 3.7384361708821516*^-7, 
   1.3135254703626624*^-7, 6.750026141432031*^-10, 
   1.7844476307432107*^-7, 4.700250872501568*^-7, 4.790493327616351*^-7, 
   1.3185930859627546*^-7, 9.985233388965574*^-8, 1.652520180742657*^-6, 
   5.827951482326862*^-6, 0.00001235279680095119, 
   0.000019106150240139018, 0.000022781693660291107, 
   0.000020731092113953582, 0.000013109809958582, 3.946301785689502*^-6, 
   5.134504740023444*^-8, 7.780288599493047*^-6, 0.000029040115811892302, 
   0.00005878356473038565, 0.00008590155552720745, 
   0.00009785592270224656, 0.00008727212228452101, 0.0000571845158523693, 
   0.00002170367937139649, 8.08098456182648*^-7, 0.000010977810739070037, 
   0.00005596990300703278, 0.0001226791758884595, 0.0001850833145826443, 
   0.00021542797098456743, 0.0001978804521430178, 0.00013796291569546232, 
   0.00006242976146775236, 8.540652199462505*^-6, 6.973671252598499*^-6, 
   0.0000662744260300727, 0.00016670723812889062, 0.00026735592535800544, 
   0.0003240383225317792, 0.00031006661061752487, 0.0002299475486797271, 
   0.00011897287743748522, 0.00002814839845044523, 1.006157109351207*^-6, 
   0.000053050691260633114, 0.00016371610470761603, 
   0.0002850090278879973, 0.0003631339021114845, 0.0003631339021114926, 
   0.000285009027888018, 0.00016371610470764002, 0.00005305069126064996, 
   1.0061571093536832*^-6, 0.000028148398450432837, 
   0.00011897287743746416, 0.00022994754867970723, 0.0003100666106175151, 
   0.00032403832253178363, 0.00026735592535802197, 
   0.00016670723812891143, 0.00006627442603008889, 6.973671252604232*^-6, 
   8.540652199456467*^-6, 0.00006242976146773874, 0.00013796291569544817, 
   0.0001978804521430098, 0.00021542797098456884, 0.00018508331458265415, 
   0.000122679175888473, 0.00005596990300704436, 0.000010977810739075563, 
   8.080984561812441*^-7, 0.000021703679371390333, 0.0000571845158523625, 
   0.00008727212228451693, 0.00009785592270224678, 
   0.00008590155552721158, 0.00005878356473039161, 
   0.000029040115811897547, 7.780288599495916*^-6, 
   5.1345047400449364*^-8, 3.9463017856879905*^-6, 
   0.000013109809958580157, 0.000020731092113952613, 
   0.000022781693660291327, 0.00001910615024014011, 
   0.000012352796800952561, 5.827951482327933*^-6, 
   1.6525201807431952*^-6, 9.985233388975904*^-8, 1.3185930859620375*^-7, 
   4.790493327615944*^-7, 4.7002508725020035*^-7, 1.7844476307437994*^-7, 
   6.75002614147472*^-10, 1.3135254703621942*^-7, 3.7384361708818175*^-7, 
   3.899996654009497*^-7, 1.279555329164664*^-7, 2.9714583165580407*^-8, 
   7.9505334264215*^-7, 2.827537287728695*^-6, 5.758310861631063*^-6, 
   8.437816077523768*^-6, 9.49662235756064*^-6, 8.188421593777321*^-6, 
   4.997503565933142*^-6, 1.5825863549117943*^-6, 1.62682920073135*^-9, 
   1.6001337336075956*^-6, 6.181458287011452*^-6, 
   0.000011958516851989679, 0.000016368321778521942, 
   0.000017348111216970557, 0.00001440131165886099, 
   8.880368748408923*^-6, 3.3289934813508912*^-6, 2.274686312589572*^-7, 
   7.950396401067178*^-7, 4.457774450221584*^-6, 9.223606851564988*^-6, 
   0.000012727730899296044, 0.00001338196603785825}, 
  {0.00002648525575123994, 0.000025190409768427642, 
   0.000018255134239730362, 8.82271678626856*^-6, 1.5735227649690242*^-6, 
   4.502002812761303*^-7, 6.588661449172083*^-6, 0.00001757580588693115, 
   0.00002850271935821431, 0.000034334952060299596, 
   0.000032395777070149286, 0.00002366800037710918, 
   0.000012234189145599772, 3.166945055076848*^-6, 3.219780062399592*^-9, 
   3.1322157177552883*^-6, 9.890935284621232*^-6, 
   0.000016206321215927084, 0.000018795479767425483, 
   0.000016699916601411576, 0.00001139670624136989, 
   5.596191770313424*^-6, 1.573549884687421*^-6, 5.881036706090492*^-8, 
   2.5324642167600287*^-7, 7.718776786474858*^-7, 7.399020279635091*^-7, 
   2.599697078882381*^-7, 1.3359484561358048*^-9, 3.5317345553877094*^-7, 
   9.302620115834506*^-7, 9.48122574796458*^-7, 2.609726778168547*^-7, 
   1.9762526619362385*^-7, 3.2706270137911645*^-6, 
   0.000011534537233061982, 0.00002444834948696802, 
   0.00003781441935363722, 0.00004508896385869089, 
   0.000041030464065387685, 0.00002594661117962098, 7.81042275625822*^-6, 
   1.0162084615276839*^-7, 0.000015398554501862447, 
   0.00005747547797892206, 0.00011634297542299173, 
   0.00017001423117731857, 0.0001936740186165801, 0.00017272682295859374, 
   0.00011317817748723378, 0.00004295538467726928, 
   1.5993684503181811*^-6, 0.0000217270111275455, 0.00011077424582603612, 
   0.000242803586525711, 0.0003663123122671701, 0.0004263697046723501, 
   0.0003916400899802079, 0.0002730527858196488, 0.00012355943770030528, 
   0.00001690344730701172, 0.000013802117426364669, 
   0.00013116870258131838, 0.00032994283686982366, 0.0005291442258696375, 
   0.0006413286225041584, 0.0006136761563205795, 0.0004551064932405159, 
   0.00023546817242536326, 0.00005571061306229231, 
   1.9913612313546385*^-6, 0.0001049966142376216, 0.00032402285968377944, 
   0.0005640828091829555, 0.0007187056253288633, 0.0007187056253288794, 
   0.0005640828091829964, 0.00032402285968382693, 0.00010499661423765494, 
   1.99136123135954*^-6, 0.00005571061306226778, 0.00023546817242532157, 
   0.0004551064932404766, 0.0006136761563205602, 0.0006413286225041672, 
   0.0005291442258696701, 0.00032994283686986486, 0.0001311687025813504, 
   0.000013802117426376014, 0.000016903447306999773, 
   0.00012355943770027834, 0.0002730527858196208, 0.0003916400899801921, 
   0.0004263697046723529, 0.0003663123122671896, 0.00024280358652573769, 
   0.00011077424582605903, 0.000021727011127556437, 
   1.5993684503154025*^-6, 0.000042955384677257094, 
   0.00011317817748722032, 0.0001727268229585857, 0.00019367401861658052, 
   0.00017001423117732675, 0.00011634297542300354, 
   0.00005747547797893244, 0.000015398554501868125, 
   1.0162084615319376*^-7, 7.810422756255228*^-6, 
   0.000025946611179617338, 0.00004103046406538577, 
   0.00004508896385869132, 0.00003781441935363938, 
   0.000024448349486970732, 0.000011534537233064103, 
   3.270627013792229*^-6, 1.976252661938283*^-7, 2.609726778167128*^-7, 
   9.481225747963776*^-7, 9.302620115835369*^-7, 3.5317345553888746*^-7, 
   1.3359484561442538*^-9, 2.599697078881454*^-7, 7.39902027963443*^-7, 
   7.718776786475436*^-7, 2.532464216761118*^-7, 5.8810367060821925*^-8, 
   1.573549884686897*^-6, 5.596191770312432*^-6, 0.000011396706241368735, 
   0.000016699916601410777, 0.000018795479767425514, 
   0.000016206321215928067, 9.890935284622687*^-6, 
   3.1322157177564047*^-6, 3.2197800624407805*^-9, 
   3.1669450550755526*^-6, 0.000012234189145597668, 
   0.00002366800037710711, 0.00003239577707014818, 
   0.000034334952060299995, 0.00002850271935821604, 
   0.000017575805886933412, 6.588661449173832*^-6, 4.50200281276627*^-7, 
   1.57352276496814*^-6, 8.822716786266729*^-6, 0.000018255134239728566, 
   0.000025190409768426738, 0.000026485255751240293}, 
  {0.00012865707024896524, 0.00012236711435286357, 
   0.00008867771979794171, 0.000042857992538151636, 
   7.643680348508172*^-6, 2.1869318445805586*^-6, 0.00003200565200783823, 
   0.00008537775560544528, 0.00013845727604818922, 
   0.00016678843431632755, 0.0001573685300769235, 0.00011497172675131571, 
   0.000059429855883905086, 0.0000153840263523436, 1.564068225601214*^-8, 
   0.000015215322118053896, 0.000048047063154446126, 
   0.00007872522835869583, 0.00009130254899228056, 0.0000811229600166909, 
   0.0000553616264564144, 0.000027184545412070944, 7.64381208759907*^-6, 
   2.856823282126716*^-7, 1.2301917327093663*^-6, 3.74953980652834*^-6, 
   3.5942121187406854*^-6, 1.2628513496160655*^-6, 6.489618827336193*^-9, 
   1.715605939625265*^-6, 4.518921248046945*^-6, 4.6056822654811225*^-6, 
   1.2677234631337004*^-6, 9.600015946401868*^-7, 0.00001588768080715224, 
   0.00005603116620891551, 0.00011876241811517486, 
   0.00018369059573747817, 0.00021902805263071954, 
   0.00019931313283093712, 0.00012604050376605484, 
   0.00003794058545872212, 4.936422160704989*^-7, 0.00007480135086805372, 
   0.0002791978554928941, 0.0005651577051986263, 0.0008258758416135006, 
   0.0009408076724872178, 0.0008390527621853907, 0.0005497841088788879, 
   0.00020866379376895496, 7.76923058622651*^-6, 0.00010554300940838767, 
   0.000538106562416308, 0.0011794637130085725, 0.001779430387045132, 
   0.0020711703734819695, 0.0019024647918129216, 0.0013264048411248419, 
   0.0006002130168362295, 0.00008211164838482165, 0.00006704635998182245, 
   0.000637176440392887, 0.0016027588761085103, 0.0025704167812824357, 
   0.0031153734142939787, 0.0029810464016438824, 0.002210764684379688, 
   0.001143830570701857, 0.0002706246949506124, 9.673408640634525*^-6, 
   0.000510040639242865, 0.0015740014826420906, 0.002740137467008887, 
   0.0034912466390638166, 0.0034912466390638946, 0.0027401374670090856, 
   0.001574001482642321, 0.000510040639243027, 9.673408640658331*^-6, 
   0.0002706246949504933, 0.0011438305707016545, 0.0022107646843794967, 
   0.0029810464016437888, 0.0031153734142940217, 0.0025704167812825945, 
   0.0016027588761087105, 0.0006371764403930428, 0.00006704635998187757, 
   0.0000821116483847636, 0.0006002130168360986, 0.0013264048411247057, 
   0.0019024647918128447, 0.0020711703734819834, 0.0017794303870452266, 
   0.0011794637130087022, 0.0005381065624164192, 0.00010554300940844081, 
   7.769230586213011*^-6, 0.00020866379376889574, 0.0005497841088788226, 
   0.0008390527621853516, 0.0009408076724872199, 0.0008258758416135403, 
   0.0005651577051986837, 0.0002791978554929445, 0.00007480135086808132, 
   4.936422160725653*^-7, 0.00003794058545870759, 0.00012604050376603714, 
   0.0001993131328309278, 0.00021902805263072163, 0.00018369059573748866, 
   0.00011876241811518806, 0.00005603116620892581, 
   0.00001588768080715741, 9.6000159464118*^-7, 1.267723463133011*^-6, 
   4.605682265480732*^-6, 4.5189212480473644*^-6, 1.7156059396258311*^-6, 
   6.489618827377235*^-9, 1.2628513496156153*^-6, 3.5942121187403643*^-6, 
   3.74953980652862*^-6, 1.2301917327098957*^-6, 2.856823282122684*^-7, 
   7.643812087596526*^-6, 0.000027184545412066127, 
   0.00005536162645640878, 0.00008112296001668701, 
   0.00009130254899228071, 0.00007872522835870062, 
   0.000048047063154453193, 0.00001521532211805932, 
   1.564068225621222*^-8, 0.00001538402635233731, 0.00005942985588389486, 
   0.00011497172675130567, 0.00015736853007691814, 
   0.00016678843431632947, 0.00013845727604819763, 
   0.00008537775560545628, 0.00003200565200784673, 
   2.1869318445829714*^-6, 7.643680348503878*^-6, 0.00004285799253814273, 
   0.00008867771979793299, 0.00012236711435285917, 
   0.00012865707024896695}, {0.00015380173104139987, 
   0.00014628246993027353, 0.00010600884027076893, 
   0.00005123413294404733, 9.137556660141207*^-6, 2.6143444951386714*^-6, 
   0.00003826081747694521, 0.00010206393305192397, 
   0.00016551728319540005, 0.0001993854660757932, 0.0001881245413908071, 
   0.00013744173220292492, 0.00007104479134180378, 
   0.000018390671253420593, 1.86974878332621*^-8, 
   0.000018188995564571465, 0.00005743735241529574, 
   0.00009411123986242262, 0.00010914666451156742, 
   0.00009697758276031998, 0.00006618146959033818, 
   0.00003249747669412427, 9.13771414624117*^-6, 3.415159114226731*^-7, 
   1.4706196685295762*^-6, 4.482347621757168*^-6, 4.296662783650951*^-6, 
   1.5096622614137376*^-6, 7.757946046118625*^-9, 2.050902937465229*^-6, 
   5.402096511637092*^-6, 5.5058140503815034*^-6, 1.515486577880702*^-6, 
   1.147623731618065*^-6, 0.000018992759633378116, 
   0.00006698186379126652, 0.00014197327401774338, 
   0.00021959097580707856, 0.00026183476412173655, 0.0002382667721980802, 
   0.0001506737843714052, 0.000045355670768684854, 5.901193552739564*^-7, 
   0.00008942048210393095, 0.00033376411723629387, 0.0006756117887865007, 
   0.000987284521710543, 0.0011246785608094343, 0.0010030367317510017, 
   0.0006572335860050141, 0.00024944492071230775, 9.287644361162014*^-6, 
   0.0001261702719867378, 0.00064327378685223, 0.0014099773950253956, 
   0.0021272011966820817, 0.002475958671426001, 0.0022742813718665193, 
   0.001585636609258436, 0.0007175182895456571, 0.00009815949979126707, 
   0.00008014986044120703, 0.0007617058224750891, 0.0019160011114075564, 
   0.0030727774983068334, 0.0037242401294508252, 0.0035636603258595726, 
   0.0026428352108812674, 0.0013673801327170581, 0.00032351542332971587, 
   0.000011563973834639614, 0.0006097226764546638, 0.0018816233901768837, 
   0.003275668293253033, 0.0041735737922634925, 0.004173573792263586, 
   0.003275668293253271, 0.0018816233901771593, 0.0006097226764548576, 
   0.000011563973834668075, 0.00032351542332957346, 0.001367380132716816, 
   0.002642835210881039, 0.0035636603258594603, 0.003724240129450876, 
   0.0030727774983070233, 0.0019160011114077956, 0.0007617058224752752, 
   0.00008014986044127291, 0.00009815949979119768, 0.0007175182895455006, 
   0.0015856366092582735, 0.0022742813718664274, 0.002475958671426017, 
   0.002127201196682195, 0.0014099773950255507, 0.0006432737868523631, 
   0.00012617027198680135, 9.287644361145878*^-6, 0.00024944492071223695, 
   0.000657233586004936, 0.0010030367317509549, 0.0011246785608094367, 
   0.0009872845217105905, 0.0006756117887865693, 0.0003337641172363541, 
   0.00008942048210396394, 5.901193552764265*^-7, 
   0.000045355670768667486, 0.00015067378437138402, 
   0.00023826677219806905, 0.00026183476412173904, 0.0002195909758070911, 
   0.00014197327401775916, 0.00006698186379127882, 0.0000189927596333843, 
   1.1476237316192523*^-6, 1.5154865778798778*^-6, 5.505814050381037*^-6, 
   5.402096511637593*^-6, 2.050902937465906*^-6, 7.757946046167688*^-9, 
   1.5096622614131993*^-6, 4.296662783650567*^-6, 4.482347621757503*^-6, 
   1.470619668530209*^-6, 3.4151591142219107*^-7, 9.137714146238128*^-6, 
   0.00003249747669411851, 0.00006618146959033146, 
   0.00009697758276031534, 0.00010914666451156761, 
   0.00009411123986242832, 0.000057437352415304186, 
   0.000018188995564577947, 1.8697487833501283*^-8, 
   0.000018390671253413068, 0.00007104479134179155, 
   0.0001374417322029129, 0.00018812454139080067, 0.00019938546607579547, 
   0.0001655172831954101, 0.0001020639330519371, 0.00003826081747695537, 
   2.6143444951415556*^-6, 9.137556660136074*^-6, 
   0.000051234132944036684, 0.0001060088402707585, 
   0.00014628246993026828, 0.00015380173104140193}, 
  {0.00006559256240432949, 0.00006238578702978418, 
   0.00004521009889673683, 0.000021850066573435037, 
   3.896937644297878*^-6, 1.1149520443150258*^-6, 
   0.000016317274461115496, 0.00004352769538164423, 
   0.00007058895015991063, 0.00008503287666230774, 
   0.00008023037606540886, 0.000058615435180328514, 
   0.00003029881314102677, 7.843157834958261*^-6, 7.974007374320856*^-9, 
   7.757148235997948*^-6, 0.00002449558335351659, 
   0.000040136072148389195, 0.000046548301860609787, 
   0.00004135849516098801, 0.0000282247289723026, 
   0.000013859354856473062, 3.897004808150779*^-6, 
   1.4564792984048624*^-7, 6.271822282357492*^-7, 1.9116083031527427*^-6, 
   1.8324183990564003*^-6, 6.438329102068893*^-7, 3.3085684843331366*^-9, 
   8.746584189920459*^-7, 2.3038580265288896*^-6, 2.348090943066643*^-6, 
   6.463168344041995*^-7, 4.894326008111374*^-7, 8.099933356065075*^-6, 
   0.000028566076928642073, 0.00006054802356710226, 
   0.00009365001737318748, 0.00011166592852361941, 
   0.00010161477389402004, 0.00006425857197548434, 
   0.000019343050595993515, 2.5167103370501413*^-7, 
   0.000038135582173964676, 0.00014234198496930185, 
   0.00028813140214365085, 0.0004210519684183261, 0.0004796470636916756, 
   0.0004277698890365717, 0.00028029356179776037, 0.00010638197254009362, 
   3.960946266493942*^-6, 0.00005380844144487335, 0.0002743400592534072, 
   0.0006013198268035268, 0.0009071977037916168, 0.0010559339778973954, 
   0.0009699236920097084, 0.0006762340549689741, 0.00030600346865148584, 
   0.00004186255298975372, 0.000034181895659373596, 
   0.0003248483378967283, 0.0008171261897756916, 0.0013104621674125206, 
   0.0015882945623931642, 0.0015198113228573294, 0.0011271026165981636, 
   0.0005831531679025218, 0.00013797117529064395, 4.931743422227534*^-6, 
   0.0002600313561745418, 0.0008024649580075356, 0.0013969899785019183, 
   0.0017799240461372216, 0.0017799240461372615, 0.0013969899785020196, 
   0.0008024649580076533, 0.0002600313561746244, 4.931743422239672*^-6, 
   0.0001379711752905832, 0.0005831531679024185, 0.0011271026165980663, 
   0.0015198113228572817, 0.001588294562393186, 0.0013104621674126014, 
   0.0008171261897757937, 0.0003248483378968077, 0.00003418189565940169, 
   0.00004186255298972413, 0.0003060034686514191, 0.0006762340549689048, 
   0.0009699236920096691, 0.0010559339778974024, 0.000907197703791665, 
   0.0006013198268035929, 0.000274340059253464, 0.000053808441444900434, 
   3.9609462664870604*^-6, 0.00010638197254006344, 0.000280293561797727, 
   0.0004277698890365517, 0.00047964706369167665, 0.0004210519684183463, 
   0.00028813140214368013, 0.00014234198496932755, 
   0.00003813558217397874, 2.5167103370606757*^-7, 
   0.000019343050595986108, 0.00006425857197547532, 
   0.00010161477389401528, 0.00011166592852362048, 
   0.00009365001737319284, 0.00006054802356710898, 
   0.000028566076928647325, 8.099933356067711*^-6, 4.894326008116438*^-7, 
   6.46316834403848*^-7, 2.348090943066444*^-6, 2.303858026529103*^-6, 
   8.746584189923345*^-7, 3.308568484354061*^-9, 6.438329102066598*^-7, 
   1.8324183990562366*^-6, 1.9116083031528854*^-6, 6.271822282360191*^-7, 
   1.4564792984028068*^-7, 3.897004808149482*^-6, 
   0.000013859354856470606, 0.000028224728972299733, 
   0.000041358495160986025, 0.00004654830186060987, 
   0.000040136072148391634, 0.00002449558335352019, 
   7.757148236000713*^-6, 7.974007374422862*^-9, 7.843157834955052*^-6, 
   0.000030298813141021557, 0.00005861543518032339, 
   0.00008023037606540612, 0.00008503287666230873, 
   0.00007058895015991491, 0.00004352769538164983, 
   0.000016317274461119826, 1.1149520443162559*^-6, 
   3.896937644295689*^-6, 0.0000218500665734305, 0.000045210098896732386, 
   0.00006238578702978193, 0.00006559256240433036}, 
  {2.5854111690627174*^-7, 2.459012190792622*^-7, 1.782011410402504*^-7, 
   8.612471306654446*^-8, 1.5360256927611154*^-8, 4.3947200150105876*^-9, 
   6.431653543336076*^-8, 1.7156974156544702*^-7, 2.7823499108154717*^-7, 
   3.3516749613329924*^-7, 3.1623785193657674*^-7, 
   2.3103991556318622*^-7, 1.194264822607148*^-7, 3.091476704664369*^-8, 
   3.143052652932619*^-11, 3.0575749679967495*^-8, 9.655234141410574*^-8, 
   1.5820124326764095*^-7, 1.834758318930682*^-7, 1.6301957326458533*^-7, 
   1.1125122552605537*^-7, 5.462834432515468*^-8, 1.536052166216197*^-8, 
   5.740891508998299*^-10, 2.47211555469179*^-9, 7.53483821439778*^-9, 
   7.2227015101391055*^-9, 2.537746256653596*^-9, 
   1.3041127834394809*^-11, 3.4475732654522907*^-9, 
   9.080938532337963*^-9, 9.255287989448636*^-9, 2.547536948048215*^-9, 
   1.929158529957059*^-9, 3.192687920673768*^-8, 1.1259669029600399*^-7, 
   2.3865744934630905*^-7, 3.691330114640786*^-7, 4.4014493141629225*^-7, 
   4.0052707462156*^-7, 2.532830302761154*^-7, 7.624300259281524*^-8, 
   9.919921979257134*^-10, 1.503160670618494*^-7, 5.610583643579375*^-7, 
   1.135705204910132*^-6, 1.659627893775849*^-6, 1.890587637104938*^-6, 
   1.6861074005409978*^-6, 1.1048113973978062*^-6, 4.19317571856176*^-7, 
   1.5612554750223883*^-8, 2.1209256111063326*^-7, 1.08134493807833*^-6, 
   2.3701757324456662*^-6, 3.575830841113903*^-6, 4.162093079121046*^-6, 
   3.823073004836487*^-6, 2.6654593364414084*^-6, 1.2061501435889391*^-6, 
   1.650063789214693*^-7, 1.3473212751274939*^-7, 1.2804295033825741*^-6, 
   3.2208029388409597*^-6, 5.1653471065476075*^-6, 
   6.2604575135516005*^-6, 5.990522438751325*^-6, 4.442612983572607*^-6, 
   2.2985696217746325*^-6, 5.43830282778518*^-7, 1.943907061928876*^-8, 
   1.0249454327093206*^-6, 3.1630138984739296*^-6, 5.506407069788671*^-6, 
   7.0157885898702576*^-6, 7.015788589870415*^-6, 5.506407069789071*^-6, 
   3.1630138984743934*^-6, 1.024945432709646*^-6, 1.94390706193366*^-8, 
   5.438302827782786*^-7, 2.2985696217742255*^-6, 4.442612983572222*^-6, 
   5.990522438751137*^-6, 6.260457513551687*^-6, 5.165347106547927*^-6, 
   3.220802938841362*^-6, 1.2804295033828869*^-6, 1.3473212751286013*^-7, 
   1.6500637892135266*^-7, 1.2061501435886761*^-6, 
   2.6654593364411348*^-6, 3.823073004836332*^-6, 4.1620930791210735*^-6, 
   3.5758308411140933*^-6, 2.3701757324459267*^-6, 
   1.0813449380785537*^-6, 2.1209256111074004*^-7, 
   1.5612554750196758*^-8, 4.19317571856057*^-7, 1.104811397397675*^-6, 
   1.686107400540919*^-6, 1.890587637104942*^-6, 1.6596278937759288*^-6, 
   1.1357052049102472*^-6, 5.610583643580388*^-7, 1.5031606706190486*^-7, 
   9.919921979298656*^-10, 7.624300259278604*^-8, 2.5328303027607984*^-7, 
   4.0052707462154126*^-7, 4.401449314162965*^-7, 3.6913301146409966*^-7, 
   2.386574493463356*^-7, 1.1259669029602469*^-7, 3.1926879206748066*^-8, 
   1.929158529959055*^-9, 2.5475369480468296*^-9, 9.255287989447852*^-9, 
   9.080938532338807*^-9, 3.447573265453428*^-9, 1.3041127834477285*^-11, 
   2.537746256652691*^-9, 7.22270151013846*^-9, 7.534838214398345*^-9, 
   2.472115554692854*^-9, 5.740891508990197*^-10, 1.5360521662156853*^-8, 
   5.4628344325145*^-8, 1.112512255260441*^-7, 1.630195732645775*^-7, 
   1.8347583189306852*^-7, 1.5820124326765054*^-7, 9.655234141411994*^-8, 
   3.0575749679978394*^-8, 3.1430526529728256*^-11, 
   3.091476704663104*^-8, 1.1942648226069427*^-7, 2.3103991556316602*^-7, 
   3.1623785193656594*^-7, 3.351674961333031*^-7, 2.7823499108156406*^-7, 
   1.715697415654691*^-7, 6.431653543337783*^-8, 4.394720015015436*^-9, 
   1.5360256927602525*^-8, 8.612471306652657*^-8, 1.7820114104023285*^-7, 
   2.4590121907925335*^-7, 2.585411169062752*^-7}, 
  {0.00004872759772857152, 0.000046345338906397206, 
   0.000033585812652498515, 0.000016232042403981056, 
   2.8949686205907457*^-6, 8.282788888034813*^-7, 
   0.000012121825353714926, 0.00003233598372837105, 
   0.00005243932911587662, 0.00006316947616961337, 
   0.00005960178025106717, 0.00004354440871734693, 
   0.00002250847236746554, 5.8265484057124455*^-6, 
   5.9237543004559114*^-9, 5.762653339178848*^-6, 
   0.000018197351773195316, 0.000029816404579470166, 
   0.00003457994084802209, 0.0000307245218206428, 
   0.000020967670555122873, 0.000010295878731811332, 
   2.8950185154734297*^-6, 1.0819936704893808*^-7, 
   4.6592299797032346*^-7, 1.4201012583779733*^-6, 1.361272427036022*^-6, 
   4.782925060861177*^-7, 2.4578791901469202*^-9, 6.497688461663089*^-7, 
   1.7114968988165415*^-6, 1.7443567793335874*^-6, 4.801377710771193*^-7, 
   3.6359114529728253*^-7, 6.0173025680808814*^-6, 
   0.000021221252139563035, 0.00004498009572260721, 
   0.00006957100327480434, 0.00008295471690136618, 0.0000754878852737233, 
   0.0000477365989535909, 0.000014369622922716685, 
   1.8696212559462757*^-7, 0.000028330274640942802, 
   0.00010574343689632562, 0.0002140479124764056, 0.00031279233784831014, 
   0.0003563216363951015, 0.00031778296668577636, 0.0002082253143427777, 
   0.00007902935597410763, 2.9425195361092413*^-6, 
   0.00003997337492267447, 0.00020380255867622794, 0.0004467102603200409, 
   0.0006739417267791305, 0.0007844353721957722, 0.0007205397953555235, 
   0.0005023627648172794, 0.00022732476636730614, 0.00003109897779875552, 
   0.0000253931482509063, 0.0002413242988473651, 0.0006070291327152386, 
   0.0009735200301913256, 0.0011799169856133447, 0.0011290419530649702, 
   0.0008373053420579678, 0.0004332145587564454, 0.00010249643681029558, 
   3.663708212792278*^-6, 0.0001931728668013073, 0.0005961375532797491, 
   0.0010378000676917313, 0.0013222752661033585, 0.0013222752661033882, 
   0.0010378000676918066, 0.0005961375532798365, 0.00019317286680136866, 
   3.663708212801295*^-6, 0.00010249643681025045, 0.00043321455875636877, 
   0.0008373053420578955, 0.0011290419530649346, 0.001179916985613361, 
   0.0009735200301913857, 0.0006070291327153144, 0.00024132429884742408, 
   0.000025393148250927172, 0.000031098977798733535, 
   0.0002273247663672566, 0.0005023627648172279, 0.0007205397953554943, 
   0.0007844353721957774, 0.0006739417267791663, 0.00044671026032009004, 
   0.0002038025586762701, 0.000039973374922694594, 
   2.9425195361041295*^-6, 0.00007902935597408522, 
   0.00020822531434275295, 0.0003177829666857615, 0.00035632163639510224, 
   0.0003127923378483252, 0.00021404791247642732, 0.00010574343689634471, 
   0.00002833027464095325, 1.8696212559541014*^-7, 
   0.000014369622922711183, 0.0000477365989535842, 
   0.00007548788527371976, 0.00008295471690136698, 
   0.00006957100327480831, 0.0000449800957226122, 
   0.000021221252139566935, 6.01730256808284*^-6, 3.635911452976587*^-7, 
   4.801377710768582*^-7, 1.7443567793334396*^-6, 1.7114968988167003*^-6, 
   6.497688461665233*^-7, 2.4578791901624646*^-9, 4.782925060859471*^-7, 
   1.3612724270359002*^-6, 1.4201012583780796*^-6, 
   4.6592299797052394*^-7, 1.0819936704878537*^-7, 
   2.8950185154724654*^-6, 0.000010295878731809506, 
   0.000020967670555120745, 0.00003072452182064132, 
   0.00003457994084802215, 0.000029816404579471976, 
   0.00001819735177319799, 5.762653339180902*^-6, 5.9237543005316894*^-9, 
   5.826548405710062*^-6, 0.000022508472367461666, 
   0.00004354440871734312, 0.000059601780251065134, 
   0.0000631694761696141, 0.0000524393291158798, 0.00003233598372837521, 
   0.000012121825353718143, 8.28278888804395*^-7, 2.8949686205891194*^-6, 
   0.00001623204240397768, 0.00003358581265249521, 
   0.000046345338906395546, 0.000048727597728572174}, 
  {0.00012465206512653627, 0.00011855791118313719, 
   0.00008591724405145678, 0.00004152385303598385, 7.4057378950484*^-6, 
   2.118854177158168*^-6, 0.000031009338319130544, 0.0000827200054493162, 
   0.00013414719733477302, 0.00016159642634889777, 0.0001524697571774041, 
   0.00011139273685451114, 0.00005757984580066856, 
   0.000014905132310799748, 1.5153798694678156*^-8, 
   0.000014741679721998303, 0.00004655139149272669, 
   0.00007627456674926515, 0.0000884603641384105, 0.00007859765868824672, 
   0.00005363825752600987, 0.000026338309418856084, 
   7.405865533193018*^-6, 2.767892360128794*^-7, 1.191896719605643*^-6, 
   3.6328192399645437*^-6, 3.4823267950752457*^-6, 1.223539665351132*^-6, 
   6.287601506439661*^-9, 1.6622003198410386*^-6, 4.378250372274172*^-6, 
   4.46231057957348*^-6, 1.2282601133632691*^-6, 9.301174126311156*^-7, 
   0.000015393108352696142, 0.00005428695497164633, 
   0.0001150654266324456, 0.00017797243523959798, 0.0002122098616751492, 
   0.0001931086536180142, 0.00012211695053855053, 0.0000367595214191315, 
   4.782754771871732*^-7, 0.00007247283683605033, 0.000270506620419249, 
   0.0005475647388741121, 0.0008001669010185393, 0.0009115209839263761, 
   0.0008129336332169018, 0.0005326697119162561, 0.00020216823498393863, 
   7.5273798411803445*^-6, 0.0001022575289252771, 0.0005213556793539191, 
   0.001142747827879388, 0.0017240379565993686, 0.0020066962801486878, 
   0.0018432423859108815, 0.0012851147808674475, 0.0005815288030396156, 
   0.00007955556987505983, 0.00006495925342290736, 0.0006173415809271276, 
   0.0015528661069321914, 0.002490401494474703, 0.003018394006490102, 
   0.0028882485003262266, 0.0021419451172288734, 0.00110822392051165, 
   0.0002622003364024533, 9.372282157013221*^-6, 0.0004941634288504493, 
   0.0015250039111250828, 0.0026548388932865585, 0.0033825665591734853, 
   0.003382566559173561, 0.002654838893286751, 0.001525003911125306, 
   0.0004941634288506063, 9.372282157036287*^-6, 0.0002622003364023379, 
   0.001108223920511454, 0.0021419451172286883, 0.002888248500326136, 
   0.0030183940064901437, 0.002490401494474857, 0.0015528661069323852, 
   0.0006173415809272785, 0.00006495925342296076, 0.00007955556987500358, 
   0.0005815288030394887, 0.0012851147808673159, 0.001843242385910807, 
   0.0020066962801487008, 0.0017240379565994603, 0.0011427478278795136, 
   0.000521355679354027, 0.00010225752892532858, 7.527379841167267*^-6, 
   0.00020216823498388128, 0.0005326697119161928, 0.0008129336332168638, 
   0.0009115209839263781, 0.0008001669010185778, 0.0005475647388741677, 
   0.00027050662041929786, 0.00007247283683607707, 4.782754771891753*^-7, 
   0.00003675952141911743, 0.00012211695053853338, 
   0.00019310865361800517, 0.00021220986167515122, 
   0.00017797243523960817, 0.00011506542663245838, 
   0.000054286954971656306, 0.000015393108352701153, 
   9.30117412632078*^-7, 1.228260113362601*^-6, 4.462310579573102*^-6, 
   4.3782503722745785*^-6, 1.662200319841587*^-6, 6.287601506479425*^-9, 
   1.2235396653506958*^-6, 3.4823267950749345*^-6, 
   3.6328192399648156*^-6, 1.1918967196061559*^-6, 
   2.7678923601248877*^-7, 7.405865533190553*^-6, 
   0.000026338309418851415, 0.00005363825752600443, 
   0.00007859765868824295, 0.00008846036413841066, 
   0.00007627456674926977, 0.00004655139149273353, 
   0.000014741679722003558, 1.515379869487201*^-8, 
   0.00001490513231079365, 0.000057579845800658656, 
   0.0001113927368545014, 0.0001524697571773989, 0.00016159642634889964, 
   0.00013414719733478115, 0.00008272000544932686, 
   0.00003100933831913878, 2.118854177160506*^-6, 7.4057378950442406*^-6, 
   0.00004152385303597523, 0.00008591724405144832, 
   0.00011855791118313293, 0.00012465206512653792}, 
  {0.00010787340707291736, 0.0001025995502103457, 0.00007435244520608387, 
   0.000035934579160318396, 6.40889645764736*^-6, 1.8336480743316323*^-6, 
   0.000026835359463685885, 0.00007158556749019649, 
   0.00011609045715444258, 0.00013984491202266008, 
   0.00013194672840446668, 0.00009639883651726985, 
   0.000049829372172423366, 0.00001289884290008692, 
   1.3114037811027513*^-8, 0.000012757391672375595, 
   0.000040285391174290494, 0.00006600771018034492, 
   0.0000765532513306899, 0.00006801810481076828, 0.00004641833717645699, 
   0.000022793069418212735, 6.409006915195885*^-6, 2.395323166087109*^-7, 
   1.0314627350327243*^-6, 3.14382748731209*^-6, 3.0135919171876615*^-6, 
   1.0588464158720618*^-6, 5.441265623059967*^-9, 1.4384616216099447*^-6, 
   3.7889206584427454*^-6, 3.861666031344728*^-6, 1.0629314730226424*^-6, 
   8.049199520001006*^-7, 0.000013321135448195813, 
   0.000046979717395463135, 0.00009957716781138432, 
   0.00015401664573202927, 0.0001836455799599712, 0.00016711546960648325, 
   0.00010567952887564344, 0.00003181154531075184, 
   4.1389771754870386*^-7, 0.00006271770806049874, 
   0.00023409536577499325, 0.0004738603721918467, 0.0006924612901697714, 
   0.0007888266757135628, 0.0007035095700199837, 0.0004609702744244667, 
   0.0001749555957015024, 6.514164919577074*^-6, 0.00008849326349169933, 
   0.0004511791551277724, 0.0009889294773687855, 0.0014919756693370085, 
   0.0017365870712245895, 0.0015951347137937713, 0.0011121332787484264, 
   0.0005032527397860526, 0.00006884707738567025, 0.00005621548251550256, 
   0.0005342449769667998, 0.0013438442236218683, 0.0021551836619454518, 
   0.0026121063059648037, 0.0024994788966164294, 0.0018536308830834566, 
   0.0009590526236684703, 0.00022690714024421285, 8.110736130199086*^-6, 
   0.0004276470884523276, 0.001319732388914641, 0.0022974871403678623, 
   0.0029272598012600455, 0.002927259801260111, 0.002297487140368029, 
   0.0013197323889148345, 0.0004276470884524635, 8.110736130219047*^-6, 
   0.00022690714024411294, 0.0009590526236683005, 0.0018536308830832964, 
   0.0024994788966163505, 0.0026121063059648393, 0.002155183661945585, 
   0.001343844223622036, 0.0005342449769669303, 0.000056215482515548766, 
   0.00006884707738562158, 0.0005032527397859428, 0.0011121332787483124, 
   0.0015951347137937067, 0.0017365870712246008, 0.001491975669337088, 
   0.0009889294773688944, 0.00045117915512786575, 0.00008849326349174387, 
   6.514164919565757*^-6, 0.00017495559570145276, 0.00046097027442441196, 
   0.0007035095700199509, 0.0007888266757135645, 0.0006924612901698046, 
   0.00047386037219189486, 0.00023409536577503553, 
   0.00006271770806052188, 4.1389771755043636*^-7, 
   0.000031811545310739656, 0.0001056795288756286, 
   0.00016711546960647544, 0.00018364557995997294, 
   0.00015401664573203808, 0.00009957716781139538, 
   0.00004697971739547177, 0.00001332113544820015, 8.049199520009334*^-7, 
   1.0629314730220643*^-6, 3.8616660313444*^-6, 3.788920658443097*^-6, 
   1.4384616216104193*^-6, 5.441265623094379*^-9, 1.0588464158716842*^-6, 
   3.013591917187392*^-6, 3.143827487312325*^-6, 1.0314627350331681*^-6, 
   2.395323166083729*^-7, 6.40900691519375*^-6, 0.000022793069418208696, 
   0.00004641833717645228, 0.00006801810481076502, 
   0.00007655325133069004, 0.00006600771018034893, 
   0.00004028539117429642, 0.000012757391672380144, 
   1.3114037811195272*^-8, 0.000012898842900081642, 
   0.000049829372172414794, 0.00009639883651726143, 
   0.0001319467284044622, 0.00013984491202266168, 0.00011609045715444963, 
   0.00007158556749020569, 0.000026835359463693007, 
   1.8336480743336552*^-6, 6.408896457643759*^-6, 
   0.000035934579160310935, 0.00007435244520607655, 
   0.00010259955021034201, 0.0001078734070729188}, 
  {0.000026803440252107394, 0.000025493038447346047, 
   0.000018474444969854802, 8.928709787178222*^-6, 
   1.5924265112751857*^-6, 4.5560882832335025*^-7, 
   6.6678152989321065*^-6, 0.00001778695540634686, 
   0.000028845140953744264, 0.000034747440037996504, 
   0.00003278496848495358, 0.000023952339367725443, 
   0.000012381166369583289, 3.2049916135503154*^-6, 
   3.258461361975475*^-9, 3.1698450502459325*^-6, 0.00001000976148498753, 
   0.0000164010182305763, 0.000019021282017724033, 
   0.00001690054349655113, 0.000011533622241766584, 5.66342244015932*^-6, 
   1.5924539568002933*^-6, 5.9516894023108404*^-8, 2.56288834671153*^-7, 
   7.811507442436027*^-7, 7.487909493947233*^-7, 2.6309289206746593*^-7, 
   1.3519980686708967*^-9, 3.5741635659759783*^-7, 9.414378505714422*^-7, 
   9.595129842777277*^-7, 2.641079113222858*^-7, 1.9999946628718616*^-7, 
   3.3099191706682236*^-6, 0.000011673109086273822, 
   0.00002474206331596058, 0.00003826870842151101, 
   0.00004563064673291938, 0.00004152338955765499, 
   0.00002625832459499939, 7.904254414506317*^-6, 1.0284168307858637*^-7, 
   0.000015583547292729717, 0.00005816596805553707, 
   0.00011774067880603972, 0.0001720567220558515, 0.000196000749818397, 
   0.00017480190195596866, 0.00011453786010654084, 
   0.00004347143548536716, 1.618582697552468*^-6, 
   0.000021988031759397846, 0.00011210504846008188, 
   0.0002457205429905884, 0.000370713058906548, 0.0004314919595956323, 
   0.00039634511558843535, 0.0002763331454726767, 0.00012504383711035418, 
   0.000017106519348106474, 0.000013967931186498597, 
   0.00013274451701000533, 0.0003339066534872751, 0.0005355011775629336, 
   0.0006490333178848682, 0.000621048644746861, 0.00046057398178408007, 
   0.00023829700381808365, 0.0000563799006756247, 2.015284741302837*^-6, 
   0.00010625800644798024, 0.00032791555578784865, 0.0005708595006664571, 
   0.000727339900671105, 0.0007273399006711213, 0.0005708595006664984, 
   0.0003279155557878967, 0.00010625800644801398, 2.015284741307797*^-6, 
   0.000056379900675599874, 0.00023829700381804148, 
   0.0004605739817840403, 0.0006210486447468414, 0.0006490333178848771, 
   0.0005355011775629667, 0.0003339066534873168, 0.00013274451701003777, 
   0.000013967931186510077, 0.00001710651934809438, 
   0.00012504383711032691, 0.00027633314547264833, 0.0003963451155884193, 
   0.0004314919595956351, 0.00037071305890656767, 0.0002457205429906154, 
   0.00011210504846010507, 0.000021988031759408915, 
   1.618582697549656*^-6, 0.000043471435485354826, 
   0.00011453786010652724, 0.0001748019019559605, 0.00019600074981839742, 
   0.00017205672205585976, 0.00011774067880605166, 
   0.00005816596805554757, 0.000015583547292735467, 
   1.0284168307901685*^-7, 7.90425441450329*^-6, 0.0000262583245949957, 
   0.000041523389557653044, 0.00004563064673291982, 
   0.0000382687084215132, 0.000024742063315963327, 
   0.000011673109086275969, 3.309919170669301*^-6, 1.999994662873931*^-7, 
   2.641079113221422*^-7, 9.595129842776464*^-7, 9.414378505715295*^-7, 
   3.574163565977158*^-7, 1.3519980686794473*^-9, 2.6309289206737217*^-7, 
   7.487909493946564*^-7, 7.811507442436612*^-7, 2.5628883467126327*^-7, 
   5.95168940230244*^-8, 1.592453956799763*^-6, 5.6634224401583155*^-6, 
   0.000011533622241765413, 0.00001690054349655032, 
   0.000019021282017724067, 0.000016401018230577293, 
   0.000010009761484989002, 3.1698450502470624*^-6, 
   3.2584613620171583*^-9, 3.204991613549004*^-6, 
   0.000012381166369581157, 0.00002395233936772335, 
   0.00003278496848495246, 0.000034747440037996903, 
   0.000028845140953746016, 0.000017786955406349146, 
   6.667815298933877*^-6, 4.5560882832385285*^-7, 1.592426511274291*^-6, 
   8.928709787176367*^-6, 0.000018474444969852983, 
   0.000025493038447345132, 0.00002680344025210775}, 
  {4.219727574817131*^-6, 4.013427988732959*^-6, 2.9084745889143334*^-6, 
   1.4056674270957904*^-6, 2.5069938773883406*^-7, 7.172755131890232*^-8, 
   1.0497295800854947*^-6, 2.8002415172919185*^-6, 4.541157237173374*^-6, 
   5.470369829526284*^-6, 5.16141339522982*^-6, 3.770872170165629*^-6, 
   1.949195649764451*^-6, 5.045692404240008*^-7, 5.129871065533475*^-10, 
   4.990360356957794*^-7, 1.575859895530515*^-6, 2.5820502230940255*^-6, 
   2.9945644097776818*^-6, 2.660691640737648*^-6, 1.8157648179986931*^-6, 
   8.916056899337555*^-7, 2.5070370855131235*^-7, 9.369882243270373*^-9, 
   4.0348143843012235*^-8, 1.2297836787255287*^-7, 
   1.1788389054595278*^-7, 4.141932233151252*^-8, 2.128481820919064*^-10, 
   5.62688834507718*^-8, 1.482127376436516*^-7, 1.5105834773703965*^-7, 
   4.157911915976471*^-8, 3.148637842391872*^-8, 5.210882283585374*^-7, 
   1.837724554456223*^-6, 3.895200237365856*^-6, 6.024731253152852*^-6, 
   7.183738224069956*^-6, 6.537123230012767*^-6, 4.133908756481587*^-6, 
   1.2443850489916097*^-6, 1.6190603961489434*^-8, 
   2.4533538831616314*^-6, 9.157202844533522*^-6, 
   0.000018536187308883593, 0.0000270872875893101, 
   0.00003085685124425385, 0.000027519467608494296, 
   0.000018031960155343007, 6.8438086047579334*^-6, 
   2.548172166237894*^-7, 3.4616266814403023*^-6, 0.00001764895699260191, 
   0.000038684353247337385, 0.000058362214040407585, 
   0.00006793077691116207, 0.00006239752799124761, 
   0.00004350376603970933, 0.000019685940407370552, 
   2.6931188953131567*^-6, 2.1990037038690258*^-6, 
   0.00002089827624977582, 0.00005256769653008938, 0.0000843051885898002, 
   0.00010217881595398935, 0.00009777312415465367, 
   0.00007250922690884056, 0.00003751564831042204, 8.8760181271014*^-6, 
   3.1727093664087306*^-7, 0.000016728443648885156, 
   0.00005162450416642607, 0.00008987173115283932, 
   0.00011450680234546773, 0.00011450680234547029, 
   0.00008987173115284584, 0.00005162450416643363, 
   0.000016728443648890472, 3.172709366416539*^-7, 8.876018127097492*^-6, 
   0.0000375156483104154, 0.0000725092269088343, 0.00009777312415465059, 
   0.00010217881595399074, 0.00008430518858980542, 
   0.000052567696530095936, 0.000020898276249780926, 
   2.1990037038708333*^-6, 2.693118895311253*^-6, 0.00001968594040736626, 
   0.00004350376603970486, 0.00006239752799124508, 
   0.00006793077691116251, 0.00005836221404041069, 
   0.00003868435324734164, 0.00001764895699260556, 3.461626681442045*^-6, 
   2.548172166233467*^-7, 6.843808604755992*^-6, 0.000018031960155340865, 
   0.00002751946760849301, 0.00003085685124425391, 
   0.000027087287589311404, 0.000018536187308885477, 
   9.157202844535177*^-6, 2.453353883162536*^-6, 1.6190603961557203*^-8, 
   1.2443850489911332*^-6, 4.133908756481007*^-6, 6.53712323001246*^-6, 
   7.183738224070024*^-6, 6.024731253153196*^-6, 3.895200237366288*^-6, 
   1.8377245544565608*^-6, 5.210882283587071*^-7, 3.1486378423951296*^-8, 
   4.157911915974209*^-8, 1.5105834773702684*^-7, 1.4821273764366537*^-7, 
   5.6268883450790364*^-8, 2.1284818209325253*^-10, 
   4.141932233149775*^-8, 1.1788389054594224*^-7, 1.2297836787256208*^-7, 
   4.034814384302959*^-8, 9.369882243257148*^-9, 2.5070370855122886*^-7, 
   8.916056899335974*^-7, 1.815764817998509*^-6, 2.6606916407375204*^-6, 
   2.9945644097776873*^-6, 2.582050223094182*^-6, 1.5758598955307467*^-6, 
   4.990360356959573*^-7, 5.129871065599097*^-10, 5.045692404237943*^-7, 
   1.9491956497641157*^-6, 3.7708721701652996*^-6, 5.161413395229644*^-6, 
   5.470369829526348*^-6, 4.541157237173649*^-6, 2.800241517292279*^-6, 
   1.0497295800857733*^-6, 7.172755131898146*^-8, 2.5069938773869324*^-7, 
   1.4056674270954984*^-6, 2.908474588914047*^-6, 4.013427988732815*^-6, 
   4.219727574817188*^-6}, {0.000066049421458588, 0.00006282031055831947, 
   0.000045524991961861766, 0.000022002254571346923, 
   3.924080222380189*^-6, 1.1227178018618869*^-6, 
   0.000016430925983561428, 0.00004383087033040639, 
   0.00007108060957721416, 0.00008562513953768307, 
   0.00008078918902206855, 0.00005902369781407598, 
   0.000030509847542022386, 7.897786249210343*^-6, 8.029547169293741*^-9, 
   7.811177584401743*^-6, 0.000024666197652366727, 
   0.000040415624086768035, 0.00004687251564927517, 
   0.000041646561403442926, 0.000028421317160236206, 
   0.000013955886711919277, 3.9241478540363474*^-6, 
   1.4666238289800615*^-7, 6.315506180216714*^-7, 1.924922854825654*^-6, 
   1.8451813847686885*^-6, 6.483172737334195*^-7, 3.33161300970759*^-9, 
   8.807505063179954*^-7, 2.3199046385312956*^-6, 2.3644456419568885*^-6, 
   6.508184987224359*^-7, 4.928415500415628*^-7, 8.156350238665238*^-6, 
   0.000028765042640776445, 0.00006096974688099834, 
   0.00009430229953445863, 0.00011244369338945477, 
   0.00010232253141710243, 0.00006470613964694926, 
   0.00001947777696553655, 2.534239487647123*^-7, 0.00003840120049053841, 
   0.00014333341177518715, 0.00029013826748112764, 0.0004239846393955555, 
   0.00048298785563307404, 0.00043074935103320534, 0.0002822458357578523, 
   0.00010712293410011366, 3.988534671321374*^-6, 0.00005418322286472542, 
   0.0002762508664458926, 0.0006055080822597921, 0.0009135164306378848, 
   0.0010632886684418495, 0.0009766793119213532, 0.0006809440958560204, 
   0.00030813481480055347, 0.0000421541300476807, 
   0.000034419976136050845, 0.00032711094053015065, 0.000822817559110672, 
   0.0013195896734055801, 0.0015993572000621418, 0.0015303969676036333, 
   0.0011349530041512097, 0.0005872148906803809, 0.00013893215895018857, 
   4.966093530732761*^-6, 0.0002618425017542367, 0.000808054210330551, 
   0.00140672015974492, 0.0017923214031936154, 0.0017923214031936555, 
   0.0014067201597450219, 0.0008080542103306694, 0.0002618425017543199, 
   4.966093530744983*^-6, 0.0001389321589501274, 0.0005872148906802769, 
   0.0011349530041511115, 0.0015303969676035852, 0.0015993572000621637, 
   0.0013195896734056617, 0.0008228175591107748, 0.00032711094053023055, 
   0.000034419976136079136, 0.00004215413004765091, 
   0.0003081348148004863, 0.0006809440958559506, 0.0009766793119213137, 
   0.0010632886684418567, 0.0009135164306379333, 0.0006055080822598587, 
   0.00027625086644594973, 0.000054183222864752694, 
   3.988534671314445*^-6, 0.00010712293410008326, 0.0002822458357578188, 
   0.00043074935103318523, 0.00048298785563307507, 0.0004239846393955759, 
   0.0002901382674811571, 0.00014333341177521304, 0.00003840120049055257, 
   2.5342394876577303*^-7, 0.000019477776965529092, 
   0.00006470613964694017, 0.00010232253141709765, 
   0.00011244369338945585, 0.00009430229953446402, 
   0.00006096974688100511, 0.000028765042640781734, 
   8.156350238667893*^-6, 4.928415500420727*^-7, 6.50818498722082*^-7, 
   2.364445641956688*^-6, 2.319904638531511*^-6, 8.807505063182859*^-7, 
   3.33161300972866*^-9, 6.483172737331884*^-7, 1.8451813847685237*^-6, 
   1.924922854825798*^-6, 6.315506180219432*^-7, 1.4666238289779915*^-7, 
   3.9241478540350405*^-6, 0.000013955886711916802, 
   0.000028421317160233323, 0.00004164656140344093, 
   0.00004687251564927526, 0.00004041562408677049, 
   0.000024666197652370352, 7.811177584404528*^-6, 8.029547169396459*^-9, 
   7.897786249207113*^-6, 0.000030509847542017138, 
   0.00005902369781407082, 0.0000807891890220658, 0.00008562513953768405, 
   0.00007108060957721847, 0.00004383087033041203, 
   0.000016430925983565792, 1.1227178018631255*^-6, 
   3.924080222377985*^-6, 0.000022002254571342353, 
   0.00004552499196185728, 0.00006282031055831722, 
   0.0000660494214585889}, {0.00010979023781752203, 
   0.00010442266841493585, 0.00007567363322428763, 
   0.00003657311008279467, 6.522777812675875*^-6, 1.8662306458757773*^-6, 
   0.00002731220397484275, 0.00007285759013561482, 
   0.00011815329880807117, 0.00014232985278901943, 
   0.00013429132428327046, 0.00009811177262074826, 
   0.00005071480330096727, 0.00001312804580849232, 
   1.3347064574009922*^-8, 0.000012984081096971626, 
   0.00004100123281178608, 0.00006718061842240234, 0.0000779135460477273, 
   0.00006922673628008763, 0.00004724315673326505, 
   0.000023198085421788167, 6.522890232973428*^-6, 2.437886289034695*^-7, 
   1.0497910657684755*^-6, 3.199690979037531*^-6, 3.067141219052696*^-6, 
   1.0776613343847042*^-6, 5.53795289306333*^-9, 1.4640220218610653*^-6, 
   3.85624697921114*^-6, 3.93028498364382*^-6, 1.0818189799827267*^-6, 
   8.192227848558069*^-7, 0.00001355784218318273, 0.00004781451226400374, 
   0.00010134658051374293, 0.0001567534077360372, 0.0001869088262347466, 
   0.00017008498803306103, 0.00010755737602556466, 
   0.00003237681296790311, 4.2125237419343906*^-7, 0.0000638321553956074, 
   0.00023825506747036725, 0.00048228052090795406, 0.0007047658156915139, 
   0.0008028435429396993, 0.0007160104153119693, 0.0004691613756267157, 
   0.00017806442737634305, 6.629916817399585*^-6, 0.0000900657234033125, 
   0.0004591962753739985, 0.0010065020235402898, 0.0015184869746789652, 
   0.0017674449404541783, 0.0016234790791397112, 0.0011318950654449567, 
   0.0005121951691586261, 0.00007007043908518368, 
   0.000057214390106653955, 0.000543738115496376, 0.001367723342616011, 
   0.0021934796833244213, 0.002658521505144195, 0.0025438927899431355, 
   0.0018865685343754136, 0.000976094280223351, 0.00023093911248271302, 
   8.254857918854862*^-6, 0.00043524606125970355, 0.0013431830584203534, 
   0.0023383117894216756, 0.0029792750452089806, 0.0029792750452090474, 
   0.002338311789421845, 0.0013431830584205503, 0.0004352460612598418, 
   8.254857918875179*^-6, 0.00023093911248261133, 0.0009760942802231783, 
   0.0018865685343752506, 0.0025438927899430557, 0.0026585215051442316, 
   0.002193479683324557, 0.0013677233426161817, 0.0005437381154965088, 
   0.00005721439010670098, 0.00007007043908513416, 0.0005121951691585144, 
   0.0011318950654448407, 0.0016234790791396455, 0.0017674449404541897, 
   0.001518486974679046, 0.0010065020235404006, 0.00045919627537409347, 
   0.00009006572340335783, 6.6299168173880675*^-6, 
   0.00017806442737629253, 0.00046916137562666, 0.0007160104153119358, 
   0.0008028435429397009, 0.0007047658156915477, 0.00048228052090800295, 
   0.00023825506747041027, 0.00006383215539563094, 4.212523741952023*^-7, 
   0.000032376812967890716, 0.00010755737602554955, 
   0.00017008498803305308, 0.00018690882623474838, 
   0.00015675340773604616, 0.00010134658051375419, 
   0.000047814512264012527, 0.000013557842183187144, 
   8.192227848566545*^-7, 1.0818189799821384*^-6, 3.930284983643486*^-6, 
   3.856246979211497*^-6, 1.4640220218615484*^-6, 5.537952893098354*^-9, 
   1.0776613343843198*^-6, 3.067141219052422*^-6, 3.1996909790377705*^-6, 
   1.0497910657689272*^-6, 2.4378862890312547*^-7, 6.522890232971256*^-6, 
   0.000023198085421784054, 0.000047243156733260256, 
   0.00006922673628008431, 0.00007791354604772744, 
   0.00006718061842240641, 0.00004100123281179211, 
   0.000012984081096976255, 1.3347064574180662*^-8, 
   0.000013128045808486948, 0.000050714803300958544, 
   0.00009811177262073968, 0.00013429132428326588, 
   0.00014232985278902108, 0.00011815329880807834, 
   0.00007285759013562419, 0.000027312203974850003, 
   1.8662306458778363*^-6, 6.5227778126722105*^-6, 
   0.000036573110082787074, 0.00007567363322428017, 
   0.00010442266841493211, 0.0001097902378175235}, 
  {0.00006782166485533573, 0.00006450591019129169, 
   0.00004674652221314472, 0.000022592620838250265, 4.02937145898522*^-6, 
   1.152842656354494*^-6, 0.00001687180191303607, 
   0.000045006943773615454, 0.00007298785021881469, 
   0.00008792264017872056, 0.0000829569310493433, 0.00006060742642808382, 
   0.000031328490228787335, 8.109700286002683*^-6, 8.244996625706883*^-9, 
   8.020767730523756*^-6, 0.00002532804305459617, 0.0000415000593676754, 
   0.000048130202764679594, 0.00004276402529358126, 
   0.000029183920231569424, 0.000014330352188296925, 
   4.029440905339424*^-6, 1.505976397693361*^-7, 6.484964350747794*^-7, 
   1.9765725399156658*^-6, 1.8946914403110893*^-6, 6.657129750431112*^-7, 
   3.4210071183399428*^-9, 9.043828748465062*^-7, 2.382152506656822*^-6, 
   2.427888637874034*^-6, 6.682813131025024*^-7, 5.06065514209844*^-7, 
   8.37520208524953*^-6, 0.000029536868581890033, 0.00006260569204032084, 
   0.00009683262643146039, 0.00011546079162763284, 
   0.00010506805782199561, 0.00006644233999792798, 
   0.00002000040624597832, 2.6022384057084403*^-7, 
   0.00003943158459525328, 0.00014717934542520655, 0.0002979232808443355, 
   0.0004353610293910736, 0.000495947424679288, 0.00044230725231627114, 
   0.00028981907875733895, 0.00010999726529646183, 4.095555354892094*^-6, 
   0.000055637071465000085, 0.000283663251945916, 0.0006217551238956545, 
   0.0009380279770869874, 0.0010918189156396126, 0.0010028856498887188, 
   0.000699215242684942, 0.00031640271297102805, 0.00004328521306056504, 
   0.00003534353570820511, 0.0003358880076346971, 0.0008448954661333135, 
   0.001354997009813149, 0.0016422712812797678, 0.0015714607023093008, 
   0.0011654061545771691, 0.0006029710879262983, 0.00014265999782989405, 
   5.0993441523599455*^-6, 0.0002688682808522838, 0.0008297359859895611, 
   0.0014444653883801616, 0.0018404131154526103, 0.0018404131154526515, 
   0.0014444653883802663, 0.0008297359859896828, 0.00026886828085236915, 
   5.099344152372495*^-6, 0.00014265999782983122, 0.0006029710879261915, 
   0.0011654061545770683, 0.0015714607023092513, 0.0016422712812797903, 
   0.0013549970098132328, 0.000844895466133419, 0.00033588800763477915, 
   0.00003534353570823416, 0.00004328521306053444, 
   0.00031640271297095904, 0.0006992152426848702, 0.001002885649888678, 
   0.0010918189156396197, 0.0009380279770870373, 0.0006217551238957228, 
   0.00028366325194597463, 0.00005563707146502809, 4.095555354884979*^-6, 
   0.00010999726529643061, 0.0002898190787573045, 0.00044230725231625043, 
   0.0004959474246792891, 0.00043536102939109453, 0.0002979232808443657, 
   0.00014717934542523314, 0.00003943158459526782, 
   2.6022384057193326*^-7, 0.000020000406245970662, 
   0.00006644233999791865, 0.0001050680578219907, 0.00011546079162763395, 
   0.00009683262643146593, 0.0000626056920403278, 
   0.000029536868581895464, 8.375202085252258*^-6, 5.060655142103676*^-7, 
   6.68281313102139*^-7, 2.4278886378738282*^-6, 2.382152506657043*^-6, 
   9.043828748468046*^-7, 3.4210071183615785*^-9, 6.657129750428739*^-7, 
   1.89469144031092*^-6, 1.9765725399158136*^-6, 6.484964350750583*^-7, 
   1.5059763976912357*^-7, 4.0294409053380826*^-6, 
   0.000014330352188294385, 0.000029183920231566463, 
   0.00004276402529357921, 0.00004813020276467968, 
   0.000041500059367677914, 0.000025328043054599893, 
   8.020767730526616*^-6, 8.244996625812356*^-9, 8.109700285999366*^-6, 
   0.00003132849022878194, 0.00006060742642807852, 
   0.00008295693104934047, 0.00008792264017872157, 
   0.00007298785021881912, 0.00004500694377362125, 
   0.00001687180191304055, 1.1528426563557658*^-6, 4.029371458982957*^-6, 
   0.00002259262083824557, 0.00004674652221314012, 
   0.00006450591019128937, 0.00006782166485533664}, 
  {6.399150949688183*^-6, 6.086300850053963*^-6, 4.410656280009185*^-6, 
   2.1316726948742863*^-6, 3.801817052620345*^-7, 1.0877371109936002*^-7, 
   1.5918985100859218*^-6, 4.246522517632294*^-6, 6.886594011510495*^-6, 
   8.29573039232888*^-6, 7.827202786011503*^-6, 5.718468740227586*^-6, 
   2.955924753947844*^-6, 7.651713710884798*^-7, 7.779369335758381*^-10, 
   7.56780352553841*^-7, 2.38976691463231*^-6, 3.91563882840725*^-6, 
   4.541210148515745*^-6, 4.034897309784646*^-6, 2.7535789819346984*^-6, 
   1.3521061007674737*^-6, 3.801882577066612*^-7, 1.4209280052418665*^-8, 
   6.118732984850483*^-8, 1.8649477379990666*^-7, 1.7876907851634543*^-7, 
   6.28117552931425*^-8, 3.2278094318253537*^-10, 8.533088276143146*^-8, 
   2.2476230136476544*^-7, 2.290776246193325*^-7, 6.305408468695685*^-8, 
   4.7748601022518075*^-8, 7.902221582435627*^-7, 2.7868805792334752*^-6, 
   5.9070103119738865*^-6, 9.136410831426699*^-6, 
   0.000010894026797656656, 9.91344526011913*^-6, 6.269008052281634*^-6, 
   1.8870904879155679*^-6, 2.455279798973286*^-8, 3.7204728393006044*^-6, 
   0.000013886755066557463, 0.000028109838495055196, 
   0.00004107744849123879, 0.00004679393288857306, 
   0.00004173284273912898, 0.00002734518589338158, 
   0.000010378528840103808, 3.8642632844033465*^-7, 
   5.249502787384239*^-6, 0.000026764367580082176, 
   0.00005866421740069323, 0.00008850538590012274, 
   0.00010301596202047647, 0.00009462487646982545, 0.000065972781614956, 
   0.00002985342110830212, 4.084072734793366*^-6, 3.3347547656772917*^-6, 
   0.000031691909475078946, 0.00007971809061347274, 
   0.00012784750154195456, 0.00015495257823091126, 
   0.00014827141543973887, 0.00010995910992073255, 
   0.000056891894620521524, 0.000013460342835035253, 
   4.811364192395494*^-7, 0.000025368423473927178, 
   0.00007828775412784398, 0.00013628907638231502, 0.000173647777014731, 
   0.00017364777701473492, 0.00013628907638232489, 
   0.00007828775412785545, 0.000025368423473935234, 
   4.811364192407336*^-7, 0.000013460342835029327, 
   0.00005689189462051145, 0.00010995910992072303, 0.0001482714154397342, 
   0.0001549525782309134, 0.00012784750154196247, 0.0000797180906134827, 
   0.00003169190947508669, 3.334754765680033*^-6, 4.084072734790479*^-6, 
   0.00002985342110829561, 0.00006597278161494922, 
   0.00009462487646982161, 0.00010301596202047714, 
   0.00008850538590012744, 0.00005866421740069968, 
   0.000026764367580087716, 5.249502787386882*^-6, 
   3.8642632843966327*^-7, 0.000010378528840100862, 
   0.00002734518589337833, 0.00004173284273912703, 
   0.000046793932888573164, 0.00004107744849124076, 
   0.00002810983849505805, 0.00001388675506655997, 
   3.7204728393019766*^-6, 2.455279798983563*^-8, 1.8870904879148454*^-6, 
   6.269008052280753*^-6, 9.913445260118665*^-6, 0.000010894026797656761, 
   9.136410831427221*^-6, 5.907010311974542*^-6, 2.7868805792339873*^-6, 
   7.902221582438199*^-7, 4.7748601022567474*^-8, 6.305408468692256*^-8, 
   2.2907762461931308*^-7, 2.2476230136478627*^-7, 8.53308827614596*^-8, 
   3.2278094318457675*^-10, 6.281175529312011*^-8, 
   1.7876907851632944*^-7, 1.864947737999206*^-7, 6.118732984853116*^-8, 
   1.4209280052398611*^-8, 3.8018825770653463*^-7, 1.352106100767234*^-6, 
   2.753578981934419*^-6, 4.034897309784453*^-6, 4.541210148515753*^-6, 
   3.915638828407488*^-6, 2.3897669146326616*^-6, 7.567803525541108*^-7, 
   7.779369335857897*^-10, 7.651713710881667*^-7, 2.955924753947336*^-6, 
   5.718468740227086*^-6, 7.827202786011238*^-6, 8.295730392328974*^-6, 
   6.886594011510913*^-6, 4.2465225176328405*^-6, 1.5918985100863445*^-6, 
   1.0877371109948003*^-7, 3.801817052618209*^-7, 2.1316726948738438*^-6, 
   4.4106562800087505*^-6, 6.086300850053744*^-6, 6.399150949688269*^-6}, 
  {0.000016508182664202837, 0.000015701108939597632, 
   0.000011378371929631221, 5.49917364099576*^-6, 9.807721501490149*^-7, 
   2.8060852228825157*^-7, 4.106693465115287*^-6, 
   0.000010954948548625871, 0.000017765661846398586, 
   0.000021400875479616145, 0.00002019219336395425, 
   0.000014752195606170356, 7.6255344128407556*^-6, 
   1.9739476162791048*^-6, 2.0068795222474856*^-9, 1.952300921616389*^-6, 
   6.164991115507434*^-6, 0.000010101352747358125, 
   0.000011715167721099405, 0.000010409009311535504, 
   7.10353376119416*^-6, 3.4880900088690904*^-6, 9.807890537903959*^-7, 
   3.665633026574737*^-8, 1.5784775602506578*^-7, 4.8110910588194*^-7, 
   4.611787760691678*^-7, 1.620383607123586*^-7, 8.326927763503718*^-10, 
   2.201319847896428*^-7, 5.798295986652659*^-7, 5.909620356247264*^-7, 
   1.6266350894365447*^-7, 1.231792520347219*^-7, 2.0385722787522295*^-6, 
   7.189443416325006*^-6, 0.000015238584930418987, 
   0.000023569617295516783, 0.000028103819668951553, 
   0.000025574168584599, 0.000016172447073696003, 4.8682137244954106*^-6, 
   6.333997702484776*^-8, 9.597874110372803*^-6, 0.00003582429779421682, 
   0.00007251623726116721, 0.00010596937443799419, 
   0.00012071645094395754, 0.00010766012498385627, 0.0000705436279380974, 
   0.000026773965987859597, 9.968816904469378*^-7, 
   0.000013542382667907485, 0.00006904526434485727, 
   0.00015133876733292883, 0.00022832139586833515, 0.0002657549933941587, 
   0.00024410812584716796, 0.00017019300502956963, 
   0.00007701423715145123, 0.000010535869406728806, 
   8.602819537301925*^-6, 0.00008175706975899313, 0.0002056524079265246, 
   0.0003298140527095054, 0.00039973825994051737, 0.000382502558418064, 
   0.0002836665498964457, 0.00014676662511827642, 0.00003472426263899642, 
   1.2412096476008255*^-6, 0.00006544408342654388, 
   0.00020196250341236654, 0.0003515911697886078, 0.00044796712012733914, 
   0.00044796712012734916, 0.0003515911697886333, 0.0002019625034123961, 
   0.00006544408342656467, 1.2412096476038803*^-6, 
   0.00003472426263898113, 0.00014676662511825043, 0.0002836665498964212, 
   0.000382502558418052, 0.00039973825994052284, 0.00032981405270952576, 
   0.0002056524079265503, 0.00008175706975901311, 8.602819537308996*^-6, 
   0.000010535869406721357, 0.00007701423715143444, 
   0.00017019300502955218, 0.00024410812584715807, 
   0.00026575499339416043, 0.00022832139586834727, 
   0.00015133876733294544, 0.00006904526434487155, 
   0.000013542382667914302, 9.96881690445206*^-7, 0.000026773965987852, 
   0.00007054362793808901, 0.00010766012498385124, 0.0001207164509439578, 
   0.00010596937443799928, 0.00007251623726117457, 
   0.00003582429779422328, 9.597874110376342*^-6, 6.333997702511289*^-8, 
   4.868213724493546*^-6, 0.000016172447073693733, 
   0.000025574168584597806, 0.00002810381966895182, 
   0.000023569617295518132, 0.000015238584930420681, 
   7.189443416326327*^-6, 2.038572278752893*^-6, 1.2317925203484935*^-7, 
   1.62663508943566*^-7, 5.909620356246763*^-7, 5.798295986653197*^-7, 
   2.2013198478971544*^-7, 8.326927763556381*^-10, 
   1.6203836071230084*^-7, 4.6117877606912663*^-7, 4.81109105881976*^-7, 
   1.578477560251337*^-7, 3.665633026569564*^-8, 9.807890537900691*^-7, 
   3.488090008868472*^-6, 7.103533761193439*^-6, 0.000010409009311535004, 
   0.000011715167721099427, 0.000010101352747358738, 
   6.16499111550834*^-6, 1.952300921617085*^-6, 2.006879522273158*^-9, 
   1.973947616278297*^-6, 7.6255344128394435*^-6, 
   0.000014752195606169066, 0.00002019219336395356, 
   0.000021400875479616393, 0.000017765661846399663, 
   0.00001095494854862728, 4.106693465116377*^-6, 2.8060852228856116*^-7, 
   9.80772150148464*^-7, 5.499173640994617*^-6, 0.000011378371929630101, 
   0.00001570110893959707, 0.000016508182664203057}, 
  {0.00007528815721036189, 0.00007160737085765265, 
   0.00005189285047673121, 0.00002507984422223254, 4.472965276067798*^-6, 
   1.279759193991533*^-6, 0.000018729219896919267, 
   0.00004996176171159407, 0.00008102308832202234, 
   0.00009760205046934667, 0.00009208966603598119, 
   0.00006727970271396294, 0.00003477744615292592, 9.002497820774918*^-6, 
   9.152688945032389*^-9, 8.903774673351474*^-6, 0.00002811640928297308, 
   0.000046068804128848896, 0.000053428860527724264, 
   0.00004747192016177321, 0.00003239678027803824, 
   0.000015907981774462023, 4.473042367776534*^-6, 1.671769456359963*^-7, 
   7.198894580133281*^-7, 2.1941735644542705*^-6, 2.103278168230424*^-6, 
   7.390013682048438*^-7, 3.797626057878784*^-9, 1.0039464558270278*^-6, 
   2.6444038612556506*^-6, 2.695175086713179*^-6, 7.418524548008047*^-7, 
   5.617783060006357*^-7, 9.29722873373566*^-6, 0.0000327885847396768, 
   0.00006949795754275642, 0.00010749293780113508, 
   0.00012817187915153584, 0.00011663500847351236, 
   0.00007375698237220094, 0.000022202252524030368, 
   2.888719034038945*^-7, 0.00004377261080796889, 0.00016338233100185158, 
   0.0003307216779870965, 0.0004832899589530118, 0.0005505463152072825, 
   0.000491000892099905, 0.00032172528366248367, 0.00012210687278194074, 
   4.5464353622188745*^-6, 0.00006176216098669714, 0.00031489176139896, 
   0.0006902041938081577, 0.001041295549988062, 0.001212017344918583, 
   0.0011132934090292766, 0.0007761919030951611, 0.0003512355122328388, 
   0.000048050485530530964, 0.00003923450830122228, 
   0.00037286594450042893, 0.0009379100736652362, 0.0015041687359338952, 
   0.0018230690542732407, 0.0017444629331605141, 0.001293705808709978, 
   0.0006693522218590392, 0.00015836544807852724, 5.660731346414463*^-6, 
   0.0002984680107877642, 0.0009210816851742627, 0.0016034866952508355, 
   0.002043024338369762, 0.0020430243383698075, 0.001603486695250952, 
   0.0009210816851743977, 0.00029846801078785897, 5.660731346428394*^-6, 
   0.00015836544807845752, 0.0006693522218589207, 0.0012937058087098662, 
   0.0017444629331604593, 0.0018230690542732656, 0.001504168735933988, 
   0.0009379100736653532, 0.00037286594450052006, 0.00003923450830125453, 
   0.000048050485530496995, 0.0003512355122327622, 0.0007761919030950815, 
   0.0011132934090292317, 0.001212017344918591, 0.0010412955499881176, 
   0.0006902041938082336, 0.0003148917613990252, 0.00006176216098672824, 
   4.546435362210976*^-6, 0.0001221068727819061, 0.00032172528366244545, 
   0.000491000892099882, 0.0005505463152072837, 0.000483289958953035, 
   0.00033072167798713005, 0.00016338233100188107, 
   0.000043772610807985036, 2.8887190340510366*^-7, 
   0.000022202252524021867, 0.00007375698237219057, 
   0.0001166350084735069, 0.00012817187915153705, 0.00010749293780114123, 
   0.00006949795754276413, 0.00003278858473968283, 9.297228733738687*^-6, 
   5.617783060012169*^-7, 7.418524548004013*^-7, 2.6951750867129507*^-6, 
   2.644403861255896*^-6, 1.003946455827359*^-6, 3.797626057902801*^-9, 
   7.390013682045804*^-7, 2.103278168230236*^-6, 2.194173564454435*^-6, 
   7.198894580136378*^-7, 1.6717694563576038*^-7, 4.473042367775045*^-6, 
   0.000015907981774459204, 0.000032396780278034946, 
   0.000047471920161770936, 0.00005342886052772436, 
   0.00004606880412885169, 0.000028116409282977213, 
   8.903774673354647*^-6, 9.152688945149473*^-9, 9.002497820771235*^-6, 
   0.00003477744615291994, 0.00006727970271395706, 
   0.00009208966603597804, 0.0000976020504693478, 0.00008102308832202726, 
   0.000049961761711600504, 0.000018729219896924237, 
   1.2797591939929449*^-6, 4.472965276065286*^-6, 0.00002507984422222733, 
   0.0000518928504767261, 0.00007160737085765008, 0.0000752881572103629}, 
  {0.0000882778650239402, 0.00008396202076813596, 0.00006084609080406484, 
   0.0000294069503771435, 5.244700355650882*^-6, 1.5005601621337389*^-6, 
   0.000021960632419840668, 0.00005858182508586286, 
   0.00009500226223799606, 0.00011444164602566409, 0.000107978192183793, 
   0.00007888768612624002, 0.00004077771074655562, 
   0.000010555727712662182, 1.0731831794449563*^-8, 
   0.000010439971543220622, 0.00003296742377031579, 
   0.000054017203015577874, 0.00006264711360740048, 
   0.0000556624031686555, 0.000037986300934475485, 
   0.000018652637013885932, 5.244790748239975*^-6, 1.960205215374554*^-7, 
   8.440943006360585*^-7, 2.5727413837582065*^-6, 2.466163512596792*^-6, 
   8.665036501373647*^-7, 4.452842690944247*^-9, 1.1771605655207069*^-6, 
   3.1006513611490544*^-6, 3.160182309363349*^-6, 8.698466438699191*^-7, 
   6.587037232420995*^-7, 0.000010901309497590636, 
   0.000038445704679524865, 0.00008148866359229471, 
   0.00012603903994783125, 0.00015028578553184205, 
   0.00013675842146490695, 0.0000864825116682517, 
   0.000026032878531844828, 3.3871190161615475*^-7, 
   0.000051324840078826116, 0.0001915712098408637, 0.000387782152354471, 
   0.0005666735293397215, 0.0006455338409665203, 0.00057571485457296, 
   0.0003772335811937864, 0.00014317436411441406, 5.330846471970612*^-6, 
   0.00007241818518597141, 0.00036922104936448557, 0.0008092873423599782, 
   0.0012209536189740123, 0.0014211305940514034, 0.0013053735001074325, 
   0.0009101107875792109, 0.00041183530437424027, 0.0000563407902805623, 
   0.00004600376415667238, 0.0004371977046624093, 0.0010997307140387577, 
   0.0017636878038200675, 0.002137609019341302, 0.002045440731435728, 
   0.001516913031127673, 0.0007848377126517626, 0.00018568874797758966, 
   6.637395524761061*^-6, 0.00034996365625827657, 0.0010799988695784695, 
   0.0018801414099634168, 0.002395513895755288, 0.002395513895755341, 
   0.0018801414099635532, 0.0010799988695786278, 0.0003499636562583877, 
   6.637395524777396*^-6, 0.00018568874797750788, 0.0007848377126516236, 
   0.0015169130311275421, 0.0020454407314356633, 0.0021376090193413314, 
   0.0017636878038201763, 0.001099730714038895, 0.00043719770466251617, 
   0.0000460037641567102, 0.00005634079028052248, 0.00041183530437415044, 
   0.0009101107875791176, 0.0013053735001073796, 0.0014211305940514127, 
   0.0012209536189740772, 0.0008092873423600672, 0.00036922104936456195, 
   0.00007241818518600787, 5.330846471961351*^-6, 0.00014317436411437343, 
   0.00037723358119374156, 0.000575714854572933, 0.0006455338409665216, 
   0.0005666735293397488, 0.00038778215235451034, 0.00019157120984089832, 
   0.00005132484007884505, 3.387119016175726*^-7, 0.00002603287853183486, 
   0.00008648251166823956, 0.00013675842146490056, 
   0.00015028578553184349, 0.00012603903994783846, 
   0.00008148866359230376, 0.00003844570467953193, 
   0.000010901309497594185, 6.58703723242781*^-7, 8.69846643869446*^-7, 
   3.1601823093630814*^-6, 3.1006513611493424*^-6, 
   1.1771605655210952*^-6, 4.452842690972409*^-9, 8.665036501370558*^-7, 
   2.4661635125965716*^-6, 2.572741383758399*^-6, 8.440943006364217*^-7, 
   1.9602052153717875*^-7, 5.244790748238228*^-6, 
   0.000018652637013882626, 0.000037986300934471636, 
   0.00005566240316865283, 0.0000626471136074006, 
   0.000054017203015581154, 0.00003296742377032064, 
   0.000010439971543224344, 1.0731831794586848*^-8, 
   0.000010555727712657864, 0.000040777710746548604, 
   0.00007888768612623312, 0.00010797819218378932, 0.0001144416460256654, 
   0.00009500226223800182, 0.000058581825085870395, 
   0.000021960632419846495, 1.5005601621353942*^-6, 
   5.244700355647936*^-6, 0.000029406950377137393, 
   0.00006084609080405885, 0.00008396202076813293, 
   0.00008827786502394137}, {0.00003650698709977802, 
   0.00003472218554699276, 0.0000251626775461042, 0.00001216113640459078, 
   2.1689265839633006*^-6, 6.20551147975782*^-7, 9.08173894142854*^-6, 
   0.00002422629876822537, 0.00003928783688902866, 
   0.00004732692271163633, 0.00004465398509628725, 
   0.00003262371307870851, 0.000016863472624527914, 
   4.365282455918275*^-6, 4.438109652637256*^-9, 4.317411916872313*^-6, 
   0.000013633557109355147, 0.000022338616063279297, 
   0.000025907483916647365, 0.00002301898254867934, 
   0.000015709095341251216, 7.713729581680613*^-6, 2.168963965486778*^-6, 
   8.106356728404077*^-8, 3.4907210019136606*^-7, 1.0639477572600423*^-6, 
   1.019872869783364*^-6, 3.5833940443503737*^-7, 1.8414567528514388*^-9, 
   4.868104316770406*^-7, 1.2822629909737857*^-6, 1.3068817961284805*^-6, 
   3.5972188722430625*^-7, 2.7240450729583983*^-7, 4.508196534785951*^-6, 
   0.000015899080073998875, 0.000033699337764175485, 
   0.00005212298240556733, 0.00006215013505597444, 0.0000565559432916893, 
   0.00003576452530850239, 0.000010765801375853527, 
   1.4007306383643135*^-7, 0.00002122519925179137, 
   0.00007922357076094503, 0.00016036588594082603, 
   0.00023434575835947792, 0.0002669581508144072, 0.0002380847652279066, 
   0.00015600356305071344, 0.00005920923282780293, 2.204551994209997*^-6, 
   0.00002994827470801006, 0.00015269000991879845, 0.0003346778103382667, 
   0.0005049208882115993, 0.0005877033416028439, 0.000539832420232302, 
   0.0003763729760853712, 0.00017031297868323183, 
   0.000023299527049119186, 0.000019024687832600104, 
   0.00018080150624207684, 0.0004547896007652071, 0.0007293666185134162, 
   0.0008840003648966694, 0.0008458845076920924, 0.0006273138169329891, 
   0.000324566755702882, 0.0000767909002460969, 2.744870559940068*^-6, 
   0.0001447261856746001, 0.00044662956890477174, 0.0007775255799478024, 
   0.0009906559800235402, 0.0009906559800235625, 0.0007775255799478588, 
   0.0004466295689048372, 0.00014472618567464604, 2.7448705599468234*^-6, 
   0.00007679090024606308, 0.0003245667557028245, 0.0006273138169329349, 
   0.0008458845076920659, 0.0008840003648966816, 0.0007293666185134613, 
   0.0004547896007652639, 0.00018080150624212102, 0.00001902468783261574, 
   0.000023299527049102717, 0.0001703129786831947, 0.0003763729760853326, 
   0.0005398324202322803, 0.0005877033416028478, 0.0005049208882116261, 
   0.00033467781033830353, 0.00015269000991883003, 
   0.00002994827470802514, 2.204551994206167*^-6, 0.00005920923282778613, 
   0.0001560035630506949, 0.0002380847652278955, 0.0002669581508144078, 
   0.00023434575835948917, 0.0001603658859408423, 0.00007922357076095934, 
   0.0000212251992517992, 1.4007306383701766*^-7, 
   0.000010765801375849405, 0.00003576452530849737, 
   0.00005655594329168666, 0.00006215013505597502, 
   0.00005212298240557031, 0.000033699337764179226, 
   0.0000158990800740018, 4.508196534787418*^-6, 2.7240450729612163*^-7, 
   3.597218872241106*^-7, 1.3068817961283695*^-6, 1.2822629909739047*^-6, 
   4.868104316772012*^-7, 1.8414567528630847*^-9, 3.583394044349096*^-7, 
   1.0198728697832729*^-6, 1.063947757260122*^-6, 3.4907210019151625*^-7, 
   8.106356728392635*^-8, 2.168963965486056*^-6, 7.713729581679246*^-6, 
   0.00001570909534124962, 0.000023018982548678234, 
   0.000025907483916647413, 0.000022338616063280653, 
   0.000013633557109357153, 4.317411916873852*^-6, 4.43810965269403*^-9, 
   4.365282455916489*^-6, 0.00001686347262452501, 0.00003262371307870566, 
   0.000044653985096285734, 0.000047326922711636875, 
   0.00003928783688903105, 0.000024226298768228488, 
   9.081738941430951*^-6, 6.205511479764666*^-7, 2.1689265839620825*^-6, 
   0.000012161136404588255, 0.000025162677546101724, 
   0.00003472218554699151, 0.00003650698709977851}, 
  {3.819951673400184*^-8, 3.633196856860126*^-8, 2.6329264569755318*^-8, 
   1.2724948578253647*^-8, 2.2694819244459463*^-9, 
   6.493210161829288*^-10, 9.502784705808965*^-9, 2.5349473586259888*^-8, 
   4.110929172498902*^-8, 4.952108403662149*^-8, 4.672422422215899*^-8, 
   3.413620713945408*^-8, 1.764529356951379*^-8, 4.567664808047355*^-9, 
   4.643868404694586*^-12, 4.517574904644642*^-9, 1.4265633357236113*^-8, 
   2.3374274513299087*^-8, 2.7108601504282236*^-8, 
   2.4086184013616383*^-8, 1.643739727751472*^-8, 8.071351969737466*^-9, 
   2.2695210390441385*^-9, 8.482182017708682*^-11, 
   3.6525571108316236*^-10, 1.1132742903838768*^-9, 
   1.0671560117893427*^-9, 3.749526642326421*^-10, 
   1.9268300025207216*^-12, 5.093798395443826*^-10, 
   1.341711011298224*^-9, 1.3674711885735382*^-9, 3.763992414124792*^-10, 
   2.8503367057995955*^-10, 4.717204640855508*^-9, 
   1.6636190044443526*^-8, 3.526169972145494*^-8, 5.453949769083134*^-8, 
   6.503152718690405*^-8, 5.917797862292726*^-8, 3.7422633077657525*^-8, 
   1.1264923305992499*^-8, 1.4656710320625726*^-10, 
   2.2209237694289428*^-8, 8.289651810320168*^-8, 1.6780073707032545*^-7, 
   2.4521044953747115*^-7, 2.793348112086506*^-7, 2.4912280349450196*^-7, 
   1.6323616903888175*^-7, 6.195427943783457*^-8, 2.3067589928371268*^-9, 
   3.1336730630122875*^-8, 1.5976899361940264*^-7, 
   3.5019407604286935*^-7, 5.283299294425571*^-7, 6.149503263807585*^-7, 
   5.648600229282116*^-7, 3.938223047249668*^-7, 1.7820899493695477*^-7, 
   2.4379735062074425*^-8, 1.9906706604801903*^-8, 1.891837895126916*^-7, 
   4.7587446527424283*^-7, 7.631813678016445*^-7, 9.249842130067038*^-7, 
   8.851012360538915*^-7, 6.563972146457409*^-7, 3.396142547147726*^-7, 
   8.035106460449816*^-8, 2.8721276998434414*^-9, 1.5143595214842475*^-7, 
   4.673361196487671*^-7, 8.135730653738655*^-7, 1.036584574430091*^-6, 
   1.0365845744301143*^-6, 8.135730653739244*^-7, 4.6733611964883555*^-7, 
   1.5143595214847285*^-7, 2.87212769985051*^-9, 8.035106460446279*^-8, 
   3.3961425471471246*^-7, 6.563972146456841*^-7, 8.851012360538636*^-7, 
   9.249842130067165*^-7, 7.631813678016917*^-7, 4.7587446527430223*^-7, 
   1.8918378951273785*^-7, 1.9906706604818264*^-8, 
   2.4379735062057193*^-8, 1.782089949369159*^-7, 3.9382230472492643*^-7, 
   5.648600229281888*^-7, 6.149503263807625*^-7, 5.283299294425851*^-7, 
   3.5019407604290783*^-7, 1.5976899361943568*^-7, 3.133673063013865*^-8, 
   2.306758992833119*^-9, 6.195427943781699*^-8, 1.6323616903886235*^-7, 
   2.4912280349449037*^-7, 2.793348112086512*^-7, 2.4521044953748295*^-7, 
   1.678007370703425*^-7, 8.289651810321665*^-8, 2.220923769429762*^-8, 
   1.4656710320687077*^-10, 1.1264923305988186*^-8, 
   3.742263307765227*^-8, 5.917797862292449*^-8, 6.503152718690468*^-8, 
   5.453949769083446*^-8, 3.526169972145886*^-8, 1.6636190044446583*^-8, 
   4.717204640857044*^-9, 2.8503367058025444*^-10, 
   3.7639924141227445*^-10, 1.3674711885734221*^-9, 
   1.3417110112983485*^-9, 5.093798395445507*^-10, 
   1.926830002532907*^-12, 3.749526642325084*^-10, 
   1.0671560117892474*^-9, 1.11327429038396*^-9, 3.652557110833195*^-10, 
   8.482182017696711*^-11, 2.269521039043383*^-9, 8.071351969736035*^-9, 
   1.643739727751305*^-8, 2.4086184013615228*^-8, 2.7108601504282286*^-8, 
   2.3374274513300506*^-8, 1.4265633357238209*^-8, 
   4.5175749046462525*^-9, 4.643868404753992*^-12, 4.567664808045486*^-9, 
   1.7645293569510756*^-8, 3.4136207139451096*^-8, 4.672422422215739*^-8, 
   4.9521084036622056*^-8, 4.110929172499151*^-8, 2.534947358626315*^-8, 
   9.502784705811488*^-9, 6.493210161836452*^-10, 2.2694819244446716*^-9, 
   1.2724948578251003*^-8, 2.6329264569752727*^-8, 
   3.6331968568599957*^-8, 3.819951673400236*^-8}, 
  {0.00003075065904976136, 0.000029247280426069948, 
   0.000021195091117339588, 0.000010243599621440293, 
   1.8269358056070478*^-6, 5.227042352793147*^-7, 7.649753648624369*^-6, 
   0.000020406358142435746, 0.00003309303157982334, 
   0.00003986453497798467, 0.00003761305930714298, 
   0.00002747968971196491, 0.000014204483532276901, 
   3.676975919458004*^-6, 3.738319910670824*^-9, 3.636653484174386*^-6, 
   0.00001148385280766649, 0.000018816320402666174, 
   0.00002182245833052718, 0.00001938940844644912, 
   0.000013232125496928446, 6.49744849444892*^-6, 1.8269672929078232*^-6, 
   6.828167200146966*^-8, 2.940313071421361*^-7, 8.961872049545484*^-7, 
   8.590619326403022*^-7, 3.0183736663230087*^-7, 1.5511005771867592*^-9, 
   4.100514119517369*^-7, 1.080079052806904*^-6, 1.1008160279359506*^-6, 
   3.030018630827688*^-7, 2.294524635675436*^-7, 3.7973556730832306*^-6, 
   0.000013392153924511803, 0.000028385712657049384, 
   0.000043904364285927526, 0.000052350461235803035, 
   0.00004763834727437561, 0.000030125266728598522, 
   9.068277439644877*^-6, 1.179867025541461*^-7, 0.00001787846429701823, 
   0.00006673180140875763, 0.00013507980453991627, 
   0.00019739472050581477, 0.0002248648746009096, 0.00020054417036541344, 
   0.00013140532152952186, 0.00004987327292469929, 
   1.8569438925798207*^-6, 0.00002522610759846047, 
   0.00012861424095296544, 0.00028190667197774077, 
   0.00042530625817083565, 0.0004950357867287374, 0.0004547130294044987, 
   0.000317027450978435, 0.00014345846522265273, 0.00001962571740992871, 
   0.00001602492387195618, 0.00015229318866927835, 0.0003830795434935524, 
   0.0006143619616399349, 0.0007446134556792116, 0.0007125076090344617, 
   0.0005284005839481631, 0.0002733899024925888, 0.00006468270813852835, 
   2.312066413307435*^-6, 0.00012190613208064886, 0.000376206164518464, 
   0.0006549273416098536, 0.0008344518870881108, 0.0008344518870881295, 
   0.0006549273416099011, 0.0003762061645185191, 0.00012190613208068758, 
   2.312066413313125*^-6, 0.00006468270813849987, 0.00027338990249254047, 
   0.0005284005839481173, 0.0007125076090344392, 0.0007446134556792218, 
   0.0006143619616399728, 0.0003830795434936002, 0.00015229318866931556, 
   0.000016024923871969353, 0.00001962571740991484, 
   0.00014345846522262142, 0.00031702745097840246, 
   0.00045471302940448024, 0.0004950357867287406, 0.00042530625817085825, 
   0.0002819066719777718, 0.00012861424095299203, 0.00002522610759847317, 
   1.8569438925765945*^-6, 0.00004987327292468514, 
   0.00013140532152950625, 0.00020054417036540409, 
   0.00022486487460091008, 0.00019739472050582426, 
   0.00013507980453992998, 0.00006673180140876968, 
   0.000017878464297024822, 1.1798670255463997*^-7, 
   9.068277439641404*^-6, 0.00003012526672859429, 0.00004763834727437338, 
   0.00005235046123580354, 0.00004390436428593004, 
   0.000028385712657052535, 0.000013392153924514265, 
   3.7973556730844664*^-6, 2.29452463567781*^-7, 3.03001863082604*^-7, 
   1.1008160279358574*^-6, 1.0800790528070044*^-6, 
   4.1005141195187215*^-7, 1.5511005771965687*^-9, 
   3.0183736663219324*^-7, 8.590619326402255*^-7, 8.961872049546155*^-7, 
   2.9403130714226265*^-7, 6.828167200137328*^-8, 1.8269672929072148*^-6, 
   6.497448494447768*^-6, 0.000013232125496927105, 
   0.000019389408446448193, 0.000021822458330527216, 
   0.000018816320402667316, 0.00001148385280766818, 
   3.6366534841756823*^-6, 3.738319910718646*^-9, 3.6769759194565*^-6, 
   0.000014204483532274458, 0.00002747968971196251, 
   0.0000376130593071417, 0.000039864534977985126, 
   0.00003309303157982535, 0.000020406358142438372, 7.6497536486264*^-6, 
   5.227042352798914*^-7, 1.8269358056060216*^-6, 
   0.000010243599621438165, 0.0000211950911173375, 0.0000292472804260689, 
   0.00003075065904976177}, {0.00007588540004021396, 
   0.0000721754148953065, 0.00005230450396934118, 
   0.000025278796589916125, 4.508448232993474*^-6, 1.289911215648978*^-6, 
   0.000018877794290378034, 0.000050358096341828864, 
   0.0000816658249800281, 0.00009837630404363465, 0.00009282019119134908, 
   0.00006781341640187032, 0.00003505332726258527, 9.073912469153066*^-6, 
   9.225295023449389*^-9, 8.974406174763038*^-6, 0.000028339449990404965, 
   0.000046434256863585614, 0.0000538526988183626, 
   0.00004784850347827956, 0.00003265377613832061, 
   0.000016034175964946305, 4.5085259362521805*^-6, 
   1.6850312010748316*^-7, 7.256001678117263*^-7, 2.2115794152198797*^-6, 
   2.1199629676956335*^-6, 7.448636881866971*^-7, 3.827751711335678*^-9, 
   1.011910521418682*^-6, 2.665381280598712*^-6, 2.7165552619675397*^-6, 
   7.477373917663885*^-7, 5.662347580862919*^-7, 9.370981411506795*^-6, 
   0.00003304868869044894, 0.00007004926811230324, 
   0.00010834565340396335, 0.00012918863581882993, 
   0.00011756024592255639, 0.00007434207876060424, 
   0.000022378377649386967, 2.911634546842857*^-7, 
   0.00004411984839376767, 0.00016467840370878116, 
   0.00033334521345632773, 0.0004871237818730987, 0.0005549136666134314, 
   0.0004948958839966821, 0.00032427745290090275, 0.0001230755172135066, 
   4.582501139654285*^-6, 0.00006225210534411326, 0.0003173897219500404, 
   0.0006956794175506379, 0.0010495558969540475, 0.00122163198679229, 
   0.0011221248976816885, 0.0007823492466388151, 0.00035402177901161465, 
   0.000048431658466851293, 0.00003954574621212245, 
   0.0003758238002920999, 0.0009453502885316654, 0.0015161009444738663, 
   0.0018375310222816708, 0.0017583013377300638, 0.0013039684655051383, 
   0.0006746620319269611, 0.0001596217230607524, 5.705636565689768*^-6, 
   0.00030083568567832017, 0.0009283884044852606, 0.0016162067692569763, 
   0.0020592311587053335, 0.00205923115870538, 0.0016162067692570936, 
   0.0009283884044853966, 0.00030083568567841574, 5.70563656570381*^-6, 
   0.0001596217230606821, 0.0006746620319268416, 0.0013039684655050256, 
   0.0017583013377300085, 0.001837531022281696, 0.00151610094447396, 
   0.0009453502885317834, 0.00037582380029219174, 
   0.000039545746212154956, 0.00004843165846681706, 
   0.00035402177901153745, 0.0007823492466387348, 0.0011221248976816432, 
   0.001221631986792298, 0.0010495558969541034, 0.0006956794175507143, 
   0.00031738972195010604, 0.00006225210534414461, 4.582501139646324*^-6, 
   0.0001230755172134717, 0.0003242774529008642, 0.000494895883996659, 
   0.0005549136666134326, 0.0004871237818731221, 0.00033334521345636156, 
   0.0001646784037088109, 0.00004411984839378394, 2.9116345468550446*^-7, 
   0.000022378377649378398, 0.00007434207876059379, 
   0.00011756024592255088, 0.00012918863581883118, 
   0.00010834565340396954, 0.00007004926811231102, 
   0.00003304868869045502, 9.370981411509845*^-6, 5.662347580868777*^-7, 
   7.477373917659818*^-7, 2.7165552619673093*^-6, 2.6653812805989592*^-6, 
   1.0119105214190157*^-6, 3.8277517113598855*^-9, 7.448636881864316*^-7, 
   2.119962967695444*^-6, 2.2115794152200453*^-6, 7.256001678120385*^-7, 
   1.6850312010724532*^-7, 4.50852593625068*^-6, 0.000016034175964943462, 
   0.0000326537761383173, 0.000047848503478277265, 
   0.00005385269881836269, 0.00004643425686358843, 
   0.000028339449990409133, 8.974406174766236*^-6, 9.225295023567401*^-9, 
   9.073912469149355*^-6, 0.00003505332726257924, 0.0000678134164018644, 
   0.00009282019119134591, 0.00009837630404363578, 
   0.00008166582498003306, 0.00005035809634183534, 
   0.000018877794290383045, 1.289911215650401*^-6, 4.508448232990942*^-6, 
   0.000025278796589910877, 0.00005230450396933603, 
   0.00007217541489530391, 0.00007588540004021498}, 
  {0.00006432227411320208, 0.00006117760226169723, 
   0.000044334544456353414, 0.00002142691061319835, 
   3.8214681996024455*^-6, 1.0933594966976384*^-6, 
   0.00001600126847002009, 0.00004268472295068133, 
   0.00006922190009227686, 0.00008338610050925595, 
   0.00007867660680296713, 0.00005748026835257253, 
   0.000029712035827299457, 7.691264522698301*^-6, 7.81957998454267*^-9, 
   7.606920615433495*^-6, 0.000024021193398654058, 
   0.00003935878306814771, 0.00004564683131794512, 
   0.00004055753221311901, 0.000027678119091250077, 
   0.000013590949788102147, 3.8215340627369*^-6, 1.428272615646711*^-7, 
   6.150359998871753*^-7, 1.8745874343879542*^-6, 1.7969311494133808*^-6, 
   6.313642189818563*^-7, 3.2444936006575426*^-9, 8.577194809836068*^-7, 
   2.2592407137079714*^-6, 2.3026170002574964*^-6, 6.338000386424898*^-7, 
   4.799540794770572*^-7, 7.943067240091496*^-6, 0.000028012856384791147, 
   0.000059375429563012554, 0.00009183635868731815, 
   0.0001095033674599574, 0.00009964686697360657, 0.0000630141182052252, 
   0.000018968446375848673, 2.46797085263105*^-7, 0.00003739703527573103, 
   0.00013958534076736098, 0.00028255134957316244, 
   0.00041289773010482725, 0.00047035805246010704, 0.0004194855491446427, 
   0.0002748652995591961, 0.00010432174239888177, 3.884237208642285*^-6, 
   0.00005276636852340556, 0.00026902709460798575, 0.0005896744586823255, 
   0.000889628598718995, 0.001035484394603816, 0.0009511398137149083, 
   0.0006631378719475894, 0.00030007729944839495, 0.00004105182828331848, 
   0.00003351991722412077, 0.0003185572124261494, 0.0008013014408529828, 
   0.0012850833030076181, 0.001557535099559064, 0.0014903781301692954, 
   0.0011052747567878078, 0.0005718596215922845, 0.00013529917770341103, 
   4.836233570279949*^-6, 0.00025499549883086376, 0.0007869241435793172, 
   0.0013699353865258594, 0.0017454534203219538, 0.001745453420321993, 
   0.0013699353865259587, 0.0007869241435794325, 0.00025499549883094475, 
   4.836233570291851*^-6, 0.00013529917770335148, 0.0005718596215921832, 
   0.0011052747567877122, 0.0014903781301692485, 0.0015575350995590852, 
   0.0012850833030076975, 0.0008013014408530829, 0.00031855721242622724, 
   0.00003351991722414833, 0.00004105182828328947, 0.0003000772994483295, 
   0.0006631378719475214, 0.0009511398137148698, 0.0010354843946038226, 
   0.0008896285987190423, 0.0005896744586823903, 0.0002690270946080414, 
   0.000052766368523432124, 3.884237208635538*^-6, 
   0.00010432174239885217, 0.0002748652995591634, 0.0004194855491446231, 
   0.000470358052460108, 0.0004128977301048471, 0.0002825513495731911, 
   0.0001395853407673862, 0.000037397035275744824, 
   2.4679708526413804*^-7, 0.00001896844637584141, 
   0.00006301411820521636, 0.0000996468669736019, 0.00010950336745995844, 
   0.00009183635868732339, 0.00005937542956301915, 
   0.000028012856384796297, 7.94306724009408*^-6, 4.799540794775538*^-7, 
   6.338000386421451*^-7, 2.302617000257301*^-6, 2.259240713708181*^-6, 
   8.577194809838899*^-7, 3.2444936006780616*^-9, 6.313642189816312*^-7, 
   1.7969311494132203*^-6, 1.8745874343880946*^-6, 6.150359998874399*^-7, 
   1.4282726156446954*^-7, 3.821534062735628*^-6, 
   0.000013590949788099739, 0.00002767811909124727, 
   0.00004055753221311707, 0.000045646831317945204, 
   0.000039358783068150096, 0.000024021193398657592, 
   7.606920615436207*^-6, 7.819579984642699*^-9, 7.691264522695153*^-6, 
   0.000029712035827294344, 0.00005748026835256751, 
   0.00007867660680296445, 0.00008338610050925691, 
   0.00006922190009228106, 0.000042684722950686824, 
   0.00001600126847002434, 1.0933594966988445*^-6, 3.821468199600299*^-6, 
   0.000021426910613193897, 0.00004433454445634905, 
   0.00006117760226169504, 0.00006432227411320293}, 
  {0.000015135055288375469, 0.000014395112819106413, 
   0.000010431934983376558, 5.041760125257674*^-6, 8.991929044977666*^-7, 
   2.572679007503042*^-7, 3.7651044885582806*^-6, 
   0.000010043731362647099, 0.00001628793912384355, 
   0.000019620780808659064, 0.00001851263516848015, 
   0.000013525128759840975, 6.991253203904851*^-6, 
   1.8097574346281859*^-6, 1.8399501110554849*^-9, 
   1.7899112815297456*^-6, 5.652195840301739*^-6, 9.261136457507893*^-6, 
   0.00001074071657541798, 9.543202582130648*^-6, 6.512671831021748*^-6, 
   3.197955596259636*^-6, 8.992084021180728*^-7, 3.36073083589076*^-8, 
   1.4471820206871553*^-7, 4.4109112828354264*^-7, 
   4.2281857522499375*^-7, 1.4856023816221212*^-7, 
   7.634305643844367*^-10, 2.0182171643615968*^-7, 5.316001895632726*^-7, 
   5.418066461008024*^-7, 1.4913338744439265*^-7, 1.1293337539624801*^-7, 
   1.8690067087257097*^-6, 6.591435642075895*^-6, 
   0.000013971060905366705, 0.000021609129735827478, 
   0.000025766183544023415, 0.000023446945272872166, 
   0.000014827245711273138, 4.463282565659947*^-6, 
   5.8071446974856645*^-8, 8.799536464201981*^-6, 
   0.000032844483176118364, 0.0000664844388130423, 
   0.00009715499117122548, 0.00011067542663040243, 
   0.00009870510746876097, 0.00006467590835427976, 
   0.000024546945218509747, 9.139624759302469*^-7, 
   0.000012415946357291836, 0.0000633021765336988, 0.0001387506218855542, 
   0.00020932994383928964, 0.00024364986746266284, 0.0002238035558602181, 
   0.00015603659065409833, 0.00007060830140963072, 9.659510633337441*^-6, 
   7.887249128598658*^-6, 0.00007495663188299739, 0.00018854653037641306, 
   0.00030238058447620115, 0.0003664885946651164, 0.0003506865345121271, 
   0.00026007156593046727, 0.00013455878401868015, 
   0.00003183594739528283, 1.1379675778388095*^-6, 
   0.00006000053677051002, 0.00018516354692108033, 0.0003223463116381835, 
   0.0004107058462106624, 0.00041070584621067155, 0.0003223463116382069, 
   0.00018516354692110746, 0.000060000536770529075, 
   1.1379675778416102*^-6, 0.00003183594739526881, 
   0.00013455878401865632, 0.0002600715659304448, 0.0003506865345121161, 
   0.00036648859466512144, 0.00030238058447621985, 0.0001885465303764366, 
   0.00007495663188301571, 7.887249128605141*^-6, 9.659510633330614*^-6, 
   0.00007060830140961532, 0.00015603659065408233, 
   0.00022380355586020906, 0.00024364986746266444, 
   0.00020932994383930078, 0.00013875062188556947, 0.0000633021765337119, 
   0.000012415946357298087, 9.139624759286591*^-7, 
   0.000024546945218502784, 0.00006467590835427206, 
   0.00009870510746875636, 0.00011067542663040267, 
   0.00009715499117123015, 0.00006648443881304904, 
   0.00003284448317612429, 8.799536464205229*^-6, 5.8071446975099724*^-8, 
   4.463282565658238*^-6, 0.000014827245711271056, 
   0.000023446945272871068, 0.00002576618354402366, 
   0.000021609129735828714, 0.000013971060905368257, 
   6.591435642077106*^-6, 1.869006708726318*^-6, 1.1293337539636485*^-7, 
   1.4913338744431155*^-7, 5.418066461007565*^-7, 5.316001895633219*^-7, 
   2.0182171643622625*^-7, 7.634305643892649*^-10, 
   1.4856023816215916*^-7, 4.22818575224956*^-7, 4.410911282835757*^-7, 
   1.4471820206877778*^-7, 3.360730835886017*^-8, 8.992084021177734*^-7, 
   3.197955596259069*^-6, 6.512671831021087*^-6, 9.54320258213019*^-6, 
   0.000010740716575417998, 9.261136457508453*^-6, 5.65219584030257*^-6, 
   1.7899112815303836*^-6, 1.839950111079022*^-9, 1.8097574346274454*^-6, 
   6.991253203903648*^-6, 0.000013525128759839793, 
   0.00001851263516847952, 0.000019620780808659287, 
   0.00001628793912384454, 0.000010043731362648391, 3.76510448855928*^-6, 
   2.57267900750588*^-7, 8.991929044972615*^-7, 5.041760125256627*^-6, 
   0.000010431934983375532, 0.000014395112819105897, 
   0.000015135055288375672}, {3.2114797899651944*^-6, 
   3.0544727463490633*^-6, 2.2135332663816564*^-6, 1.06980188969335*^-6, 
   1.907981031488282*^-7, 5.458920685284495*^-8, 7.989106575249261*^-7, 
   2.1311610478063125*^-6, 3.4561081092701776*^-6, 
   4.1632977104974235*^-6, 3.928162307291731*^-6, 2.8698724148214525*^-6, 
   1.4834612720651495*^-6, 3.840091308098227*^-7, 
   3.9041565977874576*^-10, 3.797980117640173*^-7, 
   1.1993291312253093*^-6, 1.9651036615796082*^-6, 2.279053069478506*^-6, 
   2.0249547583480176*^-6, 1.3819119630217695*^-6, 6.785683679980972*^-7, 
   1.908013915606283*^-7, 7.131073493511152*^-9, 3.0707491471190015*^-8, 
   9.359432238767784*^-8, 8.971710266561529*^-8, 3.15227261057181*^-8, 
   1.6199093969913735*^-10, 4.282418208334026*^-8, 
   1.1279927509979793*^-7, 1.1496496450580956*^-7, 3.164434160703507*^-8, 
   2.3963127044283946*^-8, 3.965811262673121*^-7, 1.3986247125004786*^-6, 
   2.9644939438324253*^-6, 4.5852018445315285*^-6, 5.467279513654602*^-6, 
   4.9751645729423174*^-6, 3.146166236946256*^-6, 9.470557909048405*^-7, 
   1.2322074467545941*^-8, 1.8671576005111313*^-6, 
   6.9692110086290704*^-6, 0.000014107211868545508, 
   0.000020615140460060217, 0.000023484017011969803, 
   0.000020944056811324188, 0.000013723463087507801, 
   5.208571556073139*^-6, 1.939320315856994*^-7, 2.634517022898471*^-6, 
   0.000013431973436854445, 0.000029441241511208772, 
   0.00004441733916827899, 0.00005169962119563737, 
   0.00004748846851715619, 0.000033109119711348965, 
   0.000014982246754986191, 2.0496339517004025*^-6, 
   1.6735810138975688*^-6, 0.00001590491107098855, 
   0.00004000734455439854, 0.00006416158497082144, 
   0.00007776454678191652, 0.00007441153644569947, 
   0.000055184111456255174, 0.000028551783076087205, 
   6.755211639885587*^-6, 2.414632657914291*^-7, 0.000012731404514495102, 
   0.000039289515462295246, 0.00006839807621918264, 
   0.00008714692477794497, 0.00008714692477794692, 0.0000683980762191876, 
   0.000039289515462301, 0.000012731404514499146, 2.414632657920234*^-7, 
   6.755211639882612*^-6, 0.00002855178307608215, 0.0000551841114562504, 
   0.00007441153644569714, 0.00007776454678191759, 
   0.00006416158497082541, 0.000040007344554403534, 
   0.000015904911070992438, 1.6735810138989444*^-6, 
   2.0496339516989536*^-6, 0.000014982246754982924, 
   0.00003310911971134557, 0.000047488468517154276, 
   0.00005169962119563771, 0.00004441733916828135, 
   0.00002944124151121201, 0.000013431973436857223, 
   2.6345170228997977*^-6, 1.9393203158536247*^-7, 5.208571556071662*^-6, 
   0.00001372346308750617, 0.00002094405681132321, 
   0.000023484017011969854, 0.000020615140460061207, 
   0.00001410721186854694, 6.969211008630329*^-6, 1.86715760051182*^-6, 
   1.2322074467597519*^-8, 9.47055790904478*^-7, 3.1461662369458143*^-6, 
   4.9751645729420845*^-6, 5.467279513654655*^-6, 4.58520184453179*^-6, 
   2.964493943832755*^-6, 1.3986247125007357*^-6, 3.9658112626744115*^-7, 
   2.396312704430874*^-8, 3.164434160701786*^-8, 1.1496496450579982*^-7, 
   1.127992750998084*^-7, 4.282418208335439*^-8, 1.6199093970016184*^-10, 
   3.152272610570686*^-8, 8.971710266560727*^-8, 9.359432238768484*^-8, 
   3.0707491471203223*^-8, 7.131073493501088*^-9, 1.9080139156056477*^-7, 
   6.785683679979768*^-7, 1.3819119630216293*^-6, 2.0249547583479206*^-6, 
   2.2790530694785103*^-6, 1.9651036615797276*^-6, 
   1.1993291312254857*^-6, 3.7979801176415266*^-7, 
   3.904156597837401*^-10, 3.8400913080966564*^-7, 
   1.4834612720648943*^-6, 2.8698724148212013*^-6, 
   3.9281623072915975*^-6, 4.163297710497472*^-6, 3.4561081092703877*^-6, 
   2.1311610478065866*^-6, 7.989106575251383*^-7, 5.4589206852905175*^-8, 
   1.9079810314872103*^-7, 1.0698018896931278*^-6, 
   2.2135332663814382*^-6, 3.054472746348954*^-6, 3.211479789965237*^-6}, 
  {0.00004264218107229041, 0.00004055743409539083, 
   0.00002939139976826945, 0.00001420488026557897, 
   2.5334262691436873*^-6, 7.24838079468954*^-7, 0.000010607973627985904, 
   0.000028297657540530207, 0.00004589036750640969, 
   0.00005528046459567081, 0.00005215832555206443, 
   0.00003810630213198821, 0.000019697469177540102, 
   5.098891464480549*^-6, 5.183957660192356*^-9, 5.042976025924994*^-6, 
   0.00001592474912617671, 0.000026092739684906045, 
   0.00003026137482344704, 0.000026887445388410206, 
   0.00001834909263239587, 9.010062996042412*^-6, 2.5334699328316417*^-6, 
   9.468673229714105*^-8, 4.0773552917313846*^-7, 1.242749854775495*^-6, 
   1.1912679472879072*^-6, 4.1856025334253015*^-7, 
   2.1509233856321285*^-9, 5.68621522195636*^-7, 1.497754128379806*^-6, 
   1.5265102550993487*^-6, 4.201750697410515*^-7, 3.1818353821611006*^-7, 
   5.265823016848837*^-6, 0.00001857100531318365, 0.00003936269128506042, 
   0.00006088252771151099, 0.00007259479686671487, 
   0.00006606047132750288, 0.00004177494461543624, 
   0.000012575051740170876, 1.6361308960223447*^-7, 
   0.000024792207237387552, 0.00009253751454066642, 
   0.00018731622873771896, 0.0002737288134508595, 0.00031182189246783894, 
   0.00027809618037375307, 0.0001822207942098691, 0.000069159660327322, 
   2.5750387196689047*^-6, 0.000034981242067752707, 
   0.00017835038079400456, 0.00039092220210658834, 0.0005897755375828217, 
   0.0006864700239689459, 0.0006305541388371259, 0.0004396244629304623, 
   0.00019893498349020613, 0.000027215136889050747, 
   0.000022221888132928575, 0.00021118616406896982, 
   0.0005312194197954656, 0.0008519405704373334, 0.0010325613429798424, 
   0.0009880399125971905, 0.0007327372510280043, 0.00037911193079015536, 
   0.00008969602076579375, 3.2061607033486267*^-6, 
   0.00016904819339297775, 0.0005216880510413879, 0.0009081929023026226, 
   0.0011571410033113353, 0.0011571410033113614, 0.0009081929023026885, 
   0.0005216880510414643, 0.00016904819339303145, 3.206160703356517*^-6, 
   0.00008969602076575426, 0.00037911193079008824, 0.000732737251027941, 
   0.0009880399125971595, 0.0010325613429798565, 0.0008519405704373859, 
   0.0005312194197955319, 0.00021118616406902142, 0.00002222188813294684, 
   0.00002721513688903151, 0.00019893498349016277, 0.0004396244629304172, 
   0.0006305541388371004, 0.0006864700239689503, 0.0005897755375828531, 
   0.0003909222021066313, 0.00017835038079404145, 0.00003498124206777032, 
   2.575038719664431*^-6, 0.00006915966032730238, 0.00018222079420984744, 
   0.00027809618037374006, 0.0003118218924678396, 0.0002737288134508726, 
   0.00018731622873773796, 0.00009253751454068313, 
   0.000024792207237396696, 1.6361308960291932*^-7, 
   0.000012575051740166062, 0.000041774944615430374, 
   0.00006606047132749979, 0.00007259479686671556, 
   0.000060882527711514465, 0.00003936269128506479, 
   0.00001857100531318706, 5.265823016850551*^-6, 3.1818353821643924*^-7, 
   4.2017506974082296*^-7, 1.5265102550992193*^-6, 1.497754128379945*^-6, 
   5.686215221958236*^-7, 2.1509233856457314*^-9, 4.185602533423809*^-7, 
   1.1912679472878006*^-6, 1.242749854775588*^-6, 4.077355291733139*^-7, 
   9.468673229700742*^-8, 2.5334699328307985*^-6, 9.010062996040815*^-6, 
   0.00001834909263239401, 0.000026887445388408915, 
   0.000030261374823447095, 0.000026092739684907628, 
   0.00001592474912617905, 5.042976025926792*^-6, 5.183957660258671*^-9, 
   5.098891464478463*^-6, 0.000019697469177536714, 
   0.000038106302131984874, 0.000052158325552062655, 
   0.00005528046459567144, 0.00004589036750641248, 
   0.000028297657540533846, 0.000010607973627988721, 
   7.248380794697536*^-7, 2.5334262691422643*^-6, 
   0.000014204880265576019, 0.000029391399768266556, 
   0.00004055743409538937, 0.00004264218107229098}, 
  {0.00006903192002193198, 0.00006565699681311858, 
   0.000047580698433229256, 0.000022995778681024618, 
   4.101274259318625*^-6, 1.1734147520720145*^-6, 
   0.000017172873635156054, 0.00004581007779208742, 
   0.00007429029425368894, 0.0000894915905983844, 0.00008443727003278744, 
   0.00006168894589719664, 0.000031887536770064725, 
   8.254415204039816*^-6, 8.392125862155364*^-9, 8.163895676536882*^-6, 
   0.000025780013601647485, 0.00004224061419438029, 
   0.00004898907030633499, 0.00004352713517397721, 
   0.00002970469763090233, 0.000014586072581065575, 4.10134494492004*^-6, 
   1.5328500481702117*^-7, 6.600686393658798*^-7, 2.0118438228263356*^-6, 
   1.9285015820944457*^-6, 6.775924027928519*^-7, 3.4820538583273012*^-9, 
   9.205212879804037*^-7, 2.4246612298642384*^-6, 2.471213507208559*^-6, 
   6.802065719950286*^-7, 5.150960858496739*^-7, 8.524654795037493*^-6, 
   0.000030063944227740894, 0.0000637228698980415, 
   0.00009856057260741657, 0.00011752115124730151, 
   0.00010694296254594385, 0.00006762798156887373, 
   0.00002035730687713873, 2.648674488956197*^-7, 0.00004013522817411962, 
   0.00014980571214146234, 0.00030323962320573643, 
   0.00044312990289600867, 0.0005047974423596043, 0.000450200078870744, 
   0.0002949908043142447, 0.00011196013009667659, 4.168639184947161*^-6, 
   0.00005662989659452805, 0.0002887251288103856, 0.0006328501383376834, 
   0.0009547667759369251, 0.0011113020628973343, 0.0010207818124478654, 
   0.0007116925073145749, 0.00032204881468373363, 0.00004405762336419748, 
   0.00003597422940745111, 0.0003418818179828314, 0.0008599723461435975, 
   0.0013791764830735995, 0.0016715770688531188, 0.0015995028985327272, 
   0.0011862024417631082, 0.0006137309074622462, 0.0001452057182838008, 
   5.190340261343849*^-6, 0.0002736661463533653, 0.0008445423500930766, 
   0.0014702413952503172, 0.0018732546784900115, 0.0018732546784900534, 
   0.001470241395250424, 0.0008445423500932003, 0.0002736661463534522, 
   5.190340261356623*^-6, 0.00014520571828373688, 0.0006137309074621376, 
   0.0011862024417630056, 0.001599502898532677, 0.0016715770688531418, 
   0.0013791764830736848, 0.0008599723461437048, 0.00034188181798291495, 
   0.00003597422940748068, 0.000044057623364166345, 
   0.00032204881468366343, 0.0007116925073145019, 0.0010207818124478242, 
   0.0011113020628973414, 0.0009547667759369758, 0.000632850138337753, 
   0.0002887251288104453, 0.000056629896594556556, 4.168639184939919*^-6, 
   0.00011196013009664482, 0.0002949908043142096, 0.000450200078870723, 
   0.0005047974423596054, 0.00044312990289603, 0.0003032396232057672, 
   0.0001498057121414894, 0.00004013522817413443, 2.6486744889672834*^-7, 
   0.000020357306877130934, 0.00006762798156886423, 
   0.00010694296254593885, 0.00011752115124730263, 0.0000985605726074222, 
   0.00006372286989804857, 0.00003006394422774642, 8.524654795040267*^-6, 
   5.150960858502069*^-7, 6.802065719946587*^-7, 2.4712135072083495*^-6, 
   2.4246612298644633*^-6, 9.205212879807074*^-7, 3.482053858349323*^-9, 
   6.775924027926103*^-7, 1.9285015820942733*^-6, 2.0118438228264864*^-6, 
   6.600686393661639*^-7, 1.5328500481680483*^-7, 4.101344944918674*^-6, 
   0.000014586072581062988, 0.000029704697630899313, 
   0.00004352713517397512, 0.000048989070306335076, 
   0.00004224061419438285, 0.000025780013601651276, 
   8.163895676539792*^-6, 8.392125862262719*^-9, 8.25441520403644*^-6, 
   0.000031887536770059236, 0.00006168894589719124, 
   0.00008443727003278455, 0.00008949159059838542, 
   0.00007429029425369346, 0.000045810077792093314, 
   0.000017172873635160614, 1.173414752073309*^-6, 4.101274259316321*^-6, 
   0.00002299577868101984, 0.000047580698433224574, 
   0.00006565699681311622, 0.0000690319200219329}, 
  {0.000041567353356202754, 0.000039535153968930514, 
   0.00002865056779647154, 0.000013846835751221984, 
   2.469569386070002*^-6, 7.065679995176441*^-7, 0.000010340591806039296, 
   0.000027584394150616905, 0.00004473366684858642, 
   0.000053887079594915315, 0.00005084363637533019, 
   0.00003714580459975278, 0.000019200979896822707, 
   4.970370133499481*^-6, 5.0532921728254264*^-9, 4.915864084933027*^-6, 
   0.00001552335404501188, 0.000025435052880508003, 
   0.000029498614486868156, 0.000026209727438916395, 
   0.00001788659017988472, 8.782957693538662*^-6, 2.4696119491824035*^-6, 
   9.230008317039476*^-8, 3.9745825356085194*^-7, 1.2114254254314108*^-6, 
   1.1612411575028997*^-6, 4.0801013255057185*^-7, 
   2.0967077706723958*^-9, 5.542889961228322*^-7, 1.4600021276944234*^-6, 
   1.4880334349692688*^-6, 4.095842463072986*^-7, 3.101634867769555*^-7, 
   5.133094052612078*^-6, 0.00001810290938740579, 0.00003837052553487843, 
   0.00005934793856610891, 0.00007076499131376201, 0.0000643953682831665, 
   0.0000407219762357331, 0.000012258088259370996, 1.594891006552083*^-7, 
   0.000024167301315325112, 0.0000902050380372353, 0.0001825947846357158, 
   0.00026682927623230114, 0.00030396219101544, 0.00027108656044138864, 
   0.00017762778430420218, 0.00006741643993179403, 2.510132963999256*^-6, 
   0.00003409951398602416, 0.00017385492752140563, 0.0003810687188397294, 
   0.0005749098089046881, 0.0006691670392371296, 0.0006146605553506956, 
   0.0004285434031547731, 0.00019392068008034473, 0.00002652915923289189, 
   0.00002166176900514335, 0.0002058630605904973, 0.0005178296413797645, 
   0.0008304667781842301, 0.0010065348705507243, 0.000963135635753097, 
   0.0007142680666145796, 0.00036955613414781265, 0.00008743516621479387, 
   3.125347051243258*^-6, 0.00016478720863459287, 0.0005085385178254285, 
   0.0008853012284153489, 0.0011279744083927492, 0.0011279744083927744, 
   0.0008853012284154131, 0.000508538517825503, 0.0001647872086346452, 
   3.12534705125095*^-6, 0.00008743516621475537, 0.0003695561341477472, 
   0.0007142680666145178, 0.0009631356357530667, 0.0010065348705507382, 
   0.0008304667781842815, 0.0005178296413798292, 0.0002058630605905476, 
   0.000021661769005161156, 0.00002652915923287314, 
   0.00019392068008030244, 0.00042854340315472914, 0.0006146605553506707, 
   0.0006691670392371341, 0.0005749098089047187, 0.0003810687188397713, 
   0.0001738549275214416, 0.00003409951398604132, 2.510132963994895*^-6, 
   0.0000674164399317749, 0.00017762778430418106, 0.00027108656044137595, 
   0.0003039621910154407, 0.000266829276232314, 0.00018259478463573435, 
   0.00009020503803725159, 0.000024167301315334026, 
   1.5948910065587587*^-7, 0.000012258088259366302, 
   0.000040721976235727374, 0.00006439536828316348, 
   0.00007076499131376269, 0.0000593479385661123, 
   0.000038370525534882695, 0.000018102909387409116, 
   5.133094052613748*^-6, 3.101634867772764*^-7, 4.095842463070759*^-7, 
   1.4880334349691426*^-6, 1.4600021276945587*^-6, 5.542889961230152*^-7, 
   2.096707770685656*^-9, 4.080101325504264*^-7, 1.161241157502796*^-6, 
   1.2114254254315014*^-6, 3.97458253561023*^-7, 9.230008317026448*^-8, 
   2.469611949181581*^-6, 8.782957693537105*^-6, 0.000017886590179882908, 
   0.000026209727438915138, 0.000029498614486868206, 
   0.000025435052880509548, 0.000015523354045014162, 
   4.915864084934779*^-6, 5.05329217289007*^-9, 4.970370133497448*^-6, 
   0.000019200979896819403, 0.000037145804599749536, 
   0.00005084363637532846, 0.00005388707959491593, 
   0.00004473366684858913, 0.000027584394150620452, 
   0.000010340591806042042, 7.065679995184236*^-7, 
   2.4695693860686145*^-6, 0.000013846835751219108, 
   0.000028650567796468722, 0.0000395351539689291, 
   0.00004156735335620331}, {3.4407064991657287*^-6, 
   3.272492719003446*^-6, 2.371529261855156*^-6, 1.1461614443874736*^-6, 
   2.0441675379180299*^-7, 5.8485636244630264*^-8, 8.559347314555482*^-7, 
   2.2832775379338428*^-6, 3.702795723809975*^-6, 4.460462598964552*^-6, 
   4.208543869000336*^-6, 3.0747161169460862*^-6, 1.589346710511461*^-6, 
   4.114186600970823*^-7, 4.182824697119969*^-10, 4.069069628057161*^-7, 
   1.2849339887922609*^-6, 2.1053674262744175*^-6, 
   2.4417256906303887*^-6, 2.169490531852328*^-6, 1.4805490874645685*^-6, 
   7.270027359956198*^-7, 2.0442027692151033*^-7, 7.640070160746114*^-9, 
   3.2899308850747817*^-8, 1.0027483103911601*^-7, 9.612086589878463*^-8, 
   3.3772732720370295*^-8, 1.7355341321790668*^-10, 
   4.588085594560204*^-8, 1.2085058114012417*^-7, 1.2317085157673788*^-7, 
   3.390302880602156*^-8, 2.5673549999981598*^-8, 4.248880104611194*^-7, 
   1.4984547476309512*^-6, 3.1760914738287094*^-6, 4.912481104742465*^-6, 
   5.857519083310472*^-6, 5.330278314075033*^-6, 3.370731042039062*^-6, 
   1.0146540622863893*^-6, 1.320159069229232*^-8, 2.0004302412611363*^-6, 
   7.466654371101388*^-6, 0.00001511414635486107, 0.00002208659322215828, 
   0.000025160242394201322, 0.000022438986729665946, 
   0.000014703006627596065, 5.580345254031579*^-6, 
   2.0777437353281959*^-7, 2.822561696067145*^-6, 
   0.000014390711236986298, 0.000031542677406113066, 
   0.00004758772825831868, 0.00005538979980757208, 
   0.000050878066482921026, 0.000035472358794986894, 
   0.000016051638856037864, 2.1959312590295767*^-6, 
   1.793036683397638*^-6, 0.000017040160446158796, 
   0.000042862960200715926, 0.00006874126472652412, 
   0.00008331516902372205, 0.0000797228299121261, 0.00005912300352364383, 
   0.00003058973184250616, 7.23738030836128*^-6, 2.5869825820306846*^-7, 
   0.000013640137606784052, 0.000042093894416709606, 
   0.00007328014521938658, 0.00009336723569075671, 0.0000933672356907588, 
   0.0000732801452193919, 0.00004209389441671577, 
   0.000013640137606788386, 2.586982582037051*^-7, 7.237380308358094*^-6, 
   0.000030589731842500746, 0.00005912300352363872, 
   0.0000797228299121236, 0.00008331516902372318, 0.00006874126472652836, 
   0.00004286296020072128, 0.00001704016044616296, 
   1.7930366833991118*^-6, 2.1959312590280245*^-6, 
   0.000016051638856034364, 0.000035472358794983255, 
   0.00005087806648291897, 0.00005538979980757245, 
   0.000047587728258321205, 0.000031542677406116536, 
   0.000014390711236989274, 2.822561696068566*^-6, 
   2.0777437353245862*^-7, 5.580345254029995*^-6, 
   0.000014703006627594317, 0.0000224389867296649, 
   0.000025160242394201373, 0.00002208659322215934, 
   0.000015114146354862602, 7.466654371102736*^-6, 2.000430241261874*^-6, 
   1.320159069234758*^-8, 1.0146540622860007*^-6, 3.3707310420385886*^-6, 
   5.330278314074784*^-6, 5.857519083310529*^-6, 4.9124811047427454*^-6, 
   3.176091473829062*^-6, 1.4984547476312265*^-6, 4.2488801046125774*^-7, 
   2.567355000000816*^-8, 3.390302880600312*^-8, 1.2317085157672742*^-7, 
   1.208505811401354*^-7, 4.5880855945617176*^-8, 1.735534132190043*^-10, 
   3.377273272035826*^-8, 9.612086589877604*^-8, 1.002748310391235*^-7, 
   3.289930885076197*^-8, 7.640070160735331*^-9, 2.0442027692144225*^-7, 
   7.27002735995491*^-7, 1.4805490874644183*^-6, 2.1694905318522238*^-6, 
   2.441725690630393*^-6, 2.1053674262745454*^-6, 1.2849339887924497*^-6, 
   4.0690696280586114*^-7, 4.182824697173477*^-10, 4.11418660096914*^-7, 
   1.5893467105111876*^-6, 3.0747161169458177*^-6, 
   4.2085438690001925*^-6, 4.460462598964604*^-6, 3.7027957238102*^-6, 
   2.2832775379341367*^-6, 8.559347314557754*^-7, 5.8485636244694784*^-8, 
   2.0441675379168813*^-7, 1.1461614443872353*^-6, 
   2.3715292618549225*^-6, 3.272492719003329*^-6, 
   3.4407064991657744*^-6}, {0.000011617814601419563, 
   0.000011049827616245676, 8.007654036389081*^-6, 3.870103761369255*^-6, 
   6.902291571667142*^-7, 1.9748132510021756*^-7, 2.8901305657362973*^-6, 
   7.7096651881621*^-6, 0.000012502779367139906, 0.00001506110083028043, 
   0.00001421047753530918, 0.000010382019450754583, 
   5.3665534751584785*^-6, 1.38918728398697*^-6, 1.412363473988894*^-9, 
   1.3739531852105912*^-6, 4.338680111329067*^-6, 7.108937781311728*^-6, 
   8.244677768401721*^-6, 7.32545446253753*^-6, 4.999189791583489*^-6, 
   2.454781598944821*^-6, 6.902410532897246*^-7, 2.5797294448366363*^-8, 
   1.1108708947871801*^-7, 3.3858580977005566*^-7, 3.245596215808476*^-7, 
   1.1403627348734788*^-7, 5.860166738133858*^-10, 1.549202985664975*^-7, 
   4.0806143927132656*^-7, 4.158960138751961*^-7, 1.1447622841135958*^-7, 
   8.668874957290992*^-8, 1.4346675989655623*^-6, 5.059649653585522*^-6, 
   0.000010724321272110353, 0.000016587376668632763, 
   0.000019778371317250885, 0.000017998101622996984, 
   0.000011381536997461099, 3.426058800155942*^-6, 4.457620350473572*^-8, 
   6.7546091686925535*^-6, 0.000025211742471311733, 
   0.000051034097285564315, 0.00007457710946697208, 
   0.00008495552629481288, 0.00007576699370672363, 
   0.00004964585184010095, 0.000018842472204173814, 
   7.015664228308026*^-7, 9.53060032697574*^-6, 0.000048591362028237625, 
   0.0001065063173000843, 0.0001606836864294978, 0.000187027991236727, 
   0.00017179377079114359, 0.0001197751938606555, 0.00005419961403961876, 
   7.414733645852491*^-6, 6.0543285997538406*^-6, 0.00005753743450361651, 
   0.00014473013754607878, 0.00023211025678984896, 0.0002813201845139172, 
   0.0002691903705370292, 0.0001996334455680303, 0.00010328862207210867, 
   0.000024437580666323526, 8.735149023150232*^-7, 
   0.00004605699146146057, 0.00014213332677566077, 0.0002474361417721519, 
   0.00031526177381455497, 0.000315261773814562, 0.0002474361417721698, 
   0.00014213332677568162, 0.0000460569914614752, 8.735149023171731*^-7, 
   0.000024437580666312766, 0.00010328862207209039, 
   0.00019963344556801305, 0.00026919037053702076, 
   0.00028132018451392107, 0.0002321102567898633, 0.00014473013754609686, 
   0.00005753743450363057, 6.054328599758817*^-6, 7.41473364584725*^-6, 
   0.00005419961403960694, 0.00011977519386064321, 
   0.00017179377079113662, 0.0001870279912367282, 0.00016068368642950634, 
   0.00010650631730009601, 0.000048591362028247674, 
   9.530600326980537*^-6, 7.015664228295837*^-7, 0.00001884247220416847, 
   0.00004964585184009505, 0.00007576699370672009, 
   0.00008495552629481306, 0.00007457710946697567, 
   0.00005103409728556949, 0.000025211742471316287, 
   6.7546091686950455*^-6, 4.4576203504922306*^-8, 
   3.4260588001546303*^-6, 0.0000113815369974595, 
   0.000017998101622996144, 0.000019778371317251072, 
   0.00001658737666863371, 0.000010724321272111544, 
   5.059649653586452*^-6, 1.4346675989660294*^-6, 8.668874957299961*^-8, 
   1.1447622841129733*^-7, 4.1589601387516085*^-7, 4.080614392713644*^-7, 
   1.5492029856654858*^-7, 5.86016673817092*^-10, 1.1403627348730723*^-7, 
   3.245596215808186*^-7, 3.38585809770081*^-7, 1.1108708947876581*^-7, 
   2.5797294448329957*^-8, 6.902410532894947*^-7, 2.454781598944386*^-6, 
   4.999189791582982*^-6, 7.325454462537179*^-6, 8.244677768401735*^-6, 
   7.108937781312159*^-6, 4.338680111329705*^-6, 1.373953185211081*^-6, 
   1.4123634740069613*^-9, 1.389187283986402*^-6, 5.366553475157555*^-6, 
   0.000010382019450753677, 0.000014210477535308696, 
   0.000015061100830280605, 0.000012502779367140665, 
   7.709665188163093*^-6, 2.8901305657370642*^-6, 1.9748132510043543*^-7, 
   6.902291571663264*^-7, 3.870103761368451*^-6, 8.007654036388294*^-6, 
   0.00001104982761624528, 0.000011617814601419719}, 
  {0.00004972930992181335, 0.000047298078077760904, 
   0.00003427624927614139, 0.00001656573081784169, 
   2.9544816173621387*^-6, 8.453061403199816*^-7, 
   0.000012371018435811897, 0.000033000727132337085, 
   0.000053517344816002014, 0.00006446807567932607, 
   0.00006082703724709195, 0.00004443956807657994, 
   0.000022971187795123823, 5.9463270292150285*^-6, 
   6.045531223373168*^-9, 5.881118446928176*^-6, 0.000018571441816736126, 
   0.000030429352014150982, 0.00003529081415193492, 
   0.00003135613777492605, 0.000021398711120182963, 
   0.000010507535118470165, 2.954532537953347*^-6, 1.104236635528968*^-7, 
   4.7550115839551913*^-7, 1.4492948327068216*^-6, 
   1.3892566341804328*^-6, 4.881249513043584*^-7, 2.5084067693639406*^-9, 
   6.631263972530479*^-7, 1.7466808067487572*^-6, 1.7802162006199754*^-6, 
   4.900081501260312*^-7, 3.7106562999541673*^-7, 6.141002599148443*^-6, 
   0.000021657505679958583, 0.000045904769058434326, 
   0.00007100120146894956, 0.00008466004930601085, 
   0.00007703971911420811, 0.00004871793879927897, 
   0.000014665024854372601, 1.9080557878363494*^-7, 
   0.000028912671124015926, 0.00010791724588819056, 
   0.00021844817872921642, 0.0003192225316887824, 0.0003636466789691491, 
   0.0003243157548258133, 0.00021250588317936678, 0.0000806539932062627, 
   3.0030100555596715*^-6, 0.0000407951231502008, 0.00020799220720306585, 
   0.00045589345701899163, 0.000687796209181682, 0.0008005613154757126, 
   0.0007353522123916374, 0.0005126900317133668, 0.0002319979700734363, 
   0.000031738291590334127, 0.00002591516508353204, 
   0.00024628529639186743, 0.0006195080668765532, 0.0009935330603850138, 
   0.0012041729983576174, 0.0011522521079625426, 0.0008545181538874782, 
   0.0004421203190652849, 0.00010460349595752932, 3.739024488584843*^-6, 
   0.00019714399661477, 0.0006083925850031688, 0.0010591345276366845, 
   0.0013494577934312173, 0.0013494577934312477, 0.0010591345276367613, 
   0.0006083925850032579, 0.00019714399661483262, 3.739024488594045*^-6, 
   0.00010460349595748327, 0.0004421203190652066, 0.0008545181538874044, 
   0.0011522521079625062, 0.001204172998357634, 0.0009935330603850752, 
   0.0006195080668766305, 0.0002462852963919276, 0.000025915165083553342, 
   0.00003173829159031169, 0.00023199797007338572, 0.0005126900317133143, 
   0.0007353522123916075, 0.0008005613154757178, 0.0006877962091817186, 
   0.0004558934570190417, 0.00020799220720310886, 0.00004079512315022134, 
   3.0030100555544547*^-6, 0.00008065399320623982, 
   0.00021250588317934152, 0.00032431575482579815, 
   0.00036364667896914986, 0.0003192225316887977, 0.0002184481787292386, 
   0.00010791724588821005, 0.000028912671124026592, 
   1.908055787844336*^-7, 0.000014665024854366987, 
   0.00004871793879927213, 0.00007703971911420451, 
   0.00008466004930601164, 0.00007100120146895363, 
   0.00004590476905843942, 0.000021657505679962564, 
   6.141002599150442*^-6, 3.7106562999580065*^-7, 4.900081501257647*^-7, 
   1.7802162006198246*^-6, 1.7466808067489192*^-6, 6.631263972532667*^-7, 
   2.5084067693798047*^-9, 4.881249513041845*^-7, 1.3892566341803088*^-6, 
   1.44929483270693*^-6, 4.755011583957237*^-7, 1.1042366355274096*^-7, 
   2.954532537952363*^-6, 0.000010507535118468301, 
   0.00002139871112018079, 0.00003135613777492455, 
   0.00003529081415193498, 0.000030429352014152825, 
   0.000018571441816738857, 5.881118446930272*^-6, 
   6.0455312234505045*^-9, 5.946327029212596*^-6, 
   0.000022971187795119872, 0.000044439568076576054, 
   0.00006082703724708988, 0.00006446807567932681, 
   0.00005351734481600526, 0.000033000727132341334, 
   0.000012371018435815182, 8.453061403209141*^-7, 2.954481617360479*^-6, 
   0.000016565730817838247, 0.00003427624927613802, 
   0.00004729807807775921, 0.00004972930992181401}, 
  {0.000056959708952697785, 0.00005417498786061977, 
   0.00003925984868538751, 0.000018974307253741033, 
   3.3840488294655743*^-6, 9.682095288323028*^-7, 0.00001416970415757198, 
   0.00003779887184520928, 0.00006129850563849305, 
   0.00007384141934019034, 0.00006967099168471484, 
   0.000050900864452077876, 0.000026311086422980577, 
   6.810893966841065*^-6, 6.92452196680766*^-9, 6.736204374845582*^-6, 
   0.000021271638845912176, 0.0000348536313307045, 
   0.000040421926344009514, 0.000035915167219263, 
   0.000024509979311694294, 0.000012035279457915455, 3.3841071536623*^-6, 
   1.2647872547100637*^-7, 5.446367068327056*^-7, 1.660015230201674*^-6, 
   1.5912477705388698*^-6, 5.590959376383842*^-7, 2.8731168749895456*^-9, 
   7.595417399873572*^-7, 2.0006396739085235*^-6, 2.0390509504277824*^-6, 
   5.612529443805086*^-7, 4.250167621493043*^-7, 7.033874414811125*^-6, 
   0.000024806401337789915, 0.00005257909850790629, 
   0.00008132442974418327, 0.00009696920741456333, 
   0.00008824091839283804, 0.000055801289403476325, 
   0.00001679724791682135, 2.1854777898897878*^-7, 
   0.000033116432439104415, 0.0001236078869067868, 0.0002502094780970441, 
   0.0003656359302939099, 0.00041651913184124405, 0.0003714696832249791, 
   0.00024340320176699835, 0.00009238069030365643, 
   3.4396330658043934*^-6, 0.00004672653501482914, 
   0.00023823325932619018, 0.0005221781413429698, 0.0007877984222051899, 
   0.0009169590247678766, 0.0008422688362537958, 0.0005872326608846278, 
   0.0002657293429926156, 0.00003635288433488415, 
   0.000029683103645313466, 0.0002820939768491793, 0.0007095815171900979, 
   0.0011379879198683627, 0.0013792538770995729, 0.00131978394256563, 
   0.0009787609242266466, 0.0005064024563306111, 0.00011981233390415621, 
   4.282660406340832*^-6, 0.00022580777184730877, 0.0006968498984853056, 
   0.0012131275203856433, 0.0015456623725252185, 0.0015456623725252532, 
   0.0012131275203857313, 0.0006968498984854077, 0.00022580777184738049, 
   4.282660406351372*^-6, 0.00011981233390410346, 0.0005064024563305214, 
   0.000978760924226562, 0.0013197839425655885, 0.0013792538770995917, 
   0.001137987919868433, 0.0007095815171901864, 0.0002820939768492482, 
   0.000029683103645337864, 0.000036352884334858455, 
   0.00026572934299255767, 0.0005872326608845675, 0.0008422688362537616, 
   0.0009169590247678826, 0.0007877984222052317, 0.0005221781413430271, 
   0.00023823325932623946, 0.00004672653501485266, 3.439633065798418*^-6, 
   0.00009238069030363022, 0.00024340320176696942, 
   0.00037146968322496177, 0.0004165191318412449, 0.0003656359302939275, 
   0.00025020947809706946, 0.00012360788690680914, 
   0.00003311643243911663, 2.185477789898936*^-7, 
   0.000016797247916814917, 0.000055801289403468485, 
   0.0000882409183928339, 0.00009696920741456427, 0.00008132442974418792, 
   0.000052579098507912133, 0.000024806401337794476, 
   7.0338744148134145*^-6, 4.2501676214974403*^-7, 5.612529443802033*^-7, 
   2.039050950427609*^-6, 2.0006396739087094*^-6, 7.595417399876078*^-7, 
   2.873116875007716*^-9, 5.590959376381849*^-7, 1.5912477705387277*^-6, 
   1.6600152302017984*^-6, 5.4463670683294*^-7, 1.2647872547082788*^-7, 
   3.3841071536611735*^-6, 0.00001203527945791332, 
   0.000024509979311691807, 0.00003591516721926127, 
   0.00004042192634400959, 0.00003485363133070661, 
   0.000021271638845915303, 6.736204374847983*^-6, 6.924521966896241*^-9, 
   6.810893966838279*^-6, 0.00002631108642297605, 0.00005090086445207343, 
   0.00006967099168471246, 0.00007384141934019118, 
   0.00006129850563849678, 0.000037798871845214146, 
   0.000014169704157575743, 9.682095288333709*^-7, 
   3.3840488294636736*^-6, 0.00001897430725373709, 
   0.000039259848685383646, 0.000054174987860617824, 
   0.000056959708952698544}, {0.00002272100856794101, 
   0.000021610194047365166, 0.000015660602463708837, 
   7.5687780996390835*^-6, 1.3498840472037976*^-6, 3.862150527916094*^-7, 
   5.652240425539144*^-6, 0.000015077824427907784, 
   0.000024451737858611643, 0.000029455057835542648, 
   0.000027791490302732268, 0.000020304158827280826, 
   0.000010495391058701394, 2.7168393768382154*^-6, 
   2.7621651484804654*^-9, 2.6870459861965134*^-6, 8.485174825480323*^-6, 
   0.000013902979327833924, 0.000016124150766950526, 
   0.000014326421906150892, 9.776936367486248*^-6, 4.800826631820595*^-6, 
   1.3499073125012839*^-6, 5.04518765620007*^-8, 2.172534851369703*^-7, 
   6.621736831493835*^-7, 6.347426082909838*^-7, 2.230212166275663*^-7, 
   1.1460752579958804*^-9, 3.029782753330624*^-7, 7.980474621102381*^-7, 
   8.133695724044532*^-7, 2.2388163831106917*^-7, 1.69537549820214*^-7, 
   2.805785418908381*^-6, 9.895177972271099*^-6, 0.000020973599929817952, 
   0.000032440001871059224, 0.000038680643440829774, 
   0.00003519896255986219, 0.000022258919470453012, 
   6.700357513288365*^-6, 8.717786748237727*^-8, 0.00001321001737936186, 
   0.00004930671011339793, 0.00009980759733769194, 
   0.00014585076464934316, 0.0001661478778119358, 0.0001481778262296639, 
   0.00009709259991839037, 0.00003685030163417414, 
   1.3720563850425594*^-6, 0.000018639034888745588, 
   0.00009503032978651673, 0.00020829484984373665, 
   0.00031424975706247446, 0.0003657714240693111, 0.0003359777954786372, 
   0.0002342448471851344, 0.00010599841168258979, 
   0.000014501025578066102, 0.000011840475744149765, 
   0.00011252620111309723, 0.00028304933483978394, 
   0.00045393899921459846, 0.0005501790605174957, 0.0005264567326312572, 
   0.0003904239637844255, 0.00020200198983933237, 0.00004779267863608717, 
   1.7083367449587897*^-6, 0.00009007385067769683, 0.0002779707411637599, 
   0.00048391189652280945, 0.000616558768557861, 0.0006165587685578749, 
   0.0004839118965228445, 0.00027797074116380063, 0.00009007385067772544, 
   1.7083367449629942*^-6, 0.00004779267863606613, 
   0.00020200198983929662, 0.0003904239637843918, 0.0005264567326312407, 
   0.0005501790605175032, 0.0004539389992146265, 0.0002830493348398193, 
   0.00011252620111312473, 0.000011840475744159498, 
   0.000014501025578055852, 0.00010599841168256667, 
   0.00023424484718511038, 0.0003359777954786236, 0.0003657714240693135, 
   0.00031424975706249115, 0.00020829484984375956, 
   0.00009503032978653638, 0.00001863903488875497, 
   1.3720563850401759*^-6, 0.000036850301634163686, 
   0.00009709259991837883, 0.000148177826229657, 0.00016614787781193616, 
   0.00014585076464935018, 0.00009980759733770208, 
   0.000049306710113406837, 0.000013210017379366732, 
   8.717786748274218*^-8, 6.7003575132858005*^-6, 
   0.000022258919470449885, 0.000035198962559860544, 
   0.00003868064344083015, 0.000032440001871061074, 
   0.000020973599929820283, 9.895177972272918*^-6, 
   2.8057854189092947*^-6, 1.695375498203894*^-7, 2.238816383109474*^-7, 
   8.133695724043842*^-7, 7.980474621103121*^-7, 3.029782753331623*^-7, 
   1.1460752580031283*^-9, 2.2302121662748678*^-7, 6.347426082909271*^-7, 
   6.62173683149433*^-7, 2.1725348513706375*^-7, 5.045187656192949*^-8, 
   1.3499073125008345*^-6, 4.800826631819744*^-6, 9.776936367485256*^-6, 
   0.000014326421906150205, 0.000016124150766950553, 
   0.000013902979327834768, 8.48517482548157*^-6, 2.6870459861974713*^-6, 
   2.7621651485158*^-9, 2.716839376837104*^-6, 0.000010495391058699588, 
   0.00002030415882727905, 0.00002779149030273132, 
   0.000029455057835542987, 0.000024451737858613127, 
   0.000015077824427909724, 5.652240425540645*^-6, 3.862150527920355*^-7, 
   1.3498840472030391*^-6, 7.5687780996375114*^-6, 
   0.000015660602463707295, 0.00002161019404736439, 
   0.000022721008567941314}, {9.557061277994164*^-31, 
   9.089823108971675*^-31, 6.587266447632647*^-31, 
   3.183629629886012*^-31, 5.677971784895352*^-32, 
   1.6245233634660125*^-32, 2.3774828455922115*^-31, 
   6.342134486040131*^-31, 1.0285052108027002*^-30, 
   1.2389581731787237*^-30, 1.1689840925669*^-30, 8.540469914889597*^-31, 
   4.414640977955978*^-31, 1.142774992988054*^-31, 
   1.1618402195937324*^-34, 1.130243099467987*^-31, 
   3.569090496978656*^-31, 5.847963350107385*^-31, 
   6.782247208550185*^-31, 6.026074575081667*^-31, 
   4.112439801944197*^-31, 2.019355530285493*^-31, 5.67806964493227*^-32, 
   2.122140284622642*^-33, 9.138260144144539*^-33, 
   2.785278852217446*^-32, 2.6698964463004503*^-32, 
   9.380866290459803*^-33, 4.820697741963034*^-35, 
   1.274407311013775*^-32, 3.356800150542979*^-32, 
   3.4212490268118855*^-32, 9.417057917823364*^-33, 
   7.131200834275308*^-33, 1.180188066970124*^-31, 
   4.162175369762769*^-31, 8.822054670241638*^-31, 
   1.3645128684006015*^-30, 1.6270108720343358*^-30, 
   1.4805621022522675*^-30, 9.362694297876168*^-31, 
   2.8183488046969413*^-31, 3.666933266287818*^-33, 
   5.556485100580634*^-31, 2.0739715341463007*^-30, 
   4.1981733377433824*^-30, 6.134871570634657*^-30, 
   6.988622202703796*^-30, 6.2327539778098886*^-30, 
   4.083973316083814*^-30, 1.5500218213345163*^-30, 
   5.771234542474004*^-32, 7.840074443075453*^-31, 
   3.997228742386047*^-30, 8.761436086318863*^-30, 
   1.3218181648320237*^-29, 1.5385320167969892*^-29, 
   1.4132120807195774*^-29, 9.852962080923944*^-30, 
   4.4585754756060314*^-30, 6.099517529291496*^-31, 
   4.9804194170812495*^-31, 4.733151682954629*^-30, 
   1.1905808801006244*^-29, 1.909388317421159*^-29, 
   2.314199644576542*^-29, 2.214417216086399*^-29, 
   1.642227163960469*^-29, 8.496741636263557*^-30, 
   2.0102873382524288*^-30, 7.185719289792853*^-32, 
   3.788746031662865*^-30, 1.1692189626387914*^-29, 
   2.0354623054648847*^-29, 2.593410373915492*^-29, 
   2.59341037391555*^-29, 2.0354623054650324*^-29, 
   1.1692189626389628*^-29, 3.788746031664069*^-30, 
   7.185719289810539*^-32, 2.0102873382515435*^-30, 
   8.496741636262053*^-30, 1.6422271639603273*^-29, 
   2.2144172160863292*^-29, 2.3141996445765737*^-29, 
   1.909388317421277*^-29, 1.1905808801007729*^-29, 
   4.7331516829557856*^-30, 4.980419417085343*^-31, 
   6.099517529287185*^-31, 4.458575475605059*^-30, 
   9.852962080922933*^-30, 1.4132120807195202*^-29, 
   1.5385320167969993*^-29, 1.321818164832094*^-29, 
   8.761436086319825*^-30, 3.9972287423868736*^-30, 
   7.8400744430793994*^-31, 5.771234542463977*^-32, 
   1.5500218213340765*^-30, 4.083973316083328*^-30, 
   6.232753977809597*^-30, 6.98862220270381*^-30, 6.134871570634952*^-30, 
   4.1981733377438084*^-30, 2.073971534146675*^-30, 
   5.556485100582684*^-31, 3.6669332663031674*^-33, 
   2.8183488046958623*^-31, 9.362694297874852*^-31, 
   1.4805621022521983*^-30, 1.6270108720343512*^-30, 
   1.3645128684006794*^-30, 8.822054670242619*^-31, 
   4.1621753697635345*^-31, 1.180188066970508*^-31, 
   7.131200834282686*^-33, 9.417057917818243*^-33, 
   3.4212490268115954*^-32, 3.3568001505432907*^-32, 
   1.2744073110141955*^-32, 4.820697741993522*^-35, 
   9.380866290456459*^-33, 2.6698964463002116*^-32, 
   2.7852788522176545*^-32, 9.138260144148471*^-33, 
   2.1221402846196467*^-33, 5.678069644930379*^-32, 
   2.019355530285135*^-31, 4.11243980194378*^-31, 6.026074575081378*^-31, 
   6.782247208550197*^-31, 5.84796335010774*^-31, 
   3.5690904969791806*^-31, 1.1302430994683901*^-31, 
   1.1618402196085948*^-34, 1.1427749929875866*^-31, 
   4.414640977955219*^-31, 8.54046991488885*^-31, 
   1.1689840925668602*^-30, 1.2389581731787379*^-30, 
   1.0285052108027627*^-30, 6.342134486040948*^-31, 
   2.377482845592843*^-31, 1.6245233634678046*^-32, 
   5.677971784892161*^-32, 3.1836296298853506*^-31, 
   6.587266447631999*^-31, 9.089823108971349*^-31, 
   9.557061277994292*^-31}}, {PlotRange -> {0, 4}, 
  DisplayFunction :> $DisplayFunction, ColorOutput -> Automatic, 
  Axes -> True, PlotLabel -> None, AxesLabel -> None, Ticks -> Automatic, 
  Prolog -> {}, Epilog -> {}, AxesStyle -> Automatic, 
  Background -> Automatic, DefaultColor -> Automatic, 
  DefaultFont :> $DefaultFont, AspectRatio -> Automatic, 
  ViewPoint -> {1.3, -2.4, 2.}, Boxed -> True, BoxRatios -> {1, 1, 0.4}, 
  Plot3Matrix -> Automatic, Lighting -> True, 
  AmbientLight -> GrayLevel[0], LightSources -> 
   {{{1., 0., 1.}, RGBColor[1, 0, 0]}, {{1., 1., 1.}, RGBColor[0, 1, 0]}, 
    {{0., 1., 1.}, RGBColor[0, 0, 1]}}, ViewCenter -> Automatic, 
  PlotRegion -> Automatic, ImageSize -> Automatic, 
  TextStyle :> $TextStyle, FormatType :> $FormatType, 
  ViewVertical -> {0., 0., 1.}, FaceGrids -> None, Shading -> True, 
  HiddenSurface -> True, Mesh -> False, ClipFill -> Automatic, 
  AxesEdge -> Automatic, MeshStyle -> Automatic, BoxStyle -> Automatic, 
  ColorFunction -> Automatic, ColorFunctionScaling -> True, 
  SphericalRegion -> False, MeshRange -> {{-0.008, 0.008}, 
    {-0.008, 0.008}}}]\
\>", "\<\
-SurfaceGraphics-\
\>"], "Output",
  CellLabel->"Out[64]="]
}, Open  ]],

Cell[BoxData[
    \(TraditionalForm\`DensityPlot[\(intensite(
          x)\)\ \(FD(10\ e, y\/\(lambda0\ f\))\)\^2, {x, \(-0.008\), 
        0.008}, {y, \(-0.008\), 0.008}, PlotRange \[Rule] {0, 0.3}, 
      PlotPoints \[Rule] 180, Mesh \[Rule] False]\)], "Input",
  CellLabel->"In[65]:="],

Cell["R\[EAcute]seau", "Section"],

Cell["\<\
Consid\[EAcute]rons un r\[EAcute]seau plan de pas a=2\[Mu]m, de largeur de \
fente e = 0.5 \[Mu]m.\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(TraditionalForm\`Clear[\[CurlyPhi]]; a = 2\/10\^6; e = a\/4; 
    lambda0 = 500\ 10\^\(-9\);\)], "Input",
  CellLabel->"In[68]:="],

Cell[TextData[{
  "D\[EAcute]terminons les directions des maxima principaux dans le cas d'une \
incidence normale : \[Theta] = arcsin k",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_0\/a\)]]
}], "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`N[
      Table[\(180\ \(\(sin\^\(-1\)\)(\(k\ lambda0\)\/a)\)\)\/\[Pi], {k, \
\(-4\), 4, 1}]]\)], "Input",
  CellLabel->"In[69]:="],

Cell[OutputFormData["\<\
{-90., -48.590377890729144, -30., -14.477512185929923, 0., 
 14.477512185929923, 30., 48.590377890729144, 90.}\
\>", "\<\
{-90., -48.5904, -30., -14.4775, 0., 14.4775, 30., 48.5904, 90.}\
\>"], "Output",
  CellLabel->"Out[69]="]
}, Open  ]],

Cell["\<\
Calculons la fonction d'interf\[EAcute]rences et tra\[CCedilla]ons le carr\
\[EAcute] du module avec NT=20 fentes en fonction de \[CurlyPhi] \
d\[EAcute]phasage entre deux rayons diffract\[EAcute]s cons\[EAcute]cutifs:\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(TraditionalForm\`\((NT = 
          20; )\)\ \((FIR(\[CurlyPhi]_) = \[Sum]\+\(n = 0\)\%\(NT - 1\)\
\[ExponentialE]\^\(\[ImaginaryI]\ n\ \[CurlyPhi]\); )\)\ \((R(\[CurlyPhi]_) = \
\[LeftBracketingBar]FIR(\[CurlyPhi])\[RightBracketingBar]\^2\/NT\^2; )\)\ \
Plot[R(\[CurlyPhi]), {\[CurlyPhi], \(-8\)\ \[Pi], 8\ \[Pi]}, 
        PlotRange \[Rule] All, PlotStyle \[Rule] RGBColor[0, 0, 1], 
        PlotPoints \[Rule] 150]\)], "Input",
  CellLabel->"In[76]:="],

Cell["Avec les trois couleurs primaires:", "Text",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Plot[{R(\[CurlyPhi]), R(\(0.65\ \[CurlyPhi]\)\/0.5), 
        R(\(0.65\ \[CurlyPhi]\)\/0.45)}, {\[CurlyPhi], \(-6\)\ \[Pi], 
        6\ \[Pi]}, PlotRange \[Rule] All, 
      PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], 
          RGBColor[0, 0, 1]}]\)], "Input",
  CellLabel->"In[84]:="],

Cell[OutputFormData["\<\
Graphics[{{RGBColor[1, 0, 0], 
   {Line[{{-18.84955435074243, 0.9999999999179593}, 
      {-18.803019113958666, 0.9300312567643401}, {-18.76067995685806, 
       0.763423861301552}, {-18.715092522430204, 0.5260661780179154}, 
      {-18.665608785658286, 0.27548894314720945}, {-18.619805064238328, 
       0.1062820614601393}, {-18.577517819138514, 0.022729166672207333}, 
      {-18.537096247308465, 0.000029826027033741912}, 
      {-18.49424480157296, 0.012807948661296338}, {-18.448179588081086, 
       0.036887785574374825}, {-18.398626753279963, 0.04798619795565797}, 
      {-18.351848788363178, 0.03839269249880597}, {-18.309050447109684, 
       0.020771527367875086}, {-18.2590516148412, 0.0040245850385127145}, 
      {-18.230750342970108, 0.00024328456883535108}, 
      {-18.204475603347323, 0.0006925557723803123}, 
      {-18.156360354799105, 0.007908985923996468}, 
      {-18.105067423247466, 0.01590855218366264}, 
      {-18.0792812555007, 0.01731082403820108}, {-18.052039060744804, 
       0.01634061763617846}, {-18.00325043760341, 0.009973334511991082}, 
      {-17.97791004288607, 0.005936974841401677}, {-17.950744955837227, 
       0.0023693118848597326}, {-17.92093869048789, 
       0.00023798062888558832}, {-17.893111883985746, 
       0.0002287587398815623}, {-17.86742210393587, 
       0.0016772014912471525}, {-17.839477126199668, 
       0.004180663500640963}, {-17.788667686633655, 
       0.008378301342251131}, {-17.73920294497301, 0.00889393061800311}, 
      {-17.69343828294105, 0.005968684277488712}, {-17.65204335899251, 
       0.0024451210881004464}, {-17.607419387177796, 
       0.0001541553004044537}, {-17.558447021735457, 
       0.000788718973791456}, {-17.512471172601728, 
       0.0033775844667977284}, {-17.463613868127563, 
       0.005665425481879434}, {-17.412175409939135, 0.00545018484460189}, 
      {-17.368257322550125, 0.003342244265732588}, 
      {-17.32021636909422, 0.0008462907897924427}, 
      {-17.29210961006361, 0.00008978187462191634}, 
      {-17.266194853685548, 0.00007754749717463852}, 
      {-17.237749269037018, 0.0007635210282968269}, 
      {-17.207633404944495, 0.001989303120964031}, 
      {-17.157021344766605, 0.003924484126013504}, 
      {-17.128258202530834, 0.004329287685638507}, 
      {-17.101347958175058, 0.004076675708277464}, 
      {-17.0512497800099, 0.0023693044083589803}, {-17.005474073250113, 
       0.0006219694703249185}, {-16.980194679324995, 
       0.00009319594144783857}, {-16.95263741079739, 
       0.00005393556665985403}, {-16.902477291849152, 
       0.0012386639274423565}, {-16.87469749160684, 
       0.0021988003262230905}, {-16.84468679727033, 
       0.0030555081204423464}, {-16.81635183920764, 
       0.0034306700768127153}, {-16.790316660057044, 
       0.0033033588698626448}, {-16.75982320263484, 
       0.002637886377708122}, {-16.72765030357918, 0.001597156036591356}, 
      {-16.700245460486176, 0.000737677314935722}, 
      {-16.670905939001674, 0.00013143501012087363}, 
      {-16.643162615053807, 0.00001659149482206516}, 
      {-16.617900328155002, 0.00031665959096821426}, 
      {-16.56848000061337, 0.001616740246455051}, {-16.54082607813778, 
       0.0023647410040900456}, {-16.51078415119309, 
       0.0028617514218234686}, {-16.48241342436079, 
       0.0028809734764325187}, {-16.456199456861384, 
       0.002504891145472921}, {-16.410089675721757, 
       0.0012836936839241244}, {-16.36044849976316, 
       0.00015957739074121203}, {-16.313585619696962, 
       0.00013893828572924443}, {-16.270674644017035, 
       0.0010079862979599813}, {-16.21899777972258, 
       0.0022695195710113573}, {-16.1709821961792, 
       0.0026211382585267264}, {-16.120886899650415, 
       0.0018183535350184412}, {-16.09440977231508, 
       0.0011359795027932789}, {-16.066161029437502, 
       0.0004691928591740055}, {-16.03824581925477, 
       0.00006621840185542985}, {-16.012541567661987, 
       0.000023417505248559258}, {-15.98432577513364, 
       0.000347046497859254}, {-15.954492500793846, 
       0.0009944478912597013}, {-15.904322956501737, 
       0.002154404340798251}, {-15.875830740455713, 
       0.0024885084109813947}, {-15.849209054628767, 
       0.0024500439007302554}, {-15.799549910946569, 
       0.001575784023570756}, {-15.754235135753156, 
       0.000498410170650876}, {-15.701929836232269, 
       9.089619921212299*^-6}, {-15.65233949036305, 
       0.0006974858569490093}, {-15.607385822101433, 
       0.00178779275299462}, {-15.558886029445574, 0.002497877103024351}, 
      {-15.51309676586179, 0.0021803406043006722}, 
      {-15.471079356307937, 0.0012356451415612539}, 
      {-15.424533719068473, 0.0002333967365966898}, 
      {-15.37357705297006, 0.00010376884690162606}, 
      {-15.347866304984278, 0.0005077696935575738}, 
      {-15.320376704721326, 0.0011656409744276257}, 
      {-15.270840104664533, 0.002329669564845917}, 
      {-15.243591980588754, 0.002627340845302487}, 
      {-15.218448427247747, 0.0025682279957651034}, 
      {-15.190850128055205, 0.0021503535093364183}, 
      {-15.1616075146618, 0.0014403474570893957}, {-15.112482630046895, 
       0.0002845157022007979}, {-15.084552891312498, 
       6.642403656622812*^-6}, {-15.058401085625722, 
       0.00012373561394605803}, {-15.009774371224246, 
       0.0011713970532365291}, {-14.965306957335178, 
       0.0023843574778897422}, {-14.913980795256062, 
       0.002917821152903106}, {-14.865214999508503, 
       0.002118425389521472}, {-14.819296904617664, 
       0.0008055284397939229}, {-14.777684182601986, 
       0.00004634167650004076}, {-14.729648726824347, 
       0.0003947027843037489}, {-14.684419478913318, 
       0.0017274096276175713}, {-14.645210873783256, 
       0.002928234626481936}, {-14.60380916311021, 
       0.0034412559248627535}, {-14.55840622985663, 
       0.0027331924415172327}, {-14.51665438763299, 
       0.0013477951088893857}, {-14.471370434315462, 
       0.0001492523032589028}, {-14.42285012456381, 
       0.0003078471292993839}, {-14.377054093121842, 
       0.0018478399874710416}, {-14.33531952806584, 0.00351159684140307}, 
      {-14.286361275768773, 0.004325958593940451}, 
      {-14.258705848413083, 0.003919390248280965}, 
      {-14.233131986068669, 0.0030604828606593006}, 
      {-14.18598688822482, 0.0010487942604493912}, 
      {-14.136376045401343, 3.1299907433441765*^-7}, 
      {-14.090606112970612, 0.0010570537193523369}, 
      {-14.040564672699032, 0.003744801237693018}, 
      {-13.995068608934762, 0.005695170930462936}, 
      {-13.952761488970024, 0.005676751533178387}, 
      {-13.902621123860428, 0.003326839057713325}, 
      {-13.857084964390005, 0.0007718726202995527}, 
      {-13.831856515331202, 0.00005583114229135657}, 
      {-13.804521645140703, 0.00025083934841939494}, 
      {-13.754923493695854, 0.003159536384191554}, 
      {-13.708154369045351, 0.007123324490593418}, 
      {-13.664420079362849, 0.009177843546379384}, 
      {-13.61880359729691, 0.007867431646844758}, {-13.56865062371379, 
       0.0034333510608321196}, {-13.525385681620032, 
       0.00031831600867798196}, {-13.485873539765102, 
       0.0006585106055122287}, {-13.440266382588414, 
       0.005599223320637206}, {-13.39699131034764, 0.012424792489132972}, 
      {-13.345463947515851, 0.017265266680274095}, 
      {-13.298829435740302, 0.014523571882365763}, 
      {-13.272945202705209, 0.010383085254142933}, 
      {-13.24499637028948, 0.005245419963734597}, {-13.194374907472396, 
       2.5876783444697866*^-7}, {-13.146735370847443, 
       0.0065000904082587775}, {-13.096497333078057, 0.0251899416441713}, 
      {-13.053604798138595, 0.04187686438914222}, {-13.006609157061119, 
       0.04755833639199254}, {-12.977989609042634, 0.04098834553003927}, 
      {-12.950926936681974, 0.02868020017703661}, {-12.900249808000838, 
       0.00347562782348663}, {-12.871882807899654, 
       0.0008053394380613334}, {-12.845685472015067, 
       0.01504026189570033}, {-12.816931308455198, 0.056490783047406824}, 
      {-12.786439161012417, 0.13538170995216986}, {-12.736045081364832, 
       0.34269020286918367}, {-12.68882053321966, 0.590838629519101}, 
      {-12.636770008435311, 0.8456853985769165}, {-12.60766354205844, 
       0.9445738987646121}, {-12.58126464968257, 0.9926457766275207}, 
      {-12.556097749060454, 0.9964959841130663}, {-12.528865472300431, 
       0.95409458520661}, {-12.479487262185897, 0.7728672245971622}, 
      {-12.384968325500065, 0.2870488738001974}, {-12.356908026083788, 
       0.171522470840421}, {-12.330703087906805, 0.09035739097010341}, 
      {-12.303368878393988, 0.03484851485877179}, {-12.273355919829225, 
       0.005167095157372136}, {-12.223788446709522, 
       0.006766005480891748}, {-12.19598947424599, 0.020952345767108995}, 
      {-12.17063523093174, 0.03431021039362147}, {-12.120772084466976, 
       0.04791155723056065}, {-12.074624468205938, 0.040447689656797306}, 
      {-12.023976574784928, 0.01998188523716507}, {-11.998079119838556, 
       0.010150038460207447}, {-11.970152827097133, 
       0.002885059429985796}, {-11.923590842498772, 
       0.0005203097741906394}, {-11.879864296898322, 
       0.006666817286625749}, {-11.828228142758777, 
       0.015230226584280667}, {-11.780172200616356, 
       0.017037046284767227}, {-11.737177659174877, 
       0.012636077455979389}, {-11.691231569152484, 
       0.005415109891281043}, {-11.640249533049598, 
       0.00033223565332428183}, {-11.593911242915276, 
       0.0009986491899332934}, {-11.5482052999996, 0.004962331012392705}, 
      {-11.499800534232861, 0.008658597806736888}, 
      {-11.474524567125187, 0.00921878165958499}, {-11.44671228739462, 
       0.008511698169174768}, {-11.397749082070236, 
       0.004881785965434126}, {-11.352833377211672, 
       0.0013419998019927428}, {-11.304565678149288, 
       0.00001917163684378727}, {-11.25900271278989, 
       0.0015956247617287197}, {-11.217357963109073, 
       0.004080604212079543}, {-11.175559717808754, 
       0.005776256200986754}, {-11.129980938632402, 
       0.0054819342395160675}, {-11.086931258719726, 
       0.0034484654260596025}, {-11.047004383949945, 
       0.001275529416624261}, {-10.995936314089692, 
       6.555504892570522*^-8}, {-10.97022868341109, 
       0.00030661012531638446}, {-10.942038898068184, 
       0.0012351492947831211}, {-10.89155046933312, 
       0.0033698338205216203}, {-10.845562821634687, 
       0.004328212950128126}, {-10.817618921991208, 
       0.004065571202134756}, {-10.791173633907107, 
       0.0032930526949870183}, {-10.760903941148527, 
       0.002066860871396306}, {-10.732926667371405, 
       0.000963333767943505}, {-10.682583742498261, 
       5.221497960480032*^-7}, {-10.656043670714537, 
       0.00023630552675351645}, {-10.627876528782403, 
       0.0009572701040439615}, {-10.581268047814195, 
       0.0025289880644501065}, {-10.531074371121768, 
       0.0034374383564553163}, {-10.483689325259146, 
       0.002831513170129638}, {-10.440286714373865, 
       0.0014570010010222132}, {-10.392112689526654, 
       0.00019306145749402282}, {-10.364828400800606, 
       1.8527788301591888*^-6}, {-10.339469305749851, 
       0.00023366560731429118}, {-10.28817540711579, 
       0.001531661903484764}, {-10.26157081392315, 
       0.0022706014867822748}, {-10.23343235737348, 
       0.0028006456113874333}, {-10.1837522551636, 
       0.0026999857501296626}, {-10.13799271557145, 
       0.0016039544426261236}, {-10.08874954815929, 
       0.00034074136848031184}, {-10.060778934288848, 
       0.00001632159607286541}, {-10.03463648024814, 
       0.00009257386587297034}, {-9.987358608750842, 
       0.0010113726804254345}, {-9.944203354804847, 
       0.0021016763856834954}, {-9.894390867720471, 
       0.002642365686639106}, {-9.847149263085969, 
       0.0020386014831323663}, {-9.804922698942876, 
       0.0009742025845598305}, {-9.760011801646108, 
       0.00011253246722495558}, {-9.721670609841352, 
       0.00007544662744620541}, {-9.679301656443233, 
       0.0008014839013082528}, {-9.633983240035489, 
       0.0019007864873563695}, {-9.58507471769212, 0.002513525165613326}, 
      {-9.538898995962398, 0.0020730733730163126}, 
      {-9.496513777010412, 0.0010818156568743582}, 
      {-9.446147980608322, 0.00011245486870768088}, 
      {-9.398545979590377, 0.0001681482862867898}, 
      {-9.35580939171296, 0.0010133820949985036}, 
      {-9.30942907780255, 0.002096294056610294}, {-9.25891780627682, 
       0.0024979148995861703}, {-9.233438881285378, 
       0.002238298333199932}, {-9.205380421310672, 
       0.0016684680562196142}, {-9.155221326261936, 
       0.00047378481847848853}, {-9.109338328664684, 
       4.2017813347690543*^-7}, {-9.063338376272911, 
       0.0005357434071569456}, {-9.019619512173596, 
       0.0016240105850102123}, {-8.973480137384056, 
       0.0025284721006714446}, {-8.923126584387722, 
       0.0024252178770856232}, {-8.879341629730705, 
       0.0014646853505505808}, {-8.832673945649713, 
       0.0003429807947718338}, {-8.788635819196696, 
       0.000016926490360248216}, {-8.748714369875296, 
       0.0005931189064485281}, {-8.697394009206478, 
       0.002002212173961036}, {-8.671549364865207, 
       0.0026020268390183118}, {-8.643186235733229, 
       0.0029200952379290234}, {-8.592978435890627, 
       0.0023892583781267665}, {-8.546113984333777, 
       0.0010830912679905822}, {-8.517699883924916, 
       0.0003717897388547411}, {-8.490787722883372, 
       0.000022533690750066018}, {-8.440352431176589, 
       0.0005339442354589148}, {-8.41214494043667, 
       0.0013615930740821407}, {-8.386052452906206, 
       0.0022337685027061286}, {-8.357414957960264, 
       0.0030351526455545523}, {-8.326997064128278, 
       0.0034339900625255416}, {-8.280120785088952, 
       0.002865596811109957}, {-8.229597592100431, 
       0.0012162055104074417}, {-8.181899921549356, 
       0.00007114550191398959}, {-8.138175356069084, 
       0.0003402797910604442}, {-8.089686312877532, 
       0.0020232520270093207}, {-8.061899032475115, 
       0.0031625070923687916}, {-8.036655499414216, 
       0.003960156797392129}, {-8.009885370389664, 0.004327383167106172}, 
      {-7.981291876192197, 0.004054980513246909}, {-7.929792828863969, 
       0.002197222115751135}, {-7.882544323831365, 
       0.00038591929440817815}, {-7.838348021685201, 
       0.0001231375590793015}, {-7.789859164549902, 
       0.0019115711868529083}, {-7.737777865127165, 
       0.004762230364978787}, {-7.711703077534936, 0.005699436017704032}, 
      {-7.683284209356821, 0.005912143540737281}, {-7.631560970633861, 
       0.004044478207401428}, {-7.580633274612053, 
       0.0010787671633947376}, {-7.534527135333173, 
       0.0000204193055606546}, {-7.487329884001496, 
       0.0019574907025359098}, {-7.442934553916066, 
       0.005657520945093975}, {-7.396064463492161, 0.008803765217416699}, 
      {-7.34544013975836, 0.008450532309691528}, {-7.3009815496009125, 
       0.004926816316123825}, {-7.254083390344327, 
       0.0009027606331275086}, {-7.214042511217899, 
       0.0001668490483732755}, {-7.170157660367507, 
       0.0037709018608482444}, {-7.119458265886162, 
       0.011564986613217188}, {-7.0908342879102735, 
       0.015403169979499823}, {-7.064391405402824, 0.017214944547984702}, 
      {-7.015844677922423, 0.01455000878086968}, {-6.964347643006407, 
       0.005695556744055893}, {-6.93603338816261, 0.0014338612361331315}, 
      {-6.909491705840101, 0.000010664087517428685}, 
      {-6.880374243937671, 0.0027101602165114113}, 
      {-6.849032796807816, 0.010973054096456252}, {-6.822699137897267, 
       0.021188506627984466}, {-6.794608860830505, 0.033099553970418236}, 
      {-6.744050552428224, 0.04741007749183809}, {-6.693254342213152, 
       0.04042054040922276}, {-6.664165008085801, 0.026769915078516414}, 
      {-6.637773439837377, 0.01243649405366024}, {-6.585736441310018, 
       0.0014766951737263075}, {-6.536684284640567, 0.05084470249427359}, 
      {-6.489217748751787, 0.1841403800041048}, {-6.445519090791236, 
       0.3792596478358543}, {-6.394860975512596, 0.648256682344535}, 
      {-6.346841539510619, 0.872314146504771}, {-6.300345604052499, 
       0.9902468999275089}, {-6.2497365052606835, 0.9633476515402755}, 
      {-6.203732711627614, 0.8069352185586095}, {-6.161143625986424, 
       0.5930321289199693}, {-6.111358254508816, 0.3322048425775147}, 
      {-6.06459007699622, 0.14013808798063387}, {-6.015818353591404, 
       0.028628003685734208}, {-5.9899037528483055, 
       0.005030281246641594}, {-5.961950278749346, 
       0.0004885552941486387}, {-5.918353316272052, 
       0.017893286697868816}, {-5.87063394321511, 0.041320304344549544}, 
      {-5.820813807934988, 0.04724431623833188}, {-5.77443355008318, 
       0.03417996786822887}, {-5.731674903847991, 0.01627773181821993}, 
      {-5.691282933194373, 0.00372839088178796}, {-5.64472593327558, 
       0.00026013300008813204}, {-5.602396447025745, 
       0.005628771550655297}, {-5.55123293408933, 0.014456338688906133}, 
      {-5.50333555878848, 0.01724897749034944}, {-5.45337914827821, 
       0.012545654840773447}, {-5.426879207294937, 0.008353783875462902}, 
      {-5.398392757033058, 0.004057407789609205}, {-5.347971072555731, 
       0.0000648038539099247}, {-5.300073835456125, 
       0.0017530605570553648}, {-5.257079540247627, 
       0.005715447968660159}, {-5.210181942051738, 0.008910121755167625}, 
      {-5.181304917258407, 0.009117825647310411}, {-5.154120097191738, 
       0.007995066626980326}, {-5.103324497824341, 
       0.0038966859592622317}, {-5.076714571006869, 
       0.0017963090505152752}, {-5.048621633386794, 
       0.0003577048717991721}, {-5.017813891023609, 
       0.00005440796550647321}, {-4.989489009586291, 
       0.0009028051076848686}, {-4.938973603385813, 
       0.0038038174931533785}, {-4.89184574508489, 0.005786676447256995}, 
      {-4.8401360359952434, 0.005250970435202043}, 
      {-4.8111508791904996, 0.0038648427997345102}, 
      {-4.7847413801434175, 0.0023621783636612703}, 
      {-4.737979664615356, 0.0003287683047402195}, 
      {-4.694109706630753, 0.00016224785185614505}, 
      {-4.645983626291362, 0.0017810320174190997}, 
      {-4.594139493640889, 0.0038312572013550054}, 
      {-4.5426813117982565, 0.004209695951753516}, 
      {-4.516815987977192, 0.0035961691406729513}, 
      {-4.4885422045977466, 0.0025231220755242713}, 
      {-4.438404294202849, 0.0006017030334932467}, 
      {-4.391789647185709, 0.000015746351044617286}, 
      {-4.3444016383099955, 0.0009664394018923923}, 
      {-4.2996954398895815, 0.0024790127398712433}, 
      {-4.259556226525709, 0.003361712970333299}, {-4.216073994527723, 
       0.003178544138011741}, {-4.168632769663265, 
       0.0018455794824507215}, {-4.1184407669823875, 
       0.0003640359333105412}, {-4.075588832323875, 
       0.000022502300027333126}, {-4.0284843985768966, 
       0.000853156573546236}, {-4.0021790164142, 0.0016146892862551458}, 
      {-3.973523253279205, 0.0023862588740326696}, 
      {-3.9213825171652723, 0.002912981520677105}, 
      {-3.870621208375331, 0.0020463383517507596}, 
      {-3.8235894616130963, 0.00073608332598049}, {-3.7947517444210463, 
       0.00016845288747224514}, {-3.7676396529026888, 
       1.4248535617211104*^-6}, {-3.7170123771105024, 
       0.0006924597319748992}, {-3.6884397921100156, 
       0.0014273218392346966}, {-3.6618183642853412, 
       0.002084429681845816}, {-3.6340470451383906, 
       0.002540065341123445}, {-3.603624969435574, 
       0.0026160162523552145}, {-3.555516488513633, 
       0.0018426312838579048}, {-3.504047526190069, 
       0.0005572696067468592}, {-3.4561759739484303, 
       4.6086222910457184*^-8}, {-3.4126158183722244, 
       0.00044515947410497797}, {-3.361793405613342, 
       0.0016492994082052367}, {-3.333107481923204, 
       0.0022355239886254342}, {-3.306620707855078, 
       0.002501230054296011}, {-3.257980807229026, 
       0.0021155559376212405}, {-3.2064108795693076, 
       0.000912207739927277}, {-3.1587467064522947, 
       0.00007285198476504193}, {-3.1067128982073053, 
       0.00029210227339890186}, {-3.0575641866805157, 
       0.0013893919577526407}, {-3.011929382283063, 
       0.002326512047628235}, {-2.9667600333415343, 
       0.002440635074229489}, {-2.9258003589400188, 
       0.0017531200022389264}, {-2.8811496888590415, 
       0.000665820859616912}, {-2.8339721992749887, 
       0.000010930339858623171}, {-2.7823629750704497, 
       0.0004900062853355015}, {-2.734874384132847, 
       0.0016637672789509034}, {-2.68376824513525, 
       0.0025885725517372903}, {-2.654754572062833, 
       0.002590122941768344}, {-2.627664503992534, 
       0.0022144496477942395}, {-2.578600390738159, 
       0.0010007174047347764}, {-2.5338597365531537, 
       0.00011472486218274566}, {-2.482216774638195, 
       0.00026082319737400915}, {-2.4332884011271556, 
       0.0014619691448853097}, {-2.3917630539860193, 
       0.002537045610542366}, {-2.345921655853297, 
       0.0029105797556860896}, {-2.298046017540716, 
       0.002097249756627501}, {-2.2530944517745897, 
       0.0008100066831921768}, {-2.211240788897457, 
       0.000045794740794663475}, {-2.172861499073095, 
       0.00021500637401745056}, {-2.1307262100951485, 
       0.0013035636154233102}, {-2.086359628421716, 
       0.0027329367404618065}, {-2.0412211474130277, 
       0.0034403007314834345}, {-1.9929932055379858, 
       0.0027598996211519876}, {-1.9474782774359523, 
       0.001252174401216209}, {-1.906117076406961, 
       0.00016596684114772792}, {-1.8574529483913846, 
       0.0002874751068127835}, {-1.8300040544364793, 
       0.0010855963033567333}, {-1.804692849969334, 
       0.002099523353674358}, {-1.758180217031686, 0.003839460876779473}, 
      {-1.7089305897245628, 0.004238984721751464}, 
      {-1.6610439249631326, 0.002825413567249425}, 
      {-1.6088360862670068, 0.000664026776109525}, 
      {-1.5595255578196794, 0.00006396757558756953}, 
      {-1.5138007833980227, 0.001543750544754854}, 
      {-1.468481402851415, 0.0040590383714272545}, 
      {-1.4274398388886087, 0.005724224100477317}, 
      {-1.3800633586166606, 0.005496873748618442}, 
      {-1.3354855848201483, 0.0032801974677784886}, 
      {-1.2865831294686674, 0.00060469836042613}, {-1.2349812229126604, 
       0.00034430762398085323}, {-1.1909244874765226, 
       0.0029651212576230664}, {-1.1426232235237035, 
       0.007059963019920576}, {-1.0905504251557767, 
       0.009218441256088415}, {-1.0613694202965949, 
       0.008404075358710607}, {-1.0347948626727395, 
       0.006499475952475995}, {-0.9860118282514051, 0.00198498594833883}, 
      {-0.9342480379912181, 0.00008330871449973516}, 
      {-0.890121557983842, 0.00337173354829058}, {-0.8414728682680637, 
       0.010747812646374389}, {-0.7972281110676503, 
       0.016363188291285788}, {-0.7557403362694065, 
       0.016797744993076454}, {-0.7069922889186531, 
       0.010458470953072308}, {-0.6623498147826603, 
       0.0026344308674407175}, {-0.6133361696946921, 
       0.0006111794796324814}, {-0.5617948799804378, 
       0.012394030305432959}, {-0.5195639005213168, 
       0.029708492139382255}, {-0.47450184611047785, 
       0.04520907127098789}, {-0.4319769577918364, 0.04646245492917817}, 
      {-0.39338384636269647, 0.03317814237702155}, 
      {-0.3479138541110981, 0.009152719460175008}, 
      {-0.29868165085145276, 0.0026838071352489863}, 
      {-0.2521943190202482, 0.05331024008925182}, {-0.20938382031580743, 
       0.17180720738285601}, {-0.159587103091406, 0.39323597766317503}, 
      {-0.1123695245147679, 0.6445968440339149}, {-0.06946018712852885, 
       0.8495143113041154}, {-0.023831879783057293, 0.981257279439885}, 
      {0.025656251676719137, 0.9783038886183307}, {0.07148529601618876, 
       0.8412118029198222}, {0.12079146322884589, 0.5997431789787485}, 
      {0.17526678530781975, 0.3156949339428602}, {0.22174504334313228, 
       0.13007434985720082}, {0.26439976089922057, 0.03278060897773626}, 
      {0.3112275823293511, 0.00008942559761468119}, 
      {0.3605753251449359, 0.015582569140780824}, {0.4007442164705111, 
       0.036609330051378786}, {0.4436973778780989, 0.047818395930798126}, 
      {0.49082253922578856, 0.0407496324608583}, {0.5347075443848628, 
       0.023227868386700067}, {0.5613641084678221, 0.01254900850548894}, 
      {0.589612231438928, 0.004219401898958083}, {0.6402822503468985, 
       0.0003595874519366277}, {0.6684382403971583, 0.00354320827437334}, 
      {0.694805025770407, 0.008209568565408764}, {0.7255866564932641, 
       0.013556217419555166}, {0.7548362408820194, 0.01674179987062853}, 
      {0.8071878985720454, 0.015451665839096658}, {0.8550673322780442, 
       0.008554197263338906}, {0.9066080831006502, 
       0.0016064362901831916}, {0.9357763190704835, 
       0.00005511541493882389}, {0.9628455355873985, 
       0.00047706057675526574}, {1.0137717730835198, 
       0.004538099639577424}, {1.061728618302597, 0.008423074074107043}, 
      {1.1047890246313155, 0.00905490328834988}, {1.151350880902838, 
       0.006367729884059841}, {1.2022445616513981, 0.002093090516732137}, 
      {1.2278719888762328, 0.0006062895654994912}, 
      {1.2559913243842644, 3.0199109600618273*^-7}, 
      {1.3057718283081068, 0.001508053777852755}, 
      {1.352228509400175, 0.004259813935521468}, {1.402202759017174, 
       0.005928843397719866}, {1.427434013822995, 0.0057243546806590665}, 
      {1.4552737213540194, 0.004730329536101723}, {1.5049993902861878, 
       0.0020013164825409854}, {1.550574261621309, 
       0.00020585658500751967}, {1.5766668191935496, 
       0.000017111104953788705}, {1.6041273081256915, 
       0.0005179485913932521}, {1.6316933628133417, 
       0.0015421956788063882}, {1.6618356194750128, 
       0.0028585990372272385}, {1.6879971959311362, 
       0.003801580865114637}, {1.7159353191643292, 
       0.0043062377245543125}, {1.7662489985641339, 
       0.003600026623266964}, {1.8169786816265945, 
       0.0015886221646361956}, {1.8455851549468163, 
       0.0005787505451635378}, {1.871950513928582, 
       0.0000648533657721756}, {1.9204128485030072, 
       0.0004489281612774437}, {1.9717011061842376, 
       0.0020920283508004942}, {2.0176281222110024, 
       0.0032874657031786146}, {2.0605800480121714, 
       0.003284746918126758}, {2.1077039723094253, 0.002075096511568693}, 
      {2.158309487328879, 0.0005065614004436101}, 
      {2.207238999611111, 0.000020653271331676054}, 
      {2.252587638399518, 0.000796532824425105}, {2.2803771507898194, 
       0.0015961437075115653}, {2.3065118841157823, 
       0.0023122740566529757}, {2.3553214835454823, 
       0.002929768867519496}, {2.3988676656635475, 
       0.0023859121684276577}, {2.445892800214242, 0.001101317684200046}, 
      {2.496135016641812, 0.00008085388926962653}, 
      {2.542281623277247, 0.0002240474574042855}, 
      {2.584436538909411, 0.0011534565150834312}, 
      {2.623725005546657, 0.0021346617010102016}, {2.6668346226361916, 
       0.002643062101128438}, {2.71296988172174, 0.0021709906020045034}, 
      {2.7614047117663043, 0.0009752957614523683}, 
      {2.8072101715792037, 0.00010373100667220776}, 
      {2.8483329848726777, 0.00010996499912743944}, 
      {2.892989709130008, 0.0009435518271975564}, {2.9405673880030756, 
       0.0020683114715189742}, {2.9858138537059453, 
       0.002514802856322162}, {3.0379695740060666, 
       0.0018560859371749639}, {3.085708684324305, 
       0.0007033364182027686}, {3.1304711289806875, 
       0.00003079574975160242}, {3.172046191762721, 
       0.00022482713156399416}, {3.217670103346778, 
       0.001190187019869701}, {3.266328062507378, 0.0022562214770770707}, 
      {3.2941002974917244, 0.0025093405366743253}, 
      {3.319663066292433, 0.0024105134907697707}, 
      {3.347723920994498, 0.0019660159607129963}, 
      {3.377381979650305, 0.0012632297076446161}, 
      {3.42726627476457, 0.00020151362081742146}, 
      {3.455590852504137, 6.648119958934213*^-9}, {3.4820457364549973, 
       0.00017388472565735822}, {3.527469881020184, 
       0.0011212041131816852}, {3.575748058861966, 
       0.0022773151877686654}, {3.6009139079965955, 
       0.0025993677601458933}, {3.6287040891800486, 
       0.0025880528130949555}, {3.6777199472534234, 
       0.001706798747177056}, {3.7044714093036797, 
       0.0010036535913817023}, {3.733322040148195, 
       0.00034975261127053305}, {3.7855443881020854, 
       0.0000673469358022323}, {3.8115022624564547, 
       0.0004575279040133788}, {3.8388432428614894, 
       0.0011448833332856102}, {3.887732841016184, 0.00246102364452845}, 
      {3.935106746995099, 0.002919536533513129}, {3.9792012026410775, 
       0.002250403646474518}, {4.027586380186651, 0.0008775574163133176}, 
      {4.0792993109474365, 7.1456229672140594*^-6}, 
      {4.1082524167434435, 0.00018285672706319802}, 
      {4.134958993039722, 0.0007677475287193398}, 
      {4.164273296411081, 0.0016982252082718865}, 
      {4.195322222842659, 0.0026910939962833252}, {4.2474913747743726, 
       0.003438385278719254}, {4.277146018079924, 0.003080721482696784}, 
      {4.304902256898263, 0.0023122846478575744}, {4.3555981799812225, 
       0.000633668200370223}, {4.403746676936673, 
       0.000011660840870706237}, {4.430294469495899, 
       0.00038853901780768114}, {4.459246876019126, 
       0.001312883530998473}, {4.509980330809967, 0.0033647011601766618}, 
      {4.535655886963932, 0.004090223900360592}, {4.56275717397784, 
       0.004327237334447806}, {4.611271290980132, 0.003261667971136778}, 
      {4.638619834969511, 0.002106569302039189}, {4.667911666513711, 
       0.0008861864588965386}, {4.69555841941481, 0.0001379794266321422}, 
      {4.7207436018735285, 0.00003511207031842956}, 
      {4.769350956826948, 0.0015420789382480063}, 
      {4.815356994977676, 0.0040942255796883745}, 
      {4.865079030561542, 0.005885548834986303}, {4.893160289585098, 
       0.005760176744828769}, {4.919117950384487, 0.004863822393809343}, 
      {4.9632366758145015, 0.002328230000224695}, 
      {5.004619135202748, 0.0003323635025393325}, 
      {5.050016678780648, 0.00040428377277789475}, 
      {5.098912078733508, 0.0035182680445400836}, 
      {5.147452328768642, 0.0075600206613132895}, 
      {5.198511675057032, 0.009178047277942157}, {5.242106425168299, 
       0.007027073388108643}, {5.289751353331864, 0.002619460552422235}, 
      {5.316711066222383, 0.0006540839886804577}, 
      {5.345910521117067, 0.000033144614300071836}, 
      {5.373482342212662, 0.0013422543949263687}, 
      {5.398881319054667, 0.004122719881316745}, {5.450087306549547, 
       0.012052244486734776}, {5.497952153838172, 0.017077824053413203}, 
      {5.549401592741292, 0.014696237079113071}, {5.576673632875388, 
       0.01037171556939665}, {5.605945843304597, 0.005003126193420367}, 
      {5.636593594020366, 0.0008179237302205719}, 
      {5.665663027958579, 0.00031433862975552653}, 
      {5.691758135473729, 0.0038278137292383414}, 
      {5.720179370351849, 0.01196229821455056}, {5.772058793754245, 
       0.03322061470792421}, {5.820824424607319, 0.047245554662242}, 
      {5.8716778672472145, 0.04094814149518559}, {5.898706681685206, 
       0.02863914782731461}, {5.927880172976738, 0.012804862508497302}, 
      {5.976715006901868, 0.0006331474433239724}, 
      {6.028193760447217, 0.04810476422490646}, {6.072145755649719, 
       0.1658719550305911}, {6.120283684146674, 0.3763889763265285}, 
      {6.168833791649759, 0.6341086210479951}, {6.220298629698128, 
       0.8752220599574286}, {6.247160232709906, 0.9575850376053855}, 
      {6.276744873085368, 0.9986215765696251}, {6.3288537582430235, 
       0.9325465100254686}, {6.377896003139811, 0.7351043978657547}, 
      {6.430647389253708, 0.4564603781120921}, {6.480096845062501, 
       0.2198133399581515}, {6.526002067950405, 0.07299623564725415}, 
      {6.573253446407416, 0.006813075224298788}, {6.62482669802691, 
       0.006371280338079928}, {6.67029463942251, 0.030016488983116294}, 
      {6.71876187021964, 0.04702216126228167}, {6.766389431346363, 
       0.043049969241915474}, {6.811253881997643, 0.026073753965220995}, 
      {6.854623392392583, 0.009130301553216593}, {6.895109725744438, 
       0.0007339734268381139}, {6.943184444896677, 0.002310704049367181}, 
      {6.968651409685801, 0.006475779544762285}, {6.995950176904344, 
       0.011479635093228746}, {7.024566550505208, 0.015591599229854923}, 
      {7.051673510506055, 0.01728730192577923}, {7.102476811303444, 
       0.014017737447070376}, {7.150190931277144, 0.006650031337551195}, 
      {7.19498223712627, 0.0011764370487793285}, {7.241693740280337, 
       0.0002995676454035406}, {7.293250410998804, 0.004179339769793827}, 
      {7.344816507349798, 0.008417941868811429}, {7.373814914837797, 
       0.00921855068125789}, {7.400400981917471, 0.008625123096227379}, 
      {7.448691334164281, 0.005155776011189055}, {7.499529158065575, 
       0.0011774433590019057}, {7.526370521153688, 
       0.00013259999338270737}, {7.555043506109986, 
       0.0001629348927847701}, {7.6066888911712605, 
       0.002544454615209361}, {7.6382800939686994, 0.004414642042454831}, 
      {7.668102001474992, 0.005638717652065548}, {7.69487687923254, 
       0.005938870741416008}, {7.7238997691401305, 0.005336563045945296}, 
      {7.771781258782295, 0.0029228536770263425}, 
      {7.817233884119583, 0.0006699617173931311}, 
      {7.842301707044616, 0.00006870316310942923}, 
      {7.869626333269627, 0.00011951345481650221}, 
      {7.917494844583833, 0.0016548918724741061}, 
      {7.963015724313758, 0.003546058365296492}, {8.011475527889585, 
       0.004322031206168978}, {8.057202592984076, 0.00333569547358344}, 
      {8.098605391952512, 0.001652091830797433}, {8.124495782494845, 
       0.000705072033790614}, {8.151810094553253, 
       0.00010218166604203923}, {8.20069289962396, 
       0.00038167080888275746}, {8.22791968657855, 
       0.0011600556122473257}, {8.25330299869194, 0.002037846213837294}, 
      {8.281154770773455, 0.00289213275119693}, {8.310970584214203, 
       0.0033992447725391646}, {8.336727370334017, 0.00336978868493042}, 
      {8.364706282312401, 0.0028614266542118733}, 
      {8.415540640196808, 0.0012505133066111201}, 
      {8.465029163480914, 0.00009383255176278256}, 
      {8.51075218263534, 0.0002446064146979381}, {8.558540268037811, 
       0.0014475076390393896}, {8.609984507161856, 
       0.0027166128082972175}, {8.658549395245178, 0.002800590580370025}, 
      {8.703015583704556, 0.0018474445912386747}, 
      {8.72892664377002, 0.0011055580159794525}, {8.756569414361854, 
       0.00042258874742971144}, {8.806325329254253, 
       0.00002673071970667659}, {8.858236494717048, 
       0.0009098108725176721}, {8.887966179243046, 
       0.0016893615708385486}, {8.914941918688758, 0.002291401001887233}, 
      {8.941764286870722, 0.002615082246889565}, {8.970122177532572, 
       0.0025620125266955424}, {9.02092828243887, 0.00159043104056912}, 
      {9.047305558309638, 0.0009071206912951053}, 
      {9.075603140386916, 0.0003033506271133348}, 
      {9.106652827124071, 4.031100007827209*^-6}, 
      {9.1356619549328, 0.00015679447810872736}, {9.343746195340495, 
       0.0013144294434048792}, {9.395925825458974, 
       0.00020244255560753312}, {9.444948980555564, 
       0.00010035565260973036}, {9.49607203408715, 0.001070849935897981}, 
      {9.52357083726919, 0.001746852633565613}, {9.552543853994, 
       0.0023006355379986978}, {9.601041379799916, 0.002427928127803369}, 
      {9.64554069207016, 0.001635826850566534}, {9.672559683019756, 
       0.0009636481979324893}, {9.698086212939245, 
       0.00040196380689076566}, {9.745866125023277, 
       0.000012297460437407808}, {9.798168510040709, 
       0.0008069979345027141}, {9.824989203275303, 
       0.0014962146718622484}, {9.854085441563727, 
       0.0021847320950138275}, {9.879530995328832, 
       0.0025629018598906993}, {9.906490623897284, 
       0.0026218551511680856}, {9.95484462210009, 0.0018575898749917468}, 
      {9.981755094981596, 0.0011581864516341486}, {10.007321283858673, 
       0.0005321457699989855}, {10.036791212788112, 
       0.00007245404746727761}, {10.063738442931518, 
       0.000031292849459607735}, {10.093346877261238, 
       0.00042989393888032037}, {10.125647197299305, 
       0.0012476804420802944}, {10.153499466882064, 
       0.002038144649930516}, {10.18361075037405, 0.0026977610575344983}, 
      {10.211758871075416, 0.00293012101896197}, {10.237641550911809, 
       0.002745143531705968}, {10.288512165434362, 
       0.0015216926410516693}, {10.334750142812595, 
       0.00031600607035379877}, {10.383570826683025, 
       0.00008378110583046528}, {10.408943081554698, 
       0.0005276492703626466}, {10.436126646964377, 
       0.0013193553557165028}, {10.48516391344854, 
       0.0028694270536523455}, {10.51511741284883, 0.003390567389074874}, 
      {10.543476705252274, 0.00335387847059318}, {10.568935892776413, 
       0.0028784728646041647}, {10.59661406513148, 
       0.0020254372746683967}, {10.642530457492754, 
       0.000534021023218731}, {10.693184022713641, 
       0.00005311710329165735}, {10.718648682700461, 
       0.0005196533852080428}, {10.74608391187966, 0.001455851098275362}, 
      {10.795718350611896, 0.003453864366119015}, 
      {10.84253120416694, 0.004331531410667649}, {10.891788812192454, 
       0.0033611191929282815}, {10.933845110972278, 
       0.0015778751522134776}, {10.979822962747768, 
       0.0001211218257178526}, {11.032156753115407, 
       0.000664105410125452}, {11.080381289649907, 0.003072824134125312}, 
      {11.10773738019456, 0.004568651929371443}, {11.133316464457353, 
       0.005581765999296044}, {11.159996476628827, 0.005946414958582154}, 
      {11.189327621171566, 0.005396119975070319}, {11.239152358444793, 
       0.0027723804227789976}, {11.284651956227917, 
       0.0004308138616756621}, {11.309786570640696, 
       2.0341189340531664*^-9}, {11.33717021227348, 
       0.0005519251111451362}, {11.386999334142537, 
       0.003939093025038477}, {11.434922058488278, 0.007845610065481774}, 
      {11.479982475782492, 0.009196414916816751}, 
      {11.53191829779559, 0.006469653853142448}, {11.57891902843828, 
       0.0021037130488869484}, {11.623496380672405, 
       1.9048293788688583*^-7}, {11.664432035441436, 
       0.0020469985115062817}, {11.70937165012951, 0.008241850535334654}, 
      {11.756759021851382, 0.015190944165287925}, {11.808585745031582, 
       0.016914010164439098}, {11.855750468849434, 0.011105126204970577}, 
      {11.90653314722703, 0.0022890451871713426}, {11.935198414472865, 
       0.000021128058621988453}, {11.961669260565744, 
       0.0015436855141918212}, {12.009302990597725, 
       0.014133417002785966}, {12.059812133170409, 0.03505137476123538}, 
      {12.10396519550155, 0.04724035291500193}, {12.152609319792743, 
       0.04174015288457492}, {12.181476124291871, 0.028858623959254127}, 
      {12.208923239869005, 0.01392014151764292}, {12.260458516596703, 
       0.0007308377670601564}, {12.289222481226808, 0.01714355638763205}, 
      {12.315933127194084, 0.056734881686785324}, 
      {12.3452452192978, 0.13202295532583327}, {12.376500596572349, 
       0.24936470136000718}, {12.476501709847923, 0.7586731127469499}, 
      {12.503899564184595, 0.8767810385266773}, {12.533277240308099, 
       0.9641111892503998}, {12.56100626410808, 0.9990435552280872}, 
      {12.58629485226163, 0.9868699794110098}, {12.61163308017188, 
       0.9337080446730437}, {12.639202196048698, 0.8355972022168252}, 
      {12.689334440650489, 0.5880759976801814}, {12.742123254916216, 
       0.3133881846534893}, {12.771052487937256, 0.18923008371235034}, 
      {12.79821805249499, 0.10047755343829708}, {12.846358172236073, 
       0.014418641036750328}, {12.871932432979975, 
       0.0007958885219634507}, {12.899508187466155, 
       0.003236440450880623}, {12.94840278336651, 0.027336136129729054}, 
      {12.993243850352922, 0.04545308990128307}, {13.018888070773025, 
       0.047955841029633815}, {13.046290739727695, 0.043927520358142146}, 
      {13.095655979289853, 0.025551197533287093}, {13.125847929491814, 
       0.013236309400840342}, {13.154357810896284, 
       0.0045858657552455264}, {13.179954451234593, 
       0.000590823258447965}, {13.207708811373768, 
       0.00042413831401876445}, {13.234878741572034, 
       0.0035541755214549917}, {13.26477283705881, 0.008880583982675943}, 
      {13.293901607485687, 0.01384159624145815}, {13.325201918195622, 
       0.016967986886802976}, {13.354447690161981, 0.01694905542067671}, 
      {13.381176490064751, 0.01458616616028461}, {13.408044577303146, 
       0.010715824207178473}, {13.433557665815702, 0.006621780812968132}, 
      {13.483913399388754, 0.0007763050628354549}, 
      {13.529521344823664, 0.0004909718783217161}, 
      {13.554825857970483, 0.0021878007013766106}, 
      {13.582168980011105, 0.004734111403871372}, {13.631712403956502, 
       0.008602517959812307}, {13.678303182375297, 0.00883877304746225}, 
      {13.727471642185112, 0.00554047676151566}, {13.773530093477172, 
       0.001749644148455347}, {13.815479590898098, 
       0.00004135889333995434}, {13.86511270013831, 
       0.0011421702535024591}, {13.892420724235667, 
       0.0027005659645070747}, {13.918262342272465, 
       0.004241307315616475}, {13.964199656513392, 0.005888254112940835}, 
      {14.014115665914911, 0.005064684230549216}, {14.040232486386333, 
       0.003763352501828762}, {14.069029258334059, 
       0.0021285600141027383}, {14.099102475186344, 
       0.0007174342349470096}, {14.127305116420652, 
       0.000048953112858325106}, {14.177674644918872, 
       0.0007463098919112438}, {14.205985292985392, 
       0.001887211200378056}, {14.23191469253256, 0.0030113834329062762}, 
      {14.282668787701835, 0.004308579736427413}, {14.330532184026149, 
       0.003665664163839326}, {14.373506622359733, 
       0.0019965144837294983}, {14.420042316928033, 
       0.0003702427296501415}, {14.470834509569476, 
       0.0001415320001065522}, {14.496428308293508, 
       0.0007028627716371445}, {14.524551137971276, 
       0.0016220120871240703}, {14.574305992516384, 
       0.003119957166426579}, {14.620805455791645, 0.003360755167456288}, 
      {14.66758701867129, 0.0022869643284738643}, {14.711950873862895, 
       0.0008429399611532002}, {14.751775766177573, 
       0.00005923404083694187}, {14.795142324225413, 
       0.00026498142114377737}, {14.8422125217394, 
       0.0014619425515167161}, {14.892271287475168, 
       0.002702684169948221}, {14.935007332398254, 
       0.0028691287983956247}, {14.982229349670408, 
       0.0019573776576383086}, {15.033835469917365, 
       0.000548980972022413}, {15.059796758525504, 
       0.00010816772038804846}, {15.088225099659432, 
       0.00002024280126874732}, {15.138597814728403, 
       0.0008389332604617559}, {15.185512655476039, 
       0.0020354576272366733}, {15.214052703310976, 
       0.002524545139098178}, {15.241024652649338, 
       0.0026364975232901033}, {15.291517711003848, 
       0.0019029132856502112}, {15.319937416295348, 0.00117709311573164}, 
      {15.34655431943932, 0.0005350987901114022}, {15.374314949646156, 
       0.00009641820115978045}, {15.40488387261045, 
       0.000031278296710788976}, {15.45261425513468, 
       0.0007821417629954835}, {15.503944694418232, 
       0.0020093033769781575}, {15.551697456015635, 
       0.002515157619050064}, {15.5953760530231, 0.0020433808989252446}, 
      {15.64605893915011, 0.0008425502178688914}, {15.674743456369129, 
       0.0002659618660937487}, {15.701366926147212, 
       0.000010862281348642306}, {15.750127432158633, 
       0.00041891821531924383}, {15.802094435809762, 
       0.0016371214098406276}, {15.851295504973129, 
       0.002465691380777322}, {15.879222080996179, 
       0.0024681267409643933}, {15.905287106995488, 
       0.0021372301988175856}, {15.932808852666742, 
       0.001536606435189463}, {15.957895769004233, 
       0.0009111965906064616}, {15.986853046705862, 
       0.00030417779425878167}, {16.01427766110181, 
       0.00001571983703769251}, {16.06284678843592, 
       0.000404808669240931}, {16.107770894355195, 0.001485699741152433}, 
      {16.157076927974302, 0.002503747929331675}, {16.181972213319902, 
       0.0026438291901886434}, {16.209444484841974, 
       0.002427696163004408}, {16.237246183476135, 
       0.0018765501117456005}, {16.266508890420482, 
       0.0011168113109830996}, {16.318816121433283, 
       0.00008299455897436914}, {16.34798593234907, 
       0.00003783467053685074}, {16.375117595921264, 
       0.0004015219006203469}, {16.40489007244445, 
       0.0011357600777509276}, {16.43668807598044, 
       0.0020382328743086334}, {16.46428035868291, 0.002656603298762473}, 
      {16.494183533240005, 0.002929732299538432}, 
      {16.5224205439958, 0.002721719408765731}, {16.548448477675212, 
       0.0021774978326186186}, {16.59739811368192, 0.000785159853654639}, 
      {16.62487289009938, 0.00019884945902091217}, 
      {16.649970470822428, 6.972077906693789*^-8}, 
      {16.6989492834922, 0.0007023157801502904}, {16.745434639184197, 
       0.002193000115194473}, {16.788161191562917, 
       0.0032728965939193898}, {16.83472537059427, 0.003244990068200866}, 
      {16.885802233347995, 0.0018171045486994842}, 
      {16.913816782198904, 0.0008713825245616219}, 
      {16.940166280204945, 0.0002196565968721405}, 
      {16.991464241120244, 0.000274465461436979}, {17.037902177532793, 
       0.0018074415937667984}, {17.087974976991585, 
       0.003743328230100054}, {17.113174671801833, 0.004261497569645651}, 
      {17.140791538076225, 0.004236884545321821}, 
      {17.18970862645989, 0.002774912874498191}, {17.23530486696938, 
       0.0008493092607030311}, {17.263008492448115, 
       0.00012111845841659341}, {17.289211288239137, 
       0.00005499513779678254}, {17.338283905333466, 
       0.0016714096559338626}, {17.36549124706163, 0.00318352849319875}, 
      {17.39136855370479, 0.0045905099480054185}, {17.421197427409975, 
       0.0057031766737238145}, {17.44850360103709, 0.005920361547670199}, 
      {17.489985199583092, 0.004645939095033593}, {17.535289120104956, 
       0.001989489509737808}, {17.57746150393328, 
       0.00016793696043944446}, {17.616635588381943, 
       0.00041286646122425265}, {17.663646454591163, 
       0.003380018749191917}, {17.706294364869713, 
       0.0070113654552286415}, {17.755524257265755, 
       0.009212369825346125}, {17.801926918341277, 0.007531642227922253}, 
      {17.847495682239668, 0.003412587031669915}, 
      {17.89566390583199, 0.0001538832153023993}, {17.936788360895967, 
       0.001103164519406778}, {17.98195374494322, 0.006557245623341815}, 
      {18.03056097655599, 0.014056538965809972}, {18.08269686916416, 
       0.01725616613256514}, {18.131907547652528, 0.01230641100530518}, 
      {18.17680115634268, 0.004240604490356168}, {18.218431672709666, 
       0.000020427166656814237}, {18.26268311969252, 
       0.004845756890967557}, {18.300461541425758, 0.017239272350207276}, 
      {18.342184514228737, 0.034730136405050425}, 
      {18.3868376624014, 0.04720332326251373}, {18.43500043343801, 
       0.04200894250299414}, {18.480471030062628, 0.020235428789484085}, 
      {18.522184935921512, 0.0016337747396824585}, 
      {18.561606219332074, 0.008153081907587324}, 
      {18.59830292976243, 0.05513022691598758}, {18.638570344670594, 
       0.16606377644804673}, {18.68161231433307, 0.3512029414478558}, 
      {18.84955435074243, 0.9999999999179593}}]}}, 
  {RGBColor[0, 1, 0], 
   {Line[{{-18.84955435074243, 1.091689193921813*^-11}, 
      {-18.803019113958666, 0.007093609890485326}, 
      {-18.76067995685806, 0.015846576217313956}, {-18.71180789424901, 
       0.015430372319361493}, {-18.665608785658286, 
       0.006580915751520212}, {-18.622883473172756, 
       0.00047267045832223955}, {-18.583438299177473, 
       0.0011149784166738148}, {-18.5401428659676, 0.006123673041523522}, 
      {-18.49424480157296, 0.009217866161206758}, {-18.448179588081086, 
       0.006469657145191714}, {-18.398626753279963, 
       0.0012829248784667893}, {-18.351848788363178, 
       0.00024382725089548942}, {-18.309050447109684, 
       0.003003634102387362}, {-18.2590516148412, 0.005864228566168626}, 
      {-18.230750342970108, 0.005589875962998084}, 
      {-18.204475603347323, 0.004142718414146415}, 
      {-18.156360354799105, 0.0008410566249510161}, 
      {-18.105067423247466, 0.0003068824426006862}, 
      {-18.0792812555007, 0.0014564067014241717}, {-18.052039060744804, 
       0.0029929466614576176}, {-18.00325043760341, 
       0.004321096879093762}, {-17.97609602310594, 
       0.0036762790245881997}, {-17.950744955837227, 
       0.0024338437162730827}, {-17.921148904284443, 
       0.0009013775147505717}, {-17.893111883985746, 
       0.00006741645019086142}, {-17.842704629394238, 
       0.0009174031281292595}, {-17.796744653462316, 
       0.0028665732859162944}, {-17.747263346079002, 
       0.0032743119412015197}, {-17.719305144727862, 
       0.0024000052950786904}, {-17.69343828294105, 
       0.0012857558111000573}, {-17.649071479235758, 
       0.00003260563517859211}, {-17.607419387177796, 
       0.0005585431590773029}, {-17.561727401869785, 
       0.0022129972689451504}, {-17.512471172601728, 
       0.002885476116209595}, {-17.463613868127563, 
       0.0015558709590590772}, {-17.412175409939135, 
       0.00007372343133686703}, {-17.368257322550125, 
       0.0004282614741197122}, {-17.32021636909422, 
       0.0019745270068048317}, {-17.29210961006361, 
       0.0025761676791548026}, {-17.266194853685548, 
       0.0025642798004852814}, {-17.237749269037018, 
       0.0019376256507180642}, {-17.207633404944495, 
       0.0009396793047241307}, {-17.157021344766605, 
       3.5680499259333464*^-7}, {-17.128258202530834, 
       0.00036067362445436473}, {-17.101347958175058, 
       0.0011420469829623206}, {-17.0512497800099, 
       0.0024350391140814335}, {-17.005474073250113, 
       0.00210780754448074}, {-16.980194679324995, 0.001366316548588847}, 
      {-16.95263741079739, 0.0005187204332527988}, 
      {-16.902477291849152, 0.00007950331798398677}, 
      {-16.87214902900725, 0.0007366860566268186}, 
      {-16.84361575854171, 0.0016446958975246235}, 
      {-16.817994965368193, 0.0023004843103939165}, 
      {-16.790316660057044, 0.002505693282747212}, 
      {-16.76003513876113, 0.0020276511992847624}, 
      {-16.728085848314446, 0.001041283993334422}, 
      {-16.7008081163618, 0.0002845420739851413}, {-16.670905939001674, 
       5.933016849350029*^-6}, {-16.64281939647733, 
       0.00041617535082304744}, {-16.617244584440424, 
       0.0011954896645100027}, {-16.589708669765006, 
       0.002085611541317608}, {-16.559794940970672, 
       0.002623053708810915}, {-16.53212676888415, 
       0.0024571785088999738}, {-16.506561947505723, 
       0.001794962068088039}, {-16.456199456861384, 
       0.0002426367054423442}, {-16.410089675721757, 
       0.00023928431530949301}, {-16.36044849976316, 
       0.0018698837167278695}, {-16.313585619696962, 
       0.0029255494025936628}, {-16.270674644017035, 
       0.002208567023171364}, {-16.21899777972258, 
       0.0003843720771311137}, {-16.1709821961792, 
       0.00021727713058052403}, {-16.120886899650415, 
       0.0020786424286387923}, {-16.09440977231508, 
       0.003058072934479079}, {-16.066161029437502, 
       0.0034398919211916547}, {-16.03824581925477, 
       0.0029467243745969914}, {-16.012541567661987, 
       0.0019214452060309214}, {-15.98488009439685, 
       0.000723821220626296}, {-15.954492500793846, 
       0.00001520857997490041}, {-15.903317589052177, 
       0.0012814254346960518}, {-15.875345117491758, 
       0.0027813226559176346}, {-15.849209054628767, 
       0.003937130297289274}, {-15.799549910946569, 
       0.003853750109174934}, {-15.754235135753156, 
       0.0015104556200837707}, {-15.701929836232269, 
       0.00003093958645451549}, {-15.65233949036305, 
       0.002359854226730873}, {-15.60626905203158, 
       0.0054100328057708905}, {-15.557725211740223, 
       0.005340605913361976}, {-15.53231363170157, 0.003700020399537447}, 
      {-15.504493851463069, 0.0015361048035560198}, 
      {-15.455647381989252, 0.00014062103618988785}, 
      {-15.409397873787938, 0.0036556353400071357}, 
      {-15.3599484959046, 0.00857231448836233}, {-15.313279542275891, 
       0.00819877441000183}, {-15.270840104664533, 
       0.0034575845343442473}, {-15.22331081796009, 
       3.640806725920351*^-6}, {-15.171745222734959, 
       0.0056264645646761655}, {-15.078117223074354, 
       0.016548171628704297}, {-15.02928332024635, 
       0.0070372743219783125}, {-15.001858046836906, 
       0.001435125551560814}, {-14.976778602364272, 
       0.00017410025670340132}, {-14.947233879158286, 
       0.00610282323378373}, {-14.919162971868152, 0.01875707423635647}, 
      {-14.893044459221684, 0.03310839666335672}, {-14.865214999508503, 
       0.04505085801792675}, {-14.819560535598821, 0.0424427327687296}, 
      {-14.777196514189729, 0.0157030584816248}, {-14.726820934949554, 
       0.004054887307317479}, {-14.681168671276952, 0.08959824786223153}, 
      {-14.632907856711785, 0.3254612221024158}, {-14.58072892135011, 
       0.6810737494756127}, {-14.531461957841621, 0.9444381803709696}, 
      {-14.486156812560466, 0.9897983339256112}, {-14.44418983626232, 
       0.8386194437679645}, {-14.405029628096898, 0.5877878888870492}, 
      {-14.358462143800189, 0.27725682148003494}, {-14.316024542949597, 
       0.08268377325733695}, {-14.271478043299645, 
       0.0034801602725624088}, {-14.229299335476465, 
       0.010865657980773475}, {-14.184779604491085, 0.04014760366802024}, 
      {-14.136376045401343, 0.04567365620958909}, {-14.088114323387414, 
       0.02309995218322873}, {-14.043886454340665, 0.003604470373204192}, 
      {-13.995329173816614, 0.0017542868195620507}, 
      {-13.944232289470484, 0.013015970329040887}, 
      {-13.899603688760015, 0.017243845055698752}, 
      {-13.858103228986195, 0.011911547631428702}, 
      {-13.812906499456297, 0.003049400712387734}, 
      {-13.763936119554815, 0.00022859595297278538}, 
      {-13.736052271998087, 0.0025533568428843627}, 
      {-13.710355979639166, 0.00571427328487912}, {-13.659798367754567, 
       0.009218806941946182}, {-13.613847632742436, 
       0.006350984256979227}, {-13.565223203363521, 
       0.0012688081722372043}, {-13.512995985662593, 
       0.00046246748816490215}, {-13.464157777008655, 
       0.00391681489297754}, {-13.436152087716374, 0.005572936453521791}, 
      {-13.410575611370612, 0.005910159317110861}, 
      {-13.381053790432391, 0.004781123230906617}, 
      {-13.353041543827512, 0.0028076296478537254}, 
      {-13.32596323918793, 0.0009902236210625136}, 
      {-13.300500386943066, 0.0000712110181828912}, 
      {-13.252948347312639, 0.001091682026695347}, 
      {-13.225924938043637, 0.002603745655687756}, 
      {-13.19742753543031, 0.003933750447814034}, {-13.146438690008216, 
       0.003811798858558307}, {-13.102510487927578, 
       0.0016165076457131955}, {-13.054380107639394, 
       0.000014229640948062585}, {-13.002927195867565, 
       0.0011939907565215202}, {-12.954978673277106, 
       0.0031229395565067863}, {-12.927949475091332, 
       0.0034358308846557327}, {-12.89860099585236, 
       0.0028651576544920843}, {-12.870885693224865, 
       0.0017491990518871008}, {-12.845290209406144, 
       0.0007003704479092238}, {-12.796839980349214, 
       0.00006570414716771754}, {-12.745461280879672, 
       0.0015984769104526425}, {-12.718936816095452, 
       0.002501672056931286}, {-12.690395295875305, 
       0.002928932988030139}, {-12.638792681477234, 
       0.001867142353629956}, {-12.607337724983363, 
       0.000725582668821469}, {-12.577427550333924, 
       0.000056982793779626025}, {-12.550580008479525, 
       0.00011409236698610081}, {-12.521265568939352, 
       0.000831080871213803}, {-12.495711694833494, 
       0.0016982828808842934}, {-12.468706518437397, 
       0.0024295231523999076}, {-12.420334638601023, 
       0.0023523114054652735}, {-12.368278369731822, 
       0.0007451487984180915}, {-12.33872235198957, 
       0.00008435522023838688}, {-12.31112059314147, 
       0.00007893360751492554}, {-12.261143851155765, 
       0.0013705630512015413}, {-12.215562221186486, 
       0.002460986357748221}, {-12.190365646446452, 
       0.0024354672047690656}, {-12.162948641949468, 
       0.0018615286403665704}, {-12.113091095583, 0.0003624665758728594}, 
      {-12.068792693556468, 0.00008489457777669247}, 
      {-12.019880605274134, 0.0013416508190741267}, 
      {-11.968797623526433, 0.0024954923357793078}, 
      {-11.920825391456317, 0.0018639799989075964}, 
      {-11.87616779821149, 0.00048592212763761046}, 
      {-11.835209463576845, 0.000016517362455551092}, 
      {-11.790243028234425, 0.0009869354796080841}, 
      {-11.742886280845507, 0.0024111651536442625}, 
      {-11.690898731830591, 0.00229214196937334}, {-11.643646516858956, 
       0.0007931419330200334}, {-11.617478620860625, 
       0.00014354483296972668}, {-11.589102766252175, 
       0.000052625374859486244}, {-11.53759400467823, 
       0.0014847452438007532}, {-11.489323855475897, 
       0.002859491397929851}, {-11.438203473385212, 
       0.0022331454521882007}, {-11.394559340734405, 
       0.0006419114107794755}, {-11.346535745011586, 
       0.00007076467449263701}, {-11.317597717405665, 
       0.0008163387032642131}, {-11.290117062800789, 
       0.0019724606235395417}, {-11.238550140422998, 
       0.003434211618221787}, {-11.209749670854313, 0.0030863193429731}, 
      {-11.183038374879233, 0.002087873126239406}, 
      {-11.151853773599608, 0.0007310758665979261}, 
      {-11.122505726074728, 0.00002383985634253452}, 
      {-11.09689994855595, 0.00024489284227338805}, 
      {-11.069229259748747, 0.0013248957487639271}, 
      {-11.020972416286575, 0.003763342078201573}, 
      {-10.993560033444313, 0.004330357198488719}, 
      {-10.964628910607027, 0.003791503117397865}, 
      {-10.912842360820612, 0.0010761723364775347}, 
      {-10.864402040032514, 0.0000910554008624205}, 
      {-10.837046338089284, 0.0011647811675276527}, 
      {-10.811762369443313, 0.0029041965042185397}, 
      {-10.765355317263012, 0.005697700109774947}, 
      {-10.716103226459845, 0.004886901972908842}, 
      {-10.672124809619563, 0.0015969382935781132}, 
      {-10.63087885489189, 5.96208479254587*^-6}, {-10.585630880911085, 
       0.002643615086845206}, {-10.536902363486774, 
       0.007835720596240407}, {-10.487964835104341, 
       0.008719984397732767}, {-10.46024812141558, 0.006249018587543627}, 
      {-10.43448711353353, 0.0030761281041359516}, 
      {-10.382380264911035, 0.0001707315177225392}, 
      {-10.353229880773513, 0.0030433726889411645}, 
      {-10.326769600055815, 0.008011148724667912}, 
      {-10.279215121821442, 0.016410764146873216}, 
      {-10.227716061784482, 0.01414375493790718}, {-10.179087887649082, 
       0.0032350772286211488}, {-10.134297262013044, 
       0.0011116422020178336}, {-10.092379774693475, 
       0.015412070686074171}, {-10.04739334257586, 0.039264377691705085}, 
      {-10.004930008117654, 0.04753969992944543}, {-9.966169464888836, 
       0.031319282397976995}, {-9.920777460296147, 0.002484683427626323}, 
      {-9.87134507082894, 0.02997663131114197}, {-9.824658041453356, 
       0.18544382240147592}, {-9.781414677947813, 0.44585253224134774}, 
      {-9.740091678285667, 0.7299701986815351}, {-9.695495087926304, 
       0.9534489935471219}, {-9.646550800368423, 0.9779701591717384}, 
      {-9.600549601511998, 0.7786212994155658}, {-9.548762913316944, 
       0.42741911095203783}, {-9.499817991161903, 0.1466921936067158}, 
      {-9.45587574247274, 0.02077865706601639}, {-9.408186972981397, 
       0.004101998404908434}, {-9.35900960189146, 0.036124568397475625}, 
      {-9.313616438831493, 0.04761547658037954}, {-9.264514752621547, 
       0.028459210441395776}, {-9.212471400757599, 0.004099721543742221}, 
      {-9.167674436298773, 0.0009796565798425836}, 
      {-9.125716085040983, 0.009720398615382621}, {-9.079684567505398, 
       0.017137701401699765}, {-9.030177495620688, 0.012935105679959227}, 
      {-9.004520743625294, 0.007679788563384886}, {-8.977174793263012, 
       0.002671993990502427}, {-8.947176208112326, 
       0.00006793938483352278}, {-8.919331044961481, 
       0.0009234243208406548}, {-8.89087523146784, 0.00400241843454949}, 
      {-8.864073462881311, 0.00718614810789737}, {-8.813981350879455, 
       0.008962596723729243}, {-8.76449369621619, 0.004537645538060757}, 
      {-8.71897144668817, 0.00045604483924960933}, 
      {-8.668999534494093, 0.0010413599640951108}, 
      {-8.64383396120353, 0.0029058276371198627}, {-8.616216076604495, 
       0.004920313646373695}, {-8.589396764851852, 0.005912655235337471}, 
      {-8.56022870746475, 0.005427429322339653}, {-8.532682011168552, 
       0.003762117689556579}, {-8.507200771584314, 
       0.0018937139262767647}, {-8.459009744857367, 
       6.486658055743942*^-7}, {-8.407822672196096, 
       0.0017372351616409063}, {-8.38146315221487, 0.003206382696698569}, 
      {-8.35305289563331, 0.004218797481506377}, {-8.301644244887488, 
       0.0033279399128934837}, {-8.274581973444914, 
       0.0019008837781958028}, {-8.245676438445294, 
       0.0005395490704920389}, {-8.213964598451021, 
       4.0509504872098265*^-6}, {-8.184466356578715, 
       0.0006058155529534573}, {-8.159178789037725, 
       0.001666044229634537}, {-8.131771340202826, 
       0.0028163979737157612}, {-8.082033463598117, 
       0.003296715824233776}, {-8.052635565535827, 0.002390634749808961}, 
      {-8.025535574675583, 0.0012240281901926525}, 
      {-7.974209705204645, 1.930523319196577*^-7}, 
      {-7.929618624031798, 0.0009399971525388491}, 
      {-7.8805777637249, 0.002630852086295933}, {-7.82936831613901, 
       0.002605184987432149}, {-7.781466944091739, 
       0.0009751017941978131}, {-7.7318975464925614, 
       7.336087326378958*^-7}, {-7.704204935342537, 
       0.00036885880766876093}, {-7.679134109712958, 
       0.0011286435703134166}, {-7.630252189548659, 
       0.002517407216245652}, {-7.584272203009757, 0.002288542589358204}, 
      {-7.55806536868688, 0.0015091156080826974}, {-7.5304204909403625, 
       0.0006074760766675892}, {-7.480949113347419, 
       0.00004772145045244833}, {-7.4533927778192774, 
       0.000574697031757077}, {-7.427705281340531, 
       0.0013777086507102292}, {-7.399519631157036, 
       0.0021849251417214053}, {-7.369349978527426, 
       0.0025144206290611017}, {-7.318910221470405, 
       0.0015323484556431608}, {-7.2923256004239985, 
       0.0006890030041196693}, {-7.264125364706596, 
       0.00008536842705141037}, {-7.212388524373443, 
       0.000547269002713204}, {-7.1645939379120955, 
       0.002007975295430848}, {-7.1188232684583275, 0.00247440809290899}, 
      {-7.075918004836441, 0.0015060940962524976}, 
      {-7.0288489319817575, 0.00018007758586269102}, 
      {-6.978184733870343, 0.0003724731335821615}, 
      {-6.932776854168836, 0.0017998840251779555}, 
      {-6.88433998764139, 0.002642562759399678}, {-6.856479640309017, 
       0.002263585228826913}, {-6.831203081731633, 
       0.0014969616053087235}, {-6.781840388124754, 
       0.00010768400897548746}, {-6.7356739949684, 
       0.0004264990735540402}, {-6.685703316074695, 
       0.002159621113784754}, {-6.638519263686577, 
       0.0029149337563488626}, {-6.5950806657797845, 
       0.0018873672889601178}, {-6.555878929046568, 
       0.0004756710897167831}, {-6.513828240327449, 
       0.00006463969254415075}, {-6.467688072077303, 
       0.0014996000045192804}, {-6.424585315579536, 
       0.003147506517884196}, {-6.3762011593787475, 
       0.0030772527057273662}, {-6.330337236502542, 
       0.0012108533288734363}, {-6.2891651551621885, 
       0.00002290729474697851}, {-6.244350873838707, 
       0.000927872008468799}, {-6.199396430165628, 0.003262580741927114}, 
      {-6.151340953426245, 0.004288097270864166}, {-6.105987874265056, 
       0.002549268349643316}, {-6.064752989197509, 
       0.00042928460159917146}, {-6.018301909136508, 
       0.00045577319643272114}, {-5.9744218795319055, 
       0.0032123503248895685}, {-5.926994474705419, 
       0.005831583422721079}, {-5.875549305025702, 0.004411133044134607}, 
      {-5.848485003110448, 0.0023219788609114746}, 
      {-5.823148411627737, 0.0006172025654087898}, 
      {-5.796722638668546, 0.000012124191457953539}, 
      {-5.767636123523691, 0.0012702269493270336}, 
      {-5.71965496413693, 0.006283782209943373}, {-5.668077003595769, 
       0.00918555076830318}, {-5.617083482315076, 0.005044760070264213}, 
      {-5.568643038394098, 0.0002162953583184376}, 
      {-5.525161141063818, 0.00229394108240793}, {-5.477731673040179, 
       0.011316916135838812}, {-5.4480976845670535, 
       0.016192451521612507}, {-5.420200259182506, 0.017148188103607406}, 
      {-5.368073136775955, 0.00830383607782209}, {-5.340765674520987, 
       0.0022853826899550045}, {-5.311936326775932, 
       0.00009546883083526883}, {-5.2803210101493905, 
       0.006266403194142225}, {-5.251253638561649, 0.01954550394801461}, 
      {-5.1994140541247535, 0.04486420823949173}, {-5.151050816580449, 
       0.041540255700147376}, {-5.123284546610474, 0.02465065908447457}, 
      {-5.097985622569702, 0.007462518693641709}, {-5.068783505603571, 
       0.0006737396657118981}, {-5.041138886982008, 0.02483998900413309}, 
      {-4.991610464507441, 0.18460538009486235}, {-4.966607990502214, 
       0.3245923439149876}, {-4.9390293024486756, 0.5094249634825545}, 
      {-4.889763125484175, 0.8327534073686647}, {-4.844623438107525, 
       0.992713436064629}, {-4.818767521491019, 0.9883185951997849}, 
      {-4.79156453469002, 0.9062182651079334}, {-4.764256891360261, 
       0.7597165232504676}, {-4.734406486337304, 0.5584775986724627}, 
      {-4.708256448353986, 0.37866185261031954}, {-4.680590156425108, 
       0.21371358075982014}, {-4.631005381635551, 0.03503453819567858}, 
      {-4.580606596116901, 0.0018838134126971347}, 
      {-4.554598919128989, 0.016462663761794828}, {-4.526010317299163, 
       0.03599549945788208}, {-4.474818238379147, 0.04677529995070216}, 
      {-4.426957196251227, 0.026042671857512523}, {-4.380251491299575, 
       0.004387553076622247}, {-4.337605241404242, 
       0.0006314710769282144}, {-4.288380427147636, 0.01069165167175074}, 
      {-4.241681654105166, 0.017295163347092014}, {-4.191651244017093, 
       0.011908954910967122}, {-4.163708450351545, 0.006131818305608847}, 
      {-4.138423868439352, 0.0019197922067729356}, 
      {-4.089112917522124, 0.0006999038529991758}, 
      {-4.042752694026566, 0.005854534569595194}, 
      {-4.01630859071958, 0.008436463039318044}, {-3.988427448066189, 
       0.009175610208805701}, {-3.938546171203761, 0.005368595222554672}, 
      {-3.9126089598171996, 0.0025002727470837356}, 
      {-3.8848599781397426, 0.0004147098088919629}, 
      {-3.854415221603652, 0.00017550489208709042}, 
      {-3.8260494686012008, 0.0017047452123181536}, 
      {-3.7791737951492244, 0.005136955526908044}, 
      {-3.7294743702366606, 0.005528822238089883}, 
      {-3.703536649639421, 0.004053297391998538}, {-3.6749640518226934, 
       0.0019619109863829413}, {-3.6246326591923506, 
       6.714480314007118*^-8}, {-3.5772724227019457, 
       0.0015867178950579222}, {-3.5263204661995786, 
       0.00407306772330716}, {-3.478221500071896, 0.0037457772546081675}, 
      {-3.434209310546817, 0.00151865391294863}, {-3.388897235430232, 
       0.000020633349290005198}, {-3.346824765561699, 
       0.0007682710294390252}, {-3.3006545206522806, 
       0.002741568091141516}, {-3.251429201976262, 0.003339902095763792}, 
      {-3.2045064652221926, 0.00175182379753127}, {-3.1602974564717097, 
       0.00018486582430830842}, {-3.120602895261158, 
       0.00022559919102173556}, {-3.077658970175611, 
       0.001650643035808639}, {-3.02855562988627, 0.0029112492544386215}, 
      {-2.983779205296183, 0.002258616898331651}, {-2.932094954542225, 
       0.00046215503327790117}, {-2.8831274625209096, 
       0.00012891564114046158}, {-2.837943491975075, 
       0.0014037888412559193}, {-2.7961344225007125, 
       0.002530296608732963}, {-2.750247867671961, 
       0.0022695259246950563}, {-2.7014933836150634, 
       0.0007345659665252005}, {-2.6527819741927514, 
       0.000013010940952732366}, {-2.625386166026587, 
       0.00043773693021944166}, {-2.6002645496780143, 
       0.0011886139712421714}, {-2.5539673249620622, 
       0.0024054850775738572}, {-2.5052184104194652, 
       0.002093341362701729}, {-2.4793052049214643, 
       0.0013262653567307082}, {-2.451618394452298, 
       0.00048329027560412447}, {-2.401744341610117, 
       0.00009221613447869469}, {-2.37123946295163, 
       0.0007740859730267774}, {-2.3424375067382823, 
       0.0016915581448256197}, {-2.31657853396429, 0.002331476052003623}, 
      {-2.2885430588765154, 0.002495192479189089}, 
      {-2.2367155469769937, 0.0013117702445895063}, 
      {-2.188220961958844, 0.00007533646294239816}, 
      {-2.160421160158786, 0.00009060326445928898}, 
      {-2.1350169060792865, 0.0006363992431510808}, 
      {-2.105694050015665, 0.001599190814891936}, {-2.0778532954214683, 
       0.002383131715430675}, {-2.051033001324056, 0.002642397692967062}, 
      {-2.022475646473039, 0.0022444083118390613}, 
      {-1.9711249393137482, 0.0006071364138966812}, 
      {-1.9396649556172656, 0.000018902231916835298}, 
      {-1.910063431214995, 0.0002468512826563122}, 
      {-1.8834835291441727, 0.0010280960087212445}, 
      {-1.8547656808910886, 0.0020826011868268195}, 
      {-1.806384569133661, 0.002920302896827386}, {-1.7789366749941504, 
       0.0024522863267932202}, {-1.753342308371655, 
       0.0015656687711117275}, {-1.7016589121808359, 
       0.00005290810017746861}, {-1.6726961238795983, 
       0.0001892959683023992}, {-1.646320291711619, 
       0.0010025032272653353}, {-1.5991485191385455, 
       0.0029269502956395794}, {-1.5478972237188011, 
       0.003201809272085638}, {-1.499496755173276, 
       0.0013156830552750237}, {-1.4547704051087975, 
       0.000014814616172460635}, {-1.4079709334118122, 
       0.0010726267432211612}, {-1.3587580025049353, 
       0.0035956528840124903}, {-1.3167396150974575, 
       0.0042711856918429165}, {-1.270831789396602, 
       0.002439142748080013}, {-1.2211686562580328, 
       0.00013625111172488574}, {-1.1933881665585242, 
       0.00018934575791330714}, {-1.1681762124083888, 
       0.0013099751161026294}, {-1.1185153901537679, 
       0.004786492621170905}, {-1.0727824026269202, 
       0.005844101371590265}, {-1.0297609018238656, 
       0.003474766231588924}, {-0.9842677754815646, 
       0.00036178309914950313}, {-0.9386018281714896, 
       0.0009680564808113443}, {-0.8884294016600103, 
       0.0060668325216830165}, {-0.8450812775443751, 
       0.00917076037410239}, {-0.7985684056183965, 0.006785045054512952}, 
      {-0.7546645799446992, 0.0015955992072073833}, 
      {-0.7145968632461965, 0.00022573511321713236}, 
      {-0.6641392215001726, 0.007219774804661178}, 
      {-0.6364776015434697, 0.012894526346950867}, 
      {-0.6104843080068306, 0.016623946720192007}, 
      {-0.5646781152953061, 0.014734402568075866}, 
      {-0.514069697682767, 0.003520077532035369}, {-0.4874062952710109, 
       0.00007254947999575915}, {-0.4593080689470084, 
       0.0027258616157037124}, {-0.40905141335418344, 
       0.024486228320734965}, {-0.3829116310104696, 
       0.038364665600294674}, {-0.3549599934840965, 0.04734832853839566}, 
      {-0.3242934398429533, 0.044144208508817326}, 
      {-0.2957354078645954, 0.02862720522851626}, {-0.24444520965537572, 
       0.00013077274776485636}, {-0.21550282844841712, 
       0.01426740464578126}, {-0.18879270438279422, 0.06715973736441691}, 
      {-0.13972994300232391, 0.28592001732293537}, 
      {-0.08773783657539191, 0.635658568235852}, {-0.04124221746647719, 
       0.9079969902968539}, {0.0022987842050221727, 0.9997030910812086}, 
      {0.05006689702060891, 0.866834821558125}, {0.10143181087154865, 
       0.5401035461397752}, {0.15319489275785256, 0.2107659809410384}, 
      {0.2019397878872628, 0.03557514139556692}, {0.22893389593665392, 
       0.0030851670189945735}, {0.2581230254952254, 
       0.004043460591229008}, {0.30904446459654367, 0.03705449499293998}, 
      {0.35785927753434615, 0.046877003898952996}, 
      {0.4094106318523687, 0.02428605430166956}, {0.45342387563401493, 
       0.004255086105226572}, {0.5017167907922546, 
       0.0013665694838019007}, {0.5310218193345055, 
       0.0073744406203917045}, {0.558772484130686, 0.013677289372027399}, 
      {0.6107743184186097, 0.01659843436284724}, {0.639860883730695, 
       0.01224546655016523}, {0.666761361066829, 0.006683678398677289}, 
      {0.6962858484253817, 0.0017366645185403595}, 
      {0.7276398551114056, 0.00001436761172369059}, 
      {0.7793500800663504, 0.00447840084153505}, {0.8278776140202663, 
       0.009009181909756284}, {0.8556544174055755, 0.008823486961894108}, 
      {0.881112581520236, 0.006842417518017619}, {0.9111739468470399, 
       0.003496818118493711}, {0.9384781336164708, 
       0.0009764543106683871}, {0.9848606219199451, 
       0.0003856688644451484}, {1.0343927927452743, 
       0.003833035007747759}, {1.0802858324746172, 0.005940560082418302}, 
      {1.123595125417394, 0.004467147527648533}, {1.170792432345651, 
       0.0011540029122664467}, {1.220741896416125, 
       0.00012750792966257894}, {1.2468333497767594, 
       0.0010979383733534652}, {1.2755229702363429, 
       0.0027039075030804226}, {1.3260123353708997, 0.00433153621960915}, 
      {1.3532632681068757, 0.0038102217230361712}, 
      {1.379123816144456, 0.00259740639172768}, {1.4276341740976284, 
       0.00031975652508234954}, {1.4798571761147465, 
       0.000533357510055115}, {1.509391303924397, 0.0017630701386799482}, 
      {1.5367639964263176, 0.00288764515385209}, {1.5868824440503562, 
       0.0032491956611178357}, {1.6322472205080432, 
       0.0015966246738477144}, {1.6574251099301698, 
       0.0005962965074839749}, {1.6846144886584336, 
       0.000026218886987723547}, {1.7338634488020195, 
       0.0008348536841973326}, {1.7823774109524764, 
       0.002545458523529105}, {1.8282577070452404, 0.002783646000062314}, 
      {1.853610147199153, 0.0021218843012415813}, {1.8811412628629598, 
       0.0011127799561400941}, {1.9292770121157181, 
       7.519968547467796*^-6}, {1.9752247576051172, 
       0.0007308159487982123}, {2.0239555015305877, 
       0.0022802516829278923}, {2.0655589047115193, 
       0.002576970102171492}, {2.111402848393226, 0.0014062573713775647}, 
      {2.138929243969369, 0.000526200848947458}, {2.1651069000227965, 
       0.00004180887553979326}, {2.2142632270858233, 
       0.0006085791660029913}, {2.2420353318212816, 
       0.0014847688589443532}, {2.271654316496284, 0.002282258168778076}, 
      {2.2996050747270242, 0.0025083012042268855}, 
      {2.324958781068887, 0.0021648652866600275}, {2.3742120231102675, 
       0.0006861346727996435}, {2.420631181294729, 
       6.826511957073937*^-6}, {2.4708069232209797, 
       0.0010500950844136198}, {2.4970075562241814, 
       0.0018757266469971285}, {2.5251068968851738, 
       0.002448439148199644}, {2.577168948073009, 0.0019111025385660182}, 
      {2.6257944045610673, 0.00042761710738125193}, 
      {2.655482021569111, 3.364710509297611*^-6}, {2.6836178656215397, 
       0.0002698095867863753}, {2.7088755995804434, 
       0.0009691678355823971}, {2.7363624191396445, 
       0.0018847229349976211}, {2.7630750968378766, 
       0.002518638647851396}, {2.7925734121602686, 0.002574828378187854}, 
      {2.8233811134506053, 0.0018880968257574027}, 
      {2.8523161842848683, 0.0009129314335797563}, 
      {2.9039533535633337, 7.560890441622977*^-6}, 
      {2.9329993494106796, 0.0004870700042476445}, 
      {2.959642455935011, 0.001393646555065861}, {3.0078143062761518, 
       0.0028271846942224416}, {3.052651468725825, 0.002497510359063065}, 
      {3.1018516240284564, 0.0007490035736728383}, 
      {3.1293965950481777, 0.00007787314065291766}, 
      {3.1544355836964444, 0.00008771762308795908}, 
      {3.2050546982165784, 0.0017759227779855732}, 
      {3.2317142841799438, 0.0028502613864876247}, 
      {3.259951404905164, 0.003428517152223192}, {3.3117907718291617, 
       0.0022983257914302433}, {3.359607818389239, 
       0.0003421003671863794}, {3.4074418840116922, 
       0.00037397823085167335}, {3.459608605989438, 
       0.002890323342586636}, {3.508880904559136, 0.004329915569787774}, 
      {3.5545844408200167, 0.0028748738519806727}, 
      {3.5990442250132046, 0.00052682078549945}, {3.6408906087771076, 
       0.0002170971061017094}, {3.6891224240144282, 
       0.0029958961008800626}, {3.7328151106716168, 
       0.005649985613686566}, {3.7816786602349026, 0.00499741229736985}, 
      {3.8332555403340867, 0.00120268576507854}, {3.8772907823934872, 
       0.00014222232137316745}, {3.9255835096464256, 
       0.003890979753413062}, {3.977630948334617, 0.00882664167483655}, 
      {4.006802483924718, 0.008953352896284133}, {4.033376687740476, 
       0.006922527893073447}, {4.08215116461838, 0.001257490242244619}, 
      {4.133921964208812, 0.001393049992400084}, {4.1780135742740745, 
       0.009089094183673324}, {4.226638955394829, 0.016924885780443513}, 
      {4.270863068450386, 0.014336693623436543}, {4.312344379269437, 
       0.004985437757969919}, {4.361069189343817, 0.0005737173273345525}, 
      {4.405704269798843, 0.014625147876753548}, {4.457816537419372, 
       0.041635262424304986}, {4.506257489801977, 0.04503205816324025}, 
      {4.545951416445644, 0.022648803364352516}, {4.58831950921507, 
       0.0001763011152031384}, {4.635329082359885, 0.04410859738210526}, 
      {4.678005515211544, 0.2004021307610612}, {4.723042477734719, 
       0.4789797039099179}, {4.771382515281914, 0.802751955163886}, 
      {4.817011582187883, 0.985325259045202}, {4.858666758146776, 
       0.964136610951217}, {4.905696536997642, 0.7375211598731064}, 
      {4.950304347277518, 0.43143977898664004}, {4.99851176231399, 
       0.15251289687389652}, {5.025767794828805, 0.05698246561109782}, 
      {5.051016403838194, 0.01170333875003117}, {5.097849323008566, 
       0.007384885660302337}, {5.149608218862637, 0.04087505554267049}, 
      {5.175605862187603, 0.04789063568600275}, {5.203666361211015, 
       0.04349283226251909}, {5.254479944737506, 0.017826230481321217}, 
      {5.2986496226558755, 0.0014963832660182304}, 
      {5.3470259656995, 0.0034666645577745253}, {5.397533233464754, 
       0.014673594563436755}, {5.444582431479832, 0.016545337995024268}, 
      {5.488735859966046, 0.009023623394469079}, {5.528905024644585, 
       0.0018094027988781996}, {5.57527230024666, 0.000562855114163763}, 
      {5.619100399988635, 0.0052953663000459535}, 
      {5.666539952523019, 0.009159668238727707}, {5.718788587896241, 
       0.006376872371207963}, {5.769699848638549, 0.001116632220747627}, 
      {5.7982981871554395, 3.003805781302239*^-6}, 
      {5.824461607171724, 0.0006847711566224581}, 
      {5.874646317268742, 0.004348269693235658}, {5.922348083323988, 
       0.005909598617559356}, {5.966190388504419, 0.003818993592410766}, 
      {6.014042754096381, 0.0006341323589496826}, 
      {6.043103307413291, 2.1021073735394195*^-6}, 
      {6.0704779142447505, 0.0006510453192557151}, 
      {6.121643608235555, 0.003374620053196732}, {6.150341760324702, 
       0.004276144009474575}, {6.17674349020335, 0.00410857549432052}, 
      {6.205725791653552, 0.0029475487699300697}, 
      {6.236342344783946, 0.0013082068654912378}, 
      {6.287225309640799, 0.000010486310706333579}, 
      {6.334725607854117, 0.0014054196424490482}, {6.3868428774009836, 
       0.003315868828071258}, {6.41606598423638, 0.0033233372811372758}, 
      {6.442708867761699, 0.0025617585543916853}, {6.4862429851579115, 
       0.000748163621940219}, {6.533169574767584, 
       0.00003652426787871341}, {6.584668801882206, 
       0.0014928324474891188}, {6.633013351335411, 
       0.0028699997468859674}, {6.684391517686787, 
       0.0022028425611756927}, {6.710224279058444, 
       0.0012653435663706725}, {6.738480047834445, 
       0.0003552804204249086}, {6.788572110062794, 
       0.0002192416777718355}, {6.835173104822324, 
       0.0016317908022290939}, {6.882488261219113, 0.002637616415278702}, 
      {6.927153487382173, 0.0019734812535066155}, 
      {6.967255079484452, 0.0006651837488500035}, 
      {7.010723591394853, 2.8255657637296635*^-6}, 
      {7.058120402503392, 0.0009284717453738595}, 
      {7.108296597171658, 0.0023430295370775963}, {7.1511347839930695, 
       0.0023081103888730158}, {7.198253428983238, 0.00096632517216613}, 
      {7.224509743757214, 0.00026128352299365447}, 
      {7.253129859249123, 4.600058870962415*^-6}, 
      {7.305222595781838, 0.0010886640208307237}, 
      {7.355937392498041, 0.0024210359085665117}, 
      {7.402955281583674, 0.002105409963183596}, {7.4317573032364015, 
       0.0012451550851204814}, {7.458852675421745, 
       0.0004316018469805424}, {7.509464026820632, 
       0.00013791742602422337}, {7.537870868841176, 
       0.0008327851018510412}, {7.563970180617898, 
       0.0017058469712962277}, {7.592621798911611, 
       0.0024597124618758416}, {7.622849200919057, 0.002603539279479799}, 
      {7.670213915089863, 0.001436521578796127}, {7.72091867733113, 
       0.00006895484695724281}, {7.768774811187885, 
       0.0005602893827920375}, {7.812348052847089, 
       0.0021056091918766682}, {7.863510765536243, 
       0.0028991825517335197}, {7.89239810915139, 0.002306038567897895}, 
      {7.919087460091468, 0.0013350366928853608}, 
      {7.968083686696926, 0.000023925440767066385}, 
      {8.02006370903337, 0.001000321572572218}, {8.069132011608524, 
       0.0029838325195415487}, {8.114720501859894, 0.003281778549678334}, 
      {8.16228372455926, 0.0015249368759677343}, {8.214239651277211, 
       3.212360489789264*^-6}, {8.259338273294716, 
       0.0011137769869376609}, {8.300259281919649, 0.003262452260849526}, 
      {8.34749566244883, 0.00429684833467966}, {8.39202785141221, 
       0.0026418119962673386}, {8.440688013758164, 
       0.00024720261487781183}, {8.492133864998182, 
       0.0009571228861799477}, {8.536056572458387, 0.004003987376157942}, 
      {8.584304448003166, 0.005947014297769778}, {8.63621911519986, 
       0.003510747293890411}, {8.664809173203393, 0.0013136196970106554}, 
      {8.6919132499244, 0.00007464948475667023}, {8.7170831609697, 
       0.0003708130936995671}, {8.744482930211003, 
       0.0023668245087138124}, {8.792450093168684, 0.007528656780516415}, 
      {8.837095840408518, 0.009058670519023353}, {8.87904085585558, 
       0.005482231440391248}, {8.925053040847068, 0.0005212506358669323}, 
      {8.974691205712519, 0.0023204606874369467}, 
      {9.023892766637132, 0.011713833485572964}, {9.075732028081301, 
       0.0172774736440594}, {9.119992023798092, 0.011062981852152695}, 
      {9.168442883571624, 0.0008883798172733068}, 
      {9.214076021328465, 0.004566422521709486}, {9.255570467935486, 
       0.023474961902270625}, {9.303467757219428, 0.045753598419864316}, 
      {9.348719320841834, 0.041489790788084166}, {9.390592417912364, 
       0.014528706708546653}, {9.429228514006963, 0.0003544215614562511}, 
      {9.471636728774694, 0.05132349538618979}, {9.516568339575675, 
       0.22836486113287777}, {9.564349853045943, 0.5354926909205534}, 
      {9.616475479136337, 0.8673538312393451}, {9.665709566422883, 
       0.9999701072258655}, {9.711391863973697, 0.8914761514889856}, 
      {9.756640370334578, 0.6186263250270868}, {9.797643272303958, 
       0.33833535470081416}, {9.84497482068498, 0.09979938243972968}, 
      {9.889538012947215, 0.006836749886188078}, {9.938362676702532, 
       0.011883037298304248}, {9.98991453103171, 0.04384971452247001}, 
      {10.033928280084185, 0.044469772532816296}, {10.082212461264298, 
       0.020771480840233655}, {10.13423454109097, 0.0011208463464444129}, 
      {10.163396603475023, 0.0007714752782764711}, 
      {10.189970446979837, 0.005593451996359059}, 
      {10.24161667779271, 0.016207125853187395}, {10.290514155232152, 
       0.01500130214635826}, {10.33211385833642, 0.006904758712809527}, 
      {10.378005383475898, 0.0003781201328998836}, 
      {10.425932051282032, 0.0020945177166501604}, 
      {10.470900259994123, 0.007395882454438545}, {10.512798470040874, 
       0.00914628978642901}, {10.551191887440673, 0.006463855963276596}, 
      {10.5930281730633, 0.0019278876244138857}, {10.637696839845587, 
       0.000025790023991002817}, {10.683225509193765, 
       0.0024419016320949664}, {10.725559841421635, 
       0.005389618336595436}, {10.77590073861726, 0.005278951348815609}, 
      {10.821615656607898, 0.0021795840852401136}, 
      {10.869409266980293, 0.00002417550734462326}, 
      {10.921189548938594, 0.0015200892622512369}, 
      {10.970295888034675, 0.003985418586172162}, {11.015139449681993, 
       0.003963979889635117}, {11.063105190073118, 
       0.0016420370542722196}, {11.108614902379928, 
       0.00003932777250363038}, {11.156647098552623, 
       0.0009188207520256934}, {11.208977181092495, 
       0.0030648736611629908}, {11.254555041378545, 
       0.0032231914232125837}, {11.303051105230525, 
       0.0014067078584201393}, {11.348811460418931, 
       0.00004563905440430395}, {11.390223534878475, 
       0.0005083638547130249}, {11.4161530518949, 0.0014259691658550782}, 
      {11.443494889824633, 0.002397908769005758}, {11.492414300374215, 
       0.0028190669338311377}, {11.519668701541246, 
       0.0021346916233492756}, {11.54506497751886, 
       0.0012051692898814783}, {11.572931445916755, 
       0.0003258028027182488}, {11.602747988169785, 
       4.256147066525386*^-6}, {11.628530367476694, 
       0.00036542601673445634}, {11.65652298687021, 
       0.0012242714439652837}, {11.70736894702587, 
       0.0025779209484172237}, {11.756868592387283, 
       0.002074977730162212}, {11.802578875943224, 
       0.0006039995302166906}, {11.850427689362162, 
       0.0000351665676341432}, {11.90191139066031, 
       0.0012710636015402716}, {11.950512557380854, 
       0.002460771471791627}, {11.99498956364929, 0.002079853099204066}, 
      {12.046936562202887, 0.0005119519128582679}, 
      {12.076344197865673, 0.000018943658125869223}, 
      {12.103652566340756, 0.00017514287098537194}, 
      {12.153654533449428, 0.001580660643815593}, {12.181614378993487, 
       0.00230579362947005}, {12.206971449243817, 0.002512226897088553}, 
      {12.233820762179096, 0.0021606609681922993}, 
      {12.26219286860584, 0.001336303093348213}, {12.31301128470218, 
       0.00005867667499414696}, {12.341291883534105, 
       0.0001176712280586072}, {12.36770061635495, 
       0.0007275064515958192}, {12.398531419592944, 
       0.0017494850247810668}, {12.427745083681192, 
       0.0024915764915776797}, {12.452890351390737, 
       0.002626107124924843}, {12.480249518010185, 
       0.0021658040477238088}, {12.528133029004245, 
       0.000618878312767686}, {12.555237249806765, 
       0.00005722885344048169}, {12.584038915473936, 
       0.00014436353606214023}, {12.635775200838752, 
       0.0017566545570965614}, {12.684658872552731, 
       0.0029217412201294982}, {12.730819113075725, 
       0.002135452169418367}, {12.75634594273769, 0.0011808036317938527}, 
      {12.784024607370457, 0.0002922942061759276}, 
      {12.832380276586271, 0.00031017376246473665}, 
      {12.878607793571819, 0.002086306452481239}, 
      {12.92756133901727, 0.0034342717145957684}, {12.969355559503562, 
       0.0026575465646800894}, {13.015340234800679, 
       0.0006902311286011714}, {13.062869136429052, 
       0.00011238762016285097}, {13.113941302087555, 
       0.0022373209495301287}, {13.162151441429629, 
       0.004233312480053731}, {13.20621248277404, 0.0036009838045400772}, 
      {13.257457681032117, 0.000871235105527312}, {13.286448186455102, 
       0.000020176550153625975}, {13.313333759212952, 
       0.00040893793007178804}, {13.362594898645582, 
       0.0035199745003565465}, {13.415052745872272, 0.00594493282598592}, 
      {13.459605414497252, 0.004251050158885359}, {13.501154422552997, 
       0.0011083502673333691}, {13.544496431974524, 
       0.0001633743305675198}, {13.592019760568599, 
       0.0038906779173009986}, {13.640137630954513, 
       0.008617910974148097}, {13.691664678734082, 0.007728546468648475}, 
      {13.739592071377594, 0.002156761202046846}, {13.783243778668872, 
       0.00015320938861469407}, {13.827582047254385, 
       0.005628492902161883}, {13.86855943040752, 0.013867431383258117}, 
      {13.913535020977443, 0.017106891517543178}, {13.961264390300215, 
       0.009161198861706858}, {14.002610187580263, 0.000781370727887244}, 
      {14.041384246669557, 0.002970076597319973}, 
      {14.08392058568424, 0.020790967893056327}, {14.12972552216583, 
       0.043670000142688695}, {14.15534949228481, 0.04797172373903642}, 
      {14.182694485811222, 0.04114380540225129}, {14.231922317645031, 
       0.009219956542687627}, {14.283281862761905, 0.013257273681330095}, 
      {14.312700429523447, 0.07247490317733622}, {14.339402181725081, 
       0.17562811839954257}, {14.384212162532817, 0.44262868236269753}, 
      {14.431602144389533, 0.7653427823431249}, {14.483574895673089, 
       0.985548320451931}, {14.531442641860526, 0.9445041234423514}, 
      {14.577560624860515, 0.7022040796432009}, {14.620661172062253, 
       0.40496379826386275}, {14.667949255297783, 0.13954300863921268}, 
      {14.718695760675628, 0.010434357090065259}, {14.766081424448883, 
       0.008427955112953876}, {14.811018160128345, 0.03833359422423781}, 
      {14.85135732027749, 0.04772792931088517}, {14.89528388048979, 
       0.03191084288398845}, {14.94273816147471, 0.007734860790149031}, 
      {14.993947990715943, 0.0005061905563419644}, 
      {15.023252825558576, 0.0056080430137417205}, 
      {15.05015009036159, 0.011970966688073948}, {15.07586592159997, 
       0.0163205697143538}, {15.102968802670503, 0.017114225340632828}, 
      {15.12934633887299, 0.014108691287534897}, {15.15755555981086, 
       0.008521984811477219}, {15.208395166424545, 
       0.0005559136768788943}, {15.239476712919979, 
       0.0004292349236668747}, {15.268850521341086, 
       0.0032143684538804744}, {15.295021518532183, 
       0.006427673161829744}, {15.32383999963555, 0.008855478422489871}, 
      {15.371896085739088, 0.00768416350573182}, {15.422827458678956, 
       0.0022487236803875026}, {15.470005654612349, 
       0.00001664849962049476}, {15.514191104770486, 
       0.002264529861822826}, {15.566173185106463, 0.005678705714993555}, 
      {15.61372026432561, 0.00504230326617592}, {15.639963213651487, 
       0.0032793398439834543}, {15.668600980972867, 
       0.0012635036312348177}, {15.720756395429179, 
       0.00013478430776947656}, {15.746368746466064, 
       0.001091696800298131}, {15.773420128113619, 
       0.0026053365905187144}, {15.82186040146782, 0.004321897931228599}, 
      {15.873991611880026, 0.00285259831239143}, {15.903581339003965, 
       0.0012683161173615677}, {15.93119865256798, 0.000218819493295114}, 
      {15.981245951903064, 0.0005923601119459133}, 
      {16.026865602136514, 0.0025371723100054296}, 
      {16.052090916411764, 0.0032950154866549096}, 
      {16.07952336456094, 0.003366987392735775}, {16.129394034184088, 
       0.0017068695286839612}, {16.17375599549871, 
       0.00016261979929022715}, {16.222709997413855, 
       0.0004869681459691941}, {16.273835583629573, 
       0.0023103118649286792}, {16.32182016005331, 
       0.0028676721029275436}, {16.36651494297793, 0.00164612412306133}, 
      {16.40748374501493, 0.00029518690899309164}, 
      {16.452462564553826, 0.00017273116867445081}, 
      {16.499805068052947, 0.001570759400600392}, 
      {16.55186727341116, 0.0026440452209539177}, 
      {16.59916004236559, 0.0018016601771505864}, 
      {16.65008475723256, 0.00025307938628547943}, 
      {16.678802984468806, 7.610594155263332*^-6}, 
      {16.705274487432057, 0.00038391984298640576}, 
      {16.75303818272009, 0.0018349138162494494}, {16.803593063741285, 
       0.0024853115113207076}, {16.847786940406188, 
       0.0015132224046179937}, {16.89638738758295, 
       0.00016333274886753908}, {16.925358452286225, 
       0.00003475180657386015}, {16.952854632248517, 
       0.0005244631371210774}, {17.00443617051724, 
       0.0020825399854149055}, {17.03325354071137, 0.002508233765062483}, 
      {17.059965104040554, 0.0023055714957325828}, 
      {17.08928000980417, 0.0015348905961258066}, {17.120481552432665, 
       0.000556884385363362}, {17.14773660362698, 
       0.00004463891855632732}, {17.177172587646062, 
       0.00015771240179451127}, {17.204964632574292, 
       0.0008535831587648586}, {17.23049417876878, 
       0.0017086275588848784}, {17.278961246694898, 
       0.002644242816896343}, {17.330084089463448, 0.001659934517322619}, 
      {17.378622975764515, 0.00019858731029934336}, 
      {17.406026122930577, 0.00001935651407660337}, 
      {17.431339340939168, 0.0004509287937223617}, 
      {17.47781386256999, 0.0020723704621541934}, {17.527109141149023, 
       0.0029173965696919642}, {17.57115166878971, 
       0.0018823971619724802}, {17.612433948552994, 
       0.00041386065526448465}, {17.657722643495916, 
       0.00014377696472337096}, {17.706466900236244, 
       0.001852946339471453}, {17.757989741677576, 0.003417964568475622}, 
      {17.787161966823177, 0.0031494563449935946}, 
      {17.8142601554402, 0.002176790553233335}, {17.86386935930146, 
       0.00022530304902464347}, {17.891614098498646, 
       0.00004907880488361696}, {17.91678392078436, 
       0.0007170620332624294}, {17.9643802190496, 0.0031498874588473252}, 
      {18.015894849864505, 0.004274363780678282}, {18.064536613579428, 
       0.0022963340122674125}, {18.10931392163472, 
       0.00019040541898243346}, {18.151293396990244, 
       0.000600281502517166}, {18.19632038878272, 0.0035572917039887043}, 
      {18.23882102904318, 0.005825519327360933}, {18.277593246203022, 
       0.005202449594672334}, {18.32302634386171, 0.001904306351878715}, 
      {18.372474951278466, 0.000048063104063327986}, 
      {18.419176233410337, 0.0032209399989918354}, 
      {18.46240786099888, 0.007835170276648356}, {18.506739265432703, 
       0.008941980631625449}, {18.54838095225631, 0.0051236302579882285}, 
      {18.594060688755565, 0.00037479768695443286}, 
      {18.643330735326952, 0.0026308366686973654}, 
      {18.692176320748608, 0.012080460804909371}, 
      {18.74363063911634, 0.017236558790308044}, {18.78756204981286, 
       0.01080230297843176}, {18.835643963218192, 0.0008018440326332729}, 
      {18.84955435074243, 1.091689193921813*^-11}}]}}, 
  {RGBColor[0, 0, 1], {Line[{{-18.84955435074243, 0.002500068772460527}, 
      {-18.665608785658286, 0.0011334992338905279}, 
      {-18.6233684186866, 0.0035536456362834086}, {-18.577517819138514, 
       0.0041219010338365844}, {-18.534219235310218, 
       0.0018560784265637064}, {-18.49424480157296, 
       0.00005304236367486069}, {-18.446453474557252, 
       0.0016274162840033077}, {-18.395789253362395, 
       0.0053978358719992455}, {-18.353162659651485, 
       0.005407913477005163}, {-18.306211436395795, 
       0.0017184744024044216}, {-18.25617890740676, 
       0.0002746421942354475}, {-18.228073101283687, 
       0.002507666253582886}, {-18.20235838958557, 0.005674358106329288}, 
      {-18.15248077030305, 0.009205489399751887}, {-18.105067423247466, 
       0.005044722377198743}, {-18.05567008823733, 
       0.000032354493987811494}, {-18.010881791913867, 
       0.004302089522277475}, {-17.962649832531216, 
       0.014766668107189131}, {-17.91047584396784, 0.015207326225047588}, 
      {-17.8620270299468, 0.003469161265683747}, {-17.817451809869024, 
       0.001697052135328724}, {-17.77483807143758, 0.020135747134578406}, 
      {-17.72981813000902, 0.04464575939864966}, {-17.68107969084696, 
       0.03907801261483704}, {-17.628831730338433, 
       0.0026245216212713446}, {-17.579516353032975, 
       0.03970548044304702}, {-17.534551921377258, 0.2278959223321592}, 
      {-17.50716804257892, 0.4148602427254445}, {-17.48183254266005, 
       0.6104386379360496}, {-17.45457367086558, 0.8070771132573081}, 
      {-17.424485151531808, 0.9577365560388312}, {-17.373927508595347, 
       0.9551386739561893}, {-17.346224391019966, 0.8173840061582051}, 
      {-17.32021636909422, 0.6325201324953531}, {-17.27311848867988, 
       0.28121506086686326}, {-17.22280301366509, 0.04744320370134689}, 
      {-17.193881372100165, 0.0032751985190703566}, 
      {-17.167602266289048, 0.0038823681540689687}, 
      {-17.116244856141, 0.04012260078707669}, {-17.088667308546757, 
       0.047991452877475825}, {-17.063240491223887, 
       0.042294722077793896}, {-17.035330497629936, 0.02689619168698793}, 
      {-17.00578167364603, 0.009970848151743771}, {-16.95612256862867, 
       0.0003763292257830826}, {-16.92790099661807, 
       0.0057253551089736475}, {-16.901497434980598, 
       0.012603863681987093}, {-16.85188421953751, 0.01678210939840597}, 
      {-16.804784257645398, 0.007893075155077289}, 
      {-16.762504736699942, 0.0006170189504289477}, 
      {-16.716415494395974, 0.002050336969756142}, 
      {-16.66644398110209, 0.008272988124607654}, {-16.638523911325585, 
       0.0091608792592633}, {-16.613242297594184, 0.007552921247490406}, 
      {-16.567607933200655, 0.002128801860305895}, 
      {-16.5175829949037, 0.0002111525879187523}, {-16.489459241560915, 
       0.002011017525480497}, {-16.46323777029213, 
       0.0042751726098593425}, {-16.435546077907, 0.005808570295847296}, 
      {-16.405899456654005, 0.005514811419784061}, 
      {-16.378299787613585, 0.003688609397428643}, 
      {-16.352188385955326, 0.0015881554390884305}, 
      {-16.30328060258438, 0.0000799702331932279}, 
      {-16.275296415903714, 0.0012209256495585748}, 
      {-16.245605856236487, 0.003064681005027776}, 
      {-16.220257920754435, 0.004158167897608453}, 
      {-16.192315578012856, 0.004157748021917281}, 
      {-16.162355135952, 0.002833067969954607}, {-16.130100123254444, 
       0.000954177827095421}, {-16.09965034517425, 
       0.00002023095387414036}, {-16.071768369401255, 
       0.0003919446470583271}, {-16.021118279488412, 
       0.002707465406807044}, {-15.974056723860102, 
       0.003305177972792236}, {-15.922412680199201, 
       0.0012070783713628984}, {-15.89352590795555, 
       0.00017556808364576747}, {-15.86731307320415, 
       0.00006239547281053469}, {-15.839652422712097, 
       0.0008139764316377594}, {-15.814182569008205, 
       0.0018764149165476085}, {-15.786224077190521, 
       0.002768529322615867}, {-15.756662853429546, 
       0.0028262105538307174}, {-15.706950806809605, 
       0.0011285130933936021}, {-15.67871841218911, 
       0.00020671390970440357}, {-15.65233949036305, 
       0.000030443410556899963}, {-15.602574396997307, 
       0.0014523293557763323}, {-15.575294112218788, 
       0.0023493408668812488}, {-15.549662198481915, 
       0.002642154372186743}, {-15.504490022611396, 
       0.0016001031659752258}, {-15.45458802547028, 
       0.00008225326764306541}, {-15.428292105095732, 
       0.00010080989303440061}, {-15.400584425177605, 
       0.000810517806018811}, {-15.351029328342998, 
       0.0023607802497140206}, {-15.32340999176693, 
       0.002460920356699632}, {-15.297692715943736, 
       0.0018974936037911016}, {-15.269686300531129, 
       0.0009181632142666268}, {-15.239301508732048, 
       0.00011045063545048021}, {-15.188336855385627, 
       0.0006271618870913466}, {-15.140183828172649, 
       0.0022128979068574543}, {-15.093306052981319, 
       0.002263486004688776}, {-15.050048989201336, 
       0.0008568552334872893}, {-15.003285010782603, 
       7.97142357164565*^-6}, {-14.951802586019893, 
       0.0013362449423547065}, {-14.925895727260983, 
       0.0022280586114291684}, {-14.898041465537563, 
       0.002644352039106909}, {-14.84770263531336, 
       0.0014902887257693584}, {-14.798917349063657, 
       0.000049003956913882604}, {-14.753648152272307, 
       0.0006946570960997901}, {-14.72592323467875, 
       0.0018083395076825787}, {-14.6998179932305, 0.0026857328487771}, 
      {-14.651035058102387, 0.002461660894241584}, 
      {-14.607566860514067, 0.0007356382688659828}, 
      {-14.56056963734895, 0.00008814733070036527}, 
      {-14.510354845887045, 0.002003784753301335}, 
      {-14.464178092532787, 0.0034360502089560963}, 
      {-14.422098467518541, 0.002443633055615346}, 
      {-14.382833144628135, 0.0005812581444275681}, 
      {-14.339750658241755, 0.0001772542152830588}, 
      {-14.293589149998844, 0.0024352418941461567}, 
      {-14.245180389345803, 0.004327067067016235}, 
      {-14.19934471229572, 0.0028070908626942575}, 
      {-14.154528646498022, 0.00030038422472168305}, 
      {-14.113458435851184, 0.0005838025680655578}, 
      {-14.068293576633906, 0.0039046494959922677}, 
      {-14.019630086232867, 0.005920107630815126}, 
      {-13.976730490021112, 0.003496827441156098}, 
      {-13.931587193640624, 0.00020730702575124003}, 
      {-13.881920530953744, 0.0021030361299045446}, 
      {-13.835735140775169, 0.007583312449934253}, 
      {-13.78505397022742, 0.0084471060961833}, {-13.756693692294395, 
       0.005255246943195026}, {-13.730937634560055, 
       0.0018246791888651768}, {-13.678738122143061, 
       0.0014320107841071495}, {-13.630633787569744, 
       0.011117391693110778}, {-13.605482849867881, 
       0.015885370161161688}, {-13.57783068869664, 0.01714077872183906}, 
      {-13.54895610417145, 0.012874818977020776}, {-13.52195518308252, 
       0.005874230306067996}, {-13.472254622939484, 
       0.0008827850230625914}, {-13.426865088420161, 
       0.018983622105508358}, {-13.40179225256851, 0.03424535899375018}, 
      {-13.374473910979066, 0.04625965728396319}, {-13.324761713839502, 
       0.03505571320353523}, {-13.275148680063882, 
       0.0012524606660951855}, {-13.228495487950763, 
       0.04238474896003688}, {-13.186603626887054, 0.2163664803676435}, 
      {-13.141370352914231, 0.5370700700790509}, {-13.091857898769092, 
       0.8825797682060039}, {-13.03964478509041, 0.993015775636123}, 
      {-12.995065957926789, 0.809368804641771}, {-12.946222713665442, 
       0.4459159391932684}, {-12.900299938729885, 0.14943381763854535}, 
      {-12.858505011032, 0.0181547822218417}, {-12.810261301249042, 
       0.008198194276540527}, {-12.764642002492975, 0.04103172922295978}, 
      {-12.722465991301695, 0.04559465392742318}, {-12.683515833459522, 
       0.02570726889088007}, {-12.640764188246031, 
       0.0039879708472338625}, {-12.595428511325467, 
       0.0018185646076759273}, {-12.547796728922073, 
       0.01346248253208317}, {-12.495788280140156, 0.016129486928410274}, 
      {-12.446663149497299, 0.006028500390214785}, 
      {-12.401041472353471, 0.00003756125137412278}, 
      {-12.355893986655094, 0.0034213953777960746}, 
      {-12.31494626045018, 0.008400391059336959}, {-12.26767883249339, 
       0.007963666171385813}, {-12.223136511300009, 
       0.002725213674790836}, {-12.174422721740491, 
       0.0000417326240790684}, {-12.122942289672638, 
       0.003471753206046874}, {-12.07898988176361, 0.005928326989358954}, 
      {-12.030730143475708, 0.003875878987256964}, 
      {-11.978780435864717, 0.00028762362883462975}, 
      {-11.949645432595963, 0.00016019041675550635}, 
      {-11.923072653231312, 0.0013585438412528994}, 
      {-11.871451056913905, 0.0041302897790881}, {-11.822533530882994, 
       0.003387411211292072}, {-11.7810287202923, 0.000995853435698629}, 
      {-11.735201176478467, 0.0000710960539280496}, 
      {-11.687339642318017, 0.0019594128073869566}, 
      {-11.642392684536324, 0.003428875203664669}, 
      {-11.600551334413746, 0.0025358891351653684}, 
      {-11.562175956446318, 0.0007563576173676065}, 
      {-11.520045240744473, 0.000033602694219851406}, 
      {-11.47567495331534, 0.0013949330202961852}, 
      {-11.430550122577918, 0.0028616586309632946}, 
      {-11.3823275002218, 0.002154828034339488}, {-11.33681724189352, 
       0.00040717394996034307}, {-11.295452327588256, 
       0.00011519432470636846}, {-11.246793627252316, 
       0.0016741842437525808}, {-11.219345049609792, 
       0.0024786613662279543}, {-11.194029270260959, 
       0.002611247362865625}, {-11.147512833769198, 
       0.0013336017470065619}, {-11.098249716785899, 
       0.000019298122855431354}, {-11.050395565627968, 
       0.0008204570332481938}, {-10.998213140920235, 
       0.0024077389817286636}, {-10.94892624203154, 
       0.0019324498894521256}, {-10.903214593449912, 
       0.0003996703822739239}, {-10.857917121655548, 
       0.0001448217809429819}, {-10.816887504709149, 
       0.001377952180971977}, {-10.769524909131054, 
       0.002507966193395517}, {-10.724951637423525, 
       0.0017398008543550655}, {-10.676073229530013, 
       0.0001840865860772304}, {-10.62448679025564, 
       0.0005366437029124464}, {-10.580443338500167, 
       0.0020978815461235247}, {-10.532147349411565, 
       0.002513856483871634}, {-10.480090224283865, 
       0.0008218477146714646}, {-10.45091507128992, 
       0.00007084798490575123}, {-10.424340731564, 
       0.00013574851825715127}, {-10.37268260200454, 
       0.0019427439411784432}, {-10.323794861370079, 
       0.0029098850644386537}, {-10.282149161419735, 
       0.001749765767861157}, {-10.236226654847506, 
       0.00012517184370871095}, {-10.188268448953135, 
       0.000718317100677739}, {-10.143289976983041, 0.00276871482055075}, 
      {-10.101364235915991, 0.003370421811396512}, 
      {-10.062962107301704, 0.0020000442194373917}, 
      {-10.02080011089653, 0.00019797368405183386}, 
      {-9.976455294884312, 0.000622466878454733}, {-9.931236900161625, 
       0.003161159793946255}, {-9.882977888905117, 0.004240378190890248}, 
      {-9.837435693556893, 0.0020485626807840145}, 
      {-9.796096297556854, 0.00007982320401653024}, 
      {-9.747400467194362, 0.0015733799510691657}, 
      {-9.719949772653647, 0.0037803608191883955}, 
      {-9.694665381362316, 0.005461365070647055}, {-9.648175089535544, 
       0.005121279172940291}, {-9.59900444268232, 0.0011479149888256554}, 
      {-9.550927079399598, 0.0005434549436434648}, 
      {-9.49857030494838, 0.006165348079386917}, {-9.449121304138167, 
       0.009144677830949001}, {-9.403319694020295, 0.004773123866559287}, 
      {-9.362199887620465, 0.00024055250478657953}, 
      {-9.316760424758542, 0.003242613346496307}, {-9.269302662599225, 
       0.013570927598706983}, {-9.22469860228289, 0.016935562701146833}, 
      {-9.175655217504808, 0.006822980821622751}, {-9.123962758746181, 
       0.0006662399638789262}, {-9.079828256551401, 
       0.017302515816353073}, {-9.031496184869793, 0.0441291368739318}, 
      {-8.979331627589872, 0.03791900424750148}, {-8.950116395542938, 
       0.016121106445245954}, {-8.923540612136556, 0.000785146745798173}, 
      {-8.871846129411718, 0.06061413294787581}, {-8.822988353002417, 
       0.3030555786093061}, {-8.777649698350482, 0.6441364273209367}, 
      {-8.735183981746182, 0.9160785203123889}, {-8.690893649676068, 
       0.9945152672044527}, {-8.64211927987541, 0.7894874066214693}, 
      {-8.601189489725522, 0.4832548340077522}, {-8.556521343118808, 
       0.18071818467599596}, {-8.514330410199442, 0.027924516295328633}, 
      {-8.475168116220411, 0.0010134012211387609}, 
      {-8.42918939431662, 0.03193692652464324}, {-8.380183508960283, 
       0.047324994866921835}, {-8.334609847628533, 0.026322320380313416}, 
      {-8.293296404987258, 0.004777011789116396}, {-8.244904237624745, 
       0.0019302955206399058}, {-8.192567009113548, 
       0.014550448371822256}, {-8.143149975916572, 0.01576814336928756}, 
      {-8.09769268901473, 0.006232955639367361}, {-8.047699955920374, 
       3.8444546319088*^-7}, {-8.000349785949032, 0.004203001813835991}, 
      {-7.957842333792496, 0.008865321440187892}, {-7.911612221129031, 
       0.0073658488895921356}, {-7.861371559742039, 
       0.0014951828731724365}, {-7.836003484714855, 
       0.00005837257297516965}, {-7.8080074262169825, 
       0.0006655880403245744}, {-7.7585723091965395, 0.0046445963993738}, 
      {-7.712170939226196, 0.005743359051998156}, {-7.668150660662796, 
       0.0028333913729172854}, {-7.621813671223943, 
       0.00009472227671320171}, {-7.582251142498489, 
       0.0008485586511037892}, {-7.538982953586437, 
       0.0034385564956699575}, {-7.492222376660944, 
       0.004150404287462498}, {-7.442276846560467, 0.001611507615035445}, 
      {-7.395141538897788, 7.948146635891852*^-8}, 
      {-7.352321166407689, 0.0012141494611519004}, 
      {-7.301276072469872, 0.003320656774810875}, {-7.275543984923817, 
       0.003328884952008714}, {-7.247244072081168, 
       0.0023848480542901554}, {-7.197195701490249, 
       0.00025601116663812257}, {-7.150380402106002, 
       0.00044489288139525724}, {-7.1220878448025475, 
       0.0015528209498301244}, {-7.095233660130907, 
       0.002557483499809636}, {-7.044854670011608, 0.002562366555839864}, 
      {-7.016710221260323, 0.001524657616033047}, {-6.990620490746507, 
       0.0005191470468288973}, {-6.961988093661075, 
       2.672625776893177*^-6}, {-6.9315107478260165, 
       0.0004318512778441635}, {-6.879868221769322, 
       0.0022361076904748416}, {-6.850796346185303, 
       0.0026437795835844336}, {-6.824089196512909, 
       0.002241744060482472}, {-6.775881045022847, 
       0.0005604957421935686}, {-6.748535684015819, 
       0.00002049194992999533}, {-6.723044854008295, 
       0.0001931717024595757}, {-6.678683732258675, 
       0.001600921410293152}, {-6.631200008280947, 
       0.0025118028216501082}, {-6.580485600061236, 
       0.0012977865328308027}, {-6.534315375039913, 
       0.00004648030956015846}, {-6.487419525943842, 
       0.0006626661057952953}, {-6.4434595229058385, 
       0.002136808130453896}, {-6.39523335177861, 0.0022997964543710996}, 
      {-6.343323676487401, 0.0006270774157177084}, 
      {-6.31741477659269, 0.00005364775747121563}, 
      {-6.289116422450996, 0.00017447572430747416}, 
      {-6.237555315995503, 0.0018679459948719394}, 
      {-6.187357391585111, 0.0025851707601148573}, 
      {-6.14072492927013, 0.0012147515505572782}, {-6.093241448392221, 
       6.591627688620503*^-6}, {-6.048481619632892, 
       0.000893166371439938}, {-6.007799256111848, 
       0.0024759846743365437}, {-5.964793021224497, 
       0.0027968612654274143}, {-5.917870324636741, 
       0.0011384828361441232}, {-5.874672336193271, 
       3.500762214562485*^-6}, {-5.828184687244652, 
       0.0011558126889878696}, {-5.777125365215395, 
       0.0032705721335720833}, {-5.75075565225932, 
       0.0033599610881440505}, {-5.722053199131825, 
       0.0024321916152659807}, {-5.669849631348178, 
       0.00017340958804811475}, {-5.619027439061409, 
       0.0009722607297977968}, {-5.571977608409652, 0.00363247542161621}, 
      {-5.521292509011047, 0.003911146830462529}, {-5.492427136561437, 
       0.002361610158623813}, {-5.465311121904446, 
       0.0007411668999759494}, {-5.4368622727798455, 
       2.711375386378862*^-7}, {-5.410761894304133, 
       0.0007311153717729221}, {-5.382107691460864, 
       0.002786505741879714}, {-5.351920917514257, 0.005080346509738197}, 
      {-5.304452709511787, 0.005455933464586781}, {-5.253710064755422, 
       0.0014936713323306548}, {-5.205820930350116, 
       0.0003026390920633735}, {-5.162280271375917, 
       0.004457342672479681}, {-5.11107886225665, 0.009158439895166536}, 
      {-5.08219125783731, 0.00820172569123983}, {-5.055539977309898, 
       0.005067604283045962}, {-5.006577465962711, 
       0.00004396431096360141}, {-4.954707719858188, 
       0.005641097062726047}, {-4.910401358257116, 0.015190384802278044}, 
      {-4.863201686382346, 0.015597797255177365}, {-4.811424430531791, 
       0.0032665061518700254}, {-4.7633881374071, 0.0026968308365083195}, 
      {-4.714274714899688, 0.026823301472598763}, {-4.668039357785246, 
       0.04753938477396601}, {-4.626524243638686, 0.03608575716479582}, 
      {-4.581647295199063, 0.0037653270358173462}, 
      {-4.556327809278546, 0.002869741852048645}, {-4.528555003094638, 
       0.04273891730702827}, {-4.499557105711755, 0.14813792828433026}, 
      {-4.4725037985788445, 0.30703448768589414}, {-4.419997201162566, 
       0.702294633393571}, {-4.372156406518191, 0.9660968861519547}, 
      {-4.324653269491892, 0.9565637140495619}, {-4.279683717868528, 
       0.7014555998707181}, {-4.232579254171385, 0.3437424962788148}, 
      {-4.180621223539647, 0.06918376064589142}, {-4.135468855420017, 
       0.00020598193532493672}, {-4.093108722350802, 
       0.021248919166694042}, {-4.04838317591606, 0.047014446225433326}, 
      {-4.000202290502675, 0.0356162985605261}, {-3.957782733183448, 
       0.010788764749908485}, {-3.9131531547788496, 
       0.00001668271096940763}, {-3.87504824143482, 
       0.006554156765226606}, {-3.83339517445469, 0.01605732638913906}, 
      {-3.783813866534389, 0.014227018244647222}, {-3.738794090014729, 
       0.004339196353727483}, {-3.686826741351179, 
       0.00027316521218884675}, {-3.6378003598708153, 
       0.005944429351674639}, {-3.5923692242596474, 
       0.009211473536080173}, {-3.550510319511052, 0.00609109652239032}, 
      {-3.50525219972413, 0.0009753208204422424}, {-3.4559502754058284, 
       0.0007950864795061822}, {-3.4062410160454517, 
       0.004816334817741348}, {-3.359082657887342, 
       0.0056330395134935275}, {-3.313171914025581, 
       0.002415589989937666}, {-3.270634348890931, 
       0.0000708484102885317}, {-3.2200308991759568, 
       0.0015565910289143034}, {-3.1742413806091228, 
       0.004056330448329353}, {-3.148823569603288, 0.004276844659038565}, 
      {-3.1213836373603345, 0.003317595826152533}, 
      {-3.0716888587177973, 0.0005586323449466711}, 
      {-3.0281814798190028, 0.00021540988760010784}, 
      {-2.980521346445914, 0.0023026093401351958}, 
      {-2.93076145883599, 0.0034014986996104175}, {-2.8843995613545776, 
       0.0017686132850701086}, {-2.840899469734068, 
       0.00011883230913175072}, {-2.8013170733036366, 
       0.000419324138207231}, {-2.7556271918132125, 
       0.002221585431344066}, {-2.71243109384026, 0.0028943066510519542}, 
      {-2.6653731392747098, 0.0014644735285222936}, 
      {-2.6135348135113263, 7.464260212094283*^-6}, 
      {-2.5874566223344178, 0.000278495515274104}, 
      {-2.559400705367545, 0.001202081434384635}, {-2.5086811037640913, 
       0.0026201438226268648}, {-2.458320675993551, 
       0.001729216146330808}, {-2.4104426914814203, 
       0.00017008174723051486}, {-2.3674668621723205, 
       0.0003176235001294956}, {-2.320551203823451, 
       0.0018766336572602765}, {-2.2917212999131613, 
       0.0024841846042683168}, {-2.2645587437109156, 
       0.002323501138465717}, {-2.213784646034234, 
       0.0007081214143225595}, {-2.1853090054659687, 
       0.0000555727287966227}, {-2.1591069443523736, 
       0.00012865157183186045}, {-2.130344017136489, 
       0.0009028321471227339}, {-2.099953371337147, 
       0.001957134786951172}, {-2.0494599905753272, 
       0.0023760998657890715}, {-2.0023143183082177, 
       0.0009250791672129675}, {-1.950586477641461, 
       0.000025174201634092686}, {-1.9215788175055333, 
       0.0006343431129765928}, {-1.8951272706462419, 
       0.0015990933742613916}, {-1.7965633454697005, 
       0.0014350219203743042}, {-1.744801328364765, 
       0.000013469348428257572}, {-1.7187731843634764, 
       0.0002534261716047262}, {-1.690298230957038, 
       0.0012243086474623824}, {-1.6383302475866717, 
       0.0028858455432029684}, {-1.5899747778736986, 
       0.0020592919213871783}, {-1.5426563301483749, 
       0.0002566012496489391}, {-1.4979794155234685, 
       0.0003847555176003191}, {-1.4471800757459679, 
       0.002619429452065809}, {-1.4010167224837806, 
       0.0033623546809823917}, {-1.3513090189352377, 
       0.0014031005021546102}, {-1.3232714985052179, 
       0.00025589830747689725}, {-1.2974175091414983, 
       0.00004563097341134916}, {-1.2462112872256914, 
       0.0022943319604043465}, {-1.216776225418112, 
       0.0038560479418133166}, {-1.1898776239682287, 
       0.004321273143255197}, {-1.1615201049662451, 
       0.0034745888282901732}, {-1.1310521613357685, 
       0.0016303187214577106}, {-1.1028173523076885, 
       0.00023634683330864135}, {-1.07600965023872, 
       0.00013815848391483245}, {-1.028192131591181, 
       0.0031201716887492613}, {-0.9848882354115465, 
       0.005819715562016136}, {-0.9349002236264159, 
       0.004159224572132087}, {-0.8878651912832816, 
       0.00045603289299541556}, {-0.8441646625608961, 
       0.001011939939014469}, {-0.8040062721344756, 
       0.005519519404363883}, {-0.7599209990926755, 
       0.009182429207519757}, {-0.7134021868234646, 
       0.006115936099276093}, {-0.6662761870132589, 
       0.00045703432422433937}, {-0.6158172773839293, 
       0.0034473590711397105}, {-0.568192817708967, 
       0.013828145513508487}, {-0.5248221745784565, 
       0.016929429075958118}, {-0.47390759771772956, 
       0.006305171250330922}, {-0.44515748254498927, 
       0.0005361807719513977}, {-0.418589811729973, 
       0.0015532436351720618}, {-0.3698217875442893, 
       0.023450169372025237}, {-0.318073924679747, 0.04754831602000031}, 
      {-0.2724517443364409, 0.03325497038588366}, {-0.22447681796134644, 
       0.0009726237715733368}, {-0.18351544855848778, 
       0.0318033863859834}, {-0.1387624838914016, 0.20567552058232544}, 
      {-0.09068936293401364, 0.5447753083538156}, {-0.04535962812271524, 
       0.8651599917542245}, {0.006887922698269162, 0.9967130064909795}, 
      {0.05430475623878157, 0.8114264934258554}, {0.09654121772071338, 
       0.4992357376195502}, {0.14120420349718416, 0.19197216976606718}, 
      {0.1901860460653558, 0.019694209070380112}, {0.23529375660077237, 
       0.005651441913575599}, {0.2767207121163347, 0.03614686228856318}, 
      {0.31543256156896426, 0.047827754755961946}, 
      {0.35790572182499963, 0.030800256972074558}, 
      {0.40347975077284015, 0.005853050139387643}, 
      {0.4291974593234747, 0.00018764097479831212}, 
      {0.45654478234100365, 0.002237936399930716}, 
      {0.5056862555160287, 0.014251005536397899}, {0.5329431721620381, 
       0.017305736706117243}, {0.558556170836461, 0.01549170758907013}, 
      {0.5866525366265153, 0.009798727456417905}, {0.6169688568792991, 
       0.003242001869883963}, {0.6683648621852427, 
       0.0005998648572373113}, {0.6942189862902342, 0.00347884662953292}, 
      {0.7225266141977805, 0.007231092422042553}, {0.7726880921142727, 
       0.008673686885357636}, {0.8194006476620526, 0.003577319285313526}, 
      {0.8687923868256834, 2.1324305552453606*^-6}, 
      {0.9154648152331789, 0.0024732991340567488}, 
      {0.9573671124475884, 0.005581792957751103}, {1.0028332618889648, 
       0.0050315001628157725}, {1.0523584499934042, 
       0.001242816353648291}, {1.0773376940535266, 
       0.0001080099073725539}, {1.1048405928302485, 
       0.0003005350209804408}, {1.153455098958385, 
       0.0030339482919614037}, {1.1989803405435315, 
       0.004302137758503766}, {1.2483546696735441, 0.002163484024302385}, 
      {1.2754521371952514, 0.0006743031747833909}, 
      {1.3009696134444333, 0.000012788335497235965}, 
      {1.3506195095768332, 0.00136878426658601}, {1.395619482343345, 
       0.0032617255031262833}, {1.4217374498267414, 
       0.003369013227807331}, {1.4493195814538504, 0.002528163504518377}, 
      {1.49870723885983, 0.00036291124901357245}, {1.5262006309600833, 
       9.138976701052366*^-6}, {1.5518583010972655, 
       0.0005232344525667215}, {1.5800101596001792, 
       0.0016508853445136073}, {1.610177559544496, 0.002701288106053337}, 
      {1.6604773082413564, 0.0023949433358807933}, 
      {1.6888922716467771, 0.0012824077796808123}, 
      {1.7151716233300442, 0.000343525944179039}, {1.7633902073818333, 
       0.0003014621210204808}, {1.8145967122870725, 
       0.0020782877812809404}, {1.860291664260955, 
       0.0025606216232115604}, {1.9031741567538267, 
       0.0012958942421331266}, {1.9502164832059319, 
       0.000027952180987149305}, {2.000908897525859, 
       0.0008759865380278268}, {2.043979137303411, 
       0.0022714059788509046}, {2.0899741356784727, 
       0.002224991944792806}, {2.140434233380091, 0.0005719155712362356}, 
      {2.18736301843476, 0.00007953500308059717}, 
      {2.212753601470306, 0.0006747690870221866}, {2.2402674116977668, 
       0.001642333193358784}, {2.2901933237598184, 
       0.0024952927438092747}, {2.3387966259580564, 
       0.001241057312824762}, {2.3835922040711384, 
       0.00004158148041751317}, {2.425530450522405, 
       0.0005465540299086559}, {2.464751993867529, 0.001953381162253509}, 
      {2.5077831968914173, 0.002626253186730733}, {2.5539936138591193, 
       0.0014097538014794947}, {2.602353038020624, 
       0.00003293245952382349}, {2.648245089632761, 
       0.0007778053255407527}, {2.689440858579345, 
       0.0023956136003028122}, {2.734331426537729, 0.002808460548153377}, 
      {2.7600899183204155, 0.0020527677367586385}, 
      {2.7872566331681417, 0.0009200897664213072}, 
      {2.835867519891136, 0.00004679799295972469}, 
      {2.8881856924558007, 0.0019530123709234305}, 
      {2.9178594455889906, 0.0031527647185591407}, 
      {2.945515443531154, 0.0034049013523415883}, 
      {2.99573875439552, 0.0015460483967229576}, {3.041453091508994, 
       9.581526238662903*^-6}, {3.066750040780515, 
       0.00037574017925187425}, {3.0942208969232596, 
       0.0017204506413343022}, {3.1441241088906424, 
       0.004192507929515138}, {3.188644629205866, 0.003461056459002646}, 
      {3.2377030251533117, 0.0005897972305432518}, 
      {3.288934719102609, 0.0007258760812418123}, 
      {3.33694990128723, 0.004341067843982044}, {3.3817373014430823, 
       0.005895434087915287}, {3.422732049950129, 0.0035079309171690666}, 
      {3.470049493689713, 0.00014322137170244372}, 
      {3.5150484752714415, 0.0018358261195928355}, 
      {3.5672969296617865, 0.00791077412012694}, {3.614690705476145, 
       0.008435484658358588}, {3.6409650211559894, 0.005519559477563269}, 
      {3.669398973394449, 0.0017398511421035164}, {3.7209592694733167, 
       0.0014451010633372658}, {3.764941567384731, 0.010193813852878906}, 
      {3.812111174772274, 0.017302763146400203}, {3.86386772905125, 
       0.009555347698695937}, {3.912207854356421, 
       0.00003932431802893558}, {3.9416873863808295, 
       0.004213962667499065}, {3.96962602206023, 0.01716440605506082}, 
      {3.9950158214295275, 0.032615097336086606}, 
      {4.022000881050387, 0.04539522343982931}, {4.05085901909689, 
       0.04645683293905254}, {4.077569978930039, 0.033167481326455105}, 
      {4.106665077774487, 0.010800978087982423}, {4.138043248977574, 
       0.0007128651488905169}, {4.188983274783603, 0.09889162149214918}, 
      {4.2368269370259055, 0.3742571040062456}, {4.266213788234218, 
       0.5992870281833196}, {4.293968755797023, 0.800962732488944}, 
      {4.345911934482051, 0.9988984949702592}, {4.391374957886142, 
       0.8861991014781543}, {4.440679855544872, 0.5440504873638426}, 
      {4.489867415033658, 0.1988423895867122}, {4.541965563045878, 
       0.01685953192619785}, {4.5871570319576, 0.006819523004933611}, 
      {4.636889143725343, 0.04200491082686699}, {4.682115922416641, 
       0.04394008138698502}, {4.724447413556337, 0.02055725033861937}, 
      {4.750038083913424, 0.0071628764133258825}, 
      {4.777946675173031, 0.00027053949729017966}, 
      {4.828757645334379, 0.007627467349875652}, {4.878224752086118, 
       0.017150439008286625}, {4.924108986692119, 0.012603161752635414}, 
      {4.949834563369908, 0.0067170805640672715}, 
      {4.97763801516118, 0.0015950475947329936}, {5.028020541942954, 
       0.0014798729974543384}, {5.058277714325755, 0.00544430754537835}, 
      {5.086091048982181, 0.008508271896131124}, {5.111683224830479, 
       0.009144827849298215}, {5.138696501536778, 0.0073014231840701025}, 
      {5.189811287235004, 0.0013618702478155936}, 
      {5.238190566114763, 0.00047719974095341926}, 
      {5.264912755648695, 0.002433756296225635}, {5.293954974873247, 
       0.004843718720997261}, {5.344754315190322, 0.005461994669474196}, 
      {5.393205047681956, 0.0018942371065300528}, 
      {5.44463221456092, 0.0000542199494985993}, {5.4885373180890875, 
       0.0021126280008546875}, {5.536957014921282, 0.004296966095414108}, 
      {5.564555600859915, 0.003934900039620481}, {5.59358647226026, 
       0.0024478419988130202}, {5.645462721353715, 
       0.00007074581620353751}, {5.67440166432161, 
       0.00029021446464620265}, {5.7013018554343535, 
       0.0014078540870612099}, {5.732706783531324, 
       0.0028773540184049047}, {5.76232873424883, 0.003441544359986218}, 
      {5.788058204465636, 0.0029640892773433658}, 
      {5.815925211362583, 0.001742738960965642}, {5.864581395701556, 
       0.00003983298240815275}, {5.892188416411592, 
       0.0002477148824284273}, {5.921390561116117, 
       0.0012871572899649734}, {5.973722783633281, 0.002908640946140515}, 
      {6.021779985230997, 0.001982371779024927}, {6.074121023235947, 
       0.00014140614748048852}, {6.123555393634445, 
       0.0005956603200918242}, {6.169348892344818, 
       0.0022228658814289516}, {6.210456180983907, 
       0.0025570203884752716}, {6.255887213454329, 
       0.0011893736514846291}, {6.303336394504174, 
       8.617688974193005*^-6}, {6.347937685258892, 0.000777809075742205}, 
      {6.396966179367156, 0.002333723733379123}, {6.448649077864739, 
       0.0019929210053980734}, {6.492775369788574, 
       0.0004994659126678472}, {6.541104194809568, 
       0.0001353732899561805}, {6.593259064351563, 
       0.0017474441744245403}, {6.62247068537908, 0.002448169549693269}, 
      {6.649046343392767, 0.0023967366932518257}, 
      {6.700737555546064, 0.0008122836946099346}, 
      {6.749598041149768, 0.000028102459613780787}, 
      {6.7913721905153634, 0.001098019430774393}, 
      {6.837381104630807, 0.0025299941257773857}, 
      {6.885427266005486, 0.0020710748485718417}, 
      {6.930434269243353, 0.00046305159026804226}, 
      {6.972436787559276, 0.00009110229584238081}, 
      {7.0108631292781185, 0.0012807650123709325}, 
      {7.055216248978823, 0.0027989222529827096}, 
      {7.097374949022984, 0.0024947582026535057}, 
      {7.142678478218073, 0.0007075132129231652}, 
      {7.190970451376008, 0.00012188944504208702}, 
      {7.236541561315209, 0.0018781038077909204}, 
      {7.277857603651945, 0.0033661322285821298}, 
      {7.326587069768242, 0.002480036252768306}, {7.354039586330968, 
       0.0011313375542242985}, {7.379295356267887, 
       0.00018599475543314346}, {7.425761709129767, 
       0.0007373710950962572}, {7.474848202954828, 
       0.0034975398422858474}, {7.523129386181594, 0.004086512806410427}, 
      {7.550408445818433, 0.002790899368688204}, {7.575645114234207, 
       0.0012125577560521416}, {7.621943129546683, 
       0.00009732507139915809}, {7.671125341057101, 
       0.003080482633570457}, {7.7150001487822975, 0.005822016264521964}, 
      {7.756187326350996, 0.004812984542284503}, {7.801369414971313, 
       0.0010922715150614721}, {7.850072396844054, 
       0.0006271653838576549}, {7.898893347784743, 0.005905686115478774}, 
      {7.926557422620334, 0.008639173511135327}, {7.952293504328525, 
       0.00909468434704681}, {8.00432502083809, 0.003650691610848736}, 
      {8.03344747685176, 0.0004616225260765099}, {8.059907104550998, 
       0.0004117640491349275}, {8.10739391640158, 0.008453334795984447}, 
      {8.158867709293627, 0.017211264633233775}, {8.207473823649703, 
       0.011194836130233374}, {8.252285931458964, 0.0008016708765875628}, 
      {8.294103243328514, 0.0050543231986261115}, 
      {8.339024051256002, 0.029050585949547077}, {8.381427021686344, 
       0.04750901500860136}, {8.420168617140067, 0.03797361414819102}, 
      {8.465494135306203, 0.005093118878165926}, {8.514900214408028, 
       0.029028831981590043}, {8.561564114647533, 0.20871874011448685}, 
      {8.60482640155054, 0.5114474895492092}, {8.653710468510337, 
       0.8610698757725888}, {8.699697934396552, 0.9999993458337155}, 
      {8.740991421348241, 0.8876640692189842}, {8.785597761864901, 
       0.5828392308281496}, {8.83440302171002, 0.2300185645310596}, 
      {8.885892476661333, 0.026726520167271787}, {8.92985328076746, 
       0.0029768976371479395}, {8.978040101840385, 0.03712052169944265}, 
      {9.029899387564335, 0.04468764947734696}, {9.07781278156234, 
       0.01848272633924644}, {9.102828070745007, 0.0060211038652956215}, 
      {9.130401693834846, 0.00010687284638782155}, 
      {9.159197189572822, 0.0028103108757495036}, 
      {9.186193190934944, 0.00965335180828566}, {9.235696943260466, 
       0.01732399661972595}, {9.281022759240447, 0.011052184898013642}, 
      {9.330786985377724, 0.0012045131478187767}, 
      {9.383107514192483, 0.0020668002438119283}, 
      {9.427317265583204, 0.007761280420747279}, {9.474481681571131, 
       0.008543539024300557}, {9.518990217295324, 0.003602617436842214}, 
      {9.55937580099555, 0.00016544264346309004}, 
      {9.60696724588129, 0.0017636054141521465}, {9.658486526832442, 
       0.0056349787835496545}, {9.707133052498476, 0.004741132022851265}, 
      {9.751923355010664, 0.0012581552237155651}, 
      {9.799786604305663, 0.000158805577935841}, {9.851134371681114, 
       0.0029089523703498994}, {9.899601516878878, 0.004293075856996312}, 
      {9.94382532495837, 0.002427124518001915}, {9.995636142551321, 
       0.00006665971712635479}, {10.02492184845174, 
       0.0003082810498543582}, {10.052036995287557, 
       0.0014497207443044282}, {10.101760361571058, 
       0.003375945734982479}, {10.126878349291259, 
       0.0032736676834872968}, {10.154624314779824, 
       0.002280431625895125}, {10.181439926171016, 
       0.0010044185266915786}, {10.209693125125888, 
       0.00010357726014270019}, {10.260221974736632, 
       0.0008329054606973686}, {10.288385117625127, 
       0.002004834157688391}, {10.314606824520796, 
       0.0027953777812504466}, {10.343379798995947, 
       0.002815710251722275}, {10.374141234500359, 0.001884555641372158}, 
      {10.400782387298197, 0.0008023890647822876}, 
      {10.42968385242082, 0.00005834690480242214}, 
      {10.456976056510143, 0.00016622004178513995}, 
      {10.482158435975709, 0.0008964958130904904}, 
      {10.529849854103508, 0.002473194218650975}, {10.580379032226226, 
       0.002099859912890612}, {10.628160545696495, 
       0.00042945652661064115}, {10.680286171786888, 
       0.0002720870124770805}, {10.729520259073432, 
       0.001888588440322689}, {10.775202556624247, 
       0.0024687893413962124}, {10.82045106298513, 0.001248995075482907}, 
      {10.861453964954508, 0.0000910080375398239}, 
      {10.908785513335532, 0.0005576207890709166}, 
      {10.953348705597765, 0.0020619217540582715}, 
      {11.002173369353082, 0.002342106393597401}, {11.053725223682262, 
       0.0007088771850494802}, {11.097738972734737, 
       0.000016162684473128328}, {11.146023153914848, 
       0.0012771226577378261}, {11.198045233741523, 
       0.002636648387241006}, {11.227207296125576, 0.002304314757590336}, 
      {11.253781139630389, 0.001410041971443801}, {11.305427370443262, 
       0.000010658121744052575}, {11.354324847882705, 
       0.0010188480403050815}, {11.399463645512368, 
       0.002683317787712808}, {11.441816076126448, 
       0.0026461454974149212}, {11.485985067242904, 
       0.0009629118752856488}, {11.534710952644673, 
       0.00003684614577011397}, {11.576609162691422, 
       0.0014003641883855887}, {11.615002580091224, 
       0.0030760882445647814}, {11.657154388275487, 
       0.003187117793968067}, {11.701507532496137, 0.001248794292012378}, 
      {11.746695402172854, 3.105029591434623*^-6}, 
      {11.794942560426767, 0.0017757745948823274}, 
      {11.840474354748013, 0.004107295575492144}, {11.881822093054573, 
       0.003770439821573876}, {11.930505828687298, 
       0.0009349601943690263}, {11.957955845774757, 
       0.00001881275853730293}, {11.983250485100658, 
       0.000461465676738667}, {12.029749325528115, 0.003797368346279447}, 
      {12.078950142332543, 0.005928714287634124}, {12.126954592512645, 
       0.0031184441557301256}, {12.17925444636846, 
       3.1724176649400274*^-7}, {12.228650526704916, 
       0.003376643563750707}, {12.274422789076963, 0.00850319022443355}, 
      {12.319821491716644, 0.007986685009199093}, {12.360906278894113, 
       0.002751906004446899}, {12.40833299425096, 0.0003205869666003736}, 
      {12.452927027959381, 0.007440057611085515}, {12.501916551602058, 
       0.016776069631177955}, {12.553574421466903, 0.012134764709348664}, 
      {12.598224684115845, 0.0013545364313584537}, 
      {12.645999537530047, 0.005773612110272646}, {12.697492210127589, 
       0.034187145634442674}, {12.745474263231516, 0.0474802789087592}, 
      {12.774801726493893, 0.03493574249440475}, {12.802531769535133, 
       0.013690770549437363}, {12.85445674880092, 0.012640317336408776}, 
      {12.89619754601563, 0.13016840568825014}, {12.942184039828854, 
       0.41538075881669606}, {12.986993515906338, 0.7553238902811665}, 
      {13.035206993250098, 0.9855276419439233}, {13.080200703239361, 
       0.9370736777473538}, {13.121376371567232, 0.6905977626298967}, 
      {13.160452971413491, 0.39119070776450854}, {13.20212020780453, 
       0.13504691475740585}, {13.250082042161644, 0.007189440302635286}, 
      {13.294620115891334, 0.012026671045085422}, {13.321887586081878, 
       0.03307394194649669}, {13.347581120696123, 0.04615544096180288}, 
      {13.395611998307615, 0.037682178000439624}, {13.441629273734149, 
       0.010876302123729411}, {13.48397742554304, 
       2.7224739746344565*^-6}, {13.530464297261217, 
       0.008142896200445253}, {13.57958773200287, 0.017220546513190046}, 
      {13.62781596395366, 0.011751235935352801}, {13.655069510651316, 
       0.00551938198446931}, {13.680290419542862, 0.001249045944051748}, 
      {13.726552125208038, 0.0013481668929227286}, 
      {13.775711043646215, 0.007608681943872161}, {13.819551349147373, 
       0.00883566421162731}, {13.860718933799761, 0.004629757173655587}, 
      {13.905879061355915, 0.0002914092238781624}, 
      {13.954573512488778, 0.001578078298288491}, 
      {13.98015370651897, 0.00379135784051541}, {14.0074879587334, 
       0.005599425940219738}, {14.056729947207225, 0.0047614379707821}, 
      {14.108101455631289, 0.0008671220230110622}, 
      {14.137547202616343, 1.5076254931139373*^-7}, 
      {14.164308889917551, 0.0007024100392377325}, 
      {14.211773146290822, 0.003502706429062835}, {14.263238496731766, 
       0.003973747511982901}, {14.311837238229527, 
       0.0013454223174214752}, {14.356656488573881, 
       3.163306070951328*^-6}, {14.398440442487432, 
       0.0012763542834049093}, {14.443339376462932, 
       0.0032153511486945623}, {14.485722225033381, 
       0.0030343716521193777}, {14.524457488375107, 
       0.0013202721598837511}, {14.569760845399266, 
       3.7765255104261115*^-6}, {14.619158135389014, 
       0.001201216790046286}, {14.665814307331399, 
       0.0028176874314058045}, {14.709082883958734, 
       0.002429785755428561}, {14.757943894622414, 
       0.0005487722685797542}, {14.803923961098198, 
       0.0001150543495095077}, {14.845210376382028, 
       0.0013949428089259453}, {14.88982295142647, 
       0.0026115881820158175}, {14.938619875857286, 
       0.0018236730079550449}, {14.990116538912634, 
       0.0001525837882894317}, {15.03408337131926, 
       0.0003666587507240825}, {15.082291801237208, 
       0.0019766939317872457}, {15.134095311988233, 
       0.0023411388433365395}, {15.181972064429027, 
       0.0008361406442245101}, {15.206963878757964, 
       0.00015951158824931806}, {15.234520203180297, 
       0.00005056263626376561}, {15.26329798846502, 
       0.000702288363770341}, {15.290285774902681, 0.001653559382190178}, 
      {15.339751726672961, 0.002496153391294418}, 
      {15.38505702750602, 0.0013658487097091645}, {15.434798196358624, 
       0.00002863609506049128}, {15.487110737494508, 
       0.0009484142374350092}, {15.53128623526046, 0.002421821274002133}, 
      {15.57842876215333, 0.0022696713171628884}, {15.622917196361776, 
       0.0006955703856908647}, {15.66329710867027, 
       7.756521123467561*^-6}, {15.710866371192381, 
       0.0012893961118461196}, {15.76237765923726, 
       0.0028966267288547333}, {15.811017238014212, 
       0.0020041505600895924}, {15.85581507830665, 
       0.0002846680695521273}, {15.903640618861555, 
       0.0004486319342927355}, {15.954963888592738, 0.00272403013310106}, 
      {16.003408512330857, 0.0032740177277771343}, 
      {16.04762552944838, 0.001435837580964236}, {16.099411525370634, 
       0.00001835365086077136}, {16.128687931271845, 
       0.0008844821423933001}, {16.155802899400783, 
       0.002441882103169809}, {16.205517990374734, 0.004330955776098242}, 
      {16.230635500769104, 0.0038156193474998285}, 
      {16.2583895784291, 0.0022767252905063805}, {16.28518847202969, 
       0.0006921110908274243}, {16.31343283323061, 
       1.8130294899779302*^-6}, {16.36395395058092, 
       0.002504393942352406}, {16.390229534443062, 0.004601355284441771}, 
      {16.41832972335945, 0.005894027429801024}, {16.449159386704423, 
       0.005240897739876876}, {16.477872723759067, 0.003027860291633781}, 
      {16.504505775089815, 0.0008670179687051614}, 
      {16.53340744070065, 0.000021908193462510752}, 
      {16.560700170452968, 0.0014528881921768474}, 
      {16.5858908696189, 0.004290403586398135}, {16.633589923339734, 
       0.009012513158623659}, {16.68414290197183, 0.0063795045885540495}, 
      {16.73187191024373, 0.0005537653938036525}, {16.783956461274855, 
       0.0034805852497810093}, {16.833152355871047, 
       0.014161292659612933}, {16.878813414169052, 0.0165653269602017}, 
      {16.924026509513176, 0.006743956517778522}, {16.965010079802635, 
       9.18760252576051*^-7}, {17.012319162161667, 0.01326795498028874}, 
      {17.05687505012608, 0.039336519333635175}, {17.150534184345247, 
       0.01513909486413376}, {17.197698749066088, 0.005914592560839406}, 
      {17.249455559462017, 0.14584694398142709}, {17.27653996060611, 
       0.3040242723934319}, {17.30556692545422, 0.5188015744636716}, 
      {17.332464269442056, 0.7239455373392946}, {17.357937979185845, 
       0.8852846449445704}, {17.41013828314842, 0.9923049557902739}, 
      {17.45772046321589, 0.7864652397879641}, {17.50282374502955, 
       0.44771622120072024}, {17.545156010209197, 0.16864649414671593}, 
      {17.589303404188648, 0.02044553347086572}, {17.63802062825572, 
       0.007552101558497905}, {17.67989891635889, 0.03838440044008632}, 
      {17.718286020684715, 0.04746328299587867}, {17.760430446497615, 
       0.02900794915821122}, {17.8047896059191, 0.005227221621684112}, 
      {17.849955388019538, 0.0011878168479988605}, 
      {17.898193958224375, 0.012722855294652464}, {17.943718215395723, 
       0.017047276361746425}, {17.985071979828355, 0.010071557680725063}, 
      {18.033746952462547, 0.0008754626746753574}, 
      {18.061196471394144, 0.00020405686113269373}, 
      {18.086498521404394, 0.0025104677643343763}, 
      {18.133003536055295, 0.008294857679289405}, {18.182226182426923, 
       0.007907545196816442}, {18.84955435074243, 
       0.002500068772460527}}]}}}, {PlotRange -> All, 
  AspectRatio -> GoldenRatio^(-1), DisplayFunction :> $DisplayFunction, 
  ColorOutput -> Automatic, Axes -> Automatic, AxesOrigin -> Automatic, 
  PlotLabel -> None, AxesLabel -> None, Ticks -> Automatic, 
  GridLines -> None, Prolog -> {}, Epilog -> {}, AxesStyle -> Automatic, 
  Background -> Automatic, DefaultColor -> Automatic, 
  DefaultFont :> $DefaultFont, RotateLabel -> True, Frame -> False, 
  FrameStyle -> Automatic, FrameTicks -> Automatic, FrameLabel -> None, 
  PlotRegion -> Automatic, ImageSize -> Automatic, 
  TextStyle :> $TextStyle, FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output",
  CellLabel->"Out[84]="],

Cell["\<\
Remarquons la s\[EAcute]paration des radiations \[AGrave] partir de l'ordre 1 \
et le recouvrement des spectres \[AGrave] partir de l'ordre 3.\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[OutputFormData["\<\
Graphics[{{RGBColor[1, 0, 0], 
   {Line[{{-12.56636956716162, 0.9999999999635375}, 
      {-12.443739190438858, 0.5898630745352811}, {-12.415578945791067, 
       0.43888437026990895}, {-12.38501187942568, 0.28724840742166213}, 
      {-12.358064164872314, 0.17572552349086668}, {-12.329496534381976, 
       0.08728328225533381}, {-12.295367946017404, 0.023970391143899206}, 
      {-12.263859502241598, 0.0014872395647029038}, 
      {-12.235441773100991, 0.0025672437480427934}, 
      {-12.204140957597199, 0.016475095732583}, {-12.170785938271171, 
       0.03423861463187254}, {-12.152048734189123, 0.04193044272994486}, 
      {-12.134905593057045, 0.04637258352714969}, {-12.101653846868702, 
       0.04694665154360718}, {-12.070044948831644, 0.03888449632888969}, 
      {-12.007254527942578, 0.013369436810565006}, 
      {-11.989177555053377, 0.007388379237071525}, 
      {-11.972148067240287, 0.003261594784500929}, 
      {-11.940317229311894, 0.000013524672697620258}, 
      {-11.91018517810254, 0.0018217661834258802}, 
      {-11.882462253585368, 0.006191321554099762}, 
      {-11.85225796737218, 0.01171161523707146}, {-11.819878753339344, 
       0.01609696676031858}, {-11.787140898612178, 0.01726247255680892}, 
      {-11.756577192018577, 0.015170814433565655}, 
      {-11.737913085012405, 0.012743861620338203}, 
      {-11.720232147200282, 0.010000266584989797}, 
      {-11.68709371507121, 0.00481663661185618}, {-11.652192288762329, 
       0.001000758535793742}, {-11.619901571660899, 
       0.000019161937114537294}, {-11.603055889404231, 
       0.0004985224103870315}, {-11.584461516163397, 
       0.0016599374595182275}, {-11.56504209770753, 
       0.003343613714368964}, {-11.54681091272948, 0.005096208594181184}, 
      {-11.513168626682505, 0.007918253539209911}, 
      {-11.481868675776727, 0.00917590932780115}, {-11.447522506724695, 
       0.00855031723434567}, {-11.428297942713998, 0.007395520157069785}, 
      {-11.410829904094005, 0.006017602928020468}, 
      {-11.375493660815927, 0.0029689837348878733}, 
      {-11.35688699841996, 0.0015958803629801885}, 
      {-11.337187782430691, 0.0005526281335948213}, 
      {-11.319963083618996, 0.0000765325980168681}, 
      {-11.301015873952052, 0.00005420216973174536}, 
      {-11.267664956653736, 0.0011403674224788178}, 
      {-11.234963040749458, 0.003030200658997699}, 
      {-11.203917703753358, 0.004787376272091298}, 
      {-11.186796366197573, 0.005481195033067996}, 
      {-11.168132259851745, 0.005893011136641227}, 
      {-11.135434384473745, 0.005639355289883463}, 
      {-11.104342408811247, 0.004398485040906866}, 
      {-11.071240640627765, 0.0025491032542127984}, 
      {-11.042278860504906, 0.001063268466273425}, 
      {-11.01172199660247, 0.00013136619369153701}, 
      {-10.993081656819108, 3.0982379148532734*^-6}, 
      {-10.972647892486254, 0.0002524500824387646}, 
      {-10.954068183048848, 0.0007806436727084397}, 
      {-10.93674519947488, 0.0014542871616054847}, 
      {-10.914960552682258, 0.0024096274492596795}, 
      {-10.89435060762993, 0.0032656840929154623}, 
      {-10.875847835602922, 0.0038717713825433854}, 
      {-10.855747290155874, 0.004259052273436761}, 
      {-10.837874623595626, 0.004321180130454091}, 
      {-10.818912147430968, 0.004091620645667964}, 
      {-10.784877233911331, 0.003056016940984313}, 
      {-10.748339768176564, 0.0015460909072540527}, 
      {-10.729165117686716, 0.0008359122351660217}, 
      {-10.709004019431012, 0.00028925575737411767}, 
      {-10.692216393191105, 0.00004474252196896809}, 
      {-10.673876997709934, 0.00002154507362969967}, 
      {-10.641712206031482, 0.0005552111821369158}, 
      {-10.609008054981777, 0.0015933983400765322}, 
      {-10.578620977159195, 0.0026090881321252177}, 
      {-10.559856467382886, 0.0030907371397548293}, 
      {-10.542164891440727, 0.0033676081274733676}, 
      {-10.509083405473357, 0.0033284486752621616}, 
      {-10.49053707942401, 0.0029991488392117297}, 
      {-10.47345967152439, 0.0025446520046823427}, 
      {-10.434892993575367, 0.0012790361178501963}, 
      {-10.40168140589201, 0.00036517300748385413}, 
      {-10.370193695561127, 2.721385383956752*^-6}, 
      {-10.341927335186362, 0.00019524056604863893}, 
      {-10.311154535251601, 0.0008671309718041016}, 
      {-10.2777457195658, 0.001836296033982693}, {-10.259431637457617, 
       0.0023225130117447436}, {-10.242224156796102, 
       0.002674331201049743}, {-10.211898705848116, 
       0.002930155690345106}, {-10.178397982507995, 
       0.002609184093841812}, {-10.149125484014458, 
       0.0019193063127167917}, {-10.118281421243115, 
       0.0010402234918554598}, {-10.091946995614622, 
       0.0004018126545862011}, {-10.063116913715843, 
       0.00002775053772740337}, {-10.031991094549031, 
       0.00012048461110983904}, {-9.998711769994737, 
       0.0007276333472788919}, {-9.969594305769098, 
       0.0014810683677806797}, {-9.938742015075157, 
       0.0022137469891775727}, {-9.921314260804161, 
       0.0024939836407371213}, {-9.902128060690783, 
       0.0026381257353458782}, {-9.868342068211874, 0.00243099128107437}, 
      {-9.849334117226734, 0.0020862313520267676}, 
      {-9.828897350017975, 0.001597366413442512}, {-9.791963577905529, 
       0.0006615331294627069}, {-9.774198964695609, 
       0.0003074656685696188}, {-9.754817837190966, 
       0.00006425413301355107}, {-9.73651177623901, 
       1.5067230152019238*^-6}, {-9.71952508333601, 
       0.00009508054730709211}, {-9.68745429185231, 
       0.0006166873761355401}, {-9.653282636994081, 
       0.0014460640224633683}, {-9.619581668830095, 
       0.0021814134225906496}, {-9.600599944309032, 
       0.0024319511387285993}, {-9.583144641082043, 
       0.0025153240511489533}, {-9.551022715433415, 
       0.0022788087722889596}, {-9.51710407263666, 
       0.0015937006835036536}, {-9.488695299294296, 
       0.0008905359486315919}, {-9.458256205945473, 
       0.0002699609098830444}, {-9.424858209400508, 
       1.6099603564579992*^-9}, {-9.393693884200683, 
       0.00023393115564067048}, {-9.361497286951693, 
       0.0008752914945943367}, {-9.325976371366668, 
       0.0017470540638916644}, {-9.308119854710863, 
       0.0021204992613176534}, {-9.288880108546811, 
       0.0024005670710268365}, {-9.254071201683287, 
       0.002471826070494214}, {-9.221243476932905, 
       0.0020190351739234917}, {-9.186698822932234, 
       0.001205534975903058}, {-9.154342647351259, 
       0.0004565509527905307}, {-9.12495762057916, 
       0.00005221453692449765}, {-9.106961904062231, 
       3.4273617756932583*^-6}, {-9.089981350209992, 
       0.00010796935446979397}, {-9.072056191359701, 
       0.0003649335397985063}, {-9.052634391423654, 
       0.000777060740915805}, {-9.020600314261566, 0.001598863434109994}, 
      {-9.003616709774173, 0.0020116372754784896}, 
      {-8.98538049561471, 0.0023674250942732644}, 
      {-8.96544062802915, 0.0025994775555157113}, 
      {-8.9467946526825, 0.0026363825640438304}, {-8.925453589528708, 
       0.0024579845306050836}, {-8.90596364977933, 
       0.0021147091912443413}, {-8.870506922894716, 
       0.0012299114557410332}, {-8.85106205892195, 
       0.0007328365986885898}, {-8.832777247341234, 
       0.00034484251688635207}, {-8.81569255046589, 
       0.00010036805587849156}, {-8.797245130015177, 
       1.7057724287818866*^-7}, {-8.765087013379915, 
       0.00026599510134784645}, {-8.7323880027554, 
       0.0010095560820652938}, {-8.702358096101252, 
       0.0018658213477319718}, {-8.669354921311696, 
       0.0026412556446680025}, {-8.65063737614817, 
       0.0028786221748146818}, {-8.633194658016082, 
       0.0029252591125056774}, {-8.614748746396554, 
       0.0027835478163628913}, {-8.597960877119457, 
       0.0024982864314330726}, {-8.578582710009492, 
       0.0020258362278703533}, {-8.560258696397945, 
       0.0014984399895319584}, {-8.528978403351475, 
       0.0006231594266903553}, {-8.495807439931152, 
       0.000056716170288842134}, {-8.467488017142081, 
       0.00006911043259301742}, {-8.436285770109828, 
       0.000636164013932319}, {-8.402509680819492, 
       0.0016842863925501475}, {-8.383966154043735, 
       0.0023009057935846843}, {-8.366491716330332, 
       0.002815156265761802}, {-8.33250254926104, 0.003405440768988601}, 
      {-8.301675160192582, 0.0032995558400307156}, 
      {-8.270215840671801, 0.0025875752451265293}, 
      {-8.236174744045107, 0.0014410934415018532}, 
      {-8.218067448050121, 0.0008451879723587437}, 
      {-8.198931769429526, 0.0003431948345853547}, 
      {-8.16465579458506, 4.649242902970599*^-6}, {-8.132543085348267, 
       0.0004763135657635437}, {-8.102553684744885, 
       0.0014924230308129291}, {-8.067542646866219, 0.00294361723006793}, 
      {-8.034365576047483, 0.004013316621618386}, 
      {-8.00479791309675, 0.004329868844747655}, {-7.972624621431141, 
       0.003842199110138218}, {-7.943379393494598, 0.002789589236729129}, 
      {-7.9163133607235645, 0.0016038105754578686}, 
      {-7.887146267916255, 0.000513064628885694}, {-7.854941417333255, 
       4.601362739878282*^-7}, {-7.821307200265632, 
       0.0005324761093414989}, {-7.789721172757805, 
       0.001918924038092049}, {-7.754842804934924, 
       0.0038856497488090076}, {-7.7223827417476345, 
       0.005389543788262191}, {-7.68851901311803, 0.005943967925060557}, 
      {-7.670606718015364, 0.005701911672837463}, {-7.651464754973032, 
       0.0050532223080524165}, {-7.590629394847108, 
       0.0015998418736442857}, {-7.556311912170857, 
       0.00019063744291471528}, {-7.524660952672926, 
       0.00016857279212738923}, {-7.506854334799672, 
       0.0007942379123906018}, {-7.4872609148827785, 
       0.001962351964760832}, {-7.447652497390131, 0.005246864233085422}, 
      {-7.429545035118641, 0.0067706419711811424}, 
      {-7.410086239081577, 0.00812457600502313}, {-7.391717838122036, 
       0.008952368225802372}, {-7.374929039281507, 0.00921886704545622}, 
      {-7.341536919436805, 0.00823639767418277}, {-7.322645562362076, 
       0.006894922639776738}, {-7.305124576150702, 0.00532332587856852}, 
      {-7.273506499649603, 0.002346861525557894}, {-7.238835595875354, 
       0.00020395394517927503}, {-7.204790215968518, 
       0.0005428989377944778}, {-7.1861983313323075, 
       0.0019412476471821843}, {-7.168858605287513, 0.0039406720320291}, 
      {-7.135813829165743, 0.008949468289571744}, {-7.104541220998515, 
       0.013743124281022407}, {-7.086966492688582, 0.01579332585188923}, 
      {-7.067868189996151, 0.01709971233152916}, {-7.0344643691202755, 
       0.01649499442619992}, {-7.015544090821685, 0.01451034493246194}, 
      {-6.995463882728249, 0.011395278218601958}, {-6.959417025763658, 
       0.004828820722384159}, {-6.928344705118186, 0.000698878535094374}, 
      {-6.894882253989902, 0.000754837091698406}, {-6.863292223414822, 
       0.006570336897190387}, {-6.834357149491302, 0.016411480055329913}, 
      {-6.7995223663629725, 0.031067598610130375}, 
      {-6.76714554374196, 0.042837737680352275}, {-6.73336681011831, 
       0.047992185174780176}, {-6.715510870170005, 0.04652219313618951}, 
      {-6.696454244824378, 0.04157080473210256}, {-6.66553241570273, 
       0.02750494649536878}, {-6.6328278169563575, 0.009975236299002158}, 
      {-6.6157391415451565, 0.0030532169676485673}, 
      {-6.596960482461387, 1.5107514016442863*^-6}, 
      {-6.563923660074151, 0.013742226855705806}, {-6.532760885159658, 
       0.05845912390677339}, {-6.499316560417588, 0.14828450416860706}, 
      {-6.467747985618447, 0.27272244575759363}, {-6.4389321819660355, 
       0.4130115961520761}, {-6.3815009317566, 0.7171562088035363}, 
      {-6.351192647346554, 0.8553622448188475}, {-6.318957672135968, 
       0.9581679487908852}, {-6.290896705384654, 0.9980243278905992}, 
      {-6.259887919881928, 0.9820825700810402}, {-6.23168357205647, 
       0.914856194079968}, {-6.2051751912489985, 0.8133229672300919}, 
      {-6.140413399246376, 0.48142798180725094}, {-6.104804384361358, 
       0.30102207306120976}, {-6.07114939458869, 0.16235114739759954}, 
      {-6.039800660838335, 0.07170500576961297}, {-6.005779130710433, 
       0.016884911871121438}, {-5.974857211569071, 0.000360110815529531}, 
      {-5.946314739968793, 0.0045101289561944435}, 
      {-5.916227545391859, 0.019061289354735386}, {-5.883094265825638, 
       0.03631874147999809}, {-5.848494027249178, 0.046896257563322885}, 
      {-5.81608627414955, 0.046595952595911865}, {-5.797686965913686, 
       0.042394666667059516}, {-5.7802000596353, 0.03643677498383206}, 
      {-5.747373169661869, 0.0227569061469246}, {-5.727411850189343, 
       0.014623737618829442}, {-5.708610818009964, 0.00816064893920031}, 
      {-5.691729497058007, 0.003821785333958185}, 
      {-5.67347196489139, 0.0009495020276635357}, {-5.642956340856394, 
       0.00035646393673683253}, {-5.614885908719801, 
       0.0035214535356489184}, {-5.584518547945331, 0.00892980796743005}, 
      {-5.552442642936288, 0.014293040700662623}, {-5.524739778698607, 
       0.016948525251500184}, {-5.4988816542015595, 
       0.017114220408786417}, {-5.470510038239905, 0.014841538070217488}, 
      {-5.440101304204889, 0.010490871699925654}, {-5.407324369973258, 
       0.005309079771198571}, {-5.390038004153222, 0.00300559551592184}, 
      {-5.371676941453874, 0.0011986608870299764}, 
      {-5.33801104200326, 8.770767523666463*^-6}, {-5.306869418321936, 
       0.001252468854785531}, {-5.27708740046, 0.0037970913469643507}, 
      {-5.249133053174778, 0.00643469727714681}, {-5.218467179247704, 
       0.008573078032788582}, {-5.185415539946742, 0.009181194843906521}, 
      {-5.152249210238501, 0.007878333972033413}, {-5.122119045343855, 
       0.005543494040109474}, {-5.089675079370467, 
       0.0027572747538110835}, {-5.072592972048763, 
       0.0015245965781930026}, {-5.054511304287104, 
       0.0005731742775713078}, {-5.021916937043022, 
       0.000015411251481832102}, {-4.991870331243577, 
       0.0007975769218232964}, {-4.963712437489975, 
       0.002299498912412002}, {-4.932744645326466, 0.004160856621383427}, 
      {-4.91428788094458, 0.005079732164697246}, {-4.896769444776508, 
       0.005677375553479564}, {-4.863904506465834, 0.005870628218983518}, 
      {-4.845544361298008, 0.005441683893636802}, {-4.828524619896917, 
       0.004759053559368464}, {-4.789964139624456, 0.002657737846347916}, 
      {-4.756627499741022, 0.0009587310451769638}, 
      {-4.7252699293358384, 0.00008357815521602901}, 
      {-4.707894652223887, 0.00001004753787553231}, 
      {-4.68912763800385, 0.0002596609353534836}, {-4.656407101867739, 
       0.001335266698342677}, {-4.62386009820265, 0.0027527571890302877}, 
      {-4.589022094171601, 0.003965018636564918}, {-4.5690141288038335, 
       0.004293240029107536}, {-4.550798945078401, 
       0.0042982925029111715}, {-4.5324881417680505, 
       0.004024053655482662}, {-4.515168046088385, 
       0.0035425475322473548}, {-4.477587374943721, 
       0.002061323388095936}, {-4.457011027060035, 
       0.0012275055222245492}, {-4.437722831347343, 
       0.0005822272824697915}, {-4.403688924213701, 
       0.000011417741861583814}, {-4.385623769454787, 
       0.000059830493207052884}, {-4.366178802216007, 
       0.0003705434256200941}, {-4.3319831773338695, 
       0.0013793581540712152}, {-4.299456824796701, 
       0.002486460486832416}, {-4.2702612945067715, 
       0.0032132651489819915}, {-4.238373199726349, 
       0.0034303278329411717}, {-4.203552877221281, 
       0.002908834614944988}, {-4.184078307540919, 0.002354087529721195}, 
      {-4.166409823533075, 0.0017704696239628115}, 
      {-4.131846181639081, 0.0006826242554619852}, 
      {-4.099557867644297, 0.00007553029440644786}, 
      {-4.070027486033809, 0.0000612573906099611}, 
      {-4.03835100972588, 0.0005998923923426486}, {-4.020304096412447, 
       0.0010817292265469262}, {-4.0031972104945455, 
       0.001584663340830274}, {-3.971124967120251, 
       0.0024400976759973926}, {-3.9373675188171355, 
       0.002910080360256366}, {-3.906115773183359, 0.002779362256144563}, 
      {-3.871816745614098, 0.0020780372086899087}, 
      {-3.835355680157767, 0.0010474030719948607}, 
      {-3.806686461255319, 0.00036167985867526653}, 
      {-3.775761644933756, 9.467636991921759*^-6}, 
      {-3.7465653606116467, 0.00014682912350451295}, 
      {-3.7197792481909304, 0.0006284779285343149}, 
      {-3.6880518498287906, 0.0014376063781799875}, 
      {-3.6580805514740606, 0.0021632125303107106}, 
      {-3.6235347317854565, 0.0026207246120380757}, 
      {-3.592125774978775, 0.0025200733667593025}, 
      {-3.560403449056952, 0.001958140194247854}, {-3.5259937982305156, 
       0.0010830202211150036}, {-3.4939713794488454, 
       0.0003587657677276379}, {-3.4644279651273338, 
       0.000019268994774187885}, {-3.432118876182264, 
       0.00013998302999646418}, {-3.4137515117856005, 
       0.0004234724620152753}, {-3.3965566693030724, 
       0.0007911487954212012}, {-3.359682960466151, 
       0.0016994343119344085}, {-3.341512770582927, 0.0020893724696583}, 
      {-3.3246553965675663, 0.002354655975297332}, 
      {-3.2907259645471174, 0.002498111431174685}, 
      {-3.2728061828696706, 0.002346518862465565}, 
      {-3.2537161970374213, 0.002034258894982896}, 
      {-3.219688519543514, 0.0012407923118269637}, 
      {-3.1888572781225464, 0.0005184072303972165}, 
      {-3.1700321752339398, 0.0001968484499985293}, 
      {-3.1527242270863884, 0.00003085119765098259}, 
      {-3.1337241515268826, 0.000015446652792531426}, 
      {-3.1136651734946903, 0.00019000623236855284}, 
      {-3.079907720898843, 0.0008373594057220555}, 
      {-3.0428793550327233, 0.001745012218999607}, 
      {-3.0083895971479553, 0.002370665308699812}, 
      {-2.976501940186962, 0.002500992372059646}, {-2.959860060155532, 
       0.002370630971738873}, {-2.941503428011237, 
       0.0020861758790115146}, {-2.9223328281237166, 
       0.0016717439958323914}, {-2.904347743485398, 
       0.0012265489514397092}, {-2.873582759315132, 
       0.0005047082660928277}, {-2.8412149469211836, 
       0.000048263487861122684}, {-2.8242586556198024, 
       2.5833785300377166*^-6}, {-2.805723472743663, 
       0.00011932417805521802}, {-2.7732047317407997, 
       0.0006890001470467225}, {-2.7415161143158127, 
       0.0014927065820597408}, {-2.711620838023751, 
       0.002197912193083836}, {-2.677163057032455, 
       0.0026275869378634188}, {-2.645875427386114, 
       0.002503869095656382}, {-2.616300436322469, 0.001970841429579861}, 
      {-2.5890509142222697, 0.0012758900625930128}, 
      {-2.5568739869810484, 0.00048626923283571333}, 
      {-2.5274937371504644, 0.00005525754660243304}, 
      {-2.4956410992898013, 0.00008554621238325428}, 
      {-2.461445772575734, 0.0006903340763672827}, 
      {-2.42975757796998, 0.0015641255310005556}, {-2.3996955080491955, 
       0.002367059552186679}, {-2.364795154549541, 
       0.0028970435851110128}, {-2.3324590184877088, 
       0.002794800415373819}, {-2.3138287797816273, 0.00247833966033282}, 
      {-2.2969708448791333, 0.002068470066349745}, 
      {-2.259214961169477, 0.00097765306795029}, {-2.2413628045018923, 
       0.0005184282175928663}, {-2.2225405165633885, 
       0.00016768498868594952}, {-2.1888661522262924, 
       0.000033134271862975516}, {-2.170104027599345, 
       0.0002615867103176945}, {-2.15262312600835, 
       0.0006486289313737456}, {-2.1334418515646876, 
       0.0012154070861814898}, {-2.112920723631742, 
       0.001900596707397127}, {-2.095172035543152, 
       0.0024763616183376374}, {-2.075904099403178, 
       0.002997535128701999}, {-2.057708518929467, 0.003323236685360119}, 
      {-2.040907866656544, 0.0034407526945861716}, 
      {-2.0091022137996064, 0.003143087072768265}, 
      {-1.9753806149498774, 0.0022162734098508763}, 
      {-1.9436044995385353, 0.0011225951867287266}, 
      {-1.9089152940418757, 0.00021144416254322143}, 
      {-1.8761494863573491, 0.00002973453312463301}, 
      {-1.8457262834257138, 0.0005747620851809806}, 
      {-1.8156133841313615, 0.0016441915578368689}, 
      {-1.7883069345303513, 0.0027848148827958434}, 
      {-1.7567860593496487, 0.0038767337688084785}, 
      {-1.7270881614203313, 0.004326277299993695}, 
      {-1.6945963049406494, 0.003975469829912781}, 
      {-1.660265706590015, 0.002792616144262718}, {-1.6305923674998497, 
       0.001495251432277962}, {-1.598778554403677, 
       0.00037101000227354676}, {-1.5645586290270788, 
       0.0000195511716424822}, {-1.5326074829071514, 
       0.0007219931965877135}, {-1.5130972305738135, 
       0.0015789280422098804}, {-1.4946125256292726, 
       0.0025784921998892292}, {-1.4599656293217762, 
       0.004502638562968725}, {-1.4322820645610184, 0.00560329062134398}, 
      {-1.401721132472537, 0.005925483549936014}, {-1.3698040402641494, 
       0.00511800987762764}, {-1.3398363297533986, 0.003543870515086281}, 
      {-1.313781874728905, 0.0019610966197935896}, 
      {-1.2863476946190688, 0.0005956949818085557}, 
      {-1.256265124547942, 1.0015243484012728*^-7}, 
      {-1.2286797808514827, 0.0005729389440657451}, 
      {-1.1985874601790238, 0.002363450876958203}, 
      {-1.166435498928996, 0.005074140362774628}, {-1.1386462732970581, 
       0.007354326586482612}, {-1.108518079508313, 0.00895280991438774}, 
      {-1.090088174525949, 0.009217571991231719}, {-1.0730935701500846, 
       0.008913134751778563}, {-1.0396466196200533, 
       0.006910277702632742}, {-1.009247913047702, 0.004100372789402857}, 
      {-0.9770604217200476, 0.001304124932717319}, 
      {-0.9451359785457608, 8.524163614099045*^-6}, 
      {-0.9103307527483435, 0.0012914360765865914}, 
      {-0.8774570671167919, 0.005077022595749245}, 
      {-0.846973884169021, 0.00986546380745957}, {-0.81731074622965, 
       0.014273692584708161}, {-0.789399921162745, 0.016880336229185104}, 
      {-0.7572302109873794, 0.016883878682515955}, 
      {-0.7280970851171047, 0.013923006180644413}, 
      {-0.6957236354915753, 0.00838111739502}, {-0.6655363309814647, 
       0.003098148408906279}, {-0.634046171921933, 
       0.00008430111550246231}, {-0.5995221775861416, 
       0.0023124591098407916}, {-0.581225083278891, 
       0.006268252727765283}, {-0.5645622853607394, 
       0.011416273778557917}, {-0.5271299115213064, 
       0.026476803165739683}, {-0.49485372409729966, 
       0.039398493022879094}, {-0.46060538723115124, 
       0.047436638573901145}, {-0.4311877338929005, 0.04632284118692289}, 
      {-0.3987552740823816, 0.035715629642457086}, 
      {-0.3692587692821061, 0.020331555701913962}, 
      {-0.3416002527499435, 0.006354216342596172}, 
      {-0.30910155451610793, 0.0002696471719571909}, 
      {-0.2793399050921127, 0.015016851550180425}, 
      {-0.24666414170013384, 0.06449936937753332}, 
      {-0.212303281890631, 0.16141288025965433}, {-0.15424485477481145, 
       0.42081459772870383}, {-0.12369141085457933, 0.5841622828477072}, 
      {-0.09138264294760672, 0.751374964201144}, {-0.06309947572250212, 
       0.8744207310974825}, {-0.03202522427912138, 0.9663595192152091}, 
      {-0.0037679134494007344, 0.999528033052964}, 
      {0.02263742455245591, 0.9830765030932362}, {0.05602209585862714, 
       0.8999004999573734}, {0.08648977222719642, 0.7747178406587325}, 
      {0.15500383437312995, 0.4168671561061905}, {0.18452355186576522, 
       0.2728979485862434}, {0.21666466619448133, 0.14650063622167406}, 
      {0.24702050708423434, 0.06374207175727631}, 
      {0.275131877165546, 0.019241359721551568}, {0.3071138297228473, 
       0.0005295591215879225}, {0.33716688814813134, 
       0.0046184381694496825}, {0.3701338098803316, 0.02081551292541688}, 
      {0.3871139730646905, 0.030018894541166213}, {0.40570551920565784, 
       0.038718579699368295}, {0.42395925067986173, 0.04476490904703786}, 
      {0.4409579213901333, 0.047622076420106955}, 
      {0.458910450548333, 0.047595039592067546}, {0.4781073428985984, 
       0.04438000986262255}, {0.5129051279945294, 0.03249247402381657}, 
      {0.544553020312363, 0.019087312087993413}, {0.5747496395538146, 
       0.00810791940857726}, {0.6067491804920065, 0.0012831427380292212}, 
      {0.634068693386575, 0.00008495880973123384}, 
      {0.6641482985163458, 0.0028927836176430386}, 
      {0.6962108871494378, 0.008472078297254559}, {0.7266776743183577, 
       0.013717437850322405}, {0.7434719142530036, 0.015808129652954295}, 
      {0.7617965458367845, 0.017100457815120988}, {0.7939153316573212, 
       0.016604650699647998}, {0.8244688325523197, 0.013314927956518093}, 
      {0.857027669500992, 0.00823721603339184}, {0.8851688303615328, 
       0.004007375782950011}, {0.9155982851441833, 0.000902615405519609}, 
      {0.94638292269384, 0.000018347437428740144}, 
      {0.9753725785310046, 0.0011882265909227486}, 
      {1.0035938357141503, 0.003557913588833577}, {1.0295487558058074, 
       0.006032435145378091}, {1.0628996087714615, 0.00848356705474018}, 
      {1.0944815040077076, 0.00920996475443015}, {1.1228335581726632, 
       0.008351067338143144}, {1.153662662175849, 0.00617571761688813}, 
      {1.1871726779715308, 0.00327419018970291}, {1.2055308904643287, 
       0.0018607753188589066}, {1.222759181017187, 
       0.0008380565604382555}, {1.2531404283446894, 
       8.886274818742933*^-6}, {1.286662543932467, 
       0.0006077483673628915}, {1.3160236102888123, 
       0.002093101332992829}, {1.3469239632144328, 0.003961431232169986}, 
      {1.3733067349677124, 0.005258830451720498}, {1.4021551242872738, 
       0.005928523362362417}, {1.4333379902835022, 0.005573701360426103}, 
      {1.4666383823461862, 0.0041578890206967365}, 
      {1.4957741888864564, 0.002512583769008494}, {1.5266089550344424, 
       0.0009566103867987062}, {1.5440997658956457, 
       0.0003575105516293663}, {1.5633322984112699, 
       0.000028013258150607777}, {1.5971786282367735, 
       0.0003312745053594367}, {1.616232426672147, 
       0.0009212699005301444}, {1.6366939501398587, 
       0.0017587879056710643}, {1.673649522724882, 
       0.0033267586828850397}, {1.6914562516964133, 
       0.0038965887257847126}, {1.7108600447910274, 
       0.004261666125775206}, {1.7291866466812496, 0.004318058555619973}, 
      {1.7461720285208393, 0.004116284707524755}, {1.7782613495506794, 
       0.0031795728308387354}, {1.8124118068998776, 
       0.001775976058697373}, {1.84617269706249, 0.0005622246406534904}, 
      {1.8651763007090345, 0.00014965165322839634}, 
      {1.8826307819100587, 2.0675496619995655*^-6}, 
      {1.914771050408897, 0.00032265541050224296}, 
      {1.9486684352714756, 0.0012925798521904433}, 
      {1.977094833171381, 0.0022732162961229246}, 
      {2.007516333535378, 0.0031114604625011324}, {2.0408936080059603, 
       0.0034407716650585477}, {2.0720012953258022, 
       0.003082978692935083}, {2.104332615535044, 0.002186102296024499}, 
      {2.13995939386329, 0.001010365933093342}, {2.1578794102074523, 
       0.0005167997631892588}, {2.1771644465043805, 
       0.00015100824808040474}, {2.2120336308518342, 
       0.00005192391851849029}, {2.2466454859988096, 
       0.0006441092363758802}, {2.279561427968119, 0.001572063523426151}, 
      {2.311971870744981, 0.002438151509398411}, {2.3413708888965017, 
       0.0028828739023744354}, {2.3594307559452306, 
       0.002921955115354943}, {2.3764514390633282, 
       0.0027872318149900783}, {2.3944197070756155, 
       0.0024828574218847903}, {2.4138648899947337, 
       0.002011484835398889}, {2.4459562932087393, 
       0.0010995411467329562}, {2.4629604379316477, 
       0.0006536480117499148}, {2.481196839134604, 
       0.0002777319829074388}, {2.501183645173258, 
       0.00004036646755434671}, {2.519851130322113, 
       0.000011913375401588656}, {2.541216681968524, 
       0.00020839032445674188}, {2.5607055963570864, 
       0.000568093758988955}, {2.5961827221969402, 0.001465383451322344}, 
      {2.6156267603962458, 0.0019552024142872456}, 
      {2.6338889026216217, 0.0023289360250029908}, 
      {2.666131354998418, 0.0026420726407376826}, {2.6832616262576434, 
       0.0025923530848277025}, {2.70173609809914, 0.0023747893498304432}, 
      {2.734490459856139, 0.0016735045931294474}, {2.7645351501471747, 
       0.0008968069201652436}, {2.7975971941471673, 
       0.0002225425885215071}, {2.816336476855661, 
       0.000031484588559900996}, {2.8337785360051617, 
       0.000010293634591493758}, {2.8522456383486974, 
       0.00015397967157404626}, {2.8690326433382873, 
       0.0004159148149991162}, {2.888410044462974, 
       0.0008331755772651331}, {2.9067113975359757, 
       0.0012861111849855136}, {2.938045935175428, 
       0.0020187900966001666}, {2.9712346397340834, 
       0.0024740868743217815}, {2.9995695333714743, 
       0.0024561168472981084}, {3.0307513942677082, 
       0.0020086886171716907}, {3.064545627080215, 
       0.0012144872801360476}, {3.0830876690173366, 
       0.0007630779216245641}, {3.100539787077462, 
       0.0003983581140710888}, {3.1345048560226205, 
       0.00001253835894559777}, {3.1652734494792134, 
       0.00013761321224984937}, {3.1968653274595127, 
       0.0006896150446256446}, {3.2310089063352145, 
       0.0015228133611208039}, {3.2491810059907134, 
       0.001941657941067389}, {3.2683621791445017, 0.002286446007360031}, 
      {3.302698470190257, 0.002512215614197547}, {3.334906521753219, 
       0.0022064352258752205}, {3.3649489372953134, 
       0.0015730523927997952}, {3.400021970779637, 
       0.0007111355600855759}, {3.4332180029045656, 
       0.00012750189150952064}, {3.4628742003466244, 
       0.000012992702602190346}, {3.4951051590555, 
       0.0003793189340269391}, {3.5244013672354195, 
       0.0010420627839587734}, {3.5514820986942444, 
       0.0017435563268702959}, {3.580702946313925, 
       0.0023627741995493347}, {3.612928461555382, 
       0.0026441535679609745}, {3.6465826605321374, 
       0.0023740304237568127}, {3.678149608779742, 
       0.0016958616668028331}, {3.7131323530398044, 
       0.0007854001326577326}, {3.7456505589496722, 
       0.0001582854709058758}, {3.779576630579767, 
       0.00002582221410295443}, {3.7975114877051275, 
       0.0002071502695221247}, {3.816654609959446, 
       0.0005701171291790406}, {3.846254312976803, 
       0.0013566575148461543}, {3.877564276474949, 
       0.0022253853370025408}, {3.911902248273338, 0.002845108389905825}, 
      {3.943534157804626, 0.0028693248786720565}, {3.9625189889573673, 
       0.0026136617228847917}, {3.980265078592239, 
       0.0022237390411214124}, {4.020633300923033, 
       0.0010722921924370562}, {4.038634186016044, 
       0.0005930822248827396}, {4.05570805042109, 
       0.00024312010510163352}, {4.0753886446789895, 
       0.000023571977625562855}, {4.093355232040457, 
       0.000027198173853734922}, {4.127151755754319, 
       0.0005617050694235288}, {4.158459144775962, 
       0.0015023800892724622}, {4.192978358634802, 
       0.0026241915595615244}, {4.210345393882425, 
       0.0030652847144102898}, {4.229366443941753, 
       0.0033670433406729717}, {4.262261809095657, 
       0.0033311304091621463}, {4.292904934677062, 
       0.0026832480319730857}, {4.321088313003081, 
       0.0017591603225628153}, {4.351234567893652, 
       0.0007576241586764072}, {4.368213572601495, 
       0.0003268357154149341}, {4.38664239869805, 
       0.000050630463399432035}, {4.4201112173851795, 
       0.00018290296728786426}, {4.452693768067791, 
       0.0010679569225015243}, {4.482772658881054, 0.002280406323329029}, 
      {4.5092825460440755, 0.003339802767603521}, 
      {4.537797417182529, 0.004130700089728624}, {4.569088461654128, 
       0.0042926337950471}, {4.598400192280579, 0.0037061081698506527}, 
      {4.631216809975655, 0.0024341856860792595}, {4.6624097892115355, 
       0.0010937279667117055}, {4.69040914817362, 0.0002325798584429653}, 
      {4.720969483810175, 0.000037040082709015626}, 
      {4.73866344596323, 0.00034640406264825694}, 
      {4.757802141721795, 0.0010079693101078969}, 
      {4.792497954905146, 0.0028027286836385793}, 
      {4.823414433756455, 0.004512351505055249}, {4.857347666575204, 
       0.005758762540419094}, {4.876390747855881, 0.005947038878962632}, 
      {4.8941678573910155, 0.005738535284187114}, 
      {4.912940900671573, 0.005136335762400196}, {4.9330642621613725, 
       0.004142985259494855}, {4.969247675538573, 0.001970206108408281}, 
      {5.002722026110323, 0.0003902234920389979}, {5.0363774836316235, 
       0.0000706397617832699}, {5.054128201320169, 0.000557671293961186}, 
      {5.072984723482676, 0.001549628209538755}, {5.104622211479832, 
       0.004009259147990913}, {5.122839496746645, 0.005605938624029095}, 
      {5.139541309365613, 0.0069820803752201534}, 
      {5.170504922263461, 0.008811236910289722}, {5.203881428833376, 
       0.009085531999269812}, {5.233304765863727, 0.007692866939572852}, 
      {5.264280278713421, 0.005033415052093283}, {5.29686134416069, 
       0.0020105306158120315}, {5.315236784128041, 
       0.0007330662218478041}, {5.3321779078481395, 
       0.00008658019493605981}, {5.363312508984706, 
       0.0006373619360145154}, {5.396272865831703, 0.003778667412305847}, 
      {5.4540893103044406, 0.012650329378026187}, 
      {5.486544164863688, 0.016408324774914683}, {5.516196635742099, 
       0.017258981840533923}, {5.5501633057009965, 0.014597540679958056}, 
      {5.58240696259503, 0.009321706998589462}, {5.612408756088748, 
       0.003916102046412757}, {5.644347528543367, 0.0002795158291298297}, 
      {5.662714282694528, 0.0001648567205593169}, 
      {5.67934415011007, 0.0016604655800239996}, {5.7117896567026145, 
       0.009143745888779293}, {5.729998801803503, 0.015620616744450356}, 
      {5.749668812423768, 0.02373684484908521}, {5.766879313037435, 
       0.031080600102435345}, {5.785303457613126, 0.038329864713544944}, 
      {5.815653414233842, 0.04652709430796346}, {5.843948432034375, 
       0.04746112782420804}, {5.877595351367219, 0.03867149729567368}, 
      {5.908231034382611, 0.02347970722917514}, {5.940174741623957, 
       0.0069485516027504475}, {5.974874341527895, 
       0.00036226720179119274}, {6.007643544728952, 
       0.018803803936924365}, {6.03791939064651, 0.06751926677748045}, 
      {6.0655683075560605, 0.14334364854168385}, {6.091489382343014, 
       0.2415404111290058}, {6.150538020525, 0.5358624011715741}, 
      {6.180293116634975, 0.6939368652968423}, {6.208344790953552, 
       0.8270816279338401}, {6.240677403206561, 0.9413435231979714}, 
      {6.270014953794216, 0.9942457870927492}, {6.3009670249556065, 
       0.989530756897658}, {6.334473644769573, 0.9155357746902324}, 
      {6.365653162824176, 0.7933390735656397}, {6.394361072109156, 
       0.6508894393347687}, {6.4590891667777734, 0.312671530813256}, 
      {6.476823083349779, 0.23334201839386445}, {6.495848056292645, 
       0.16015578076912942}, {6.530191182942225, 0.0637730653180414}, 
      {6.54727944448892, 0.033226542857359306}, {6.565881592993609, 
       0.012063562707354973}, {6.599716977731809, 
       0.00005663579816561347}, {6.6326570604625035, 
       0.009893037023901985}, {6.663155733878941, 0.02622411675214705}, 
      {6.6955303570904325, 0.04124747662325613}, {6.713968970204402, 
       0.046249018220356056}, {6.731292185957361, 0.04798077232589287}, 
      {6.76613914815014, 0.04311939719137139}, {6.785743802257975, 
       0.03659913158930929}, {6.803732217349208, 0.029291512322500036}, 
      {6.832163826637628, 0.01728578555028567}, {6.862560305672759, 
       0.0067716518295628855}, {6.891247576573428, 0.001129008446744681}, 
      {6.917333059387077, 0.00008728736367964204}, 
      {6.948004329670291, 0.0029913872527808655}, 
      {6.981277839081971, 0.008822928411375237}, {7.012478295778901, 
       0.014092430607105588}, {7.041690470150313, 0.016951567094520902}, 
      {7.071828821415586, 0.016920309357251185}, {7.10500566911087, 
       0.013680285754786428}, {7.137333229921239, 0.008703129121829248}, 
      {7.172088282539983, 0.003524062607354111}, {7.204317626386167, 
       0.0005679230670260798}, {7.2349369876952, 0.00010215623107126828}, 
      {7.262421925242202, 0.0014597676979550647}, {7.2924056882844575, 
       0.004097713865444716}, {7.325221673118242, 0.0071039246603051085}, 
      {7.359870654589938, 0.009021313806372446}, {7.377990370680793, 
       0.009208006327833407}, {7.397868151453797, 0.008733066670653907}, 
      {7.415942867627204, 0.007760597214699111}, {7.432807501627323, 
       0.006509201099664538}, {7.465588356730615, 0.0036777443907664914}, 
      {7.496624525249214, 0.001347916263680766}, {7.513764557543629, 
       0.0004981024194310038}, {7.532398489501059, 
       0.000040218091566711116}, {7.564997409119831, 
       0.00043390732956268734}, {7.594594919556316, 
       0.0018236234808939548}, {7.627245991388668, 0.003794954874875983}, 
      {7.661345034043436, 0.005434459965622817}, {7.693339181293243, 
       0.005944491673758302}, {7.72314907455187, 0.0053630439332645365}, 
      {7.750465364991125, 0.004123631479940457}, {7.782720822941303, 
       0.0023011790750858624}, {7.8120122280827875, 
       0.0008665626049149602}, {7.844307968719592, 
       0.00004709974883667064}, {7.878790180883582, 
       0.00029417305748016923}, {7.9107387912869775, 
       0.0013674239148699092}, {7.940882925517664, 0.002683243878477291}, 
      {7.957982765727611, 0.0033690055638433136}, {7.9760762514537165, 
       0.003933518898931926}, {8.008506194334814, 0.004330264086436278}, 
      {8.043404328996381, 0.003782697106508383}, {8.063231231991985, 
       0.0031118106571743154}, {8.081770212244548, 0.002357553221363861}, 
      {8.09934048522384, 0.0016220905225860062}, {8.118482933592194, 
       0.000899683063357559}, {8.153315824170084, 
       0.00008424592587461198}, {8.187227208940412, 
       0.0001355896116797383}, {8.21865077110434, 0.0008629894661857826}, 
      {8.255348286548594, 0.0021077588662414314}, 
      {8.289853949199342, 0.003093968605325217}, {8.308977340750674, 
       0.003382685671574576}, {8.329624551903088, 0.003422919280194053}, 
      {8.348386669889745, 0.0032122111229259402}, 
      {8.365616037408117, 0.0028380222714414842}, 
      {8.39631900071074, 0.0018934244786854779}, {8.42965402986971, 
       0.0008174155593757119}, {8.461133948379702, 
       0.0001405123952059573}, {8.49020397485976, 
       0.000019552678058305496}, {8.524077722302506, 
       0.000507739877584596}, {8.541167824943928, 0.0009432248136130597}, 
      {8.559996260235774, 0.0014906639071709583}, 
      {8.59316048192962, 0.002393413542456014}, {8.623510479588042, 
       0.002874834721173745}, {8.65414423975463, 0.002848257670728157}, 
      {8.683271410927315, 0.0023580802791679845}, 
      {8.71401076266314, 0.0015332513004483175}, {8.747572147320342, 
       0.0006197662516143738}, {8.776743455581943, 
       0.0001067476068712769}, {8.807848715557329, 
       0.00003556723266693984}, {8.83720181138435, 
       0.00042845466819500756}, {8.863822434584058, 
       0.0010536373911621986}, {8.897998956129472, 
       0.0019361711065129107}, {8.915213578657962, 0.002296283295264275}, 
      {8.934113843274618, 0.002557725905341122}, {8.967564279978573, 
       0.0025838433672780636}, {8.99880066400656, 0.00211644663464009}, 
      {9.038021090973853, 0.0011440453534445128}, 
      {9.0573224813897, 0.0006676658784055431}, {9.075184325741875, 
       0.00031036567328938844}, {9.108546224264531, 
       1.1009256613080497*^-6}, {9.126144768575834, 
       0.00006113497743918828}, {9.144845449668127, 
       0.00028719835092349475}, {9.176166087529069, 
       0.0009433337808338071}, {9.2055772651148, 0.00167314960470832}, 
      {9.237840817678386, 0.002303744549906803}, {9.272629381588589, 
       0.002508415064493966}, {9.307441237340514, 0.002132815175747421}, 
      {9.324947110034154, 0.0017707436344146647}, 
      {9.344100921538562, 0.0013055375170016048}, 
      {9.375935436349746, 0.0005507841201748882}, 
      {9.409647226840903, 0.00005680258345032293}, 
      {9.444438415675563, 0.00009540392199893465}, 
      {9.476523917359396, 0.0006121653656599803}, 
      {9.513983406821806, 0.0015176404088364335}, 
      {9.532298900318558, 0.001940237379621544}, {9.549038111762808, 
       0.002248920816923824}, {9.579247428160368, 0.00251325946507479}, 
      {9.611708839188756, 0.002303832026419642}, {9.628628847668473, 
       0.0020126824780755644}, {9.647077868235664, 
       0.0015987341760525394}, {9.680663183061773, 
       0.0007696440935182615}, {9.71313900212477, 
       0.00016615864425345673}, {9.74255284000741, 
       3.350619770578918*^-6}, {9.776506770436436, 
       0.00034720304548727543}, {9.808458708332008, 
       0.0010644588610256448}, {9.836173878844333, 
       0.0017808996892116334}, {9.865422418871036, 
       0.0023872230391182195}, {9.897497007939535, 
       0.0026444563679164663}, {9.926975299976398, 
       0.0024171796278219925}, {9.961456390631051, 
       0.0016927643328652365}, {9.992861363723087, 
       0.0008709336727137769}, {10.010234202177346, 
       0.0004710734577945678}, {10.02911172651553, 
       0.00015478852389679535}, {10.063415491066126, 
       0.00002942587846406418}, {10.095496881131282, 
       0.00047455169846012603}, {10.129542560029646, 
       0.001359627677760812}, {10.161441372319356, 
       0.0022424996410400676}, {10.190657130538545, 
       0.0027963658231431043}, {10.22482407283742, 
       0.0028841633451739657}, {10.242756764443584, 
       0.0026654232824529383}, {10.26161648746506, 
       0.0022694763021702956}, {10.293808231894584, 
       0.0013647726137298228}, {10.328162121590124, 
       0.0004484446006467774}, {10.34784649537609, 
       0.00011600914237627123}, {10.365713010605658, 
       7.488446288125377*^-7}, {10.400611727183202, 
       0.0003434729856697264}, {10.420172685758384, 
       0.0008251660432522556}, {10.44135464482558, 
       0.0014926786302469066}, {10.461075440526757, 
       0.002154588595807495}, {10.479777050111736, 0.002726483079635893}, 
      {10.512406433344648, 0.003365582091207651}, {10.542188355168282, 
       0.0033673725510584944}, {10.574250576496961, 
       0.0027355625691849405}, {10.59237645375386, 
       0.0021697584942481406}, {10.609164121809435, 
       0.001587941831965198}, {10.639373637233987, 
       0.0006175387704099313}, {10.667764528575438, 
       0.00007003995975794117}, {10.697371159021527, 
       0.00009755925933681798}, {10.730085576483688, 
       0.0008664530491070049}, {10.76343335655358, 0.002173700680823629}, 
      {10.794491952246188, 0.0034114123947766683}, 
      {10.826892615217421, 0.004223880554719881}, {10.844037165700968, 
       0.004330876366641818}, {10.862372252373135, 0.004166906280373303}, 
      {10.88241276794212, 0.0036804359804734365}, {10.901352181560746, 
       0.0029900128860340693}, {10.936807865725386, 
       0.0014516413087582853}, {10.969572549089387, 
       0.0003221204937199813}, {10.988062369583735, 
       0.000027951458330738167}, {11.005128141675135, 
       0.00004593825827917833}, {11.037067869499714, 
       0.0008477394631226965}, {11.071416646382033, 
       0.002559094271174222}, {11.101103833153553, 0.00423051571145195}, 
      {11.133500144125762, 0.005586941485465286}, 
      {11.1531325496069, 0.0059304092757558905}, {11.17135432234957, 
       0.0058502448476500804}, {11.188768924479305, 
       0.005415459245684796}, {11.207328713260965, 0.004619326669106588}, 
      {11.24250402157992, 0.0025666596617279973}, {11.274858385075161, 
       0.0008060933152189718}, {11.292901362700663, 
       0.0001984747814032336}, {11.3119580854944, 
       3.5912018793851554*^-6}, {11.331087419380989, 
       0.00033477546802586984}, {11.352079308372836, 
       0.0012968624262375032}, {11.370236782867519, 
       0.002551256486900558}, {11.389696558665536, 0.004173930350971971}, 
      {11.424806290918154, 0.0071397819333526135}, 
      {11.442300606006789, 0.008284619554613942}, {11.461325617403583, 
       0.009048658905544094}, {11.49591203319799, 0.008819214366472752}, 
      {11.529583039800299, 0.0066708969327022825}, 
      {11.560727100853839, 0.0037535398251296232}, 
      {11.590898690985291, 0.0011949279872509053}, 
      {11.622655829701154, 1.8514081279128835*^-6}, 
      {11.649770097566387, 0.0008363410372601518}, 
      {11.679421869639814, 0.0037739611554756846}, 
      {11.711243714416293, 0.008544552913796386}, {11.741277576584318, 
       0.0132271476234017}, {11.775895228928654, 0.016820400950404938}, 
      {11.807341546325334, 0.016977765441049855}, {11.837288260474628, 
       0.01406284475230703}, {11.864892141655076, 0.009451164952201503}, 
      {11.894596499849463, 0.004078754001373327}, {11.927262678974058, 
       0.0002937608613676435}, {11.955261858011799, 
       0.0008101763636596716}, {11.981450397838463, 
       0.005317795774488306}, {12.009104233248392, 0.014058629958146628}, 
      {12.038804705613021, 0.026289607819905386}, {12.071593615572827, 
       0.03942499353671579}, {12.106492740956428, 0.047507790778601906}, 
      {12.12658584434966, 0.04751551913608239}, {12.14477530531569, 
       0.04414797261408471}, {12.163061268327615, 0.03772200156818872}, 
      {12.180260401124126, 0.029496551152220163}, {12.211672167801288, 
       0.012492998402863614}, {12.244805156398138, 
       0.0005340753999710201}, {12.26214060474024, 
       0.0010699263429134005}, {12.281138880801736, 0.01006990948340863}, 
      {12.314514744217865, 0.05396063412257254}, {12.347473718731447, 
       0.13915719923387546}, {12.377477252596789, 0.25359499707301064}, 
      {12.44486677792646, 0.5959204707832044}, {12.474800078395072, 
       0.7504644949062375}, {12.507309575802951, 0.8892600628244116}, 
      {12.538010281920794, 0.9735408392204592}, {12.56636956716162, 
       0.9999999999635375}}]}}, {RGBColor[0, 1, 0], 
   {Line[{{-12.56636956716162, 5.122371894011727*^-13}, 
      {-12.507119971238707, 0.001309131406112028}, 
      {-12.474538596166004, 0.0023074492650740725}, 
      {-12.443739190438858, 0.002641164357444985}, 
      {-12.415055840241674, 0.002229743381854741}, 
      {-12.383920959134462, 0.0012583975868008695}, 
      {-12.355820981198397, 0.00039955630935141603}, 
      {-12.329496534381976, 9.92124216468251*^-6}, 
      {-12.298335291683264, 0.0002881623092208985}, 
      {-12.264012622769247, 0.0012767412867912475}, 
      {-12.230568476938446, 0.002231382791403048}, 
      {-12.21178120598362, 0.0024911120925021754}, 
      {-12.194592257405441, 0.002476734304995023}, 
      {-12.1640641287751, 0.0018931976117170421}, {-12.130741280551971, 
       0.0008448256536989146}, {-12.099266217816988, 
       0.00010949677598745487}, {-12.070044948831644, 
       0.00007077044712033326}, {-12.037190847919808, 
       0.0007887999299999088}, {-12.018681262076564, 
       0.0013806347255474472}, {-12.001651560128591, 
       0.0019039119987943596}, {-11.97032096900914, 
       0.0024856847418838115}, {-11.937221282639474, 
       0.0022654593975844563}, {-11.907529411907865, 
       0.001454270311150804}, {-11.879809402981838, 
       0.0005836600648740621}, {-11.849395117787516, 
       0.000027624805219513922}, {-11.816790783322801, 
       0.00025457105519356883}, {-11.782055478018803, 
       0.0012625184802653587}, {-11.763734568977709, 
       0.0018711175973053647}, {-11.744270906430575, 
       0.0023835674561408777}, {-11.727309024691007, 
       0.0026183062762953385}, {-11.708586389707932, 
       0.002590401131106776}, {-11.675571159207198, 
       0.001865974657349133}, {-11.643611708656964, 
       0.000792035171246703}, {-11.609159232736477, 
       0.00004118875270809703}, {-11.57663327139898, 
       0.00024414602405992787}, {-11.54681091272948, 
       0.001140894391476113}, {-11.513483673317577, 
       0.002333163340962586}, {-11.482020649073737, 
       0.002919201415947445}, {-11.46461933573009, 0.00285131421010852}, 
      {-11.445755627230023, 0.0024629859151688647}, 
      {-11.412804097001905, 0.001297187037100456}, 
      {-11.381295279517598, 0.0002743755679534573}, 
      {-11.347936314433975, 0.00005465894013093392}, 
      {-11.319455944522542, 0.000748397771913697}, 
      {-11.28812746987092, 0.0020587905733030517}, 
      {-11.269235012625812, 0.0028064944337847595}, 
      {-11.251299589405486, 0.003288459923097614}, 
      {-11.217649218902734, 0.003272027310367799}, 
      {-11.198852188599853, 0.0027360448886399784}, 
      {-11.18142410778852, 0.002015948015325141}, {-11.161077350656303, 
       0.001103661940485456}, {-11.141934825831301, 
       0.00039602154563299715}, {-11.107168918239688, 
       0.000055282832434281876}, {-11.075688400684095, 
       0.0010131583490346529}, {-11.041785408576478, 
       0.0027993085134147156}, {-11.024096968435478, 
       0.0036409909415915176}, {-11.005159791244457, 
       0.004212060910768751}, {-10.986473384744293, 
       0.0043069561953445615}, {-10.969458070969997, 
       0.0039592081311319955}, {-10.936171204134949, 
       0.002376229149949977}, {-10.917545013644077, 
       0.0013212146171347019}, {-10.897310392154896, 
       0.0004061983103365664}, {-10.878201400914707, 
       0.00001004999838795056}, {-10.860545086422741, 
       0.00017159619736811183}, {-10.842370743998014, 
       0.0008711610768862809}, {-10.825330906020788, 
       0.001917660740234845}, {-10.805067291999553, 
       0.003404102093037934}, {-10.786512490262561, 0.00469143239554292}, 
      {-10.768074284951886, 0.005607569063264051}, 
      {-10.74868751859992, 0.005947187793015135}, {-10.729226051618305, 
       0.005545203439572852}, {-10.707965658128535, 
       0.004355263937554412}, {-10.691039860185581, 
       0.0030654657143465974}, {-10.672715790080208, 
       0.0016396239405871433}, {-10.639481470347787, 
       0.00004938699126921215}, {-10.619538605827659, 
       0.00022752438047512463}, {-10.60117526900338, 
       0.0012458627685166756}, {-10.566414925503407, 
       0.004763105478152679}, {-10.535951744268187, 
       0.007914322221468673}, {-10.502486326054282, 
       0.009200531646783307}, {-10.485628766326817, 
       0.008583946743368308}, {-10.467542622799543, 
       0.007055757266449405}, {-10.434892993575367, 
       0.0031250303579960933}, {-10.402843940347033, 
       0.00025792211473524474}, {-10.384590059399649, 
       0.00009711189698083223}, {-10.367439142332428, 
       0.0012148122093205128}, {-10.33294006492098, 
       0.0067364889064347264}, {-10.315171746362811, 
       0.010447890078652607}, {-10.29571956288016, 0.014177147280731463}, 
      {-10.262997077535998, 0.01731589159616591}, 
      {-10.2285178070968, 0.01428755906248495}, {-10.196585224157426, 
       0.007162944895859045}, {-10.166851742292748, 
       0.0011887306497333266}, {-10.148636436292781, 
       5.619056571269284*^-6}, {-10.128874239945567, 
       0.002051421977822911}, {-10.110212367169176, 0.00747150002260832}, 
      {-10.092991886511818, 0.01510448701908065}, {-10.05830480190171, 
       0.03390932950353033}, {-10.02582580504496, 0.04657956731090401}, 
      {-9.990978533778554, 0.04423080623886875}, {-9.972491690312754, 
       0.03530887819427489}, {-9.952615201961608, 0.02186414510456986}, 
      {-9.931837376588224, 0.007826274485198043}, {-9.912096037138861, 
       0.00026663916955660985}, {-9.894375610871556, 
       0.003613422533678482}, {-9.875042691158367, 0.023749245520927005}, 
      {-9.857738052343443, 0.060263422467973754}, 
      {-9.83902851255808, 0.12200054669144418}, {-9.805118264682742, 
       0.292193823648369}, {-9.741750092985871, 0.719219075251078}, 
      {-9.723134060214438, 0.8319205570759978}, {-9.705763075148356, 
       0.9160657644129196}, {-9.687642897079161, 0.9749890280950018}, 
      {-9.667763148970103, 0.999901467803474}, {-9.634918200953848, 
       0.9454000773034786}, {-9.616505573489189, 0.8675046712118415}, 
      {-9.599725888119519, 0.7736031699967956}, {-9.536855978076558, 
       0.3486664009232701}, {-9.51963164845859, 0.24515381587967253}, 
      {-9.501342164807616, 0.15337934837908673}, {-9.468501400490936, 
       0.0440032247159213}, {-9.43802430379146, 0.003354598311985929}, 
      {-9.409426425195589, 0.003553576381863913}, {-9.378054273326658, 
       0.023449830617339833}, {-9.34425192260994, 0.04336473362928256}, 
      {-9.311049756450913, 0.04728638874907056}, {-9.28089642330952, 
       0.03710926760262072}, {-9.246089814786215, 0.018307832056182458}, 
      {-9.213246694042024, 0.004322142254489669}, {-9.182817889241608, 
       3.9533728783523393*^-7}, {-9.154776297682433, 
       0.0030421824518972133}, {-9.123995642575325, 
       0.010129497540261524}, {-9.09142398098825, 0.016188662082756166}, 
      {-9.058613968246112, 0.016837649796464037}, {-9.040200431237691, 
       0.014670646253764987}, {-9.023384084072566, 0.011611708967015981}, 
      {-8.990361494389418, 0.00487008922914243}, {-8.95975927638342, 
       0.0007065820471618229}, {-8.942537582268235, 
       2.404428507524663*^-6}, {-8.924211893787128, 
       0.0005739598634636452}, {-8.90388113561642, 
       0.0024338330564866286}, {-8.885480912332865, 
       0.004680670598860228}, {-8.86801564818743, 0.006769215288396249}, 
      {-8.84915730534855, 0.008461431588445256}, {-8.815000712092335, 
       0.009000871230685312}, {-8.780098775390584, 0.006294062829669706}, 
      {-8.747573963037572, 0.002677023717382876}, 
      {-8.72889010771533, 0.0010406023651860568}, {-8.711885682712559, 
       0.000181210064793898}, {-8.692257546236533, 
       0.00006833225247894646}, {-8.673697161350026, 
       0.0007655051861691111}, {-8.655671626600954, 
       0.001973710101529291}, {-8.63655657697834, 0.0034842975453939413}, 
      {-8.60225670881236, 0.005598147390006001}, {-8.58320417474945, 
       0.005947598815226713}, {-8.56534994825234, 0.0056267207180962075}, 
      {-8.54576282671394, 0.004653958076505444}, {-8.524686200663592, 
       0.0031712332847667435}, {-8.490574667159066, 
       0.0008746618354857183}, {-8.471263103378169, 
       0.00014674969901015315}, {-8.453328781037946, 
       0.000019365366806610237}, {-8.420492048358758, 
       0.0010532121486946466}, {-8.402129865467943, 
       0.002063788091195181}, {-8.385475789921832, 
       0.0029995245914198904}, {-8.35397141227161, 0.004201677893037185}, 
      {-8.31988155972262, 0.004027848331080557}, {-8.287693133121659, 
       0.002617808711206347}, {-8.258069030540014, 
       0.0010539413511601238}, {-8.224799034212928, 
       0.00004492789852310229}, {-8.193271804768655, 
       0.0003298820280648357}, {-8.164969488377087, 
       0.0014037727463446779}, {-8.13417305101254, 0.00273066334989523}, 
      {-8.100721773508223, 0.003437774555879487}, {-8.083827149801902, 
       0.00332712196746655}, {-8.065172948105744, 0.002858237352187342}, 
      {-8.032240938699262, 0.0015113841898764533}, 
      {-8.001314357209054, 0.00036573375490998275}, 
      {-7.972004696779284, 4.184873148091927*^-6}, 
      {-7.941137002365488, 0.0005537742252425784}, 
      {-7.914782279903176, 0.001500817900273309}, {-7.885944501874075, 
       0.0024955110232079015}, {-7.854794733530997, 0.00292988843560065}, 
      {-7.821506552927516, 0.002396182071587927}, {-7.790090723084104, 
       0.0012898241196004179}, {-7.761536433193512, 
       0.0003640569508194779}, {-7.727549598188619, 
       0.000014596252122630426}, {-7.710412567633954, 
       0.00023237392259796753}, {-7.691555924661312, 
       0.00072022848103739}, {-7.657834522472957, 0.0018493163762072795}, 
      {-7.627013013338446, 0.00256076381962295}, {-7.608383260198878, 
       0.0026339524553994705}, {-7.590691736147053, 
       0.0024245904180357093}, {-7.572020189773994, 
       0.001959004640236228}, {-7.551659854479914, 
       0.0012910792078106343}, {-7.533941706711148, 
       0.0007111538797666434}, {-7.515072388799733, 
       0.0002345962404303518}, {-7.481138962039778, 
       0.000046029981779745523}, {-7.446736450906747, 
       0.0007674542036999377}, {-7.427364668332085, 
       0.0013888090078744092}, {-7.409559638796649, 
       0.0019341188233016249}, {-7.376785632756996, 
       0.0025011721687316166}, {-7.342195834414425, 
       0.0021808867593671537}, {-7.311135837526937, 
       0.0012810008100192368}, {-7.282167723345961, 
       0.0004166019054020433}, {-7.250382947490422, 
       1.2955133162052223*^-7}, {-7.216343704527733, 
       0.0004447727691159881}, {-7.184090603833334, 
       0.001425057511993906}, {-7.165527893401953, 
       0.0019832982852056764}, {-7.148525269828156, 
       0.0023525226287725498}, {-7.130642114616456, 
       0.002513917091140805}, {-7.11138335972271, 0.0023904799865187326}, 
      {-7.076549146652419, 0.0015263187941009656}, 
      {-7.043910860779169, 0.0005111168805879809}, 
      {-7.013575549418705, 0.000012628677136486173}, 
      {-6.981926724151627, 0.0002884878739893005}, 
      {-6.9473416700710535, 0.0013134937984858514}, 
      {-6.9290278265418275, 0.0019169599642703688}, 
      {-6.909194873633149, 0.0024202540782981004}, 
      {-6.8904675359502825, 0.0026371540259363217}, 
      {-6.873218087739922, 0.0025675217546670616}, 
      {-6.840519108194535, 0.0018077084257908816}, 
      {-6.80593489905087, 0.0006542228351137837}, {-6.788008275395991, 
       0.0002085171475336797}, {-6.76876917282288, 
       2.3868716306300483*^-6}, {-6.734032599135041, 
       0.00047067289586373356}, {-6.71283172777302, 
       0.0011687874875503095}, {-6.692725058915167, 
       0.0019162118713825591}, {-6.6746755919349186, 
       0.0024938302124854557}, {-6.655019524981073, 
       0.002871579563155329}, {-6.622292178106041, 
       0.0027010119321212588}, {-6.591532772529627, 
       0.0017551233596678822}, {-6.573724035562938, 
       0.0010752697523806194}, {-6.554953361284251, 
       0.00044942677344664083}, {-6.521376704619408, 
       6.416882349090664*^-6}, {-6.488747632130572, 
       0.0006601104310064673}, {-6.4702470837919135, 
       0.0013888116025579248}, {-6.453015255146353, 0.00214015413613986}, 
      {-6.434687726780693, 0.0028514953501163278}, 
      {-6.417365911456784, 0.0033013169555946194}, 
      {-6.397400174133972, 0.003431564088016384}, {-6.379238240325358, 
       0.003157008706946524}, {-6.3483147097753285, 
       0.0020208720509411167}, {-6.315538560817642, 
       0.0006180241665515652}, {-6.287556072526379, 
       0.000012267935132040933}, {-6.2567405837262475, 
       0.00044510001436196754}, {-6.223666289997584, 
       0.0019778016122780893}, {-6.205428325201075, 
       0.0029628602961297244}, {-6.18809476151397, 0.003750437879706751}, 
      {-6.154515432205091, 0.00431648507821162}, {-6.123798763882037, 
       0.0034746525544633745}, {-6.0909587736947, 0.0016875306102988833}, 
      {-6.0736860785997555, 0.0007912193849027249}, 
      {-6.055441578156326, 0.00015901298177462743}, 
      {-6.021906091449998, 0.0003265569300961778}, 
      {-5.991057775758401, 0.0019910550615468343}, 
      {-5.963366471771268, 0.004020612269756175}, {-5.933686896974911, 
       0.0056478765717777775}, {-5.9011218902134805, 
       0.005721812099934059}, {-5.870725394318343, 
       0.0040661689339735515}, {-5.836011650702918, 
       0.001392985920094149}, {-5.816399459113532, 
       0.00031977844507454634}, {-5.798257793510964, 
       3.161055692106317*^-6}, {-5.764973906576157, 
       0.001481024071715359}, {-5.748167835205905, 0.003087000483792695}, 
      {-5.729620753620218, 0.005171953488638455}, {-5.697687312633152, 
       0.008298867703501927}, {-5.663269491192514, 0.009080190629755085}, 
      {-5.63077649518305, 0.0066740082074467875}, {-5.600990090202443, 
       0.003042783957514357}, {-5.572702331827715, 
       0.0004106143639422644}, {-5.542487839614945, 
       0.000519903009352479}, {-5.513973388302576, 0.004032441059305181}, 
      {-5.488069252165722, 0.00916417965904151}, {-5.457581431281031, 
       0.014958491208039215}, {-5.424537786824908, 0.01729088519121107}, 
      {-5.393335197990851, 0.013930640831654633}, {-5.364571581271482, 
       0.007454355207091592}, {-5.334823740309869, 0.001350801797214706}, 
      {-5.306997578055036, 0.00041671492811626363}, 
      {-5.276468806626691, 0.00767009709941657}, {-5.243678219681503, 
       0.023702674873254333}, {-5.209368803877671, 0.04133331698195744}, 
      {-5.176803653329765, 0.047948265639212215}, {-5.147571190112547, 
       0.03988632605544122}, {-5.115710776456129, 0.0192161178020777}, 
      {-5.098551514481276, 0.007787800964495508}, {-5.080450675071566, 
       0.0005111200129608355}, {-5.04805865404699, 0.01506263257707513}, 
      {-5.0131965699549115, 0.09478117343395581}, {-4.993421568311221, 
       0.1758854547514076}, {-4.974987684583439, 0.2739075191644481}, 
      {-4.93938005765223, 0.5069722447890094}, {-4.905698984521717, 
       0.7375055032887065}, {-4.875461289098208, 0.9036632452436616}, 
      {-4.842618787284174, 0.9950453843231848}, {-4.812497672863213, 
       0.9761027373314971}, {-4.780546022122765, 0.8534879502396393}, 
      {-4.75326765854542, 0.6885727431336939}, {-4.723203089653409, 
       0.4800951815257998}, {-4.691428614931361, 0.27377532421019757}, 
      {-4.657227212937022, 0.10900169391149694}, {-4.624940227554408, 
       0.024263021113940644}, {-4.595381659507639, 
       0.0002602492077611263}, {-4.561349765707082, 
       0.011847497599300861}, {-4.542316154313129, 0.025246807620361893}, 
      {-4.525047733801393, 0.03655573291962677}, {-4.4914139972912155, 
       0.047854195740181675}, {-4.459709491663192, 0.04237572241587461}, 
      {-4.441698551504416, 0.034089575815747224}, {-4.422658784490642, 
       0.023646004419507784}, {-4.388549150205903, 0.007137146879711013}, 
      {-4.369570885453504, 0.0018158414021518003}, 
      {-4.351841961711008, 0.00001685563591292945}, 
      {-4.3323902619817956, 0.001244346710892987}, 
      {-4.311524926960099, 0.00517121790823524}, {-4.276819079818801, 
       0.013212768061717456}, {-4.257203050870447, 0.01629995625746865}, 
      {-4.239043054251799, 0.01732444230673098}, {-4.205739480097959, 
       0.014473133833809292}, {-4.188916973582039, 0.01135952853583961}, 
      {-4.170336616424902, 0.007479416241253347}, {-4.138384296942319, 
       0.001914819476426483}, {-4.10391807676349, 
       0.00003777184289878539}, {-4.071378334137829, 
       0.002353091542248094}, {-4.0415247680300315, 
       0.006000949929698215}, {-4.00788863791503, 0.008907663230370766}, 
      {-3.9761142554185986, 0.00875103438310759}, {-3.9475870597134635, 
       0.006370098197693935}, {-3.9166432113433842, 
       0.002914500094155152}, {-3.882926350518947, 
       0.00033171475584349005}, {-3.8659229360489604, 
       5.202548976610072*^-7}, {-3.8472074921049253, 
       0.0004340222462651825}, {-3.8141212358661924, 
       0.0026255351515921473}, {-3.7831471150247222, 
       0.004911353420072979}, {-3.7520911042110447, 
       0.005944352915465917}, {-3.7225899653909105, 
       0.0052217290045142705}, {-3.696108674439158, 
       0.0035164829273824838}, {-3.6672232389007653, 
       0.001445530383730832}, {-3.6359241128577393, 
       0.00010320147933490372}, {-3.602581079807557, 
       0.00039820421814426436}, {-3.5711174435183883, 
       0.001936614723939005}, {-3.5426093866112844, 
       0.0034760509136480505}, {-3.508352398191944, 
       0.0043308695523899595}, {-3.491104901748813, 
       0.004142096868108006}, {-3.4721862168522697, 
       0.003498362381678073}, {-3.4383071389610653, 
       0.0017356758251094776}, {-3.4074385988558284, 
       0.0003738788235733751}, {-3.3886905871972117, 
       0.000019148683492886143}, {-3.3709425029464635, 
       0.00009589324210490477}, {-3.352209231284152, 
       0.0005724049439263281}, {-3.331845615564451, 
       0.0013994837156085693}, {-3.298311400590664, 
       0.002824744941567289}, {-3.2792265309244213, 
       0.003322026391138939}, {-3.2613218749265616, 
       0.0034350946880765364}, {-3.2291932498615523, 
       0.0027636863504075754}, {-3.1945824798175133, 
       0.001319876149544907}, {-3.176564358420047, 
       0.0006218896665428638}, {-3.1576075089753375, 
       0.00013598582120049585}, {-3.1237295276215318, 
       0.0001648518879930471}, {-3.0922348367324455, 
       0.0010931834559785275}, {-3.0629533232599964, 
       0.0021836390680249314}, {-3.0308212788922315, 
       0.002894913842247808}, {-2.996517919294807, 
       0.0026139113508508224}, {-2.9639106234816275, 
       0.0015541858506805553}, {-2.9451748334882653, 
       0.0008680962530197359}, {-2.9280674761992467, 
       0.0003579321326857783}, {-2.9100175486447912, 
       0.00004744837747705253}, {-2.8906400900936395, 
       0.00003997550439000695}, {-2.872683347563637, 
       0.0003288547266550158}, {-2.855648080764674, 
       0.0008047352174876036}, {-2.825549058967382, 
       0.0018195920481422893}, {-2.7935266962702388, 
       0.00256394701109584}, {-2.7750863931802163, 0.00263361534662163}, 
      {-2.758400325224877, 0.0024418273830023184}, 
      {-2.725854777699335, 0.0015431557463177201}, 
      {-2.7075422371758537, 0.0009255824927008737}, 
      {-2.6904802186072163, 0.0004266771454830444}, 
      {-2.672681219767581, 0.00008916346894098396}, 
      {-2.6531833166514733, 0.000011181333937828241}, 
      {-2.6334238030611354, 0.0002569617886070822}, 
      {-2.612284044726982, 0.0008049442966470724}, 
      {-2.5927588193121696, 0.0014338720035443969}, 
      {-2.5747304566985862, 0.001977912351861476}, 
      {-2.5563957739305763, 0.0023707567792079303}, 
      {-2.536491683275685, 0.002514859319600401}, {-2.518944363118392, 
       0.0023686931863823118}, {-2.5003400070344726, 
       0.0019679999213453297}, {-2.464993003231912, 
       0.000866164187592371}, {-2.432649292841709, 
       0.00010714095723245913}, {-2.4003768351562402, 
       0.00010970106446261935}, {-2.3696952008326893, 
       0.0008209452213201699}, {-2.3526977305782237, 
       0.0013658440177391792}, {-2.3345755418914673, 
       0.0019216561496191178}, {-2.3019667772565224, 
       0.0024977031132728546}, {-2.27126791079521, 
       0.0022748784344221295}, {-2.2434301047560155, 
       0.001529530257410229}, {-2.2123577847802833, 
       0.0005558344626469259}, {-2.1795270557151007, 
       9.058914901906609*^-6}, {-2.162406729685025, 
       0.00006770517063627344}, {-2.143612229479963, 
       0.00040505806635370386}, {-2.1105649493093477, 
       0.0014347830516674134}, {-2.0919451849361774, 
       0.0020317902722510046}, {-2.071982291583904, 
       0.002490471218636991}, {-2.053139789735727, 
       0.0026444753163284334}, {-2.0359576620409108, 
       0.002514015244164217}, {-2.0026906797508084, 
       0.0016564895021147941}, {-1.9851432161090332, 
       0.0010549176916889852}, {-1.966499028513022, 
       0.0004774853822214092}, {-1.9323187375292024, 
       4.387941054287296*^-7}, {-1.9006914559261654, 
       0.0004740186427143169}, {-1.86815281595463, 
       0.0015975870587817806}, {-1.8378760740531506, 
       0.002585783436334122}, {-1.8062898280694932, 
       0.002919880054403683}, {-1.7717342761014234, 
       0.0022321571638278916}, {-1.7417827739571552, 
       0.001123091367798268}, {-1.7145646687558864, 
       0.00026778262601675476}, {-1.6831464504588107, 
       0.000038334504538372496}, {-1.6534821414207541, 
       0.0007317305679600186}, {-1.621167407446476, 
       0.002081275197043235}, {-1.5869511417946158, 
       0.0032477879572491773}, {-1.557738880466996, 
       0.0033759412451687264}, {-1.5256015027997885, 
       0.002472508489802404}, {-1.4910737680367203, 
       0.0009541670055844302}, {-1.471689921751497, 
       0.00029069511396788623}, {-1.4539764085541926, 
       0.000010334491940012587}, {-1.4195980838093791, 
       0.0005818007591890234}, {-1.386957385355472, 
       0.0021691633737489745}, {-1.3570796512202932, 
       0.003664368578625173}, {-1.3289669069601642, 
       0.004324422607961244}, {-1.2965644669421914, 
       0.003728965100755326}, {-1.2672205792166966, 
       0.002231788612339888}, {-1.2412530127282653, 
       0.0008271536526946971}, {-1.2138520176291032, 
       0.000025770518391450506}, {-1.1838036109521144, 
       0.0005064683378239141}, {-1.1561907723365428, 
       0.0021072587624902848}, {-1.126199367143435, 
       0.004293747327693497}, {-1.094086868514432, 0.005824864335497822}, 
      {-1.0637782390324686, 0.005583178834550308}, 
      {-1.0361767762125516, 0.003967518850292151}, 
      {-1.0037742869069561, 0.001461222089986001}, 
      {-0.9854774580446127, 0.0004112540300544346}, 
      {-0.9685695561717766, 4.518191691872334*^-6}, 
      {-0.9375331520697812, 0.0010417002237532189}, 
      {-0.904600352144086, 0.004234594801160589}, {-0.8719102903580094, 
       0.007712593903832569}, {-0.8415326954210729, 
       0.009212561695604464}, {-0.8098395030256954, 
       0.007891219481039604}, {-0.7752126255522458, 0.00395843747111762}, 
      {-0.7451614387155707, 0.000775398002080346}, 
      {-0.7178887321190127, 0.00010476416942440997}, 
      {-0.6864070683299822, 0.00310285657139015}, {-0.6567219669145747, 
       0.00876947842188187}, {-0.6242978390036575, 0.01496809263940954}, 
      {-0.590010914557601, 0.017259529261360956}, {-0.560737964381874, 
       0.014045517368516733}, {-0.5285762546620838, 
       0.006785253738469891}, {-0.4939769232129599, 
       0.0004785073676363096}, {-0.4745662414377105, 
       0.000349889498410427}, {-0.456851573379491, 0.003323247395518241}, 
      {-0.4224487166258144, 0.017203586237039183}, 
      {-0.3898276989650046, 0.03496562362338711}, {-0.277832229571106, 
       0.015908881980119863}, {-0.2506172933353591, 
       0.0012826812567016475}, {-0.22125204628714282, 
       0.008368498002489197}, {-0.18902421928885496, 
       0.06650511930041972}, {-0.15874011559117818, 0.1829082235434612}, 
      {-0.12557313915377405, 0.37465587351530977}, 
      {-0.09062136533176005, 0.6157127041213578}, {-0.05825105666247384, 
       0.8232754831154199}, {-0.028106413708968214, 0.956389376594131}, 
      {-0.00019989328307886453, 0.9999977547000506}, 
      {0.029640942164978007, 0.9515936162719346}, {0.0627533392149959, 
       0.7973789823712069}, {0.0928684046806672, 0.6000785983857838}, 
      {0.12463216125890711, 0.3808396061409431}, {0.15878763703669713, 
       0.18267780738415085}, {0.19102997313913783, 0.06098387855217759}, 
      {0.22051795617653944, 0.009025224022365982}, 
      {0.2535311042960996, 0.0021944901664505668}, 
      {0.28490114022939805, 0.020947002457498424}, 
      {0.3188004949381462, 0.041970409826359176}, {0.33798501129827974, 
       0.04747567235001138}, {0.35578896172098745, 0.0472262231628662}, 
      {0.3875234005574386, 0.036132421217356006}, {0.41740747694360125, 
       0.01988378905843416}, {0.4442403610932605, 0.007296560190542455}, 
      {0.4732551568568941, 0.0004643578257133584}, 
      {0.504969308113406, 0.0018554000352200364}, {0.5384613436232609, 
       0.009177436554392212}, {0.567055997306752, 0.015116065307367366}, 
      {0.5984310804786933, 0.017286041067315235}, {0.6160640059504767, 
       0.01605997407149377}, {0.6352374771242854, 0.013125754221533495}, 
      {0.6700916310519796, 0.006016854543204722}, {0.7040232615552471, 
       0.0009275766414694137}, {0.7354046586895444, 
       0.00021552747852309872}, {0.7692475892394343, 
       0.00322110338593143}, {0.7887316310658741, 0.005645048132174805}, 
      {0.8065892631178314, 0.007599543387924802}, {0.8253600146885852, 
       0.00890893720938546}, {0.8455872183046704, 0.009161666429667497}, 
      {0.8634186452853747, 0.008371544021889684}, {0.8821849046638292, 
       0.0067326122928654765}, {0.9138787271719515, 
       0.0032018232594764064}, {0.9477247731259456, 
       0.0004439259615387606}, {0.979666200011863, 
       0.00020071616543856983}, {1.0086780122131398, 
       0.001816265988334692}, {1.042830281042919, 0.00444560343581825}, 
      {1.0620887488299389, 0.005517386154619084}, {1.0798384522260795, 
       0.005937966510201701}, {1.1124642952944592, 
       0.0051278469786085615}, {1.1469926080770112, 
       0.0027796182757786002}, {1.1789738557836542, 
       0.000719846250603306}, {1.2138234631651907, 
       0.0000255072832863959}, {1.2467384132163353, 
       0.0010931200495483335}, {1.277244504754669, 
       0.0027990417765802592}, {1.3074956846600874, 
       0.004088847077188937}, {1.3348775785344764, 0.004272363360614358}, 
      {1.3664861323719044, 0.003247776110125567}, {1.3962124951003423, 
       0.0016661640191659947}, {1.4288561274772813, 
       0.00028624057460108394}, {1.4632843952446661, 
       0.00011196129163082746}, {1.4926787373896309, 
       0.0010207316078137995}, {1.5248887752328242, 
       0.0024433587738785607}, {1.5596313305043408, 
       0.0033972007296334543}, {1.5790955425776783, 
       0.0033766755126472814}, {1.5968122867957506, 
       0.0029986359845154257}, {1.631263847822003, 
       0.0016397433758477578}, {1.66384514505434, 0.0004006705640062395}, 
      {1.691658607003029, 5.379393551597153*^-10}, 
      {1.7223070320278697, 0.000465607835013366}, {1.7543131891917256, 
       0.0016029263131269566}, {1.7843098835968154, 
       0.0025939837985149592}, {1.8122900743312342, 
       0.002929182139826143}, {1.8379008684015576, 
       0.0025851784935396922}, {1.8674616622027511, 
       0.001623486521604768}, {1.89557403494888, 0.0006230763509333978}, 
      {1.9257525597010245, 0.000026522289228265993}, 
      {1.9579379943543345, 0.0002714807379111635}, 
      {1.9883106527157528, 0.0011631656253401853}, 
      {2.0158612277148316, 0.002068145727407069}, {2.0483381357766897, 
       0.00263397996146237}, {2.0666393115779558, 0.0025647929365344765}, 
      {2.083484507006145, 0.00225719309223754}, {2.1144687873620427, 
       0.0013016663946226114}, {2.147216670987112, 
       0.00032083308723018783}, {2.179347024241406, 
       8.361543890385424*^-6}, {2.197505549210245, 
       0.0002131748213478631}, {2.214312996395169, 
       0.0006099787792276858}, {2.244531956297389, 0.001564637849343392}, 
      {2.2779021941290463, 0.002386735956303414}, {2.3077018565765486, 
       0.002452692108372242}, {2.335690161696414, 0.0018904957867220474}, 
      {2.3650161689005778, 0.0009668896542011338}, 
      {2.3971089908683925, 0.0001572806011384603}, 
      {2.4298627340719685, 0.0000734828491231047}, 
      {2.4643616856769865, 0.0008466538907620484}, 
      {2.4966761763402263, 0.0018662874186518208}, 
      {2.5260507639668415, 0.0024580103653947722}, 
      {2.5608649456841515, 0.0022953668304330015}, 
      {2.580000541930838, 0.0018302319821127185}, 
      {2.598073517812359, 0.001260367021798854}, {2.63023317977538, 
       0.000323883337964585}, {2.6651105091542995, 
       0.000020237158003634627}, {2.6951591986223993, 
       0.0005500137391261297}, {2.7232842579077534, 
       0.001456189760235324}, {2.7541403144467678, 0.002357542836883766}, 
      {2.787303052707428, 0.0026209274875769197}, 
      {2.821981928871924, 0.001931350246561985}, {2.85491822161271, 
       0.0008281321583639778}, {2.8844832233069777, 
       0.00010928285574422558}, {2.916726128098505, 
       0.00013060873149877658}, {2.947318424269984, 
       0.0009423891825278582}, {2.975031658867674, 0.001963238511721485}, 
      {3.0070224308637754, 0.002815831534169898}, {3.0371327462003377, 
       0.00282341962526142}, {3.065099742136916, 0.0021107864395803165}, 
      {3.0908078753186237, 0.0011467566856399407}, 
      {3.1190295736857334, 0.0002594161990459859}, 
      {3.1488183869398862, 0.000027838240245480953}, 
      {3.1810984105468747, 0.0007808898353415749}, 
      {3.1993290339224085, 0.0015247908480198235}, 
      {3.216180996911195, 0.002256946190505137}, {3.2471097705064604, 
       0.003264699098822429}, {3.279938566259341, 0.003310028664142427}, 
      {3.3092487106475406, 0.0024054300747035785}, 
      {3.3367410248063516, 0.0011829932407696271}, 
      {3.3669007482382654, 0.0001674612381240727}, 
      {3.3993842621786317, 0.00016808509833684675}, 
      {3.431999379206342, 0.001404511006063716}, {3.4676446095119497, 
       0.003291219883337701}, {3.485644405661421, 0.003998209617498517}, 
      {3.504856841859471, 0.004326910882051447}, {3.539447468165024, 
       0.0036148404299302266}, {3.571902369907691, 0.001891517412711964}, 
      {3.6062325045142085, 0.00028231349157614835}, 
      {3.6355422603922647, 0.00009616317971404002}, 
      {3.6677544324907565, 0.0014792847242366988}, 
      {3.7001504798652087, 0.0038119139203041308}, 
      {3.7304327170838207, 0.0055655284360527114}, 
      {3.7631747588497024, 0.005781168882516593}, {3.7815464606691327, 
       0.0050050087255401375}, {3.798318148626936, 
       0.0038715976326687703}, {3.828571257892333, 
       0.0015228075478994727}, {3.8615211403071115, 
       0.0000309168328968849}, {3.892641208879788, 
       0.0008384196583579316}, {3.921469265322333, 0.003433453368273278}, 
      {3.9469660347040234, 0.00630340703219713}, {3.974485916540699, 
       0.008662982781588512}, {4.004688825165984, 0.009032045045562868}, 
      {4.033078961295402, 0.006954242678876316}, {4.063211533122078, 
       0.003313699438449984}, {4.094975483443505, 0.0003451787738134522}, 
      {4.1220951958683605, 0.0004036455918651629}, 
      {4.151797755935334, 0.003917642732717266}, {4.186468115193542, 
       0.010858349731593086}, {4.21847438630297, 0.01620691060975192}, 
      {4.235192268562304, 0.01729418994495061}, {4.253604890261197, 
       0.016653987330923187}, {4.272832811860394, 0.013980855121664703}, 
      {4.290844471999567, 0.010113335650988448}, {4.323308339691168, 
       0.0027102951728653823}, {4.354166021620174, 
       0.0000819255185014052}, {4.3711730239225055, 
       0.0021300163979923194}, {4.389735580987997, 0.007580927622670471}, 
      {4.422276678471155, 0.023433677314599586}, {4.454202493363228, 
       0.040123628181063936}, {4.488735090007116, 0.04797611356523031}, 
      {4.521341068091501, 0.03861103731875213}, {4.551337920262991, 
       0.018779505655669153}, {4.578464927212271, 0.00264026031867152}, 
      {4.608238920780969, 0.0054501019189421565}, {4.6393270447601385, 
       0.053567540375134566}, {4.668348450333843, 0.15438288628729965}, 
      {4.68633017910272, 0.24469742539477515}, {4.703363434583749, 
       0.34691895294239933}, {4.735286807833068, 0.5646516530697301}, 
      {4.753359790653371, 0.6891885381197177}, {4.772558653880944, 
       0.8095729272661565}, {4.807039945849078, 0.9620751870459116}, 
      {4.840701517119412, 0.9968582341480356}, {4.859865029778818, 
       0.960734594257998}, {4.877854647048174, 0.8929367596833514}, 
      {4.897193260065785, 0.7901458875817261}, {4.914923118614975, 
       0.6768124815712033}, {4.954880215639397, 0.40055966623990835}, 
      {4.984802971725632, 0.21921456269840522}, {5.0167676201786575, 
       0.08295689337692408}, {5.035141689891924, 0.03560992001043789}, 
      {5.0518357160999035, 0.010856046803105606}, 
      {5.084459810248852, 0.0014591941692598009}, 
      {5.118132587462375, 0.020955619103568288}, {5.135862701702006, 
       0.033203687830416106}, {5.154632522767416, 0.043061236339664646}, 
      {5.189098994533873, 0.047212263837636666}, {5.220875145930971, 
       0.03606629461447125}, {5.252821276814229, 0.01870521062087332}, 
      {5.287643450575821, 0.003971471439291283}, {5.320532893981858, 
       0.00006931623414182051}, {5.351024827348105, 
       0.004305859169284945}, {5.381252357974726, 0.011423796613748255}, 
      {5.4086213651756045, 0.016232313357809156}, 
      {5.440214941803672, 0.01689671458167508}, {5.469936456762762, 
       0.01284945513623354}, {5.502554130390986, 0.00616685142735544}, 
      {5.536965713122572, 0.000952323766706761}, {5.566345725959677, 
       0.00013266322633708055}, {5.5985500827836345, 
       0.002753372995209143}, {5.633275730729021, 0.006945284808774448}, 
      {5.6527336342084675, 0.008603760499681926}, 
      {5.670450149567381, 0.009211051172286046}, {5.704895986823793, 
       0.007732767163559403}, {5.7374819972543385, 0.004273054209301105}, 
      {5.765273242710395, 0.001456631584190203}, {5.795906721372455, 
       0.000019263808309283122}, {5.827897664360929, 
       0.0008751467533792189}, {5.85788942238972, 0.0030709804683597586}, 
      {5.884005413058702, 0.004953555337619238}, {5.911462937235872, 
       0.005925449978830089}, {5.941569529660124, 0.00533154575318071}, 
      {5.9691352353672915, 0.003604492494257327}, 
      {5.999299033963757, 0.0014402597547658604}, 
      {6.031478765810846, 0.00008591009086913948}, 
      {6.061846421479003, 0.0003321564101601306}, 
      {6.089401034988774, 0.001599844742893212}, {6.121872123680524, 
       0.00338542166340913}, {6.140172983467345, 0.0040745288858880895}, 
      {6.157023129184066, 0.004328534319216362}, {6.188011549167989, 
       0.0037535904800764883}, {6.220773989073591, 
       0.0021363562827536064}, {6.252869092416682, 
       0.0005799013466176701}, {6.271010627351215, 
       0.00009599151977763544}, {6.2878075720876545, 
       0.00001371539358326969}, {6.31860956776302, 
       0.0007301452316588584}, {6.351357054102445, 
       0.0021557513751041877}, {6.380546731360297, 
       0.0031885903251457686}, {6.407970652767595, 
       0.0034189724945382326}, {6.438053715833268, 0.002735004162273277}, 
      {6.470507467907592, 0.0013776150300327586}, 
      {6.502987043199361, 0.00025119581218574906}, 
      {6.521399156876009, 6.334062134290254*^-6}, {6.5385420251301065, 
       0.00009789166813852424}, {6.573185878655652, 
       0.001055259593873187}, {6.590951266745758, 0.0017331667892544267}, 
      {6.610223921655712, 0.002396387094880438}, {6.6447493721035435, 
       0.0029299705420219534}, {6.677367723598773, 
       0.0024188866028013326}, {6.709122216630663, 
       0.0013064632113242046}, {6.738421927663475, 0.000356698620462066}, 
      {6.766241937969141, 3.2884226735291214*^-8}, 
      {6.796150965987034, 0.0003858446926588395}, 
      {6.824384492783149, 0.001261621257865214}, {6.850201159873066, 
       0.0020997241952959863}, {6.880379493624842, 
       0.0026282765284379494}, {6.913301526162697, 
       0.0023358328573688876}, {6.944397291243934, 
       0.0014139223390888889}, {6.9732497808766505, 
       0.0004966048856563289}, {7.00579891729224, 
       2.4316787166892953*^-6}, {7.036444300206424, 
       0.0003291523385281957}, {7.063960937087891, 
       0.0011163442381649025}, {7.093709365718526, 
       0.0020305748991673923}, {7.126231643904718, 
       0.0025129508239315223}, {7.160570513208757, 
       0.0021090754170347698}, {7.1898882243941395, 
       0.0012364627204812827}, {7.222050485258886, 
       0.0003121986980354126}, {7.256526064426126, 
       0.00001890080863002858}, {7.288404399517857, 
       0.0005780967996013107}, {7.305040309711966, 
       0.0010827751538788023}, {7.323392539029024, 
       0.0016728607186898587}, {7.342558631140965, 
       0.0021888873158711986}, {7.36054162202552, 0.0024697633945071737}, 
      {7.393478173954488, 0.0023064385814818176}, 
      {7.423659577515835, 0.0015086878096013218}, 
      {7.440701347658309, 0.0009550226622123448}, 
      {7.458896871963241, 0.0004305078644331957}, 
      {7.4916618824787, 1.276983416877871*^-8}, {7.52163464577588, 
       0.00037629012039239656}, {7.54885312006645, 
       0.0011955022022173288}, {7.581392649829504, 0.002218638201907314}, 
      {7.611377172847049, 0.002642919462675163}, {7.642486691950128, 
       0.002280174291327211}, {7.676191190484415, 0.0012299234364986037}, 
      {7.705904534083641, 0.00032881519920556967}, 
      {7.737344474555989, 8.220044096486439*^-6}, 
      {7.771599483396634, 0.0006457306746874669}, 
      {7.802880915263697, 0.0017686547260681179}, 
      {7.820161215894175, 0.0023563516403604942}, {7.8389877453965005, 
       0.002796693841838316}, {7.873245768690953, 0.0027782236402380724}, 
      {7.905200797011314, 0.0018643841298737075}, 
      {7.939201802852526, 0.0006137825366891969}, 
      {7.971284779912394, 6.601513535475383*^-6}, 
      {8.000319140100746, 0.00033954485128187556}, 
      {8.28942500244437, 0.0027107569146063324}, {8.321292997731694, 
       0.00406684800657007}, {8.351425194064173, 0.00424621993795642}, 
      {8.386156767243772, 0.002963384661297253}, {8.41776411102817, 
       0.0011926816283264008}, {8.447573621454728, 
       0.00009237821369640445}, {8.475101115122877, 
       0.00024473747590910403}, {8.50531533381024, 
       0.0017648451997856452}, {8.537353435348322, 
       0.0040951480298378855}, {8.567997311508458, 0.005712092950515055}, 
      {8.596711736129738, 0.005772927700742054}, {8.62821320184443, 
       0.004118993785982226}, {8.662107711142069, 0.0015003777292314573}, 
      {8.679596508735226, 0.000470481728943906}, {8.698690869223379, 
       1.4879049428968193*^-6}, {8.733474842907219, 
       0.0013835155886675167}, {8.767339102044824, 0.00486344466270728}, 
      {8.79878595745577, 0.008062623375855539}, {8.816778470646145, 
       0.009060427161612247}, {8.836246148831316, 0.009084349999026133}, 
      {8.854627926893938, 0.008055993124757532}, {8.87154405938327, 
       0.006374186650945799}, {8.905665837303827, 0.002234305230261733}, 
      {8.937529127110086, 0.00003126908369997249}, 
      {8.971815882930105, 0.0019415449203136757}, 
      {8.989981582472817, 0.004799961729419295}, {9.00945997049419, 
       0.008715327258565476}, {9.029872640629192, 0.012877843804337444}, 
      {9.04921462415991, 0.015924007425077977}, {9.066578163577475, 
       0.017249677263083588}, {9.085470464646443, 0.01676830534175023}, 
      {9.116975950929232, 0.011743965041904572}, {9.151760182559057, 
       0.0036447156933366426}, {9.169240160450002, 
       0.0007979521836277252}, {9.188088157018566, 
       0.00011139359155120247}, {9.222201399312743, 
       0.007297613405740939}, {9.34873459824393, 0.041482876943665585}, 
      {9.381247805555658, 0.021155583602631936}, {9.411949621050711, 
       0.002540602660530484}, {9.42892786911822, 0.00030742628119187704}, 
      {9.447337332437227, 0.01037084564531437}, {9.479499357972257, 
       0.07252934221522779}, {9.51024591997463, 0.19546688077951338}, 
      {9.54280560127322, 0.3874364823046363}, {9.601188560984168, 
       0.7824883612953307}, {9.633937311996037, 0.9420306763431641}, 
      {9.652323578304513, 0.9888539800774306}, {9.669127471656468, 
       0.9995938933589553}, {9.701738504092635, 0.9319103810512733}, 
      {9.732704912294587, 0.7763313005115066}, {9.802782488828013, 
       0.3063354390960573}, {9.82295653874706, 0.19384383307559644}, 
      {9.841941085807465, 0.11082543874424282}, {9.858987687824106, 
       0.056981364558779876}, {9.87740761618291, 0.020191861272043345}, 
      {9.894118475924436, 0.00375699311443316}, {9.912441476846299, 
       0.0003138034269243839}, {9.931572436250026, 0.007673135455368364}, 
      {9.949413620872885, 0.019562734505610874}, {9.981370265532416, 
       0.040173439428094065}, {10.015591055917362, 0.04791010448860775}, 
      {10.050049595720791, 0.038036060315079195}, {10.082657755891272, 
       0.020528789207294968}, {10.111931804699802, 0.006836681522254367}, 
      {10.143741319898785, 0.00016392106084149664}, 
      {10.178564083647542, 0.0031321152268954946}, 
      {10.198378347809959, 0.0075965934095248286}, 
      {10.216960150556213, 0.011977439576232152}, {10.236488152152658, 
       0.015557579203255125}, {10.254373626005542, 0.017189061816085236}, 
      {10.27401027687347, 0.016856097149209905}, {10.294662045418422, 
       0.014352315909433028}, {10.329207636892454, 0.007503082850741665}, 
      {10.361313316344068, 0.0019098977935188219}, 
      {10.379781905503496, 0.0002840125742641108}, 
      {10.396544914226732, 0.00005302693165293807}, 
      {10.41589491044851, 0.0011163791450081219}, {10.434142827881534, 
       0.0030347794700873996}, {10.464686305620548, 
       0.006749979837082617}, {10.49746358588418, 0.009107337001993458}, 
      {10.528402437166402, 0.008467944274380208}, {10.556641354329592, 
       0.0058711107439663015}, {10.589714151736413, 
       0.002238491334540072}, {10.608411342432992, 0.000752206085160828}, 
      {10.625728144623439, 0.00006682477884994626}, 
      {10.657478371737184, 0.000674147854237251}, {10.691244475664666, 
       0.0030818106625441354}, {10.723272503874721, 
       0.0052809175902605145}, {10.757835241346006, 
       0.005876731794774552}, {10.790466664463578, 0.004438759860133726}, 
      {10.820417218124971, 0.0022657743142066246}, 
      {10.85358710492518, 0.00037921399692862547}, 
      {10.872393576833293, 4.6802497497139035*^-6}, 
      {10.889909063806469, 0.00018812410462395898}, 
      {10.908442499968013, 0.0008619961548418746}, 
      {10.925300295062158, 0.0017511658478220242}, 
      {10.943313591990066, 0.0027787146956298327}, 
      {10.963149131818215, 0.003734691463449216}, {10.993477240068701, 
       0.004330507185293061}, {11.025619936594968, 
       0.0035779176477532316}, {11.05539400996099, 0.002059481419291689}, 
      {11.083279366929204, 0.0006872569285467952}, 
      {11.116085162975896, 6.596054143082377*^-8}, 
      {11.146092037910444, 0.0005265612828714062}, 
      {11.180727158043954, 0.0019847087132062492}, 
      {11.2136423449377, 0.0031856744149453844}, {11.242062488661809, 
       0.0034121868047949705}, {11.272351544979854, 0.0026960559997364}, 
      {11.300933836712739, 0.0014984554352494564}, 
      {11.3268423562103, 0.0005014763432822531}, {11.357405848893231, 
       2.318455534687937*^-7}, {11.390458533632419, 
       0.0005152989639094494}, {11.42166692778209, 
       0.0016379417249839678}, {11.450372510666122, 
       0.0025847574579705747}, {11.483709540329427, 
       0.0029099607137809402}, {11.51528209328288, 
       0.0022774899115322513}, {11.543625647294942, 
       0.0012585719181280174}, {11.574449171129574, 
       0.0002910464289421853}, {11.607949148501158, 
       0.00003135196979813811}, {11.624863741594963, 
       0.00028186678694709454}, {11.643529215306453, 
       0.0007894139498924792}, {11.676866662114536, 
       0.0019064126929525366}, {11.707424932438904, 
       0.0025785225974471466}, {11.736445198055074, 
       0.0025206465107936193}, {11.766990508949485, 
       0.001768046224336298}, {11.800249951732013, 
       0.0006718319920405218}, {11.831185497210164, 
       0.000044911566590466985}, {11.858014056584587, 
       0.00011748242120231991}, {11.88666785786273, 
       0.000783402480174333}, {11.916143959130848, 0.001725588173002615}, 
      {11.947342566851466, 0.0024264984379130574}, 
      {11.964827121005502, 0.0025119290985149466}, 
      {11.984055059686145, 0.0023134506932389765}, 
      {12.017895409749073, 0.0014061166532355804}, 
      {12.036944662446391, 0.0007962583135492609}, 
      {12.057403734214077, 0.0002677938671563726}, 
      {12.076715914900696, 0.00001690587938426968}, 
      {12.094357150860398, 0.00005364484263152044}, 
      {12.128421930157174, 0.0007741760341429652}, 
      {12.147688069279052, 0.0013894607050029808}, 
      {12.165546350301785, 0.0019344518433231591}, 
      {12.19827567803946, 0.002500759552649949}, {12.233111386632345, 
       0.0021766558023934156}, {12.266866338241329, 
       0.0011832863719477933}, {12.284608251454125, 
       0.0006308348489524455}, {12.303322340801843, 
       0.00019224384041843695}, {12.337742350692073, 
       0.00007306245038141703}, {12.369360291537253, 
       0.0007785304798270318}, {12.397784946485425, 
       0.0017252670336758958}, {12.428208194445764, 
       0.0024989008300010185}, {12.461587526840693, 
       0.0025436810628166233}, {12.492700827288756, 
       0.0017967037306964853}, {12.56636956716162, 
       5.122371894011727*^-13}}]}}, {RGBColor[0, 0, 1], 
   {Line[{{-12.56636956716162, 0.008830503877159473}, 
      {-12.535346075972443, 0.015754811185889867}, 
      {-12.507119971238707, 0.017135770568018023}, 
      {-12.474538596166004, 0.01240136259173993}, {-12.443739190438858, 
       0.005396418700580166}, {-12.415255648781839, 
       0.0008488213868458093}, {-12.388958866118317, 
       0.00016746333092898083}, {-12.360095243978401, 
       0.0028579608304699577}, {-12.329496534381976, 
       0.0069624514628503584}, {-12.29878639205406, 
       0.009177660488906616}, {-12.26575116885331, 0.007786644571348401}, 
      {-12.234565858908786, 0.004110090022918573}, 
      {-12.206033631406457, 0.0010511312320462232}, 
      {-12.172701076560804, 0.00007295883936294468}, 
      {-12.153833561980074, 0.0009174418670952972}, 
      {-12.136317068898217, 0.002290288640340389}, 
      {-12.104240236532737, 0.0049368828297748244}, 
      {-12.070044948831644, 0.005916959544768998}, 
      {-12.052854170333802, 0.005366047950863625}, 
      {-12.034692707163202, 0.004185917898246706}, 
      {-12.002166958402272, 0.001579163608429708}, 
      {-11.98406401540396, 0.0004972433338256247}, 
      {-11.967163303891487, 0.000025650768517693653}, 
      {-11.948619909432306, 0.00018676678248529977}, 
      {-11.928741255990499, 0.0010309661646479222}, 
      {-11.911614735957247, 0.002076589666152333}, 
      {-11.89298475079978, 0.0032191507110917467}, 
      {-11.859111791089102, 0.004325110589561797}, 
      {-11.82613529664867, 0.0035640923763867603}, 
      {-11.7956255219607, 0.0018167385245870008}, {-11.76604765282384, 
       0.0003591510980253955}, {-11.738279591451864, 
       0.00003277342717685683}, {-11.70781826791319, 
       0.0009499675010528143}, {-11.674980781734485, 
       0.0025471223907554707}, {-11.642409245418378, 
       0.0034287733091595486}, {-11.608116939959425, 
       0.0028420310098711417}, {-11.57883821503342, 
       0.0015076984320755097}, {-11.54681091272948, 
       0.00024892650203121603}, {-11.528073073375742, 
       4.6900384929186195*^-7}, {-11.5107965691237, 
       0.00017203123666904727}, {-11.491832846024678, 
       0.0007350935508678367}, {-11.47175560329633, 
       0.0015626326808605953}, {-11.438014229844404, 
       0.002734293018014071}, {-11.418838801687226, 
       0.0029294812597507173}, {-11.400898638783374, 
       0.0027158407792939932}, {-11.368358269749042, 
       0.0015977221941459463}, {-11.351177302945619, 
       0.0008958088985637349}, {-11.332885754461586, 
       0.0003011040032801089}, {-11.29938196820371, 
       0.00006104086117995371}, {-11.268318194566103, 
       0.0008605931257834842}, {-11.24805199332544, 
       0.0016273955863891612}, {-11.228985256653996, 
       0.002257466672140695}, {-11.211864719513224, 
       0.0025892615248393714}, {-11.19336929468918, 
       0.0026054104479742686}, {-11.176002776448765, 
       0.0022952736657434847}, {-11.15767978897768, 
       0.001713437376473122}, {-11.124886986781199, 
       0.0005331854833614881}, {-11.106515332966557, 
       0.00010780916410060005}, {-11.086846709797605, 
       0.00001549490864623592}, {-11.06828302885926, 
       0.0002932699544939205}, {-11.051379465513943, 
       0.000787018712041134}, {-11.031533210488277, 
       0.0014964803820988835}, {-11.009973167997629, 
       0.002172354315508621}, {-10.989612487501963, 
       0.002497657182331067}, {-10.970799637907591, 
       0.0024285879226035737}, {-10.937144286545456, 
       0.001540391304541375}, {-10.905873400490858, 
       0.0004725406841368905}, {-10.87324806942084, 
       1.1667609570810796*^-6}, {-10.85600443369145, 
       0.00017877158996731002}, {-10.837607006137288, 
       0.0006534319459499117}, {-10.817408186089418, 
       0.0013591561074184752}, {-10.798364312144466, 
       0.0019982729999310873}, {-10.781265519618941, 
       0.002391230840500883}, {-10.762754163521521, 
       0.0025109110660300736}, {-10.745409608047893, 
       0.002305432429057713}, {-10.727070768859639, 
       0.001810025897494757}, {-10.694213593575292, 
       0.0006586419847928822}, {-10.663395346645695, 
       0.00002011885566876201}, {-10.63033105701903, 
       0.00037070625191723127}, {-10.599121590502513, 
       0.001441656937691429}, {-10.570642445389721, 
       0.002365162762723478}, {-10.537280000224293, 
       0.0025854542135698576}, {-10.51842138971513, 
       0.002199482156775427}, {-10.500959234593402, 
       0.0016095707616102619}, {-10.469179567442934, 
       0.00046374971576881044}, {-10.434892993575367, 
       0.000013635562682988759}, {-10.404336080841407, 
       0.000674041057780044}, {-10.37629626939751, 
       0.0017973125867117897}, {-10.349487854715129, 
       0.0026957125198563358}, {-10.321240166003276, 
       0.0028880233736489486}, {-10.290203212852628, 
       0.0020761383130455456}, {-10.261303681443234, 
       0.0008752001095582248}, {-10.229592419237061, 
       0.00003501216611166552}, {-10.195687146533079, 
       0.00045049857537162114}, {-10.162836777582935, 
       0.0018884111989592703}, {-10.14553222931167, 
       0.0026791402771635473}, {-10.12719667132986, 
       0.0032668149661390228}, {-10.093540942131233, 
       0.0032177992066808343}, {-10.062484689598666, 
       0.0019762373329062525}, {-10.034700673015566, 
       0.0006505018768735377}, {-10.004828148645265, 
       3.24895622032269*^-9}, {-9.97204777393739, 0.0008197342229047675}, 
      {-9.941354110890545, 0.00257652094091037}, {-9.923853095580203, 
       0.003540350158850983}, {-9.905205640148443, 
       0.0042003503308851815}, {-9.871662488892655, 
       0.003928624138885218}, {-9.85111913556829, 0.0029080407305786954}, 
      {-9.831775914912015, 0.0016885044279426004}, 
      {-9.814194259320331, 0.0006919967538146909}, 
      {-9.795629186282268, 0.00007168616692104458}, 
      {-9.760972094892578, 0.0007145291517945855}, 
      {-9.729101964309804, 0.003027515630317336}, {-9.694803106103084, 
       0.0054549429331536845}, {-9.675337436193661, 
       0.005946705084582426}, {-9.657173638060653, 0.005582271177836881}, 
      {-9.626300617172953, 0.003450390720714178}, {-9.592734284723475, 
       0.0007334557598930937}, {-9.561034189757288, 
       0.00011674837863274107}, {-9.531720093303688, 
       0.0021348030288616928}, {-9.497610609615858, 
       0.006280950447503709}, {-9.4803902094789, 0.008087774210831766}, 
      {-9.461391792507234, 0.009149229918058041}, 
      {-9.4283268162056, 0.007860140195798625}, {-9.397300626691107, 
       0.003932598383239472}, {-9.366211125655013, 
       0.0004660469310958326}, {-9.333014381072823, 
       0.0009675964294936427}, {-9.301685866604524, 
       0.006279854714003838}, {-9.273234134598155, 0.01276672013611531}, 
      {-9.239737016148693, 0.017247454519503064}, {-9.220849155563231, 
       0.016593972445366395}, {-9.20344309326673, 0.013835907069604058}, 
      {-9.169411940195426, 0.005194462478180625}, {-9.137589058801513, 
       0.00004240160678085683}, {-9.107090154422037, 
       0.004510705971328548}, {-9.074341832220716, 0.020559127006459312}, 
      {-9.041063490056718, 0.040049456769651534}, {-9.022244461460094, 
       0.04679896049397546}, {-9.004804762717482, 0.0475882997632569}, 
      {-8.986548113124472, 0.0418889225196491}, {-8.967121123484977, 
       0.029510895698156667}, {-8.948693069519107, 0.015017359308192544}, 
      {-8.931364406534518, 0.0036776013747523988}, 
      {-8.91443621817992, 0.0001780843366727435}, 
      {-8.89615778981068, 0.011301899910417839}, {-8.864294265423746, 
       0.08543708532945107}, {-8.800144650989568, 0.46980911998183444}, 
      {-8.768847832029753, 0.7099640937540577}, {-8.740364181217384, 
       0.8909043606929856}, {-8.710238382772975, 0.9924567281353852}, 
      {-8.678002038320944, 0.9674827618742894}, {-8.661164868089665, 
       0.900662876608017}, {-8.642882959111848, 0.7945309913041038}, 
      {-8.609674323754298, 0.549208599704681}, {-8.5792162408705, 
       0.3209285347837934}, {-8.55067381660927, 0.15075721774513143}, 
      {-8.520905634910969, 0.04217495809782485}, {-8.488107150070032, 
       0.000756618684157001}, {-8.459870910655521, 0.008522843055401796}, 
      {-8.43402882210939, 0.02832455153657225}, {-8.404201027120893, 
       0.04547436548048399}, {-8.375838102578697, 0.04646110581065045}, 
      {-8.34305615449382, 0.03150504374870939}, {-8.325809763966344, 
       0.02089941274016864}, {-8.307583884928944, 0.010741512480057563}, 
      {-8.274090148233615, 0.00048804025679704855}, 
      {-8.243264724425067, 0.0022351675598764834}, 
      {-8.21362885456673, 0.009591657846507739}, {-8.185952523464993, 
       0.015679756915367517}, {-8.155586478334415, 0.017042253382703154}, 
      {-8.123023734108067, 0.01204979880502082}, {-8.088353980699793, 
       0.004272738691411435}, {-8.06876151884462, 0.0011998603805954652}, 
      {-8.050628980579297, 0.00002811349262682097}, 
      {-8.017370445356246, 0.001961561982116428}, 
      {-8.00057316646176, 0.00417180355539629}, {-7.982026448056477, 
       0.006669984594923082}, {-7.950117336255688, 0.009152843272955742}, 
      {-7.91570842622523, 0.007772931567287306}, {-7.883223192494964, 
       0.003928570469568033}, {-7.853428907198076, 0.00084932280702901}, 
      {-7.825177461018274, 0.00003213213416651845}, 
      {-7.794986570595435, 0.0015723076077798401}, 
      {-7.766493818538994, 0.004028884397804005}, {-7.740596355188331, 
       0.005654292101673067}, {-7.710132448038873, 0.005675463813645183}, 
      {-7.6770980993799895, 0.00357404492709371}, {-7.646122385465472, 
       0.001156622806543088}, {-7.617133089962636, 
       0.00002429015145033004}, {-7.587198613914908, 
       0.0006079364651729088}, {-7.554260367956571, 
       0.0025519789194014346}, {-7.522165369315705, 
       0.004113780530928171}, {-7.4876751672653725, 
       0.004020900735200134}, {-7.4556786172599, 0.0024218928159303326}, 
      {-7.425293473143578, 0.0007163007605851264}, 
      {-7.398018380235832, 8.144510297620525*^-6}, 
      {-7.368276331790387, 0.0005203355122776745}, 
      {-7.351151236972152, 0.0012712492239687573}, 
      {-7.333077353186219, 0.0021749310416400752}, 
      {-7.300725201222458, 0.0033305832359732616}, 
      {-7.265906807490151, 0.0031001102673391535}, 
      {-7.246151436980545, 0.0023350848337084134}, 
      {-7.227726585533111, 0.0014490929305020453}, 
      {-7.194301227711902, 0.00018782384911233217}, 
      {-7.163855566831028, 0.00011665744316854645}, 
      {-7.1470140642237086, 0.0005540864343755843}, 
      {-7.128712551453911, 0.0012696988234964426}, 
      {-7.095454231117478, 0.0025512143950036773}, 
      {-7.065825097287755, 0.0029194764616898255}, 
      {-7.033153198516759, 0.0021814542338193217}, 
      {-6.9990329867692775, 0.0008107717331658179}, 
      {-6.967032728230044, 0.000029861407884267222}, 
      {-6.937204357126494, 0.00028206654617765956}, 
      {-6.909882885536016, 0.0011797001399796753}, 
      {-6.877621330703445, 0.0022962908346290884}, 
      {-6.848336989432604, 0.0026374130511823035}, 
      {-6.81600621180983, 0.0019981888444119454}, 
      {-6.78150141855483, 0.0007433924394457987}, {-6.749532315735522, 
       0.00002759711321961432}, {-6.719381800496293, 
       0.0002703223723683059}, {-6.578462757034275, 
       0.001224492486921501}, {-6.544230777531038, 
       0.00019096626687342368}, {-6.512236200828828, 
       0.000082036135096156}, {-6.478863979193342, 0.000950984254043081}, 
      {-6.46004198337144, 0.001624541578196727}, {-6.442191413422092, 
       0.0021690996539674152}, {-6.422820399543741, 
       0.0024900032941455046}, {-6.4051385328133525, 
       0.002456175347490847}, {-6.386102888898342, 
       0.0020801411406626198}, {-6.365372864476431, 
       0.0013999694142894747}, {-6.347572214626753, 
       0.000765523533076333}, {-6.3286399814830485, 
       0.00023369694695447374}, {-6.294616540001887, 
       0.0000859982399459771}, {-6.264726352721239, 
       0.0008639765852130306}, {-6.2319933524066755, 
       0.002052663706694984}, {-6.197818659751012, 0.002644475291793854}, 
      {-6.1659875790134455, 0.002124500977439969}, 
      {-6.1361120891918715, 0.0010393152083402143}, 
      {-6.108935698965628, 0.00020287446809681478}, 
      {-6.077565948638787, 0.00008670606385252863}, 
      {-6.047917596112608, 0.0009148819388776951}, 
      {-6.015686270858535, 0.0022124706986069312}, 
      {-5.981523977652006, 0.0029281003742234334}, 
      {-5.952358075004673, 0.0024959814054395183}, 
      {-5.920239360720952, 0.0012382705045299548}, 
      {-5.885766313828953, 0.00011545803219970978}, 
      {-5.866402999465191, 0.000023373199675523733}, 
      {-5.848690421007305, 0.00036037775431350006}, 
      {-5.814330917742208, 0.0018205861633044543}, 
      {-5.78167526538472, 0.003159855692602548}, {-5.7513211477030755, 
       0.0033683372157383294}, {-5.723804528166221, 
       0.0025114154651083285}, {-5.694171966008536, 
       0.0010611226464474553}, {-5.662123676759553, 
       0.000041500011079907166}, {-5.63235829436345, 
       0.00039920656600699397}, {-5.604977987619227, 
       0.0017560088931243972}, {-5.578998664789696, 
       0.003286809356998671}, {-5.551153993573198, 0.004274276336332083}, 
      {-5.52098394974272, 0.0038995519231979315}, {-5.492822935677295, 
       0.002386823115245104}, {-5.459335110806436, 
       0.00047160964990285983}, {-5.4288076872699405, 
       0.00007707898395732497}, {-5.397015318574536, 
       0.0016088217616566283}, {-5.36243868054847, 0.004371290393081688}, 
      {-5.329784049696405, 0.0059139594966454365}, 
      {-5.299577869495002, 0.005198072770087465}, {-5.2687061070142684, 
       0.0027692865500995863}, {-5.239989302286274, 
       0.0005707829292758023}, {-5.210030076292671, 
       0.00014830065829976772}, {-5.177264692185258, 
       0.002632924535745269}, {-5.144007759071612, 0.006716120974532145}, 
      {-5.125394744486158, 0.008487166603804278}, {-5.108485632034476, 
       0.00920128777731878}, {-5.076050574323108, 0.007622592902997102}, 
      {-5.04543570769878, 0.003660089951453741}, {-5.016499642122916, 
       0.0004781567886604856}, {-4.985870381094476, 
       0.0007099342151311014}, {-4.959720461005344, 
       0.004594606939293522}, {-4.930961019780838, 0.011089577337515978}, 
      {-4.900052879858431, 0.01655258680995535}, {-4.866854817767442, 
       0.016117264378074515}, {-4.83551767501838, 0.009446152101742567}, 
      {-4.80688980783386, 0.002324252889636814}, {-4.773337151396934, 
       0.0007605686804250037}, {-4.754592508275154, 
       0.005407322229450253}, {-4.737622505820388, 0.013027280454225585}, 
      {-4.704156240552414, 0.0329838089166239}, {-4.673412143808301, 
       0.04656435257168031}, {-4.655874061295275, 0.0477028695950985}, 
      {-4.637373614388657, 0.0422373099178575}, {-4.618802456552923, 
       0.030691326854820247}, {-4.59844844561408, 0.014750353786653734}, 
      {-4.580821726821664, 0.003370902092557552}, {-4.561954254206879, 
       0.0006614572146545652}, {-4.527935056976904, 0.04426731920571007}, 
      {-4.493793269477669, 0.17740105784281204}, {-4.474517422429927, 
       0.29347107239607934}, {-4.456710360143043, 0.42060446587992706}, 
      {-4.424661549769004, 0.6675684012426533}, {-4.407650081853413, 
       0.7889778855783733}, {-4.389339281823374, 0.8966261765072457}, 
      {-4.357736008881169, 0.9957448144754529}, {-4.3281112126288575, 
       0.967502474436912}, {-4.2942040190499275, 0.8024909496000449}, 
      {-4.2631621587833, 0.5755848457234468}, {-4.229275449949316, 
       0.3206295991704839}, {-4.197332482488143, 0.13441364892518137}, 
      {-4.168651885178006, 0.03668488759313218}, {-4.137607897968291, 
       0.0006048022713241886}, {-4.103709854495573, 
       0.012959377698222467}, {-4.08663237890163, 0.026387405680772892}, 
      {-4.06787547582052, 0.03938350193171571}, {-4.034684448791502, 
       0.04784495285488064}, {-4.003678390291966, 0.03752254267809718}, 
      {-3.9750902656919767, 0.020401652977076173}, 
      {-3.9439731538864344, 0.004973613597729065}, 
      {-3.9145847987521525, 5.689494966008741*^-7}, 
      {-3.887377843089959, 0.00348778878925767}, {-3.855756690395333, 
       0.011651005924307171}, {-3.822142299553632, 0.017120425048471825}, 
      {-3.7938613707529294, 0.01585206632721744}, {-3.7626252551743558, 
       0.009653969259337886}, {-3.7281839628781404, 
       0.002453015526944576}, {-3.710861263573246, 
       0.00046976063690615174}, {-3.6919005767842528, 
       0.00007555182256358029}, {-3.6582973378626766, 
       0.0031238944588167657}, {-3.6270142657257693, 0.0072710726442255}, 
      {-3.6079711841577224, 0.00886395788137747}, {-3.5899821302569004, 
       0.009182522627548163}, {-3.5563126225165878, 
       0.006776199766797187}, {-3.519612799915428, 0.002309837806037281}, 
      {-3.50110507768376, 0.0006855463420743193}, {-3.4807338611513408, 
       1.0064779104936613*^-6}, {-3.446610127735859, 
       0.0014527145885321275}, {-3.414664759400836, 
       0.0041859886051584475}, {-3.3852886252019565, 
       0.0058229270294966355}, {-3.3537103742816647, 
       0.005398426339665918}, {-3.336055592493126, 0.004273968018651109}, 
      {-3.3167979942806234, 0.00271294133053488}, {-3.2998201902118436, 
       0.0013979488359236905}, {-3.281733695355513, 
       0.0003898999425942792}, {-3.247596742083535, 
       0.00022110135125780395}, {-3.2159262206003247, 
       0.0018142587243307868}, {-3.18307651277867, 
       0.0037251532789636488}, {-3.1644351374933355, 
       0.004276878816189678}, {-3.147043847210624, 0.004249341182125154}, 
      {-3.1286727841925472, 0.003670909430495469}, 
      {-3.1119341971102656, 0.002790415869999534}, 
      {-3.0923911586434585, 0.0016122028527079443}, 
      {-3.0743225566924925, 0.0006689536193647207}, 
      {-3.0422773578299545, 5.582094191492311*^-6}, 
      {-3.007443286821901, 0.0009765027084358762}, 
      {-2.9769645008470422, 0.002467604229480237}, 
      {-2.9441310306794626, 0.0034177834955103027}, 
      {-2.9258853544091274, 0.003333062044338753}, 
      {-2.909167919171317, 0.002873301799005526}, {-2.876366936240036, 
       0.0013789814263663943}, {-2.8574915563063534, 
       0.0005700455575855204}, {-2.8399425765823687, 
       0.00010264784806921614}, {-2.8216339651276985, 
       0.000021952769372982982}, {-2.801620540287985, 
       0.00041017667620146017}, {-2.781886350165475, 
       0.0011400882464806005}, {-2.763268969097682, 
       0.0019261763691428304}, {-2.7284457819615007, 
       0.002888090047309815}, {-2.7089293833207106, 
       0.002854599894082691}, {-2.6909475508009963, 
       0.0024436379847633887}, {-2.671209148299962, 
       0.0017075228105669995}, {-2.65032625680467, 0.000855524265647935}, 
      {-2.617281059376416, 0.00003108162082893074}, 
      {-2.5871080055958395, 0.00028683753704099676}, 
      {-2.552280489189384, 0.0014753006854500018}, 
      {-2.51924019622211, 0.0024843577218620727}, {-2.4887928438898617, 
       0.0025494288231808406}, {-2.4605825357120983, 
       0.0018100190816563771}, {-2.4298554317436576, 
       0.0006846488908486737}, {-2.3966838242152746, 
       9.610686828944343*^-6}, {-2.3776279727970833, 
       0.0001152080625389946}, {-2.360130947544158, 
       0.0005153602198091151}, {-2.3257653654501715, 
       0.0017051835453538312}, {-2.2945281447839663, 
       0.0024575817749890993}, {-2.2615934146711907, 
       0.0022625680941346167}, {-2.117870667783933, 
       0.0013498511707566868}, {-2.085462361959322, 
       0.0023211141358965483}, {-2.06716999571095, 0.002514716765540612}, 
      {-2.050279977553416, 0.0023894119292716853}, 
      {-2.0192634104682137, 0.0015357896717515995}, 
      {-1.9863784312587787, 0.0004193114603840937}, 
      {-1.956984863790759, 1.1763193892423026*^-7}, 
      {-1.9294452943251916, 0.00039978327798286114}, 
      {-1.8992325961208594, 0.0014452060912629214}, 
      {-1.8667286181257718, 0.0024539809976889004}, 
      {-1.8323427108964088, 0.002513697455026966}, 
      {-1.812877757936648, 0.0020233331845727486}, 
      {-1.7948044597090818, 0.0013675520776812204}, 
      {-1.761710004324504, 0.00026135751405215456}, 
      {-1.74320556610057, 6.0645403410977025*^-6}, 
      {-1.726425696954871, 0.00010495488396127451}, 
      {-1.6946740509560305, 0.00104649268264231}, {-1.6603232415369664, 
       0.0023999371275925476}, {-1.6278886609636165, 
       0.002928025016639207}, {-1.598043753336715, 
       0.0023543696410292855}, {-1.5702242161254147, 
       0.0012332880476612572}, {-1.5438670000187904, 
       0.0002870334809775477}, {-1.5134860518242081, 
       0.000053015595733748546}, {-1.4857822290741836, 
       0.0008271175307258315}, {-1.4552577860728597, 
       0.0022605241325732305}, {-1.4220497846467646, 
       0.003364489943159295}, {-1.3911420024380847, 
       0.0031493919894893447}, {-1.3625427979403233, 
       0.001968903260056964}, {-1.3349497897888716, 
       0.0006522718922893896}, {-1.3052008307685106, 
       4.2726895329493374*^-8}, {-1.2725528385409135, 
       0.0008056092532087894}, {-1.2418988687667885, 
       0.0025560711172341703}, {-1.209327518727359, 
       0.004104278763951235}, {-1.1750313385707531, 
       0.004036826105113165}, {-1.1457493368515417, 
       0.002565466878274446}, {-1.1137146426159288, 
       0.000659565164788904}, {-1.0789091691126764, 
       0.00007709696645376624}, {-1.0468143073720204, 
       0.0016310120621897246}, {-1.0122778242611363, 
       0.0043907766991663115}, {-0.99264932350449, 0.005559623177802775}, 
      {-0.9742830936039033, 0.005947509664491548}, 
      {-0.9434587985713253, 0.004802734847878501}, 
      {-0.9103404963871298, 0.0020288382969461147}, 
      {-0.8921934532665369, 0.000689189645271409}, 
      {-0.8749636386456636, 0.00003707201662125189}, 
      {-0.8426352541103238, 0.0011325124619002993}, 
      {-0.813089050967653, 0.0043677139771517385}, 
      {-0.7811663081356746, 0.008038451531225059}, 
      {-0.75102592417064, 0.009179769515677094}, {-0.723328563469142, 
       0.007320554971819104}, {-0.6908922433595022, 
       0.003029282821631785}, {-0.6566654147209752, 
       0.000043662443987652094}, {-0.627867333223228, 
       0.0015788368148560122}, {-0.5962947774723877, 
       0.0075485119012888065}, {-0.5620007209827326, 
       0.014945997982726058}, {-0.5427827211741787, 0.0171247824143392}, 
      {-0.5252812730303544, 0.016963407751656622}, 
      {-0.49125680834962243, 0.010923644567616962}, 
      {-0.4590632360982858, 0.0027398651612231717}, 
      {-0.427365667331429, 0.0003272315127413488}, 
      {-0.3980742864943648, 0.008033952782889845}, 
      {-0.3659247840719444, 0.025863558006562436}, 
      {-0.3318108729529643, 0.04408935950353536}, {-0.29772870152565506, 
       0.046111424250393725}, {-0.2785736965716637, 
       0.037326049049805334}, {-0.2610319311122077, 
       0.024629568420904847}, {-0.22868180304218874, 
       0.00239401886884646}, {-0.19466337164094255, 
       0.013352471835279814}, {-0.17654407283283174, 
       0.04807484876316275}, {-0.15721009480924136, 0.11392953920098485}, 
      {-0.1224062305614547, 0.3083949837095111}, {-0.08478949079383194, 
       0.5907107731888273}, {-0.06485280946829972, 0.7401936401461078}, 
      {-0.043460596447735325, 0.8756364285658775}, 
      {-0.0249324534451541, 0.9576117177834353}, {-0.008023212088961226, 
       0.9955422559509108}, {0.025091620300218, 0.9570782441232065}, 
      {0.042905131247880625, 0.878634424284811}, {0.062300509679517106, 
       0.7580935288681937}, {0.09758222614486609, 0.4911688694654666}, 
      {0.13026511154204332, 0.2567887900315361}, {0.16501896305030436, 
       0.08357616325267449}, {0.19468896931827936, 0.013320158344711182}, 
      {0.22746951663930903, 0.001926865990666525}, 
      {0.24593851746161352, 0.012773623605896312}, 
      {0.2654013810927941, 0.028044478419482658}, {0.3002127753453488, 
       0.046736887090915565}, {0.31961355379620715, 0.04732467228065626}, 
      {0.337680404668596, 0.04171621508347972}, {0.3575049597642869, 
       0.03104290347312942}, {0.37870363582325667, 0.018078752459269386}, 
      {0.3970561033359511, 0.00847962895483274}, {0.41696947529932, 
       0.0018821417913340557}, {0.4357741950228651, 
       3.3494083890500075*^-6}, {0.45312855136429814, 
       0.0016232059909653718}, {0.48599148202861964, 
       0.009545144818991616}, {0.520816529386847, 0.016569475519846787}, 
      {0.553730598973882, 0.016150940129902133}, {0.5838329315899379, 
       0.010454039339221073}, {0.6162371750083173, 
       0.0033718814714753962}, {0.6345755694508882, 
       0.0008357805830186237}, {0.6515942870124145, 
       2.011101749441433*^-6}, {0.681994838997021, 0.001911294081628617}, 
      {0.7143906884487106, 0.006244173451504849}, {0.7456919009076733, 
       0.00903258598984111}, {0.7740616220538359, 0.008585605707654109}, 
      {0.791542140930384, 0.007005472366416724}, {0.8100026115956307, 
       0.004760023360573402}, {0.8430573229969884, 0.001098627759193577}, 
      {0.8614584011013371, 0.00011094480116566585}, 
      {0.8786308471366719, 0.00011050669494515034}, 
      {0.8974726308353052, 0.0010260051726915915}, 
      {0.9176633981497314, 0.0026676295820026396}, 
      {0.9350716995360728, 0.004173040960950818}, 
      {0.954000921765822, 0.00542909892376287}, {0.9884110720900082, 
       0.00571824418959847}, {1.0219104509240027, 0.003638215437030111}, 
      {1.0528920835585032, 0.0012075275785457557}, 
      {1.084002278739536, 0.000012629201489969192}, 
      {1.1167434605144648, 0.0008075708187447973}, 
      {1.144697934943279, 0.002499245908284093}, {1.175264911343168, 
       0.004044190760894674}, {1.2083054363592836, 0.00413174427088647}, 
      {1.226795473426383, 0.0034058473584224146}, {1.2435896349677964, 
       0.002453865898244362}, {1.2762815017197873, 
       0.0006385294441789101}, {1.3071328387059253, 
       3.7208956843184156*^-6}, {1.3360829912339909, 
       0.0006983008993684631}, {1.3667212775610782, 
       0.0021751055773426074}, {1.392878950564566, 
       0.0031959601943845456}, {1.4216413847687186, 0.00337037780523999}, 
      {1.4525586705772076, 0.0023844994132989593}, 
      {1.4857601747955949, 0.000828031738242228}, 
      {1.517100326249722, 0.000018939981073963106}, 
      {1.545725435985004, 0.00033663673453801485}, 
      {1.5790585403394033, 0.0016104480673775755}, 
      {1.6104067619632105, 0.00270648215776534}, {1.6277785631149089, 
       0.0029277644744187497}, {1.6465382165865192, 
       0.0027626601449726096}, {1.6792426485827585, 
       0.001684610090815328}, {1.6983984159604562, 
       0.0009002990799347324}, {1.7186014338401392, 
       0.000257441971389578}, {1.7358504695432608, 9.74171769737838*^-6}, 
      {1.7547517972210882, 0.00012343807903094983}, 
      {1.772249306788156, 0.0005508421733370261}, {1.7909748764342965, 
       0.0012204063074044184}, {1.8247348595305646, 
       0.0023598329463137436}, {1.8588865165960091, 
       0.0025783632207838415}, {1.8781660086166665, 
       0.002172270119073356}, {1.8959730145848155, 0.001567629455428665}, 
      {1.928668291274599, 0.0004210482823793681}, 
      {1.963343880663633, 0.000018480199819271873}, 
      {1.9943282509240332, 0.0006557490438470997}, 
      {2.0233673099175, 0.001679079165109009}, {2.0552247147698464, 
       0.002455995601648469}, {2.089508791140324, 0.002235691296191681}, 
      {2.1213854078927374, 0.0012225680929258752}, 
      {2.1558821464303315, 0.00018491112858532788}, 
      {2.1884549178036403, 0.00009395717134938669}, 
      {2.2184363083645215, 0.0008641885235289726}, 
      {2.236560783264038, 0.0015124752852666845}, {2.2534888689903503, 
       0.0020601140070199897}, {2.271146364091936, 
       0.0024304567744837845}, {2.2905365965137956, 
       0.002493006136338296}, {2.3220936922620736, 0.001827212447912868}, 
      {2.355937667848238, 0.0006439895813447143}, 
      {2.375332537301968, 0.0001528142792550073}, {2.3964390735382097, 
       8.533927618936794*^-6}, {2.416372853788337, 
       0.00029587286485270624}, {2.434823469095739, 
       0.0008552781761884856}, {2.4690189365507504, 
       0.0020907752689135785}, {2.488491461043171, 
       0.0025451085364936203}, {2.506780358036821, 0.002632039666897516}, 
      {2.5394569061123646, 0.0019424444340430825}, 
      {2.557837520173322, 0.0012620621817903928}, 
      {2.57469756039995, 0.0006461153674358358}, {2.5914835346797367, 
       0.00019018137046501076}, {2.609853211818773, 
       4.195787802649707*^-9}, {2.629031436443803, 
       0.0002068323888253608}, {2.64688205183265, 0.0007282127056686366}, 
      {2.6799950875985155, 0.0020591792982673648}, 
      {2.6986754450247785, 0.0026595976050343443}, 
      {2.715906356083552, 0.00291936798290072}, {2.747565328660778, 
       0.002492096039978297}, {2.78109766603196, 0.0011731740635670994}, 
      {2.8111002277005923, 0.00017002117102960328}, 
      {2.839182112154774, 0.00009061142344095503}, 
      {2.8699908015036186, 0.001082046375026872}, 
      {2.903102631582678, 0.002635520540325945}, {2.921311279525501, 
       0.003240188708982217}, {2.9382010862865817, 
       0.0034420442762210924}, {2.9567365580199865, 
       0.003203167996404945}, {2.9764786465265707, 0.002489538301308867}, 
      {2.993731665288597, 0.0016474159657665491}, {3.0123782239804404, 
       0.0007582566847491268}, {3.046167580414761, 
       1.225489570416641*^-6}, {3.0635609863904785, 
       0.0002754739912619688}, {3.0819202259984015, 
       0.0010309768124974934}, {3.1147851706762983, 
       0.0029557523016078596}, {3.1444319628961073, 
       0.004199176470153838}, {3.1769451133555613, 0.003967477409986928}, 
      {3.4417991476517997, 0.001840182420757746}, {3.4744061689373735, 
       0.00004527324937275147}, {3.504990885992776, 
       0.0009556716140488462}, {3.5368878378830173, 
       0.004377778973173129}, {3.554031384572259, 0.006512270985648672}, 
      {3.5720646309272652, 0.0083135587930084}, {3.6023213138880914, 
       0.00909697955198506}, {3.630038394287114, 0.006922602011011334}, 
      {3.660241319334347, 0.002865699538172678}, {3.6924790050084435, 
       0.00006065175685132314}, {3.7267657711001627, 
       0.0022360470780346943}, {3.758637030583567, 0.008720144321967025}, 
      {3.778140114433865, 0.013116778544524713}, {3.796535933932929, 
       0.016195935661295062}, {3.830941479351479, 0.016364147389239855}, 
      {3.8492146754860244, 0.013195510175207528}, 
      {3.868543690497816, 0.008299932040194628}, {3.9031825954436568, 
       0.0007065487728099952}, {3.9224490195379693, 
       0.0003200674638179494}, {3.9404583284525643, 
       0.003830974290857622}, {3.9602172472730595, 0.012009929739220725}, 
      {3.981425313362846, 0.024284421179211427}, {4.015228334825928, 
       0.04299225928350098}, {4.034340254670617, 0.04781756843076662}, 
      {4.052044569901203, 0.04614568071646781}, {4.084502092868021, 
       0.028039900380662043}, {4.119027032390734, 0.0033458659772981963}, 
      {4.1497854730434325, 0.00744002749955933}, {4.178697798279807, 
       0.06317590503167823}, {4.210413056379625, 0.2015762873282699}, 
      {4.244644850308525, 0.43237601010311444}, {4.277044265440973, 
       0.6818965432247918}, {4.307669416036256, 0.8822471541693375}, 
      {4.324596555157426, 0.9563717867769417}, {4.342969086913199, 
       0.9966742800180738}, {4.375083428679364, 0.9567607338475566}, 
      {4.405753472561042, 0.801436147012317}, {4.438264808219909, 
       0.5628760018635398}, {4.468724763310118, 0.3331145551668554}, 
      {4.4965912982219844, 0.16286079427314853}, {4.529256941022135, 
       0.04104505586524478}, {4.547270663516639, 0.010172658604473694}, 
      {4.564393137165601, 0.00019696829082078464}, 
      {4.594760855277513, 0.011979605035450137}, {4.627906173328298, 
       0.036971697236683705}, {4.646946697552989, 0.04591856436943232}, 
      {4.664209369145376, 0.047905760990384454}, {4.684136367764466, 
       0.04316477530664699}, {4.702907302597671, 0.03371682098369817}, 
      {4.736100597325053, 0.013840255289166077}, {4.754943020790949, 
       0.00528189237405098}, {4.772532812113245, 0.000872229554311296}, 
      {4.805210817599278, 0.0020071387085641846}, 
      {4.823533973316929, 0.006233767958517434}, {4.84023930538006, 
       0.010688201905527222}, {4.857833197911995, 0.014683517481523673}, 
      {4.876970178695053, 0.01708151259019222}, {4.911763626936714, 
       0.014968416531361571}, {4.944026478650027, 0.008050373625045765}, 
      {4.9782991874515625, 0.0015114069151638378}, 
      {5.007558721343676, 0.00006670822172159086}, 
      {5.039853210974547, 0.002905137906040613}, {5.057966849688845, 
       0.005401829207242252}, {5.074818094082677, 0.007493365681172351}, 
      {5.092398314356458, 0.008893083600610105}, {5.111627487418542, 
       0.009146140194854595}, {5.1311429135424955, 0.008031552777762904}, 
      {5.151990048534519, 0.005758429393421332}, {5.171243915637105, 
       0.003339728226501564}, {5.18899489984509, 0.0014342413924606117}, 
      {5.207102244894573, 0.0002499276871595593}, 
      {5.226729878180096, 0.00006971754611174}, {5.244033332134671, 
       0.0008068409814675887}, {5.262351473244835, 
       0.0022102745586020274}, {5.296936620003835, 0.005038751308522554}, 
      {5.329000646670935, 0.005923278132950983}, {5.360946777554194, 
       0.004480673479465013}, {5.395768951315786, 0.0017005797959610664}, 
      {5.426468622010685, 0.00012496435467655628}, 
      {5.45915032808807, 0.00046408995098260353}, 
      {5.491306329152044, 0.00229004790417455}, {5.521556942366832, 
       0.003920970181937744}, {5.548719850302576, 0.0043037338624971585}, 
      {5.578061957502727, 0.0033357668098428555}, 
      {5.610432143690318, 0.0014366102609883102}, {5.6287947836770185, 
       0.0005312097805881124}, {5.64591412364121, 
       0.00006412330101311814}, {5.680487074288474, 
       0.0004866601088830906}, {5.699859416533957, 
       0.0013361806267892004}, {5.717498027974945, 
       0.0022176876730012392}, {5.7490528376975325, 
       0.0033320867004021327}, {5.783329988566278, 
       0.0031134444975266114}, {5.815700244277604, 
       0.0017537276750051079}, {5.845607497994303, 
       0.0004564479478641564}, {5.873333506377468, 
       6.200732461498896*^-7}, {5.903180766279306, 
       0.0005711605409934805}, {5.931357465194638, 
       0.0017121844644758066}, {5.957156153374104, 0.002630429524853052}, 
      {5.985802789295593, 0.0029073528952944265}, 
      {6.017095086835234, 0.002161020959578926}, {6.050134291156715, 
       0.0008304219444281123}, {6.080112980183521, 
       0.00005463912947590983}, {6.112231340585346, 
       0.000275954890675007}, {6.142510986878829, 0.001283331129435255}, 
      {6.174476033220751, 0.0023561145079342236}, 
      {6.2090792314859, 0.0025748057439471963}, {6.239402595462232, 
       0.0018033020093070034}, {6.271461906344351, 
       0.0006348094547658223}, {6.29883304899843, 
       0.00003867976246289903}, {6.328899489813556, 
       0.0002392302057161966}, {6.360934661598559, 
       0.0012387367000547022}, {6.3949932129167, 0.002294886683538273}, 
      {6.412744125062926, 0.002510555029499088}, {6.432352232260293, 
       0.0023753031257698013}, {6.466942325413182, 
       0.0013796713416399011}, {6.499400812925082, 
       0.0003228971194962991}, {6.517661728095075, 
       0.000026828302856602066}, {6.534417184234052, 
       0.00004747880930866465}, {6.56528630471379, 
       0.0007609659145211451}, {6.5978103217780575, 
       0.0018947651237548066}, {6.627127196022824, 
       0.0024918244211951765}, {6.65847011946823, 0.002211399566314907}, 
      {6.688050615770387, 0.0012644829645645172}, 
      {6.714948313030642, 0.0003784815469896764}, 
      {6.746574583801973, 9.580086807542467*^-6}, 
      {6.780884118700569, 0.000722478202878859}, {6.813283266103282, 
       0.0019072956985655345}, {6.843177796482199, 
       0.0026026609798928146}, {6.874914582314435, 
       0.0023632766014809983}, {6.909034498382938, 
       0.0012121880922726683}, {6.941243019636952, 
       0.00019295605438424308}, {6.970694411830288, 
       0.00006778564806887984}, {7.005121549150894, 
       0.001046515045559656}, {7.023305240494404, 0.0017977787671446918}, 
      {7.0426786702423625, 0.0024996263203763817}, 
      {7.061288609434359, 0.0028840118309799486}, 
      {7.078152403926485, 0.0028899922394797846}, 
      {7.111067031712004, 0.0020103004554414116}, 
      {7.14523585644964, 0.0006153896920625502}, {7.162439937205194, 
       0.00014191279647053512}, {7.181313243163479, 
       0.000010438876776077733}, {7.201780340246458, 
       0.00038368343112156174}, {7.220877187911327, 
       0.0011269320561441071}, {7.239564341508877, 0.002024597495122345}, 
      {7.257256913784951, 0.0028056672276104877}, 
      {7.292023681381219, 0.0034316118359121904}, 
      {7.323704796012425, 0.002607189283305188}, {7.357974599703033, 
       0.0009475145028849936}, {7.3772413086264566, 
       0.00023681951372444662}, {7.394896353956366, 
       3.969087632631447*^-9}, {7.425383368916846, 
       0.0007203266023390585}, {7.4574625377507955, 
       0.002529926555629719}, {7.485507049960489, 0.0039480261705377604}, 
      {7.516166581657363, 0.004248232719184148}, {7.549693028018668, 
       0.002834424622558778}, {7.5684531078972315, 0.001648435482108495}, 
      {7.585489266585736, 0.0006875336702837705}, 
      {7.618655354493532, 0.00004213108645685944}, 
      {7.649948202388199, 0.0014139957504248988}, 
      {7.682816406135542, 0.004032651133455529}, {7.717594530845694, 
       0.00587776998361446}, {7.747286676606215, 0.005353610719515562}, 
      {7.779929263629364, 0.0028632610150354228}, 
      {7.797937748104213, 0.0013430625343186433}, 
      {7.815024129776824, 0.0003159917954104077}, 
      {7.834719210240031, 0.00003659913262901012}, 
      {7.852704618461415, 0.0007987127744606276}, 
      {7.885271578602842, 0.004186181821369416}, {7.90233236096266, 
       0.006323184357522227}, {7.920752606914481, 0.008217344054587345}, 
      {7.953833960943505, 0.009042608063032928}, {7.984939446651099, 
       0.006303952550916526}, {8.012658565449678, 0.0025394602344593785}, 
      {8.043027068033224, 0.00004581487628923572}, 
      {8.076039011331176, 0.0021434161450996714}, 
      {8.110849038946666, 0.009262284244179186}, {8.143088707006871, 
       0.015759586224764928}, {8.17313036899261, 0.01705664663358569}, 
      {8.203533112772561, 0.012169415967715074}, {8.232279867513922, 
       0.004669071387928668}, {8.258088036675762, 
       0.00023852512299162446}, {8.286108656805158, 
       0.0026470622738129566}, {8.316611899209006, 0.015503810569956979}, 
      {8.348956471394946, 0.03496924804110033}, {8.376570389285146, 
       0.04663019070400511}, {8.406993077612933, 0.04450430238228207}, 
      {8.43825650246541, 0.02503019243585215}, {8.467715336856493, 
       0.003927938737453111}, {8.501669700808746, 0.009374817748500517}, 
      {8.532463261191104, 0.07556964741266362}, {8.566579568761437, 
       0.23845855250155537}, {8.585802644176605, 0.36756392170984215}, 
      {8.603492994341185, 0.5010911508854469}, {8.637601430935023, 
       0.7588347850087657}, {8.669452262464326, 0.9377366610129698}, 
      {8.697361757652956, 0.9995893164241574}, {8.727288046783004, 
       0.9486492609038406}, {8.760499006687798, 0.7690898780476131}, 
      {8.790787064907034, 0.5424157623558538}, {8.822316479982856, 
       0.30761118291050477}, {8.85662188211408, 0.11555129811550363}, 
      {8.889020904973487, 0.021236989418862352}, {8.91900352752083, 
       0.00006161017281635967}, {8.953186513637537, 0.01853965105565979}, 
      {8.985285536638044, 0.0412581279100412}, {9.003652932781074, 
       0.047426837383072545}, {9.020497609082197, 0.04714002908409065}, 
      {9.038990718419697, 0.04103075819597752}, {9.058465450045151, 
       0.030335712431759494}, {9.092676070529999, 0.010415409558231116}, 
      {9.111827144283017, 0.003082280939937092}, {9.1292325457327, 
       0.00017225686267924916}, {9.149860248167904, 
       0.001144100347671657}, {9.169338729887057, 0.005175925649060796}, 
      {9.187109194652479, 0.009896206946157308}, {9.206661396909364, 
       0.014481364420177561}, {9.238573103059302, 0.017281406136251547}, 
      {9.272366636848737, 0.012948367378670696}, {9.303669091730121, 
       0.005843842974434853}, {9.332962024857178, 0.000972874863076826}, 
      {9.367452742766028, 0.0005495399823485687}, 
      {9.398975094049801, 0.00416596393577446}, {9.416380949284504, 
       0.0065232287149079825}, {9.435359721168664, 0.008462264234277688}, 
      {9.469909415902917, 0.008822132282642904}, {9.487039492058829, 
       0.007462427193985735}, {9.505117306802342, 0.005353925260275048}, 
      {9.537475273656378, 0.0015636331465692902}, 
      {9.572300039510917, 9.576971734402494*^-6}, 
      {9.592058273687481, 0.0006932824936979197}, 
      {9.610484443349266, 0.002058570956720368}, {9.643305797989095, 
       0.0048063152107539996}, {9.674364687750906, 0.005947671524203799}, 
      {9.691521685239199, 0.005597441244695772}, {9.710164674322888, 
       0.004529656653242385}, {9.742770882352932, 0.0019197347385799563}, 
      {9.772405420242816, 0.00023194489734955115}, 
      {9.805080876672323, 0.00031559947296656057}, 
      {9.839204704465791, 0.0021620003314695687}, 
      {9.871206005740863, 0.003911743309246516}, {9.901037533137874, 
       0.004274475112542547}, {9.928359888711011, 0.0033149363506847994}, 
      {9.958357391807219, 0.001550422031509047}, {9.98990561736951, 
       0.00017601799560489558}, {10.024684110659399, 
       0.00030132579427351514}, {10.056250798367204, 
       0.0016620795747142208}, {10.073745072783625, 
       0.0025133358970800624}, {10.092689083281615, 
       0.003196348445912588}, {10.127052026142088, 0.003269944806002295}, 
      {10.159298828551178, 0.002059553500072507}, {10.193402288395554, 
       0.0005275248904636644}, {10.222518570604821, 
       4.4200530181949515*^-8}, {10.25451195518404, 
       0.000620940232098603}, {10.273857114508285, 
       0.0013968357166918078}, {10.292202500897519, 
       0.002152528642102851}, {10.326603913817781, 0.002924831731893487}, 
      {10.345831388653483, 0.0027723439896892295}, 
      {10.363639324816459, 0.002281488676845488}, {10.383183384493043, 
       0.0015119714925985054}, {10.403968330309029, 
       0.0006869654916683313}, {10.438176062842517, 
       1.436753915271805*^-6}, {10.470324477133413, 
       0.0004978757910049285}, {10.488712468841156, 
       0.001141713561283987}, {10.505589775429463, 
       0.0017799345235009888}, {10.524118189590359, 
       0.002349995469785508}, {10.543645981664174, 0.002635578002075728}, 
      {10.576098208821175, 0.0022252843465609766}, 
      {10.59441170351022, 0.0016180129685768748}, {10.611314730051545, 
       0.0009834188369322676}, {10.642361326966055, 
       0.00011710542841154425}, {10.675265500696723, 
       0.00016900719351965298}, {10.704687603053637, 
       0.001016496176300871}, {10.732243316270702, 0.001972184561249888}, 
      {10.762474113479648, 0.002510000441506623}, {10.794985063917546, 
       0.002093637459131546}, {10.829404396736498, 
       0.0009284471339127526}, {10.847586707202549, 
       0.0003654973820845556}, {10.866964688927219, 
       0.000031433076792909456}, {10.885573673408015, 
       0.000060683349694177324}, {10.902441853250144, 
       0.0003794172478826009}, {10.93536990307409, 
       0.0014773854085949473}, {10.967140135658969, 
       0.002373672530328767}, {11.001497841193885, 0.002354330695014447}, 
      {11.033938437922194, 0.0014100445139549821}, 
      {11.063777404763165, 0.0004067845260728778}, 
      {11.091822140114827, 9.276026644168844*^-8}, 
      {11.121878316837961, 0.0004449370311355828}, 
      {11.150247193652707, 0.0014371673488614593}, 
      {11.176106296041821, 0.002297935751890333}, {11.206433712549261, 
       0.002632768748681325}, {11.239414680467473, 
       0.0019369274363047228}, {11.27056224906056, 
       0.0007805725899105279}, {11.299372251368776, 
       0.00006115438164965622}, {11.328964134760868, 
       0.00020976243814139234}, {11.356737977473573, 
       0.001115719657168077}, {11.389766606243263, 0.002412730686653908}, 
      {11.420041803147141, 0.0029301831482885297}, 
      {11.4500941951842, 0.002406021573833796}, {11.481725871821268, 
       0.0011382269903660628}, {11.513479113584928, 
       0.00012136227257391401}, {11.548204000572413, 
       0.0002847792269351216}, {11.581347076083482, 
       0.001629601823735815}, {11.611897256440542, 
       0.0029764727837670773}, {11.64543126358665, 0.003403648966422271}, 
      {11.662335334809141, 0.0030354130881526066}, 
      {11.68092491061735, 0.002273678435248517}, {11.712132407883992, 
       0.0007599875942528744}, {11.74564954561181, 
       6.843379420092588*^-7}, {11.777287785471756, 
       0.0008125659705642618}, {11.806188594954431, 
       0.002459060395648951}, {11.836046566301468, 
       0.0039703260649176396}, {11.863722689665416, 
       0.004283754057751816}, {11.894096162693474, 
       0.0031568995281806623}, {11.926424399430868, 
       0.0011615973241199582}, {11.957288922576588, 
       0.00002512578503137285}, {11.986319006031204, 
       0.0006028442870378553}, {12.012386131449068, 
       0.002368477991788774}, {12.04053913258464, 0.004615914660614431}, 
      {12.073476374243917, 0.0059446646381418975}, 
      {12.104177596292063, 0.004940988458404995}, {12.137864648769094, 
       0.0021562109354929136}, {12.156607185648852, 
       0.0007422633189347035}, {12.173920303707751, 
       0.000049966731490731115}, {12.192063876051483, 
       0.0002335868447694149}, {12.211768967332572, 0.00154107905150675}, 
      {12.229140891363114, 0.003436320275190019}, 
      {12.24756719903642, 0.005754352689649511}, {12.279461149100433, 
       0.00881586193249288}, {12.297604185879127, 0.009196064158875677}, 
      {12.314610156248587, 0.008426073968084681}, {12.344314559790798, 
       0.005030948306368178}, {12.376756075653146, 
       0.0009712125517361677}, {12.407399339905611, 
       0.0002686826999103304}, {12.435863982229257, 
       0.003813892435625481}, {12.468832625158054, 0.011135870550514822}, 
      {12.486935066518605, 0.014818381008673626}, {12.503997899895028, 
       0.016941615649914227}, {12.53670129179906, 0.015549320497110067}, 
      {12.56636956716162, 0.008830503877159473}}]}}}, 
 {PlotRange -> All, AspectRatio -> GoldenRatio^(-1), 
  DisplayFunction :> $DisplayFunction, ColorOutput -> Automatic, 
  Axes -> Automatic, AxesOrigin -> Automatic, PlotLabel -> None, 
  AxesLabel -> None, Ticks -> Automatic, GridLines -> None, Prolog -> {}, 
  Epilog -> {}, AxesStyle -> Automatic, Background -> Automatic, 
  DefaultColor -> Automatic, DefaultFont :> $DefaultFont, 
  RotateLabel -> True, Frame -> False, FrameStyle -> Automatic, 
  FrameTicks -> Automatic, FrameLabel -> None, PlotRegion -> Automatic, 
  ImageSize -> Automatic, TextStyle :> $TextStyle, 
  FormatType :> $FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output",
  CellLabel->"Out[83]="],

Cell["\<\
et en fonction de \[Theta] direction d'observation:\
\>", "Text"],

Cell[BoxData[{
    \(\(\[CurlyPhi][\[Theta]_] = 
        2\ Pi\ a\ \ Sin[Pi/180\ \[Theta]]/lambda0;\)\), "\n", 
    \(Plot[
      Evaluate[{R[\[CurlyPhi][\[Theta]]], R[0.65/0.5\ \[CurlyPhi][\[Theta]]], 
          R[0.65/0.45  \[CurlyPhi][\[Theta]]]}], {\ \[Theta], \(-\ 40\), \ 
        40}, PlotRange \[Rule] All, 
      PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], 
          RGBColor[0, 0, 1]}]\n\)}], "Input",
  CellLabel->"In[87]:="]
}, Open  ]],

Cell["\<\
Tra\[CCedilla]ons l'intensit\[EAcute] r\[EAcute]sultante en fonction de \
\[CurlyPhi] en tenant compte de la fonction de diffraction:\
\>", "Text",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(TraditionalForm\`IR(\[CurlyPhi]_) := 
      NT\^2\ \(R(\[CurlyPhi])\)\ \[LeftBracketingBar]FD(e, \[CurlyPhi]\/\(2\ \
\[Pi]\ a\))\[RightBracketingBar]\^2\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(TraditionalForm\`Plot[{IR(\[CurlyPhi]), 
        NT\^2\ \[LeftBracketingBar]FD(e, \[CurlyPhi]\/\(2\ \[Pi]\ a\))\
\[RightBracketingBar]\^2}, {\[CurlyPhi], \(-9\)\ \[Pi], 9\ \[Pi]}, 
      PlotRange \[Rule] All, 
      PlotStyle \[Rule] {RGBColor[0, 1, 0.5], RGBColor[0, 0, 1]}]\)], "Input",\

  CellLabel->"In[92]:="]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 527}},
CellGrouping->Manual,
WindowSize->{697, 517},
WindowMargins->{{3, Automatic}, {Automatic, -2}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "TutorialBook.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 49, 0, 61, "Title"],
Cell[1769, 51, 113, 2, 32, "Input"],
Cell[1885, 55, 49, 0, 92, "Section"],
Cell[1937, 57, 132, 4, 60, "Subsection"],
Cell[2072, 63, 1050, 24, 117, "Text"],
Cell[3125, 89, 279, 5, 102, "Input"],
Cell[3407, 96, 197, 6, 44, "Text"],
Cell[3607, 104, 88, 2, 32, "Input"],
Cell[3698, 108, 170, 3, 60, "Subsection"],
Cell[3871, 113, 335, 7, 80, "Input"],
Cell[4209, 122, 144, 3, 40, "Subsection"],
Cell[4356, 127, 104, 2, 32, "Input"],
Cell[4463, 131, 144, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[4632, 138, 141, 3, 32, "Input"],
Cell[4776, 143, 220, 5, 28, "Output"]
}, Open  ]],
Cell[5011, 151, 193, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[5229, 159, 128, 3, 32, "Input"],
Cell[5360, 164, 125, 5, 28, "Output"]
}, Open  ]],
Cell[5500, 172, 109, 1, 44, "Text"],

Cell[CellGroupData[{
Cell[5634, 177, 504, 13, 32, "Input"],
Cell[6141, 192, 259, 8, 51, "Output"]
}, Open  ]],
Cell[6415, 203, 87, 1, 44, "Text"],

Cell[CellGroupData[{
Cell[6527, 208, 131, 3, 32, "Input"],
Cell[6661, 213, 171, 5, 28, "Output"]
}, Open  ]],
Cell[6847, 221, 121, 2, 44, "Text"],

Cell[CellGroupData[{
Cell[6993, 227, 131, 3, 32, "Input"],
Cell[7127, 232, 246, 6, 28, "Output"]
}, Open  ]],
Cell[7388, 241, 324, 8, 42, "Text"],
Cell[7715, 251, 62, 0, 92, "Section"],
Cell[7780, 253, 365, 10, 70, "Text"],
Cell[8148, 265, 114, 2, 31, "Input"],
Cell[8265, 269, 60, 1, 44, "Text"],

Cell[CellGroupData[{
Cell[8350, 274, 238, 4, 56, "Input"],
Cell[8591, 280, 246, 4, 56, "Input"]
}, Open  ]],
Cell[8852, 287, 60, 1, 44, "Text"],

Cell[CellGroupData[{
Cell[8937, 292, 239, 4, 56, "Input"],
Cell[9179, 298, 246, 4, 56, "Input"]
}, Open  ]],
Cell[9440, 305, 61, 0, 92, "Section"],
Cell[9504, 307, 108, 1, 44, "Text"],
Cell[9615, 310, 150, 3, 32, "Input"],
Cell[9768, 315, 156, 3, 32, "Input"],
Cell[9927, 320, 146, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[10098, 328, 293, 5, 90, "Input"],
Cell[10394, 335, 42139, 620, 28, "Output"]
}, Open  ]],
Cell[52548, 958, 158, 4, 44, "Text"],
Cell[52709, 964, 192, 4, 58, "Input"],
Cell[52904, 970, 155, 4, 60, "Input"],

Cell[CellGroupData[{
Cell[53084, 978, 257, 5, 95, "Input"],
Cell[53344, 985, 61274, 1104, 28, "Output"]
}, Open  ]],
Cell[114633, 2092, 104, 1, 44, "Text"],

Cell[CellGroupData[{
Cell[114762, 2097, 281, 5, 95, "Input"],
Cell[115046, 2104, 560135, 8528, 28, "Output"]
}, Open  ]],
Cell[675196, 10635, 288, 5, 95, "Input"],
Cell[675487, 10642, 33, 0, 92, "Section"],
Cell[675523, 10644, 157, 4, 44, "Text"],
Cell[675683, 10650, 150, 3, 56, "Input"],
Cell[675836, 10655, 245, 6, 47, "Text"],

Cell[CellGroupData[{
Cell[676106, 10665, 167, 4, 65, "Input"],
Cell[676276, 10671, 253, 6, 28, "Output"]
}, Open  ]],
Cell[676544, 10680, 277, 5, 64, "Text"],
Cell[676824, 10687, 475, 8, 115, "Input"],
Cell[677302, 10697, 85, 1, 44, "Text"],

Cell[CellGroupData[{
Cell[677412, 10702, 336, 6, 90, "Input"],
Cell[677751, 10710, 141649, 2377, 28, "Output"],
Cell[819403, 13089, 201, 4, 44, "Text"],
Cell[819607, 13095, 139717, 2346, 28, "Output"],
Cell[959327, 15443, 75, 2, 28, "Text"],
Cell[959405, 15447, 450, 9, 169, "Input"]
}, Open  ]],
Cell[959870, 15459, 192, 4, 44, "Text"],
Cell[960065, 15465, 210, 4, 55, "Input"],
Cell[960278, 15471, 336, 7, 90, "Input"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

